(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    892289,      24540]
NotebookOptionsPosition[    811634,      23238]
NotebookOutlinePosition[    833626,      23683]
CellTagsIndexPosition[    832868,      23656]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Induction and Recursion", "BookChapterTitle",
 CounterAssignments->{{
   "ChapterNumber", 
    5}},ExpressionUUID->"47c967f1-5845-4d56-9049-0a22dac73236"],

Cell[CellGroupData[{

Cell["Introduction", "Section",ExpressionUUID->"47cc0bc9-9590-4b22-ba32-b0ab1a3e37fb"],

Cell[TextData[{
 "In this chapter, we describe how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to help you make conjectures and prove them with mathematical \
induction and strong induction. We will also look at several examples of \
using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to explore recursive definitions and to implement recursive algorithms. \
Recursion is an important tool in any computer programming language, and the \
Wolfram Language is no exception. We conclude with an example of proving \
program correctness. "
}], "Text",ExpressionUUID->"0b4f3de8-6f51-45bd-a254-ad022bf3fe04"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.1 Mathematical Induction", "Section",
 CellTags->"Section1",ExpressionUUID->"daddaeef-b204-47dd-adda-fc8af60412ef"],

Cell[TextData[{
 "In this section, we will demonstrate how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " both to discover propositions and to aid in the use of mathematical \
induction to verify them. We begin with two examples of how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to discover and prove summation formulas. We then consider a question of \
divisibility. "
}], "Text",ExpressionUUID->"db70ca0a-9e5a-4a85-b0fb-ea42a68b6b01"],

Cell[CellGroupData[{

Cell["Summation Example 1", "Subsection",
 CellTags->"Section1a",ExpressionUUID->"23439bcd-c311-42a7-bde2-436ac6d76ec8"],

Cell["\<\
As our first example, we will explore a formula that you have already seen: \
\>", "Text",ExpressionUUID->"0eef5a25-f624-4a49-a6c3-943c0ea29dc8"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], "n",
     LimitsPositioning->False], "i"}], "=", 
   RowBox[{
    RowBox[{"1", "+", "2", "+", "3", "+", "\[CenterEllipsis]", "+", "n"}], 
    "=", 
    FractionBox[
     RowBox[{"n", "(", 
      RowBox[{"n", "+", "1"}], ")"}], "2"]}]}], TraditionalForm]], "Equation",\
ExpressionUUID->"c5f23668-0266-4bd3-8164-40852d0cd78e"],

Cell["\<\
This formula is the subject of Example 1 in Section 5.1 of the text. Here, we \
will proceed as if we did not already know the formula. \
\>", "Text",ExpressionUUID->"42d38fac-6a8a-432e-88a3-744e3b8c79cf"],

Cell[CellGroupData[{

Cell["Listing and Graphing to Find the Formula", "Subsubsection",ExpressionUUID->"87ec4074-c168-4935-bf08-fee7e8d38899"],

Cell[TextData[{
 "Our first step is to discover the formula. To do this, we will have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " compute the sums for a variety of values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "0b93482d-ef92-4aef-bf3c-f5e9672498a0"],
 ", using the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function. "
}], "Text",ExpressionUUID->"db9f157c-3001-41dd-93ec-6f32fd678e80"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function has essentially the same syntax as ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ". The first argument is an expression representing the values to be added \
in terms of a variable. The second argument is a list indicating the values \
of the variable over which the sum should be computed. Refer to Section 2.4 \
for a description of the behavior of the second argument. A table summarizing \
the main possibilities is shown below."
}], "Text",ExpressionUUID->"d44b29db-47d6-4a0c-9c9f-03cc5aa675b3"],

Cell[TextData[Cell[BoxData[GridBox[{
   {Cell[BoxData[
     RowBox[{"{", 
      StyleBox["i", "CodeVar"], ",", 
      StyleBox[
       SubscriptBox["i", "max"], "CodeVar"], "}"}]], "myCode",ExpressionUUID->
     "b7fcfacb-01a0-4506-b0ff-59dc0db4aea6"], Cell[TextData[{
     "sum from ",
     Cell[BoxData[
      FormBox[
       RowBox[{
        StyleBox["i", "CodeVar"], "=", "1"}], TraditionalForm]],
      ExpressionUUID->"246080bc-c385-4cc1-990b-7e7fa003cb33"],
     " to ",
     Cell[BoxData[
      FormBox[
       StyleBox[
        SubscriptBox["i", "max"], "CodeVar"], TraditionalForm]],
      ExpressionUUID->"9ffd6115-3f4e-4cc1-b955-7ecfdf03691b"]
    }],ExpressionUUID->"174714ff-7dd4-4326-b9a2-db129f3bc05c"]},
   {Cell[BoxData[
     RowBox[{"{", 
      StyleBox["i", "CodeVar"], ",", 
      StyleBox[
       SubscriptBox["i", "min"], "CodeVar"], ",", 
      StyleBox[
       SubscriptBox["i", "max"], "CodeVar"], "}"}]], "myCode",ExpressionUUID->
     "c1ec686c-51ba-4529-8eae-12ebbb3d0603"], 
    RowBox[{"sum", " ", "from", " ", Cell[TextData[{
      Cell[BoxData[
       FormBox[
        RowBox[{
         StyleBox["i", "CodeVar"], "=", 
         StyleBox[
          SubscriptBox["i", "min"], "CodeVar"]}], TraditionalForm]],
       ExpressionUUID->"bc0bbe74-7d07-4f84-bfd6-18253f390714"],
      " to ",
      Cell[BoxData[
       FormBox[
        StyleBox[
         SubscriptBox["i", "max"], "CodeVar"], TraditionalForm]],
       ExpressionUUID->"7ef0eae1-9d41-41b2-a941-45642ced3ad3"]
     }],ExpressionUUID->"60e12d98-bf8f-4cff-a973-8043b7e61f75"]}]},
   {Cell[BoxData[
     RowBox[{"{", 
      StyleBox["i", "CodeVar"], ",", 
      StyleBox[
       SubscriptBox["i", "min"], "CodeVar"], ",", 
      StyleBox[
       SubscriptBox["i", "max"], "CodeVar"], ",", 
      StyleBox["step", "CodeVar"], "}"}]], "myCode",ExpressionUUID->
     "971f2d18-bdf2-4baa-981e-d13f905136c0"], 
    RowBox[{"sum", " ", "from", " ", Cell[TextData[{
      Cell[BoxData[
       FormBox[
        RowBox[{
         StyleBox["i", "CodeVar"], "=", 
         StyleBox[
          SubscriptBox["i", "min"], "CodeVar"]}], TraditionalForm]],
       ExpressionUUID->"b4116590-a795-407a-a411-2be62d722396"],
      " to ",
      Cell[BoxData[
       FormBox[
        StyleBox[
         SubscriptBox["i", "max"], "CodeVar"], TraditionalForm]],
       ExpressionUUID->"a926d9cb-9d27-49fd-9f68-7c6b36212f9d"],
      " by ",
      Cell[BoxData[
       FormBox[
        StyleBox["step", "CodeVar"], TraditionalForm]],ExpressionUUID->
       "477ff7ba-30eb-4f5c-b927-ec3808c5fdf5"]
     }],ExpressionUUID->"927b66fc-d746-49af-b00c-01c12099bb60"]}]},
   {Cell[BoxData[
     RowBox[{"{", 
      StyleBox["i", "CodeVar"], ",", 
      StyleBox["list", "CodeVar"], "}"}]], "myCode",ExpressionUUID->
     "6e522798-b10a-44e7-af59-c2a83a1b5654"], 
    RowBox[{"sum", " ", "over", " ", "members", " ", "of", " ", 
     StyleBox["list", "CodeVar"], Cell[TextData[StyleBox[
     "", "Input"]],ExpressionUUID->"4409af30-4ad8-4a8c-b8e7-63660d1f7ae7"]}]}
  },
  GridBoxDividers->{
   "Columns" -> {{True}}, "ColumnsIndexed" -> {}, "Rows" -> {{True}}, 
    "RowsIndexed" -> {}}]],
 FontFamily->
  "Times",ExpressionUUID->"d0508ce0-da72-4339-b107-895852ed7d3d"]], "Text",
 TextAlignment->Center,ExpressionUUID->"9380b944-ed33-4994-9fb4-b5266949c9fc"],

Cell["\<\
In our situation, we want to add the first several positive integers. For \
example, the sum of the first 10 positive integers is \
\>", "Text",ExpressionUUID->"d8f8056c-df34-4083-ac72-3241426b5810"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{"i", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"36f0e232-f861-40d3-8380-d9c88ddfe472"],

Cell[BoxData["55"], "Output",
 CellLabel->"Out[1]=",ExpressionUUID->"ccb0b7b4-b1cf-4fb2-b015-d30e4f3776a5"]
}, Open  ]],

Cell[TextData[{
 "To discover the formula for the sum of the first ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "b910a67e-cabb-472a-9ffe-3849f03d4980"],
 " positive integers, we need several specific examples to analyze. To \
calculate a lot of examples at once, we will embed the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function inside a ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 ", with the maximum value of the summation as the table variable. This will \
produce the list of the sums of the first ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "d86ae16b-3bc4-4588-81ac-393443e6bbc6"],
 " positive integers for different values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "bc8cee70-ace6-45b0-b635-f455b0a9252b"],
 "."
}], "Text",ExpressionUUID->"0ac48196-e4a6-430e-8f58-1d4e84b64806"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "n"}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "50"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"ced40932-4f97-4c44-9b5e-f20b5cfcbea9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "6", ",", "10", ",", "15", ",", "21", ",", "28", ",", 
   "36", ",", "45", ",", "55", ",", "66", ",", "78", ",", "91", ",", "105", 
   ",", "120", ",", "136", ",", "153", ",", "171", ",", "190", ",", "210", 
   ",", "231", ",", "253", ",", "276", ",", "300", ",", "325", ",", "351", 
   ",", "378", ",", "406", ",", "435", ",", "465", ",", "496", ",", "528", 
   ",", "561", ",", "595", ",", "630", ",", "666", ",", "703", ",", "741", 
   ",", "780", ",", "820", ",", "861", ",", "903", ",", "946", ",", "990", 
   ",", "1035", ",", "1081", ",", "1128", ",", "1176", ",", "1225", ",", 
   "1275"}], "}"}]], "Output",
 CellLabel->"Out[2]=",ExpressionUUID->"29528880-8bc5-4d4d-9f51-7a956bcc4772"]
}, Open  ]],

Cell[TextData[{
 "Remember that we are working as if we do not already know the answer. Just \
looking at the data, you might notice a pattern, but if not, it is sometimes \
helpful to pair the value of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "48d92d42-00cc-4dd8-af98-5f03c2246f73"],
 " with the result. To do this, we only need to modify the expression so that \
the first argument of the ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " function is the list consisting of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "1e09035a-86af-408d-b07a-270c87a2216e"],
 " and the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function. "
}], "Text",ExpressionUUID->"84a2f348-5049-40bb-a42b-deccef75188b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"n", ",", 
     RowBox[{"Sum", "[", 
      RowBox[{"i", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "50"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"c7a04e72-27e4-463f-a409-7b8448802ceb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "21"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "28"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "45"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10", ",", "55"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "66"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "78"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"13", ",", "91"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"14", ",", "105"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "120"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", "136"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17", ",", "153"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "171"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"19", ",", "190"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", "210"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"21", ",", "231"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22", ",", "253"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23", ",", "276"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"24", ",", "300"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"25", ",", "325"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"26", ",", "351"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27", ",", "378"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28", ",", "406"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"29", ",", "435"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "465"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"31", ",", "496"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", "528"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"33", ",", "561"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"34", ",", "595"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"35", ",", "630"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"36", ",", "666"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"37", ",", "703"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"38", ",", "741"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"39", ",", "780"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"40", ",", "820"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"41", ",", "861"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"42", ",", "903"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"43", ",", "946"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"44", ",", "990"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"45", ",", "1035"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"46", ",", "1081"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"47", ",", "1128"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"48", ",", "1176"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"49", ",", "1225"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"50", ",", "1275"}], "}"}]}], "}"}]], "Output",
 CellLabel->"Out[3]=",ExpressionUUID->"d03a98a5-37f4-4f8a-9ff4-bf659ee20c74"]
}, Open  ]],

Cell[TextData[{
 "The entry ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"23", ",", "276"}], "}"}], TraditionalForm]],ExpressionUUID->
  "771df267-6f21-4bf3-96ba-975882d5c8f1"],
 " indicates that the sum of the first ",
 Cell[BoxData[
  FormBox["23", TraditionalForm]],ExpressionUUID->
  "38111d36-757c-4973-813b-1b98efd78748"],
 " positive integers is ",
 Cell[BoxData[
  FormBox["276", TraditionalForm]],ExpressionUUID->
  "96549892-180f-438f-adc7-201fa264f806"],
 "."
}], "Text",ExpressionUUID->"1d6b9f61-36af-46ec-a370-86e787495344"],

Cell[TextData[{
 "This still may not be enough to get an idea of what the formula could be, \
in which case a graph of the data can be useful. The ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " function is used to graph functions and data, and was first discussed in \
Section 2.3 of this manual. In this situation, we want to plot the points \
that the previous application of ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " produced: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "6"}], "}"}], ",", "\[Ellipsis]"}], TraditionalForm]],
  ExpressionUUID->"f59546bf-06b6-4ace-95c3-e746df613fed"],
 ". To do this, apply ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " to the output above. Note that either of the previous two lists can be \
used. Given a list of pairs, ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " produces the graph interpreting the pairs as ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "99ea6ce3-28a1-4021-955e-c65783d85cdc"],
 "\[Dash]",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "239c1330-3893-40d8-8d8e-a6368133803a"],
 " coordinates. Given a list of values, the values are interpreted as the ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "9b0a8b93-3f1f-4125-9026-9e50e73165ed"],
 " coordinates with the ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "d187c7bf-3743-46ab-9006-ea764db7593e"],
 " coordinate being the position of the value in the list. That is, the first \
element is plotted at ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "a2651264-cbea-44d3-932a-c5fd27335a37"],
 "-value 1, the second element at ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "6680b927-e5f8-468b-91b4-8a7681dcf1d4"],
 "-value 2, etc. In this case, the plots are identical, so we will use the \
shorter of the two expressions. Since ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " computes the sums quickly, we go out to a maximum of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1000"}], TraditionalForm]],ExpressionUUID->
  "e2eb64a6-3f0d-42e7-b7aa-db617662b10a"],
 ". That way, we will be sure to have a good idea of the shape of the graph. \
"
}], "Text",ExpressionUUID->"584abdec-71ae-4a4e-858c-5421a45887f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{"i", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1000"}], "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"3e40bb71-13ce-4d6b-a131-2afcf17517b2"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxd233YFGXZx/GRUFelGhGfliQcE3Uz1BFRV0MdFXVLkKmQNkIdFWwT0FFJ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      "]]}, {}}, {}, {}, {}, {}},
  
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0., 1000.}, {0, 500500.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellLabel->"Out[4]=",ExpressionUUID->"fb3f435f-33ca-477a-8a8f-c642d5d96e3a"]
}, Open  ]],

Cell["\<\
The particular values in the list may not have been helpful at all in \
figuring out what kind of formula we were looking for, but this graph \
probably looks very familiar. It looks very much like the right half of a \
parabola, suggesting that the formula is quadratic. (Of course, it may be \
cubic, quartic, or some other polynomial, but we will start with the simplest \
possibility based on the graph.) \
\>", "Text",ExpressionUUID->"d7a989c3-eda0-4423-9bc0-70c631912926"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Finding the Coefficients", "Subsubsection",ExpressionUUID->"656e596d-897d-4205-9ec6-c9c220c29025"],

Cell[TextData[{
 "Now that we have guessed the kind of formula, we can write it as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "n", ")"}], "=", 
    RowBox[{
     RowBox[{"a", "\[CenterDot]", 
      SuperscriptBox["n", "2"]}], "+", 
     RowBox[{"b", "\[CenterDot]", "n"}], "+", "c"}]}], TraditionalForm]],
  ExpressionUUID->"f5f3501a-76c7-440d-8cc8-7d409e3d970f"],
 ". Determining the coefficients ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "e526cb45-4d72-4505-99c6-79deeb3012c8"],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "f441c7ab-6218-46fd-82e9-a7307894f9cd"],
 ", ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],ExpressionUUID->
  "4a54f0c6-d67f-4047-acf0-76a183d42423"],
 " is our next task. We will have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " find them for us."
}], "Text",ExpressionUUID->"938ed338-09b0-4ec1-8a97-56bbbeb0f0d0"],

Cell["\<\
We already know a bunch of values for this function. Here are the first few \
again. \
\>", "Text",ExpressionUUID->"b4babc3e-7197-4c2e-8440-ec738469cd79"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumList", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{"i", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[5]:=",ExpressionUUID->"94c74825-3591-4fba-85c1-a10945e33b09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "3", ",", "6", ",", "10", ",", "15", ",", "21", ",", "28", ",", 
   "36", ",", "45", ",", "55"}], "}"}]], "Output",
 CellLabel->"Out[5]=",ExpressionUUID->"2447c7bc-046a-4be7-9230-26ef647348e9"]
}, Open  ]],

Cell[TextData[{
 "This data tells us a lot of information about our formula. For instance, if \
we plug in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "2"}], TraditionalForm]],ExpressionUUID->
  "6a79f789-a0eb-4452-a35b-b57d865be616"],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "2", ")"}], "=", "3"}], TraditionalForm]],
  ExpressionUUID->"43c62754-c646-4b6f-b77c-1f0ef9ff3278"],
 ", meaning"
}], "Text",ExpressionUUID->"4ee9c175-4037-4939-bea6-3755f307733e"],

Cell[BoxData[
 FormBox[
  RowBox[{"3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "\[CenterDot]", 
      SuperscriptBox["2", "2"]}], "+", 
     RowBox[{"b", "\[CenterDot]", "2"}], "+", "c"}], "=", 
    RowBox[{
     RowBox[{"4", "a"}], "+", 
     RowBox[{"2", "b"}], "+", "c"}]}]}], TraditionalForm]], "Equation",Express\
ionUUID->"bd63fa19-1d6f-4a4e-abce-c2b99c66bbe2"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "12eab2e8-9b36-444d-8ed4-f07a0b92a8d1"],
 ", we have"
}], "Text",ExpressionUUID->"4c4465f4-5dd3-4913-b6b5-380600fcefa7"],

Cell[BoxData[
 FormBox[
  RowBox[{"1", "=", 
   RowBox[{"a", "+", "b", "+", "c"}]}], TraditionalForm]], "Equation",Expressi\
onUUID->"0ba2ae3d-7d92-41c6-836d-22c535399637"],

Cell[TextData[{
 "For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "3"}], TraditionalForm]],ExpressionUUID->
  "38085c90-1674-4b34-8f54-004599835bff"],
 ":"
}], "Text",ExpressionUUID->"77701318-002e-43e5-bfab-509aebf0d381"],

Cell[BoxData[
 FormBox[
  RowBox[{"6", "=", 
   RowBox[{
    RowBox[{"9", "a"}], "+", 
    RowBox[{"3", "b"}], "+", "c"}]}], TraditionalForm]], "Equation",Expression\
UUID->"5ad86855-08b1-4e23-84d2-3965a9651151"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can generate these equations for us. We can apply ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " with first argument an equation, formed with the ",
 StyleBox[ButtonBox["Equal",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Equal"], "FunctionLink"],
 " (",
 StyleBox["==", "Code"],
 ") operator, representing the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "n", ")"}], "=", 
    RowBox[{
     RowBox[{"a", "\[CenterDot]", 
      SuperscriptBox["n", "2"]}], "+", 
     RowBox[{"b", "\[CenterDot]", "n"}], "+", "c"}]}], TraditionalForm]],
  ExpressionUUID->"26c77452-1c60-4923-967b-31b5254c8551"],
 ". Instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "a4ac16a4-b495-4373-a365-e76e7aa8bfac"],
 ", we use the data in ",
 StyleBox["sumList", "Code"],
 ". Therefore, our expression will be ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"sumList", "[", 
    RowBox[{"[", "n", "]"}], "]"}], "\[Equal]", "a", "*", "n", "^", "2", "+", 
   "b", "*", "n", "+", "c"}]], "myCode",ExpressionUUID->
  "029b19d1-ba61-4964-aef4-c850bda84a9b"],
 "."
}], "Text",ExpressionUUID->"aebb1f43-7fb2-4583-8526-b653f0b22da0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumEquations", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sumList", "[", 
      RowBox[{"[", "n", "]"}], "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"a", "*", 
       RowBox[{"n", "^", "2"}]}], "+", 
      RowBox[{"b", "*", "n"}], "+", "c"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[6]:=",ExpressionUUID->"24a23fb1-4507-4499-b732-7e6a1353237d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "\[Equal]", 
    RowBox[{"a", "+", "b", "+", "c"}]}], ",", 
   RowBox[{"3", "\[Equal]", 
    RowBox[{
     RowBox[{"4", " ", "a"}], "+", 
     RowBox[{"2", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"6", "\[Equal]", 
    RowBox[{
     RowBox[{"9", " ", "a"}], "+", 
     RowBox[{"3", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"10", "\[Equal]", 
    RowBox[{
     RowBox[{"16", " ", "a"}], "+", 
     RowBox[{"4", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"15", "\[Equal]", 
    RowBox[{
     RowBox[{"25", " ", "a"}], "+", 
     RowBox[{"5", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"21", "\[Equal]", 
    RowBox[{
     RowBox[{"36", " ", "a"}], "+", 
     RowBox[{"6", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"28", "\[Equal]", 
    RowBox[{
     RowBox[{"49", " ", "a"}], "+", 
     RowBox[{"7", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"36", "\[Equal]", 
    RowBox[{
     RowBox[{"64", " ", "a"}], "+", 
     RowBox[{"8", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"45", "\[Equal]", 
    RowBox[{
     RowBox[{"81", " ", "a"}], "+", 
     RowBox[{"9", " ", "b"}], "+", "c"}]}], ",", 
   RowBox[{"55", "\[Equal]", 
    RowBox[{
     RowBox[{"100", " ", "a"}], "+", 
     RowBox[{"10", " ", "b"}], "+", "c"}]}]}], "}"}]], "Output",
 CellLabel->"Out[6]=",ExpressionUUID->"b055254c-6ac9-48f4-b155-702c88052fca"]
}, Open  ]],

Cell[TextData[{
 "The list of equations stored as ",
 StyleBox["sumEquations", "Code"],
 " is a system of equations. In particular, we have ten equations in three \
variables. You have probably seen systems of at least two and three equations \
in two or three variables in previous mathematics courses. You can have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " solve the system of equations by applying the ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 " function to the list. We provide ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 " with the list of equations and the list of variables appearing in them. \
(The second argument can sometimes be omitted and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will deduce the variables.)"
}], "Text",ExpressionUUID->"d46d1613-3fd9-4449-9107-c6828aa8511c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{"sumEquations", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"99bd79b9-189e-49ec-bd20-ae38a6061cb2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "\[Rule]", 
     FractionBox["1", "2"]}], ",", 
    RowBox[{"b", "\[Rule]", 
     FractionBox["1", "2"]}], ",", 
    RowBox[{"c", "\[Rule]", "0"}]}], "}"}], "}"}]], "Output",
 CellLabel->"Out[7]=",ExpressionUUID->"b6c0ba7a-dc31-4f0f-ae62-085485019a8a"]
}, Open  ]],

Cell[TextData[{
 "You may recall that to solve a system of equations in three unknowns, only \
three equations are required. In this situation, having more equations is \
useful. If we were wrong about the formula being quadratic but attempted to \
find coefficients with only three equations, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " may still have found values for ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "e3d0fe8a-24ae-467f-bf90-6ae8582fc7fd"],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "2391e497-ad1d-4bba-8ab6-c45586f5f220"],
 ", and ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],ExpressionUUID->
  "3ef7fdae-c3b2-4456-b993-4a44256c91a8"],
 " that satisfied the three equations we chose. With ten equations, if the \
actual formula were not quadratic, there is a greater chance that no values \
of ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "a29201c8-0774-4c34-b862-66466372e393"],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "cb0c4173-4aee-4b36-81fd-0cba2a036fd8"],
 ", and ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],ExpressionUUID->
  "a207f6e3-fa2e-4cb6-9f2c-fb0ee87a64fc"],
 " would satisfy all ten equations. In that case, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " would have returned an empty list to indicate the absence of a solution \
and that our guess about the kind of formula was incorrect. "
}], "Text",ExpressionUUID->"642230e6-5b2d-4c3a-af6d-08a666ca65f3"],

Cell[TextData[{
 "Let us review what we have done so far. Our goal is to find a formula for \
the sum ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], "n",
     LimitsPositioning->False], "i"}], TraditionalForm]],
  CellChangeTimes->{{3.553527478053399*^9, 3.5535275179520683`*^9}},
  ExpressionUUID->"2a280480-aa28-42bc-b25c-4d772b42b3c4"],
 ". We used ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to compute many values of this sum and graphed them. This graph suggested \
a quadratic formula, that is, one of the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "\[CenterDot]", 
     SuperscriptBox["n", "2"]}], "+", 
    RowBox[{"b", "\[CenterDot]", "n"}], "+", "c"}], TraditionalForm]],
  ExpressionUUID->"e26b14de-9654-471f-a91f-5576a768f63f"],
 " for some values of ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "b0d3a48d-421d-4022-8e3a-e05351f97fc8"],
 ", ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "421581c7-88b4-4ff6-9031-efdbfc6cd711"],
 ", and ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],ExpressionUUID->
  "a9fe37b9-5b7c-4a28-8b7c-576e7dc0ea77"],
 ". We then used the Wolfram Language\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["Solve",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Solve"], "FunctionLink"],
 " function to determine that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "=", 
    RowBox[{"b", "=", 
     FractionBox["1", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "2629d90c-ad67-48bd-b26a-08efb83c182e"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", "0"}], TraditionalForm]],ExpressionUUID->
  "6f95bb06-c995-4f3a-a117-40e72f05df50"],
 ". In other words, we have found the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["n", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], "n"}]}], TraditionalForm]],ExpressionUUID->
  "43c74336-a322-418c-9592-d5bc2b30d88d"],
 ", which, of course, is the same as ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"n", "(", 
     RowBox[{"n", "+", "1"}], ")"}], "2"], TraditionalForm]],ExpressionUUID->
  "5140c57c-f18c-4d7c-bd68-f8e88675415c"],
 ". Although we have found a formula, we have not yet proven anything, we \
have only made a conjecture."
}], "Text",ExpressionUUID->"6c0f6838-fe1d-4a05-98f4-3085752ab86f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Induction Proof", "Subsubsection",ExpressionUUID->"c3388b61-aeed-4d54-a7d3-291de727528b"],

Cell["\<\
To prove that our formula is correct, we use mathematical induction. First, \
we make our formula into a function.\
\>", "Text",ExpressionUUID->"b9df7387-6ad9-4032-a6a4-5999105e42d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sumF", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", 
    RowBox[{"n", "^", "2"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "*", "n"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[8]:=",ExpressionUUID->"c866c538-47a8-463d-8f6f-95d10ea017fb"],

Cell[TextData[{
 "To complete the basis step of the induction, we need to see that the \
formula agrees with the sum for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "872a99e4-b441-4af2-b079-3a45b78ade72"],
 "."
}], "Text",ExpressionUUID->"e0f916cf-3b68-4bdb-a280-d80b9fab5c77"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{"i", ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"2c4681bd-408e-4c53-8ac0-39967df0f97d"],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[9]=",ExpressionUUID->"5f8958eb-eaa0-429f-b4dc-db04ab836a24"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumF", "[", "1", "]"}]], "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"eb166352-807b-4773-9291-f5aebd9645a5"],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[10]=",ExpressionUUID->"b1f0f8ca-1732-418d-b3ae-8e6fe184042b"]
}, Open  ]],

Cell["They are equal and the basis step is verified. ", "Text",ExpressionUUID->"3fa6ddf2-4bf6-4d65-94d6-7bd82a100a2f"],

Cell[TextData[{
 "For the inductive step, we assume that the formula is correct for ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "f8fcef52-431b-4836-8747-cec875da0882"],
 " and need to demonstrate that it is true for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "aaed1b9b-be82-40e0-8e4d-6ac300de8129"],
 ". In Example 1 of the textbook, this was done by starting with the sum ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "+", "2", "+", "\[CenterEllipsis]", "+", "k", "+", 
    RowBox[{"(", 
     RowBox[{"k", "+", "1"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "8a064c35-b2c3-4092-9091-47e443480c3c"],
 " and applying the inductive hypothesis to the first ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "7427bcf2-d757-4f7b-8873-3fb85a6e19c3"],
 " terms to obtain ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"k", "(", 
      RowBox[{"k", "+", "1"}], ")"}], "2"], "+", 
    RowBox[{"(", 
     RowBox[{"k", "+", "1"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "1c7b0640-368f-4276-bd8d-a10b7fad9a63"],
 ". Then, algebra is used to turn that expression into the formula evaluated \
at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "af569863-6a82-49a3-b9d3-64f1b8d3b755"],
 ". With ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", we can just check whether the expressions are the same. "
}], "Text",ExpressionUUID->"a14504db-5a67-456c-9f0c-2580194e2aaa"],

Cell[TextData[{
 "The sum of the first ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "f88e2276-ba7f-40c0-91bb-129ab527cda2"],
 " terms is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "+", "2", "+", "\[CenterEllipsis]", "+", "k", "+", 
     RowBox[{"(", 
      RowBox[{"k", "+", "1"}], ")"}]}], "=", 
    RowBox[{
     RowBox[{"f", "(", "k", ")"}], "+", 
     RowBox[{"(", 
      RowBox[{"k", "+", "1"}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "6d1afa75-1402-4c1f-8460-aafbfc833262"],
 "."
}], "Text",ExpressionUUID->"6ffb1849-54c6-4b8b-90ce-722a1a49715b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sumF", "[", "k", "]"}], "+", 
  RowBox[{"(", 
   RowBox[{"k", "+", "1"}], ")"}]}]], "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"70f07cfe-b4df-481e-a57f-eb390a31a081"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"3", " ", "k"}], "2"], "+", 
  FractionBox[
   SuperscriptBox["k", "2"], "2"]}]], "Output",
 CellLabel->"Out[11]=",ExpressionUUID->"a9173423-61f4-48f6-a83b-1dd727ceb285"]
}, Open  ]],

Cell[TextData[{
 "That used the inductive hypothesis. We need to see if this is the same as \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"k", "+", "1"}], ")"}], TraditionalForm]],ExpressionUUID->
  "0a033731-c067-4209-ae91-138997c93a49"],
 "."
}], "Text",ExpressionUUID->"5a81b676-6a1d-4215-8665-223da1304bf6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumF", "[", 
  RowBox[{"k", "+", "1"}], "]"}]], "Input",
 CellLabel->"In[12]:=",ExpressionUUID->"bcfe3fbd-9d6a-4529-b07d-78ebe8833678"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"1", "+", "k"}], "2"], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "k"}], ")"}], "2"]}]}]], "Output",
 CellLabel->"Out[12]=",ExpressionUUID->"3e7d46a6-6976-45a3-a2e8-dabafe5bafdd"]
}, Open  ]],

Cell[TextData[{
 "To check whether ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"k", "+", "1"}], ")"}], TraditionalForm]],ExpressionUUID->
  "7572aba5-865f-42e0-a435-91b9f750f5f6"],
 " is the same as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "k", ")"}], "+", 
    RowBox[{"(", 
     RowBox[{"k", "+", "1"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "4dc43778-4837-4f8a-90c7-f8c0ed95e0d9"],
 ", we will apply the ",
 StyleBox[ButtonBox["Reduce",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reduce"], "FunctionLink"],
 " function. The first argument to ",
 StyleBox[ButtonBox["Reduce",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reduce"], "FunctionLink"],
 " will be the equation formed by identifying the two expressions. The second \
argument is the variable ",
 StyleBox["k", "Code"],
 ". ",
 StyleBox[ButtonBox["Reduce",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reduce"], "FunctionLink"],
 " will apply algebraic rules to the expression to determine the values of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "02da18b6-8709-4546-9c64-b21be5bf8aaa"],
 " for which the equation holds. If there is more than one equation or more \
than one variable, you can use a list in either of the arguments."
}], "Text",ExpressionUUID->"4a9ba93a-6a1e-4798-ac56-5f446e5f69ba"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sumF", "[", "k", "]"}], "+", 
     RowBox[{"(", 
      RowBox[{"k", "+", "1"}], ")"}]}], "\[Equal]", 
    RowBox[{"sumF", "[", 
     RowBox[{"k", "+", "1"}], "]"}]}], ",", "k"}], "]"}]], "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"e353ec01-e4ca-4a8a-be15-0cea15f4e6de"],

Cell[BoxData["True"], "Output",
 CellLabel->"Out[13]=",ExpressionUUID->"5f824f84-1c55-4ec7-b659-696dcb591462"]
}, Open  ]],

Cell[TextData[{
 "The output ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " indicates that the equation is valid for all values of ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "850388d9-61c7-4b78-a051-24563af69f04"],
 ", in particular, it is true for the positive integers. This means that the \
inductive step is verified, and hence the formula is correct."
}], "Text",ExpressionUUID->"625f11e3-ee2a-4237-bfa5-5ff6cd28bec5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summation Example 2", "Subsection",
 CellTags->"Section1b",ExpressionUUID->"bd31a980-0692-4a77-a89b-9fff71ffe5be"],

Cell[TextData[{
 "As a second example of using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find and prove summation formulae, consider the sum ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], "n",
     LimitsPositioning->False], 
    RowBox[{
     RowBox[{
      SuperscriptBox["i", "2"], "(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], TraditionalForm]],
  CellChangeTimes->{{3.553527478053399*^9, 3.5535275179520683`*^9}},
  ExpressionUUID->"0c5195d1-f0ed-4226-8178-b4c48ad055bd"],
 ". For this example, we will not go through the process of computing values \
and graphing as we did above. That is a very valuable process, and we \
strongly recommend that you go through it yourself with a few examples. \
However, the Wolfram Language includes a function that will give us the \
result. "
}], "Text",ExpressionUUID->"ff3ec579-4aa9-4135-abe5-257f26f0b98f"],

Cell[CellGroupData[{

Cell[TextData[{
 "Using ",
 StyleBox["Sum", "Code"],
 " to Determine the Formula"
}], "Subsubsection",ExpressionUUID->"ab22606f-840e-43c6-a376-194c80e7d85d"],

Cell[TextData[{
 "Above, we used the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function to determine the numeric sum of a sequence of numbers. The \
numbers being added were determined by a formula, and the bounds of the sum \
were explicit values so that the sum could be calculated and added. To \
calculate ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], "10",
     LimitsPositioning->False], 
    RowBox[{
     RowBox[{
      SuperscriptBox["i", "2"], "(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], TraditionalForm]],
  CellChangeTimes->{{3.553527478053399*^9, 3.5535275179520683`*^9}},
  ExpressionUUID->"422e7a21-a3df-48b9-8d6f-385f480aa6bb"],
 ", we use ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " as in the previous example, with the formula given as the first argument. \
The bounds, ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "c1065bc7-f6e4-4d99-afc7-62a97537866a"],
 " ranging from 1 to 10, are given in the second argument in the form ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}], TraditionalForm]],ExpressionUUID->
  "50069e52-c1cf-44e2-88c6-050e121d62ab"],
 "."
}], "Text",ExpressionUUID->"59f7b595-d31d-4e60-9914-71a89d340f71"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"i", "^", "2"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"23585170-f2ab-467c-91ea-95e1c5a5071c"],

Cell[BoxData["4311014402"], "Output",
 CellLabel->"Out[14]=",ExpressionUUID->"7902d23d-1afe-4f6c-bdd3-71b99df5999e"]
}, Open  ]],

Cell[TextData[{
 "(Note the use of the exclamation mark for the computation of factorial. You \
can also use the functional form ",
 StyleBox[ButtonBox["Factorial",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Factorial"], "FunctionLink"],
 " if you prefer.) "
}], "Text",ExpressionUUID->"cd5a1473-621d-447d-ac9c-dc5ce99c7b2e"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function can also be used for computing symbolic sums, as in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], "n",
     LimitsPositioning->False], 
    RowBox[{
     RowBox[{
      SuperscriptBox["i", "2"], "(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], TraditionalForm]],
  CellChangeTimes->{{3.553527478053399*^9, 3.5535275179520683`*^9}},
  ExpressionUUID->"fd1b076d-68b0-480f-9ec5-c241e060f56d"],
 ". All we need to do is replace the upper bound of 10 with the symbol ",
 StyleBox["n", "Code"],
 ", provided that ",
 StyleBox["n", "Code"],
 " has not been assigned a value."
}], "Text",ExpressionUUID->"dea75859-c471-4921-96b0-44bf7d04d503"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"i", "^", "2"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "n"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[15]:=",ExpressionUUID->"a4a62592-1fe8-4b34-ba6e-b0ae8f037f1a"],

Cell[BoxData[
 RowBox[{"2", "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2", "+", "n"}], ")"}], "!"}], "+", 
  RowBox[{"n", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "n"}], ")"}], "!"}]}]}]], "Output",
 CellLabel->"Out[15]=",ExpressionUUID->"ee8a267e-abae-4946-a6ab-0f20321ee342"]
}, Open  ]],

Cell[TextData[{
 "Applying ",
 StyleBox[ButtonBox["Simplify",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Simplify"], "FunctionLink"],
 " to the output, we obtain a slightly simpler formula."
}], "Text",ExpressionUUID->"d015af62-0607-4546-82df-a40e49a35416"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"5e0c1fb3-0859-413d-ad3a-778cd5cce6e5"],

Cell[BoxData[
 RowBox[{"2", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "n"}], ")"}], "!"}]}]}]], "Output",
 CellLabel->"Out[16]=",ExpressionUUID->"871b1125-0da1-4479-8313-b47361798de8"]
}, Open  ]],

Cell[TextData[{
 "Note that you can use symbols in place of any of the bound specifications. \
You can also use the symbol ",
 StyleBox[ButtonBox["Infinity",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Infinity"], "FunctionLink"],
 " in place of the upper bound, provided the series is convergent."
}], "Text",ExpressionUUID->"495a4af2-2e90-43e2-8200-09fd24c28d75"],

Cell[TextData[{
 "Similarly, the Wolfram Language provides the ",
 StyleBox[ButtonBox["Product",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Product"], "FunctionLink"],
 " function for computing numeric and symbolic products. The syntax is the \
same."
}], "Text",ExpressionUUID->"d9516cea-42ee-4a72-9756-ca9295756597"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Induction Proof", "Subsubsection",ExpressionUUID->"0268c6ec-b606-409b-a66e-c1ba854c1093"],

Cell[TextData[{
 "Now that the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function has determined the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      StyleBox[
       RowBox[{"i", "=", "1"}], "TI"], "n",
      LimitsPositioning->False], 
     RowBox[{
      RowBox[{
       SuperscriptBox["i", "2"], "(", 
       RowBox[{"i", "+", "1"}], ")"}], "!"}]}], " ", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"n", "-", "1"}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", "2"}], ")"}], "!"}]}], "+", "2"}]}], 
   TraditionalForm]],
  CellChangeTimes->{{3.553604401518861*^9, 3.5536044232207212`*^9}},
  ExpressionUUID->"3c8692e3-c19a-4434-ad7b-2207fc0ff130"],
 ", we will use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to help us prove it. Even though we can be very confident that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has given us a correct formula, applying a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function is not the same as a proof."
}], "Text",ExpressionUUID->"f1f96bde-02bf-47ec-9f28-69af7c83f4f3"],

Cell["As before, we define a function based on the formula.", "Text",ExpressionUUID->"04dd1f30-c63c-47b9-b74d-4b0ddc5380a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sumF2", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "-", "1"}], ")"}], "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "+", "2"}], ")"}], "!"}]}], "+", "2"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[17]:=",ExpressionUUID->"759e963b-a478-4115-a59d-d96ed2216fa0"],

Cell[TextData[{
 "For the basis step of the induction, we need to see that the formula holds \
for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "9152b904-a49c-4a43-8e9f-11dadd8fd822"],
 ". The value of the sum for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "95c4642b-fb2d-4640-9073-0d8162d92524"],
 " is"
}], "Text",ExpressionUUID->"8f140c5d-e6e3-4405-a218-ead653db6a85"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"1", "^", "2"}], "*", 
  RowBox[{"(", 
   RowBox[{"1", "+", "1"}], ")"}]}]], "Input",
 CellLabel->"In[18]:=",ExpressionUUID->"2a079b22-d6b3-4321-81ff-7704e722a7e6"],

Cell[BoxData["2"], "Output",
 CellLabel->"Out[18]=",ExpressionUUID->"94240cd0-08db-413a-8b34-62e1eac7e8d3"]
}, Open  ]],

Cell[TextData[{
 "On the other hand, the formula applied to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "31658284-bf1a-4d35-8d9b-becd380dffee"],
 " is"
}], "Text",ExpressionUUID->"9849048e-d169-4b27-8a29-5ed8d79f9c2c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumF2", "[", "1", "]"}]], "Input",
 CellLabel->"In[19]:=",ExpressionUUID->"87ba7334-3e27-4ef0-8cfa-a29fb09015a0"],

Cell[BoxData["2"], "Output",
 CellLabel->"Out[19]=",ExpressionUUID->"ea0044f9-466f-459e-9821-e083ee1bba1f"]
}, Open  ]],

Cell["The basis step is verified.", "Text",ExpressionUUID->"46b7c36e-2284-4a6d-a27f-578b4866717d"],

Cell[TextData[{
 "For the inductive step, we assume that the formula is correct for ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "9f062b42-d2a9-4b0e-95a0-c18ef8d4cf12"],
 ". That is, we assume that"
}], "Text",ExpressionUUID->"95577a10-c63e-41f9-b203-2e7d9d9242ab"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], "k",
     LimitsPositioning->False], 
    RowBox[{
     RowBox[{
      SuperscriptBox["i", "2"], "(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k", "-", "1"}], ")"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "+", "2"}], ")"}], "!"}]}], "+", "2"}]}], 
  TraditionalForm]], "Equation",ExpressionUUID->"98df4e77-19fc-4aea-adae-\
d0a0631bbc89"],

Cell[TextData[{
 "We need to show that the formula works for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "f8d78b96-3693-47d9-b452-a5a35f9c0539"],
 ". Now,"
}], "Text",ExpressionUUID->"a9babc60-a251-4741-a008-7c9afe8d47da"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     StyleBox[
      RowBox[{"i", "=", "1"}], "TI"], 
     RowBox[{"k", "+", "1"}],
     LimitsPositioning->False], 
    RowBox[{
     RowBox[{
      SuperscriptBox["i", "2"], "(", 
      RowBox[{"i", "+", "1"}], ")"}], "!"}]}], " ", "=", 
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      StyleBox[
       RowBox[{"i", "=", "1"}], "TI"], "k",
      LimitsPositioning->False], 
     RowBox[{
      RowBox[{
       SuperscriptBox["i", "2"], "(", 
       RowBox[{"i", "+", "1"}], ")"}], "!"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "+", "1"}], ")"}], "2"], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "+", "1"}], ")"}], "+", "1"}], ")"}], "!"}]}]}]}], 
  TraditionalForm]], "Equation",ExpressionUUID->"f801961a-3798-42a5-b940-\
63b7f2f47333"],

Cell[TextData[{
 "Using the inductive hypothesis that the formula is correct for ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "56fc3d22-20cd-40b8-879e-dd3477302d19"],
 ", this is"
}], "Text",ExpressionUUID->"aa4a0a58-28d4-4a6c-8d27-2c4ccc0e71e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sumF2", "[", "k", "]"}], "+", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"k", "+", "1"}], ")"}], "^", "2"}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "+", "1"}], ")"}], "+", "1"}], ")"}], "!"}]}]}]], "Input",\

 CellLabel->"In[20]:=",ExpressionUUID->"e60ce76f-8950-49b7-99c9-920ddaf46777"],

Cell[BoxData[
 RowBox[{"2", "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "k"}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "k"}], ")"}], "!"}]}], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "k"}], ")"}], "2"], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "+", "k"}], ")"}], "!"}]}]}]], "Output",
 CellLabel->"Out[20]=",ExpressionUUID->"d8a22cd3-d795-4843-bd03-94340688ecd5"]
}, Open  ]],

Cell[TextData[{
 "We need to check to see if this is the same as the formula applied to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "cd725ac0-59ac-4dbd-af67-5d23acf53409"],
 "."
}], "Text",ExpressionUUID->"451cf9da-7aeb-48bd-84c0-2216f79a5696"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumF2", "[", 
  RowBox[{"k", "+", "1"}], "]"}]], "Input",
 CellLabel->"In[21]:=",ExpressionUUID->"b4e2612b-d144-4a8e-b672-06adfd479727"],

Cell[BoxData[
 RowBox[{"2", "+", 
  RowBox[{"k", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "+", "k"}], ")"}], "!"}]}]}]], "Output",
 CellLabel->"Out[21]=",ExpressionUUID->"1405ab3d-8c02-49b3-849a-c84c2ed420ee"]
}, Open  ]],

Cell[TextData[{
 "Again, we use ",
 StyleBox[ButtonBox["Reduce",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reduce"], "FunctionLink"],
 " applied to the equation formed by identifying these two expressions."
}], "Text",ExpressionUUID->"650d5d6a-9305-4a44-8192-73c4d5293a8b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sumF2", "[", "k", "]"}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"k", "+", "1"}], ")"}], "^", "2"}], "*", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"k", "+", "1"}], ")"}], "+", "1"}], ")"}], "!"}]}]}], 
   "\[Equal]", 
   RowBox[{"sumF2", "[", 
    RowBox[{"k", "+", "1"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[22]:=",ExpressionUUID->"d24e75ee-ba0c-4a63-9b14-de3a50d409d3"],

Cell[BoxData[
 TemplateBox[{
  "Reduce","fexp",
   "\"Warning: \\!\\(\\*RowBox[{\\\"Reduce\\\"}]\\) used FunctionExpand to \
transform the system. Since FunctionExpand transformation rules are only \
generically correct, the solution set might have been altered.\"",2,22,1,
   22492403800461946764,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellLabel->
  "During evaluation of \
In[22]:=",ExpressionUUID->"65b3e0b7-13ac-4d05-b094-368ed18f306a"],

Cell[BoxData["True"], "Output",
 CellLabel->"Out[22]=",ExpressionUUID->"a2c0b3a0-63d2-4193-a484-247bb3b973c1"]
}, Open  ]],

Cell[TextData[{
 "Observe that a warning message was produced this time. The reason for this \
is the inclusion of the factorials, which ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " treats with particular care. However, the output is correct, the equation \
is true, as you can verify by hand."
}], "Text",ExpressionUUID->"950f6f8f-9b45-4635-8a21-64f48c40f25b"],

Cell["\<\
It should be pointed out that this \[OpenCurlyDoubleQuote]proof\
\[CloseCurlyDoubleQuote] of the formula for the sum is only correct modulo \
the correctness of the Wolfram Language functions that we have used and the \
proper functioning of the computer it is run on. One of the drawbacks of \
computer-aided proof is the degree to which your computer or software could \
be introducing hidden errors.\
\>", "Text",ExpressionUUID->"86e076de-ac75-45f7-8c8d-a5f9f53d71ae"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Divisibility", "Subsection",
 CellTags->"Section1c",ExpressionUUID->"2351ad9f-4f6d-45e7-8cda-b44fa444c1e1"],

Cell[TextData[{
 "For a final example, we will see how ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to help prove results about divisibility. In Example 8 from \
Section 5.1 of the text, it was shown that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "3"], "-", "n"}], TraditionalForm]],ExpressionUUID->
  "bdcb5b1f-cd13-46c7-9206-bdc09d65ecf7"],
 " is divisible by 3 for all positive integers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "3ea9b8f7-5505-4143-89fb-18a424e96af4"],
 ". Exercise 33 asks you to prove that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "5"], "-", "n"}], TraditionalForm]],ExpressionUUID->
  "555e2576-dea9-448f-9916-7428c4e4cb30"],
 " is divisible by 5 for all positive integers. These two facts suggest that \
perhaps ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "7"], "-", "n"}], TraditionalForm]],ExpressionUUID->
  "f137fa5c-a0e5-4247-87b6-8f70808e0566"],
 " is divisible by 7 for all positive integers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "370b5d07-ec04-4526-aeaf-e86bef7f682d"],
 ". We will use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to help prove this fact. "
}], "Text",ExpressionUUID->"29f14c3c-beb7-49fe-b728-65a9ff8cb3d7"],

Cell[TextData[{
 "We begin by creating a function to represent the expression ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "7"], "-", "n"}], TraditionalForm]],ExpressionUUID->
  "e232d30f-82a8-42e6-89d9-cff4e0c210f0"],
 ". "
}], "Text",ExpressionUUID->"dd7925eb-2752-4db3-994d-3dae7a8a3e93"],

Cell[BoxData[
 RowBox[{
  RowBox[{"divisibleEx", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"n", "^", "7"}], "-", "n"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[23]:=",ExpressionUUID->"783e802e-4f33-43cb-a752-bc860301f3c2"],

Cell[TextData[{
 "The basis case is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "f4ac6099-c363-4f8b-be8f-21251139344d"],
 ". For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "08c54b9b-4e25-4b79-8487-3885c42ec858"],
 ", the expression is"
}], "Text",ExpressionUUID->"842beb33-559c-448b-a2b6-2ef1ee3951b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"divisibleEx", "[", "1", "]"}]], "Input",
 CellLabel->"In[24]:=",ExpressionUUID->"f5b22f79-12bc-417f-a8f6-025187ae026f"],

Cell[BoxData["0"], "Output",
 CellLabel->"Out[24]=",ExpressionUUID->"1866b6f6-70a6-446c-8d57-315e6da66a9f"]
}, Open  ]],

Cell["This is divisible by 7, so the basis case holds.", "Text",ExpressionUUID->"27e14c7c-1454-45e0-b8bb-58dfa8d81456"],

Cell[TextData[{
 "The inductive hypothesis is that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", "7"], "-", "k"}], TraditionalForm]],ExpressionUUID->
  "f2161ff5-c55f-490b-9284-c6753d2408ac"],
 " is divisible by ",
 Cell[BoxData[
  FormBox["7", TraditionalForm]],ExpressionUUID->
  "c3c0dd0b-83b0-437e-b483-8c52386b4bde"],
 " for a positive integer ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "6dbb1646-e92a-4e1b-b19f-ee8181ee9a8e"],
 ". We need to show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "+", "1"}], ")"}], "7"], "-", 
    RowBox[{"(", 
     RowBox[{"k", "+", "1"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "57b31d91-ba4b-4242-aaa9-c10ce74f6728"],
 " is divisible by 7. To do this, we use the following fact: if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "|", "a"}], TraditionalForm]],ExpressionUUID->
  "29afc338-e404-4d50-8c2a-1baf6d8c9f38"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "|", 
    RowBox[{"b", "-", "a"}]}], TraditionalForm]],ExpressionUUID->
  "816c8b87-fb5c-4d9e-80a8-d52d26940fec"],
 " then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "|", "b"}], TraditionalForm]],ExpressionUUID->
  "eba5f93b-006f-4e75-8bb6-105320e09606"],
 ". (The reader should verify this statement, which is equivalent to Theorem \
1, part (i), of Section 4.1.) "
}], "Text",ExpressionUUID->"d08428f5-488d-4518-9db1-671f55bff3c6"],

Cell[TextData[{
 "By assumption, 7 divides ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", "7"], "-", "k"}], TraditionalForm]],ExpressionUUID->
  "d729db16-8605-4acf-a9ec-4ae5c1b22d39"],
 ". We will have ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " compute the difference with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "+", "1"}], ")"}], "7"], "-", 
    RowBox[{"(", 
     RowBox[{"k", "+", "1"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "d744cae0-fafa-49a0-b73a-f004b3ad15b5"],
 "."
}], "Text",ExpressionUUID->"7c5f461b-7ac2-430b-a634-901e2a675810"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"divisibleEx", "[", 
   RowBox[{"k", "+", "1"}], "]"}], "-", 
  RowBox[{"divisibleEx", "[", "k", "]"}]}]], "Input",
 CellLabel->"In[25]:=",ExpressionUUID->"e2a198ef-0bdd-4916-a4cd-71b2903c8709"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "-", 
  SuperscriptBox["k", "7"], "+", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", "k"}], ")"}], "7"]}]], "Output",
 CellLabel->"Out[25]=",ExpressionUUID->"000445a2-cfd2-49b2-8694-78dbe1f9cb28"]
}, Open  ]],

Cell[TextData[{
 "We apply the ",
 StyleBox[ButtonBox["Expand",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Expand"], "FunctionLink"],
 " function to the result."
}], "Text",ExpressionUUID->"93496d00-4da1-4403-aebd-c50d16ceb685"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", "%", "]"}]], "Input",
 CellLabel->"In[26]:=",ExpressionUUID->"825a8668-abdc-4ff3-883f-984dba62e157"],

Cell[BoxData[
 RowBox[{
  RowBox[{"7", " ", "k"}], "+", 
  RowBox[{"21", " ", 
   SuperscriptBox["k", "2"]}], "+", 
  RowBox[{"35", " ", 
   SuperscriptBox["k", "3"]}], "+", 
  RowBox[{"35", " ", 
   SuperscriptBox["k", "4"]}], "+", 
  RowBox[{"21", " ", 
   SuperscriptBox["k", "5"]}], "+", 
  RowBox[{"7", " ", 
   SuperscriptBox["k", "6"]}]}]], "Output",
 CellLabel->"Out[26]=",ExpressionUUID->"e580aefb-b86d-4a2c-a008-063e8a40bac5"]
}, Open  ]],

Cell[TextData[{
 "You can see that the coefficients are all multiples of 7 and thus the \
expression is divisible by 7. We can confirm this with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by checking that the difference is divisible by 7 by using the ",
 StyleBox[ButtonBox["Reduce",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Reduce"], "FunctionLink"],
 " function on the equation formed by setting the difference equal to 0 and \
invoking the ",
 StyleBox[ButtonBox["Modulus",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Modulus"], "FunctionLink"],
 " option."
}], "Text",ExpressionUUID->"dfd36103-c004-4e4d-bd4e-d1fe82fc63de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"divisibleEx", "[", 
      RowBox[{"k", "+", "1"}], "]"}], "-", 
     RowBox[{"divisibleEx", "[", "k", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{"Modulus", "\[Rule]", "7"}]}], "]"}]], "Input",
 CellLabel->"In[27]:=",ExpressionUUID->"fc77deda-2775-439b-8066-bab597334c0d"],

Cell[BoxData["True"], "Output",
 CellLabel->"Out[27]=",ExpressionUUID->"745c6b48-f1d5-4498-bdb0-8c6cf2b39047"]
}, Open  ]],

Cell[TextData[{
 "Thus, the inductive step is verified and hence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "7"], "-", "n"}], TraditionalForm]],ExpressionUUID->
  "1ac6fec9-d91a-408c-8b13-888d01bcdaf3"],
 " is divisible by 7 for all positive integers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "98cada53-5049-499f-bb81-a38345823af6"],
 "."
}], "Text",ExpressionUUID->"ec71b2bb-bdea-4f97-9b3b-402dbba42588"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Strong Induction and Well-Ordering", "Section",
 CellTags->"Section2",ExpressionUUID->"2abca2a8-1a9c-471b-8a26-5a91e638b1cd"],

Cell[TextData[{
 "In this section, we will see one way that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be used to support a proof by strong induction. In particular, we will \
consider the class of problems illustrated in Example 4: \
\[OpenCurlyDoubleQuote]prove that every amount of postage of 12 cents or more \
can be formed using just 4-cent and 5-cent stamps.\[CloseCurlyDoubleQuote] \
The second solution to that example will form the model for this discussion. \
(See also Exercises 3 through 8 as other examples of problems of this kind.) \
"
}], "Text",ExpressionUUID->"c94da6ed-3ae4-4459-a097-9ad2d08d3419"],

Cell[TextData[{
 "The basis step of the strong induction argument requires several \
propositions to be verified. Using the notation in the text, the propositions \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", "(", "b", ")"}], ",", 
    RowBox[{"P", "(", 
     RowBox[{"b", "+", "1"}], ")"}], ",", "\[Ellipsis]", ",", 
    RowBox[{"P", "(", 
     RowBox[{"b", "+", "j"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "bcd8ef25-aa37-4724-be69-2aa5d806a3bd"],
 " must all be demonstrated for some integer ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "d18f2df0-3042-43dc-9618-a39b31ee6d0b"],
 " and a positive integer ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "a130c5b9-5140-4f1e-a573-c36a1b87e9bd"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be useful in these situations because it can often verify the basis \
cases for you. This is particularly useful when ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]],ExpressionUUID->
  "0e11ee0c-54e6-48cc-83e4-efd7fa02efd1"],
 " is large."
}], "Text",ExpressionUUID->"a84b67bc-6e95-436d-98dd-bca4c8321a67"],

Cell[TextData[{
 "Showing that every amount of postage over 12 cents can be formed using 4- \
and 5-cent stamps requires four basis cases: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", "(", "12", ")"}], ",", 
    RowBox[{"P", "(", "13", ")"}], ",", 
    RowBox[{"P", "(", "14", ")"}], ",", 
    RowBox[{"P", "(", "15", ")"}]}], TraditionalForm]],ExpressionUUID->
  "efd38213-a428-4e26-9b44-b09fd53e57e0"],
 ". We begin by showing how to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to demonstrate ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "(", "12", ")"}], TraditionalForm]],ExpressionUUID->
  "45f64a90-61ac-4d7f-8022-1ebdf32f2db9"],
 ", that postage of 12 cents can be formed using 4- and 5-cent stamps. \
Although you may object that it is obvious that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"12", "=", 
    RowBox[{"4", "\[CenterDot]", "3"}]}], TraditionalForm]],ExpressionUUID->
  "49eb951d-8466-4e53-85c1-f9a47171e1da"],
 ", our ultimate goal is to generalize our code to encompass the entire class \
of postage problems."
}], "Text",ExpressionUUID->"d1db73d0-bd93-4f47-8c51-83a2dacfe6ea"],

Cell[CellGroupData[{

Cell["Making Postage", "Subsubsection",ExpressionUUID->"c55b2f72-cac6-4f6d-b303-69dee60547c3"],

Cell[TextData[{
 "To verify ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "(", "12", ")"}], TraditionalForm]],ExpressionUUID->
  "15ad3d09-957b-4d0d-b250-ffe087220455"],
 ", we must find nonnegative integers ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "40819fb8-28e6-4d74-be0b-faf0e0d9ab37"],
 " and ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "10f2bdb9-5e6d-44d3-b983-ce537b6de684"],
 ", representing the number of stamps of the two denominations, such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"12", "=", 
    RowBox[{
     RowBox[{"4", "a"}], "+", 
     RowBox[{"5", "b"}]}]}], TraditionalForm]],ExpressionUUID->
  "d9f86dab-5d6c-4772-9a27-3dc6ab2c0eab"],
 ". The most straightforward way of finding ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "642c5261-7313-4d20-9fa5-6841d330f964"],
 " and ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "21aad04b-d5cf-4719-a616-d88a92752f71"],
 " is to test all the possibilities. We know that ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "bc84d841-00ca-4fda-9a5a-98ecbd4ba481"],
 " and ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "51e40e9d-14f9-41fb-9388-b21e4496b88e"],
 " both must be nonnegative. "
}], "Text",ExpressionUUID->"84337b95-2eac-49ac-9268-a409506082a3"],

Cell[TextData[{
 "In addition, the maximum possible values of ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "8a66e8c9-301f-49b1-86d3-c278edaf8a4a"],
 " and ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "0c262af5-889e-4225-8cdb-5a7de53f48ce"],
 " are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftFloor]", 
    FractionBox["12", "4"], "\[RightFloor]"}], TraditionalForm]],
  ExpressionUUID->"9b17e51e-2c3a-48c2-87f1-ece273dfc71e"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftFloor]", 
    FractionBox["12", "5"], "\[RightFloor]"}], TraditionalForm]],
  ExpressionUUID->"806bc04b-0363-4496-9ab6-6706cdd6f9ef"],
 ", respectively. (Recall that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftFloor]", "x", "\[RightFloor]"}], TraditionalForm]],
  ExpressionUUID->"cc4b5bb0-d58c-465d-9587-bbc2526fe116"],
 " is the notation used to represent the floor of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "6458c01f-406a-43ad-bfb8-7530a3095eac"],
 ", that is, the largest integer less than or equal to ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "38b28123-fd86-41b7-b39f-4f56fa70d247"],
 ".) To see why this is so, consider ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "2cdb22af-9efc-4bbc-b499-5d906c6b5e95"],
 ": ",
 Cell[BoxData[
  FormBox[
   RowBox[{"12", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"4", "a"}], "+", 
      RowBox[{"5", "b"}]}], "\[GreaterEqual]", 
     RowBox[{"5", "b"}]}]}], TraditionalForm]],ExpressionUUID->
  "e2653479-a18e-4bd2-860d-2e5641e7fcb3"],
 " since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "\[GreaterEqual]", "0"}], TraditionalForm]],ExpressionUUID->
  "01b66cd5-bd5b-432b-b852-e2f8bbc0240e"],
 ". That is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"5", "b"}], "\[LessEqual]", "12"}], TraditionalForm]],
  ExpressionUUID->"8a14f691-6fcb-4495-b55e-608e218456c3"],
 " and so ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "\[LessEqual]", 
    FractionBox["12", "5"]}], TraditionalForm]],ExpressionUUID->
  "d299d60e-a745-4d95-abbf-818377ff3751"],
 ". Moreover, since ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "d4349609-a6c7-41e2-8fcf-a0d3a1153c0e"],
 " must be an integer, we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "\[LessEqual]", 
    RowBox[{"\[LeftFloor]", 
     FractionBox["12", "5"], "\[RightFloor]"}]}], TraditionalForm]],
  ExpressionUUID->"9871de99-8106-4e5b-8fd3-633967cc23d1"],
 ". Similarly for ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "0fc7280a-147c-4788-820d-8ea1b569dd10"],
 "."
}], "Text",ExpressionUUID->"1d98fe50-a999-454c-9e49-af752c8193c4"],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "632dd12d-6888-4613-8d37-928a78e5471e"],
 " and ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "8aa6b2ee-894a-4c59-b26f-7c20556647e2"],
 " must be between 0 and the floor of 12 divided by 4 or 5, respectively, we \
can use a pair of nested ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loops to check all the possible values. Within the loops, we only need to \
check to see if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"4", "a"}], "+", 
     RowBox[{"5", "b"}]}], "=", "12"}], TraditionalForm]],ExpressionUUID->
  "9884b654-aee4-40a7-8163-bbbd8928d5f9"],
 ". If so, we terminate the loops, which we enclose in a ",
 StyleBox[ButtonBox["Catch",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Catch"], "FunctionLink"],
 ", by applying ",
 StyleBox[ButtonBox["Throw",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Throw"], "FunctionLink"],
 " to the pair ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], TraditionalForm]],ExpressionUUID->
  "a714bd08-2257-4e70-a772-9413ac47d9dc"],
 "."
}], "Text",ExpressionUUID->"9957b041-5021-4f2e-a1d1-1dac040f8b29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Catch", "[", "\[IndentingNewLine]", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"a", "=", "0"}], ",", 
    RowBox[{"a", "\[LessEqual]", 
     RowBox[{"Floor", "[", 
      RowBox[{"12", "/", "4"}], "]"}]}], ",", 
    RowBox[{"a", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"b", "=", "0"}], ",", 
      RowBox[{"b", "\[LessEqual]", 
       RowBox[{"Floor", "[", 
        RowBox[{"12", "/", "5"}], "]"}]}], ",", 
      RowBox[{"b", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"4", "*", "a"}], "+", 
          RowBox[{"5", "*", "b"}]}], "\[Equal]", "12"}], ",", 
        RowBox[{"Throw", "[", 
         RowBox[{"{", 
          RowBox[{"a", ",", "b"}], "}"}], "]"}]}], "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellLabel->"In[28]:=",ExpressionUUID->"f73026dc-1518-44c6-9779-96663373ddcb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "0"}], "}"}]], "Output",
 CellLabel->"Out[28]=",ExpressionUUID->"c289a9cc-6bad-44ff-9ff9-afe72983bb15"]
}, Open  ]],

Cell[TextData[{
 "We can very easily generalize this by replacing the target value and the \
stamp denominations with variables. The following function implements this \
generalization. It accepts the two denominations and the target value as \
input and returns a list whose elements represent the number of each kind of \
stamp required. In the event that the function fails to form the desired \
amount of postage with the given stamps, it returns ",
 StyleBox[ButtonBox["Null",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Null"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"d9e2611c-77bf-4b6b-9fe1-624329ffae22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"makePostage", "[", 
   RowBox[{"stampA_Integer", ",", "stampB_Integer", ",", "postage_Integer"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Catch", "[", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"a", "=", "0"}], ",", 
       RowBox[{"a", "\[LessEqual]", 
        RowBox[{"Floor", "[", 
         RowBox[{"postage", "/", "stampA"}], "]"}]}], ",", 
       RowBox[{"a", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"b", "=", "0"}], ",", 
         RowBox[{"b", "\[LessEqual]", 
          RowBox[{"Floor", "[", 
           RowBox[{"postage", "/", "stampB"}], "]"}]}], ",", 
         RowBox[{"b", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"stampA", "*", "a"}], "+", 
             RowBox[{"stampB", "*", "b"}]}], "\[Equal]", "postage"}], ",", 
           RowBox[{"Throw", "[", 
            RowBox[{"{", 
             RowBox[{"a", ",", "b"}], "}"}], "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True,
 CellLabel->"In[29]:=",ExpressionUUID->"31d7496f-25d0-4506-b31b-3a7d4c214939"],

Cell[TextData[{
 "Applying ",
 StyleBox["makePostage", "Code"],
 " with stamps 4 and 5 and with postage 13 tells us that it requires two \
4-cent stamps and one 5-cent stamp to make 13 cents postage."
}], "Text",ExpressionUUID->"3ed871b9-8687-4a65-885f-891fee8e2289"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makePostage", "[", 
  RowBox[{"4", ",", "5", ",", "13"}], "]"}]], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"fe6b5250-f844-492d-bbc3-29f3a7d51024"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "1"}], "}"}]], "Output",
 CellLabel->"Out[30]=",ExpressionUUID->"c35d2a0d-a64b-4f13-b02b-b951fe4d63cc"]
}, Open  ]],

Cell["\<\
On the other hand, it is not possible to make 11 cents postage with 4- and \
5-cent stamps and so the function does not produce output.\
\>", "Text",ExpressionUUID->"cebb47be-7173-4ca5-9dfb-1ffcf7cc009a"],

Cell[BoxData[
 RowBox[{"makePostage", "[", 
  RowBox[{"4", ",", "5", ",", "11"}], "]"}]], "Input",
 CellLabel->"In[31]:=",ExpressionUUID->"f9c81190-ec27-4e96-b81c-08f0a6966722"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Automating the Basis Step", "Subsubsection",ExpressionUUID->"578f2682-b880-49c1-b1cd-b3ba38b89d4f"],

Cell[TextData[{
 "The ",
 StyleBox["makePostage", "Code"],
 " function finds the number of stamps of each denomination needed to produce \
the desired postage. As a result, it verifies individual basis step \
propositions. With a simple loop, we can verify all of the basis cases. \
Recall that the basis step was to verify that postage can be made for 12, 13, \
14, and 15 cents."
}], "Text",ExpressionUUID->"9ac532f9-0c4c-4d63-95bf-b037c6813011"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"p", "=", "12"}], ",", 
   RowBox[{"p", "\[LessEqual]", "15"}], ",", 
   RowBox[{"p", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"makePostage", "[", 
     RowBox[{"4", ",", "5", ",", "p"}], "]"}], "]"}]}], "\[IndentingNewLine]",
   "]"}]], "Input",
 CellLabel->"In[32]:=",ExpressionUUID->"e566f0cb-9341-452f-b92e-147c6a1de650"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "0"}], "}"}]], "Print",
 CellLabel->
  "During evaluation of \
In[32]:=",ExpressionUUID->"c9e3b108-70b2-4765-a542-7842d92507df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "1"}], "}"}]], "Print",
 CellLabel->
  "During evaluation of \
In[32]:=",ExpressionUUID->"7eb16782-5e1e-489f-bd13-901242d6b0e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2"}], "}"}]], "Print",
 CellLabel->
  "During evaluation of \
In[32]:=",ExpressionUUID->"a9748a40-c925-4b8b-8912-ad6bc3c52c8d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "3"}], "}"}]], "Print",
 CellLabel->
  "During evaluation of \
In[32]:=",ExpressionUUID->"30488a1f-dff0-4b42-a6a0-d9b9dd89bd6f"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "We will write a function that does this in a moment, but first observe that \
the number of propositions in the basis step is equal to the smaller \
denomination stamp. The reason for this is in the proof of the inductive \
step. You should review the second solution to Example 4 in the text. The key \
point is that to make postage of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "7e31f624-506c-4cd3-9129-a684f4c61d71"],
 " cents, the proof relies on the inductive assumption that you can make \
postage of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"k", "+", "1", "-", "4"}], "=", 
    RowBox[{"k", "-", "3"}]}], TraditionalForm]],ExpressionUUID->
  "8488b19b-4bd7-4a95-84f4-9d460441067b"],
 " cents. This requires that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"k", "-", "3"}], "\[GreaterEqual]", "12"}], TraditionalForm]],
  ExpressionUUID->"3cecbb15-95c3-49a4-816c-d88359ea0a93"],
 " or ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "\[GreaterEqual]", "15"}], TraditionalForm]],ExpressionUUID->
  "970c1be9-8d12-4536-ac73-f58d07d6fe61"],
 "."
}], "Text",ExpressionUUID->"e56db94a-f894-48aa-bc88-2e7ae927e866"],

Cell[TextData[{
 "Generically, if ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "d5eb9f65-3ba5-4afd-abf4-c7fc1c67eb58"],
 " is the smaller of the stamps and ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "4380f130-cc2e-4143-a11f-5a97bc0bd477"],
 " is the minimum postage that we claim can be made (",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "12"}], TraditionalForm]],ExpressionUUID->
  "bc91df99-162d-4801-9ba0-c4babb5d910e"],
 " in the example), then the inductive step requires ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"k", "+", "1", "-", "a"}], "\[GreaterEqual]", "x"}], 
   TraditionalForm]],ExpressionUUID->"5207787a-6f52-4a3c-a02e-975e1d1cc9dd"],
 ". Which is to say ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "\[GreaterEqual]", 
    RowBox[{"x", "+", 
     RowBox[{"(", 
      RowBox[{"a", "-", "1"}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "0e274bbc-2a98-4f7d-b05a-a8d96bd369b5"],
 ". Thus, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", "(", "x", ")"}], ",", 
    RowBox[{"P", "(", 
     RowBox[{"x", "+", "1"}], ")"}], ",", "\[Ellipsis]", ",", 
    RowBox[{"P", "(", 
     RowBox[{"x", "+", 
      RowBox[{"(", 
       RowBox[{"a", "-", "1"}], ")"}]}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"773d19ad-6941-4918-87e0-6678d6f2fbd9"],
 " comprise the basis step. "
}], "Text",ExpressionUUID->"28fb07fa-2053-49d1-9d26-93da4159a296"],

Cell["\<\
This is useful to us in the following way: given the values of the stamps and \
the minimum value of postage, we can automate the verification of the \
appropriate basis cases. \
\>", "Text",ExpressionUUID->"c647dc0a-e8f3-4645-92fe-c0cf261c8543"],

Cell[TextData[{
 "We first create the following message to be given in case one of the basis \
cases fails. Note the use of placeholders ",
 StyleBox["`1`", "Code"],
 ", ",
 StyleBox["`2`", "Code"],
 ", and ",
 StyleBox["`3`", "Code"],
 ". These serve as variables. When ",
 StyleBox[ButtonBox["Message",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Message"], "FunctionLink"],
 " is called, it will be given with three additional arguments, beyond the \
name of the message, and the values of the arguments will be substituted in \
for these variables."
}], "Text",ExpressionUUID->"b324d677-50e0-4f65-bdc7-54c22577ae87"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"postageBasis", "::", "fail"}], "=", 
   "\"\<Cannot form postage of `3` using stamps of amounts `1` and \
`2`.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[33]:=",ExpressionUUID->"66f1ccc7-3ba5-47ec-9db1-b86a611edc1d"],

Cell[TextData[{
 "Here is the ",
 StyleBox["postageBasis", "Code"],
 " function. Note that the expression ",
 StyleBox["postageList", "Code"],
 " terminates the first argument of ",
 StyleBox[ButtonBox["Check",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Check"], "FunctionLink"],
 ", and ",
 StyleBox[ButtonBox["Null",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Null"], "FunctionLink"],
 " is the second argument of ",
 StyleBox[ButtonBox["Check",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Check"], "FunctionLink"],
 ". Consequently, if the main body of the function, contained in the first \
argument of ",
 StyleBox[ButtonBox["Check",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Check"], "FunctionLink"],
 ", is successful, the result of the function will be the list of rules that \
specify the numbers of stamps needed for each amount of postage. If there is \
an amount of postage that is not possible, then the message will be generated \
and the result of the function will be ",
 StyleBox[ButtonBox["Null",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Null"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"9e38d069-f51f-4221-9291-f89c6cb1b647"],

Cell[BoxData[
 RowBox[{
  RowBox[{"postageBasis", "[", 
   RowBox[{
   "stampA_Integer", ",", "stampB_Integer", ",", "minpostage_Integer"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"small", ",", 
      RowBox[{"postageList", "=", 
       RowBox[{"{", "}"}]}], ",", "postage", ",", "R"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"small", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"stampA", ",", "stampB"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Check", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"postage", "=", "minpostage"}], ",", "\[IndentingNewLine]", 
          
          RowBox[{"postage", "\[LessEqual]", 
           RowBox[{"minpostage", "+", "small", "-", "1"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"postage", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"R", "=", 
            RowBox[{"makePostage", "[", 
             RowBox[{"stampA", ",", "stampB", ",", "postage"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"R", "=!=", "Null"}], ",", "\[IndentingNewLine]", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"postageList", ",", 
               RowBox[{"postage", "\[Rule]", "R"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Message", "[", 
              RowBox[{
               RowBox[{"postageBasis", "::", "fail"}], ",", "stampA", ",", 
               "stampB", ",", "postage"}], "]"}]}], "\[IndentingNewLine]", 
            "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", "postageList"}], ",", 
       RowBox[{"(*", 
        RowBox[{"end", " ", "of", " ", "Check", " ", "argument", " ", "1"}], 
        "*)"}], "\[IndentingNewLine]", "Null"}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[34]:=",ExpressionUUID->"65fa4a01-d4c6-48bb-87f4-0a5689bb1a02"],

Cell["\<\
We apply it to the example of using 4- and 5-cent stamps to make postage of \
at least 12 cents.\
\>", "Text",ExpressionUUID->"98eb1556-166f-48c7-96bf-fa1129430a85"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"postageBasis", "[", 
  RowBox[{"4", ",", "5", ",", "12"}], "]"}]], "Input",
 CellLabel->"In[35]:=",ExpressionUUID->"0b653860-75c9-4457-8e64-6c6f52f8d7b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"12", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"3", ",", "0"}], "}"}]}], ",", 
   RowBox[{"13", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}]}], ",", 
   RowBox[{"14", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], ",", 
   RowBox[{"15", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "3"}], "}"}]}]}], "}"}]], "Output",
 CellLabel->"Out[35]=",ExpressionUUID->"d696e01c-d6e2-479a-b6d2-d387fadc463d"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["postageBasis", "Code"],
 " function above accepts as input the denominations of the two stamps and \
the minimum value such that all postage values equal to or greater than that \
minimum can be made. The function uses the ",
 StyleBox[ButtonBox["Min",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Min"], "FunctionLink"],
 " command to set ",
 StyleBox["small", "Code"],
 " equal to the lesser of the two denominations. The ",
 StyleBox["postageList", "Code"],
 " variable is used to store the information that shows how to make the \
various amounts of postage. This list will store rules of the form ",
 Cell[BoxData[
  RowBox[{
   StyleBox["postage", "CodeVar"], "\[Rule]", "{", 
   StyleBox["a", "CodeVar"], ",", 
   StyleBox["b", "CodeVar"], "}"}]], "myCode",ExpressionUUID->
  "b37ada46-1264-4341-a81b-cb1c081e92dd"],
 " which indicate that the specified amount of ",
 Cell[BoxData[
  FormBox[
   StyleBox["postage", "CodeVar"], TraditionalForm]],ExpressionUUID->
  "5076f24a-7a87-4bf0-b773-ceebe6525a29"],
 " can be made with ",
 StyleBox["a", "CodeVar"],
 " stamps of value ",
 Cell[BoxData[
  FormBox["A", TraditionalForm]],ExpressionUUID->
  "ae0d3919-f266-4f03-9121-31b3bca2f4a3"],
 " and ",
 StyleBox["b", "CodeVar"],
 " stamps of value ",
 Cell[BoxData[
  FormBox["B", TraditionalForm]],ExpressionUUID->
  "b1ac38ae-6c83-41ab-b5ad-e59c101a7f9f"],
 "."
}], "Text",ExpressionUUID->"1081f727-a142-4797-8c2d-d3301b9ec1fc"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop considers each of the basis cases (using the observation above). For \
each amount of postage, we use ",
 StyleBox["makePostage", "Code"],
 " to determine if it is possible to form that postage from the stamp values. \
If so, ",
 StyleBox["makePostage", "Code"],
 " returns a pair indicating how the desired postage is made and this is \
added to the ",
 StyleBox["postageList", "Code"],
 "."
}], "Text",ExpressionUUID->"ef00774e-c157-4ae5-8e35-0aef1136d830"],

Cell[TextData[{
 StyleBox[ButtonBox["Check",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Check"], "FunctionLink"],
 " evaluates its first argument, and the output of the ",
 StyleBox[ButtonBox["Check",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Check"], "FunctionLink"],
 " is the output of the first argument, unless a message had been raised, in \
which case the second argument is evaluated. If ",
 StyleBox["makePostage", "Code"],
 " ever returns ",
 StyleBox[ButtonBox["Null",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Null"], "FunctionLink"],
 ", that indicates the particular basis case cannot be verified. In this \
case, the message ",
 StyleBox["postageBasis::fail", "Code"],
 " is raised. If no messages are raised, that means every amount of postage \
succeeded and ",
 StyleBox["postageList", "Code"],
 ", the last expression of the first argument to ",
 StyleBox[ButtonBox["Check",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Check"], "FunctionLink"],
 " is output. "
}], "Text",ExpressionUUID->"ad185b6f-beb3-4d13-8df5-f6ed0def8fe5"],

Cell["\<\
The following indicates that it is false that every amount of postage of 12 \
cents or larger can be obtained using 4- and 6-cent stamps.\
\>", "Text",ExpressionUUID->"772e3028-1f39-4517-8b19-6e1dfb27913b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"postageBasis", "[", 
  RowBox[{"4", ",", "6", ",", "12"}], "]"}]], "Input",
 CellLabel->"In[36]:=",ExpressionUUID->"8e39bf1b-580e-4433-8d81-9b059946b05d"],

Cell[BoxData[
 TemplateBox[{
  "postageBasis","fail",
   "\"Cannot form postage of \\!\\(\\*RowBox[{\\\"13\\\"}]\\) using stamps of \
amounts \\!\\(\\*RowBox[{\\\"4\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"6\\\"}]\\).\"",2,36,2,22492403800461946764,"Local",
   "Global`postageBasis"},
  "MessageTemplate2"]], "Message", "MSG",
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"793a5ecc-8538-4c93-8a39-e68b22828f55"],

Cell[BoxData[
 TemplateBox[{
  "postageBasis","fail",
   "\"Cannot form postage of \\!\\(\\*RowBox[{\\\"15\\\"}]\\) using stamps of \
amounts \\!\\(\\*RowBox[{\\\"4\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"6\\\"}]\\).\"",2,36,3,22492403800461946764,"Local",
   "Global`postageBasis"},
  "MessageTemplate2"]], "Message", "MSG",
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"5fd150d3-68c2-49f0-af1c-7d1bdd7fd17d"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3 Recursive Definitions and Structural Induction", "Section",
 CellTags->"Section3",ExpressionUUID->"f7bb09c9-e3df-4653-a631-0a718b3538f3"],

Cell[TextData[{
 "In this section, we will show how functions and sets can be defined \
recursively in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",ExpressionUUID->"96f8dcde-48d9-4f6e-8e8b-212e1f99b190"],

Cell[CellGroupData[{

Cell["A Simple Recursive Function", "Subsection",
 CellTags->"Section3a",ExpressionUUID->"3c6f5a8b-3705-48ed-a025-2265f2e96a1b"],

Cell[TextData[{
 "First, we consider the recursively defined function from Example 1 in \
Section 5.3 of the text. This function is defined by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "0", ")"}], "=", "3"}], TraditionalForm]],
  ExpressionUUID->"4bf23a0b-ef0b-45ad-9e06-ec577c18d544"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"n", "+", "1"}], ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", "n", ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"acc09037-76dd-419a-bf71-22f5690151ea"],
 "."
}], "Text",ExpressionUUID->"cd2fad7f-faf9-4f11-af42-2a766b074f0b"],

Cell[TextData[{
 "In order to represent this function with the Wolfram Language, we must \
transform the recursive part of the definition into an equation for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "a2d28be8-6a0e-4f36-9c39-fe3279f524bf"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    RowBox[{"n", "+", "1"}], ")"}], TraditionalForm]],ExpressionUUID->
  "a879c5ed-a805-4be3-8b5c-40c2fc84961e"],
 ". We have to decrease all of the arguments in the recursive part of the \
definition by 1: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "n", ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"b75487db-1b44-4c2e-8cf0-d1f5e25c027c"],
 ". The formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"n", "+", "1"}], ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", "n", ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"ca312a14-8e72-4186-af45-3baddc6aa1f9"],
 " is perhaps more expressive in that the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "0e3d35d6-a254-4501-9415-3e69de472d79"],
 " suggests that the definition is about the \[OpenCurlyDoubleQuote]next\
\[CloseCurlyDoubleQuote] value of the function. However, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " cannot interpret ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "e988a77a-519b-4d10-98af-305d471f11cf"],
 " as a parameter in a function definition, at least not in a natural way."
}], "Text",ExpressionUUID->"42ad5d34-3586-47e8-8b9d-528615ae15c0"],

Cell[TextData[{
 "It is also important to point out that changing the recursive formula also \
changes the domain over which it is valid. The formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"n", "+", "1"}], ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", "n", ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"10a7dbd4-eff6-49ec-8813-a5cb42e596c4"],
 " applies for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[GreaterEqual]", "0"}], TraditionalForm]],ExpressionUUID->
  "f27e7912-2855-4d55-8640-fb57d0cbe54d"],
 ", while ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "n", ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"beb89a4a-d1c5-4e9a-970b-68aa052299c0"],
 " applies for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[GreaterEqual]", "1"}], TraditionalForm]],ExpressionUUID->
  "001030f4-e53d-43bb-8c7c-576d7ea8bd30"],
 ". This does not affect the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "n", ")"}], TraditionalForm]],ExpressionUUID->
  "af2902ec-715d-435e-912a-6c0b7ace86db"],
 " for any ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "986d18bc-2303-4833-afbb-a5a200c17f45"],
 "."
}], "Text",ExpressionUUID->"2b2f06bd-14a3-4807-a507-966bd7f15391"],

Cell[TextData[{
 "The most natural way to define a recursive function is to define the \
function just like any other. In this case, the function will refer to \
itself, but ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has no problem with that."
}], "Text",ExpressionUUID->"95c39884-b2ce-4175-a958-8804624a1cac"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"2", "*", 
    RowBox[{"f", "[", 
     RowBox[{"n", "-", "1"}], "]"}]}], "+", "3"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[37]:=",ExpressionUUID->"481ee305-53fe-415a-99cc-3d69137ae524"],

Cell[TextData[{
 "We also must define the basis step. To declare ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "0", ")"}], "=", "3"}], TraditionalForm]],
  ExpressionUUID->"fbd02333-57be-4d62-bfb1-66e9ecfabaec"],
 ", you make the assignment as shown below."
}], "Text",ExpressionUUID->"b10b0098-cbfc-445b-ba2f-ba9c663ad44d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "0", "]"}], "=", "3"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[38]:=",ExpressionUUID->"30c2ea0a-5628-4be0-a2b1-038345096464"],

Cell[BoxData["3"], "Output",
 CellLabel->"Out[38]=",ExpressionUUID->"7edf9e74-0f9d-4a75-8b73-c489ea13d6ed"]
}, Open  ]],

Cell[TextData[{
 "Note that the recursive part of the definition must be given as a ",
 StyleBox[ButtonBox["SetDelayed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SetDelayed"], "FunctionLink"],
 " (",
 StyleBox[":=", "Code"],
 "). The basis step can be defined with either ",
 StyleBox[ButtonBox["Set",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Set"], "FunctionLink"],
 " (",
 StyleBox["=", "Code"],
 ") or ",
 StyleBox[ButtonBox["SetDelayed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SetDelayed"], "FunctionLink"],
 " (",
 StyleBox[":=", "Code"],
 ")."
}], "Text",ExpressionUUID->"b1dc6fba-1431-416d-8618-42c6fa46fdc3"],

Cell[TextData[{
 "Now that the recursive definition and the basis step have been assigned, \
you can use ",
 StyleBox["f", "Code"],
 " like any other function."
}], "Text",ExpressionUUID->"28b44e23-7267-4baf-bc63-d91dfaf35cdc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "10", "]"}]], "Input",
 CellLabel->"In[39]:=",ExpressionUUID->"e152eb2c-dcff-4f8c-8f1b-4a4fb1b79e72"],

Cell[BoxData["6141"], "Output",
 CellLabel->"Out[39]=",ExpressionUUID->"56e77e17-2450-4f82-99e8-c24a1808f560"]
}, Open  ]],

Cell[TextData[{
 "Moreover, you can compute the values of ",
 StyleBox["f", "Code"],
 " from 1 to 9 using ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"95669d6f-a3b6-453b-bbfd-07c4b778b6e0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "9"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[40]:=",ExpressionUUID->"ef870385-7d1e-48d6-942b-cfefbaf05bb7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9", ",", "21", ",", "45", ",", "93", ",", "189", ",", "381", ",", "765", 
   ",", "1533", ",", "3069"}], "}"}]], "Output",
 CellLabel->"Out[40]=",ExpressionUUID->"f8b7a72b-e41c-4a02-8cdc-ae558a77a1f0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Down Values", "Subsubsection",ExpressionUUID->"5eda2463-7dbc-415f-8642-b14a91b4bb7a"],

Cell[TextData[{
 "It is worth understanding a bit of what ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is doing when you define and evaluate a recursively defined function. Any \
time you evaluate a function, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " checks the function\[CloseCurlyQuote]s list of \[OpenCurlyDoubleQuote]down \
values.\[CloseCurlyDoubleQuote] Briefly, the down values for a symbol are the \
expressions associated with the symbol when it is applied to arguments, as \
opposed to the symbol by itself. Here are the down values for the function ",
 StyleBox["f", "Code"],
 ". "
}], "Text",ExpressionUUID->"2f309107-db95-4511-90da-ab47ac001127"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DownValues", "[", "f", "]"}]], "Input",
 CellLabel->"In[41]:=",ExpressionUUID->"ffb01f96-4b99-4bf6-b663-54fd49c0dfea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"f", "[", "0", "]"}], "]"}], "\[RuleDelayed]", "3"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"f", "[", "n_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"f", "[", 
       RowBox[{"n", "-", "1"}], "]"}]}], "+", "3"}]}]}], "}"}]], "Output",
 CellLabel->"Out[41]=",ExpressionUUID->"293f0086-6984-49a3-b91b-308af77066f1"]
}, Open  ]],

Cell[TextData[{
 "This indicates that ",
 StyleBox["f", "Code"],
 " has two down values: one associated to the argument 0 and one associated \
to arguments matching the pattern ",
 StyleBox["n_", "Code"],
 "."
}], "Text",ExpressionUUID->"2f0b4fc7-588a-4100-b6a4-8870ff8c7c2e"],

Cell[TextData[{
 "Whenever you apply ",
 StyleBox[ButtonBox["Set",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Set"], "FunctionLink"],
 " (",
 StyleBox["=", "Code"],
 ") or ",
 StyleBox[ButtonBox["SetDelayed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SetDelayed"], "FunctionLink"],
 " (",
 StyleBox[":=", "Code"],
 ") with the left hand side of the operator of the form ",
 StyleBox["f[\[Ellipsis]]", "Code"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " understands this to be the creation or modification of one of ",
 StyleBox["f", "Code",
  IgnoreSpellCheck->True],
 StyleBox["\[CloseCurlyQuote]s",
  IgnoreSpellCheck->True],
 " down values. Note that such an assignment does not affect any down values \
other than the one, if any, whose left hand side has exactly the same form. \
Consequently, when dealing with recursive functions, it is a good idea to \
apply ",
 StyleBox[ButtonBox["Clear",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Clear"], "FunctionLink"],
 " to a function name when redefining a function, as this will remove all the \
down values for the symbol."
}], "Text",ExpressionUUID->"5336645b-efb1-4454-bdc5-0d9938b794f4"],

Cell[TextData[{
 "When you evaluate ",
 StyleBox["f", "Code"],
 " at a particular value, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " checks the more specific down values first. That is, if you enter ",
 StyleBox["f[0]", "Code"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will use the down value associated to ",
 StyleBox["f[0]", "Code"],
 " and output 3 rather than applying the formula ",
 StyleBox["2*f[0-1]+3", "Code"],
 "."
}], "Text",ExpressionUUID->"22db71ba-5fa3-4834-9180-190e38795ec2"],

Cell[TextData[{
 "If you apply ",
 StyleBox["f", "Code"],
 " to 0, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " sees that 0 has a specific down value and returns the value. If you apply ",
 StyleBox["f", "Code"],
 " to a different value, say 2, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not find a specific down value for 2 and so it applies the formula. \
The formula says that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "2", ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", "1", ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"3331746f-f123-4579-a38e-a437e8d5429a"],
 ". When ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " tries to evaluate this, it recognizes that it needs to find ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "1", ")"}], TraditionalForm]],ExpressionUUID->
  "a8d513b9-12f3-4a7a-8b33-518b6e9deb4b"],
 ". Again, it checks the down values and, not finding a result for 1, it \
applies the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "1", ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"f", "(", "0", ")"}]}], "+", "3"}]}], TraditionalForm]],
  ExpressionUUID->"8aa98d7a-ae56-4aab-ab65-a34e11bcc6f9"],
 ". Since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "0", ")"}], TraditionalForm]],ExpressionUUID->
  "cf5b2856-d9bf-49bd-918a-987b6d0232fd"],
 " has a specific value, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " looks up ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "0", ")"}], TraditionalForm]],ExpressionUUID->
  "dd1527f2-9c65-47fd-bd47-274762102cc2"],
 ", which allows it to compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "1", ")"}], "=", "9"}], TraditionalForm]],
  ExpressionUUID->"7702a45d-9986-4ffd-81e4-65a4c456cde4"],
 " and then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "2", ")"}], "=", "21"}], TraditionalForm]],
  ExpressionUUID->"dda0131d-90e3-4fb9-bbbb-0bf55241b70d"],
 "."
}], "Text",ExpressionUUID->"d8534b34-5de2-4026-be02-c5a2c28de99a"],

Cell[TextData[{
 "You may be wondering why the output above indicates that ",
 StyleBox["f", "Code",
  IgnoreSpellCheck->True],
 StyleBox["\[CloseCurlyQuote]s",
  IgnoreSpellCheck->True],
 " list of down values only has the value for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", "0", ")"}], TraditionalForm]],ExpressionUUID->
  "c3740709-9d89-41bc-93b6-fbd78e574cfb"],
 ", even though we have computed other values. The reason is that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not automatically store down values. Most of the time, you do not \
execute functions on the same input multiple times, so it would be a waste of \
memory to store every value computed. You have to explicitly tell ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to store down values."
}], "Text",ExpressionUUID->"39895587-edac-4f14-aab4-2438ee222742"],

Cell[TextData[{
 "We have seen that you can store a specific value as a down value by making \
an assignment such as ",
 StyleBox["f[0]=3", "Code"],
 ". An assignment of this form can be given within the body of a function. \
Doing so causes the function to store values as it calculates them, as we \
will see below."
}], "Text",ExpressionUUID->"d9b1d99b-15c7-4f93-98bb-a860110b1eba"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Second Recursive Function", "Subsection",
 CellTags->"Section3b",ExpressionUUID->"8e0d04b2-6c71-40ef-abbb-9335e015d7c0"],

Cell[TextData[{
 "Now, consider the function ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "cac4650c-1060-44fa-851f-2a069a761840"],
 " defined by the basis values ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "(", "0", ")"}], "=", "1"}], TraditionalForm]],
  ExpressionUUID->"f79f16ae-ecd4-487a-b29f-79df3b56a7d8"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "(", "1", ")"}], "=", "1"}], TraditionalForm]],
  ExpressionUUID->"09454f89-a021-487e-a397-d11effb8cf8c"],
 " and the recursive formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"F", "(", "n", ")"}], "=", 
    RowBox[{
     RowBox[{"F", "(", 
      RowBox[{"n", "-", "1"}], ")"}], "+", 
     RowBox[{"F", "(", 
      RowBox[{"n", "-", "2"}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "98d0adc2-7176-4f36-912c-9f4e1a74fccb"],
 ". This is the function whose values are the Fibonacci numbers."
}], "Text",ExpressionUUID->"d0df0366-436f-418f-9c2f-328efcf1a9bf"],

Cell["\<\
We will define this function as indicated above. First, we establish the \
basis values.\
\>", "Text",ExpressionUUID->"4c11c02a-efd8-49d4-a345-1ec5af5de640"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "0", "]"}], "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "1", "]"}], "=", "1"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[42]:=",ExpressionUUID->"d667a90f-e91e-4c69-9709-823811adc770"],

Cell["Note that these have been stored as down values.", "Text",ExpressionUUID->"60b0cfdd-eedd-443a-a585-76cef3fcb8d2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DownValues", "[", "F", "]"}]], "Input",
 CellLabel->"In[44]:=",ExpressionUUID->"696334fc-b253-4219-a2b4-8af544100615"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "0", "]"}], "]"}], "\[RuleDelayed]", "1"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "1", "]"}], "]"}], "\[RuleDelayed]", "1"}]}], 
  "}"}]], "Output",
 CellLabel->"Out[44]=",ExpressionUUID->"c34abee3-0453-4ffc-ac64-9047a8c3fe50"]
}, Open  ]],

Cell["\<\
For the recursive part of the definition, we enter the following.\
\>", "Text",ExpressionUUID->"47eeb557-4a10-4da4-944f-4c486f04c8c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"F", "[", "n", "]"}], "=", 
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"n", "-", "1"}], "]"}], "+", 
    RowBox[{"F", "[", 
     RowBox[{"n", "-", "2"}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[45]:=",ExpressionUUID->"ef0aded6-64b4-4ac6-93c1-3efd0fd70bc6"],

Cell[TextData[{
 "This may look a bit strange, but it is actually fairly straightforward. The \
expression is an application of ",
 StyleBox[ButtonBox["SetDelayed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SetDelayed"], "FunctionLink"],
 " (",
 StyleBox[":=", "Code"],
 "), which is an assignment to the symbol ",
 StyleBox["F", "Code"],
 " with argument matching the pattern ",
 StyleBox["n_", "Code"],
 ", that is, with any argument. Note that this has created a single entry in \
the down values list."
}], "Text",ExpressionUUID->"30137ac9-0392-45b6-9a3f-4e228318e5cd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DownValues", "[", "F", "]"}]], "Input",
 CellLabel->"In[46]:=",ExpressionUUID->"e25f77e6-a226-40c8-a639-db1107c158de"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "0", "]"}], "]"}], "\[RuleDelayed]", "1"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "1", "]"}], "]"}], "\[RuleDelayed]", "1"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "n_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"F", "[", "n", "]"}], "=", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "+", 
       RowBox[{"F", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellLabel->"Out[46]=",ExpressionUUID->"c6f8d2a3-5082-4fc2-9cb8-ab561aacf06b"]
}, Open  ]],

Cell[TextData[{
 "The \[OpenCurlyDoubleQuote]value\[CloseCurlyDoubleQuote] associated to ",
 StyleBox["F", "Code"],
 " with argument matching ",
 StyleBox["n_", "Code"],
 " is the expression ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "n", "]"}], "=", 
   RowBox[{"F", "[", 
    RowBox[{"n", "-", "1"}], "]"}], "+", 
   RowBox[{"F", "[", 
    RowBox[{"n", "-", "2"}], "]"}]}]], "myCode",ExpressionUUID->
  "fea679a4-c25b-462c-96fe-e35c9e573c60"],
 ". It can be useful to think of ",
 StyleBox["F", "Code"],
 " as representing both a function and a computer program. Assigning ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "0", "]"}], "=", "1"}]], "myCode",ExpressionUUID->
  "bba52754-0e3e-4d29-a6ff-3b2d93b3e5f8"],
 " and ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "1", "]"}], "=", "1"}]], "myCode",ExpressionUUID->
  "4b908a6d-c8a2-4577-9a61-f537c1d04da2"],
 " establish the basis values for the function ",
 StyleBox["F", "Code"],
 ". Setting ",
 StyleBox["F[n_]", "Code"],
 " defines the action of the program ",
 StyleBox["F", "Code"],
 ". That program has a single line of code which is ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"F", "[", "n", "]"}], "=", 
   RowBox[{"F", "[", 
    RowBox[{"n", "-", "1"}], "]"}], "+", 
   RowBox[{"F", "[", 
    RowBox[{"n", "-", "2"}], "]"}]}]], "myCode",ExpressionUUID->
  "b9572c53-53aa-4ee3-a253-12e8ad835597"],
 ". That line of code in the program sets a particular value of the function ",
 StyleBox["F", "Code"],
 "."
}], "Text",ExpressionUUID->"8ce3da16-0776-413e-91b3-4ab0200cb682"],

Cell[TextData[{
 "The function ",
 StyleBox["F", "Code"],
 " is now completely defined and produces correct output."
}], "Text",ExpressionUUID->"4636cecc-8f7b-49b7-a9c1-de28e2351831"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"F", "[", "n", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[47]:=",ExpressionUUID->"d933c04b-d664-4fde-b3ea-a09daff60443"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "2", ",", "3", ",", "5", ",", "8", ",", "13", ",", "21",
    ",", "34", ",", "55", ",", "89"}], "}"}]], "Output",
 CellLabel->"Out[47]=",ExpressionUUID->"a0f0dfa7-330f-45f4-8c8b-b25c89255d44"]
}, Open  ]],

Cell[TextData[{
 "Observe that, unlike the function ",
 StyleBox["f", "Code"],
 " above, ",
 StyleBox["F", "Code"],
 " has added the results of its calculations to its down values."
}], "Text",ExpressionUUID->"12f04348-4526-4051-abe4-bc3cc6b11d70"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DownValues", "[", "F", "]"}]], "Input",
 CellLabel->"In[48]:=",ExpressionUUID->"540f7d4a-49d0-49f0-8cc4-dc3eecee9f20"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "0", "]"}], "]"}], "\[RuleDelayed]", "1"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "1", "]"}], "]"}], "\[RuleDelayed]", "1"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "2", "]"}], "]"}], "\[RuleDelayed]", "2"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "3", "]"}], "]"}], "\[RuleDelayed]", "3"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "4", "]"}], "]"}], "\[RuleDelayed]", "5"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "5", "]"}], "]"}], "\[RuleDelayed]", "8"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "6", "]"}], "]"}], "\[RuleDelayed]", "13"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "7", "]"}], "]"}], "\[RuleDelayed]", "21"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "8", "]"}], "]"}], "\[RuleDelayed]", "34"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "9", "]"}], "]"}], "\[RuleDelayed]", "55"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "10", "]"}], "]"}], "\[RuleDelayed]", "89"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"F", "[", "n_", "]"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"F", "[", "n", "]"}], "=", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"n", "-", "1"}], "]"}], "+", 
       RowBox[{"F", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellLabel->"Out[48]=",ExpressionUUID->"2fd07ac5-13e0-44a4-9401-be99445bb698"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparing Complexity", "Subsection",
 CellTags->"Section3c",ExpressionUUID->"a487e06b-c4e0-4a04-b37b-bef3df9bd215"],

Cell[TextData[{
 "The difference in time complexity between a recursive function that stores \
computed values and one that does not is very significant, perhaps much more \
than you might think. To illustrate this, we create two new functions, both \
of which model the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "n", ")"}], "=", 
    RowBox[{
     RowBox[{"2", "\[CenterDot]", 
      RowBox[{"g", "(", 
       RowBox[{"n", "-", "1"}], ")"}]}], "+", 
     RowBox[{"3", "\[CenterDot]", 
      RowBox[{"g", "(", 
       RowBox[{"n", "-", "2"}], ")"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"dfc09064-5e28-45db-bdab-85796c6acad2"],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "0", ")"}], "=", "5"}], TraditionalForm]],
  ExpressionUUID->"604cd02a-f978-48de-a370-245558481b9c"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "1", ")"}], "=", "2"}], TraditionalForm]],
  ExpressionUUID->"a8d7be96-7577-4521-ba22-64834e3d52a7"],
 ". The function ",
 StyleBox["gR", "Code"],
 " will \[OpenCurlyDoubleQuote]remember\[CloseCurlyDoubleQuote] computed \
values while ",
 StyleBox["gF", "Code"],
 " will be \[OpenCurlyDoubleQuote]forgetful\[CloseCurlyDoubleQuote] and not \
store values."
}], "Text",ExpressionUUID->"57f47e80-d585-44fc-a9b5-3c343781fd97"],

Cell[TextData[{
 "We will track the recursive calls by adding a ",
 StyleBox[ButtonBox["Print",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Print"], "FunctionLink"],
 " statement every time the formula is used. Here are the two functions."
}], "Text",ExpressionUUID->"8da5c269-39f6-488e-98a3-4ae3b3d97f76"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gR", "[", "n_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Computing gR[\>\"", ",", "n", ",", "\"\<]\>\""}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gR", "[", "n", "]"}], "=", 
      RowBox[{
       RowBox[{"2", "*", 
        RowBox[{"gR", "[", 
         RowBox[{"n", "-", "1"}], "]"}]}], "+", 
       RowBox[{"3", "*", 
        RowBox[{"gR", "[", 
         RowBox[{"n", "-", "2"}], "]"}]}]}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gR", "[", "0", "]"}], "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gR", "[", "1", "]"}], "=", "2"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[49]:=",ExpressionUUID->"29a5cd36-fb53-4c83-b441-d4943898f49a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gF", "[", "n_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Computing gF[\>\"", ",", "n", ",", "\"\<]\>\""}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"2", "*", 
       RowBox[{"gF", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}], "+", 
      RowBox[{"3", "*", 
       RowBox[{"gF", "[", 
        RowBox[{"n", "-", "2"}], "]"}]}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gF", "[", "0", "]"}], "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gF", "[", "1", "]"}], "=", "2"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[52]:=",ExpressionUUID->"aeca2099-d9dd-442d-8b64-af48a904e3fb"],

Cell[TextData[{
 "Observe what happens when we attempt to compute ",
 StyleBox["gR[5]", "Code"],
 "."
}], "Text",ExpressionUUID->"f98cbdff-1a59-4bdc-9419-51f46d7df001"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gR", "[", "5", "]"}]], "Input",
 CellLabel->"In[55]:=",ExpressionUUID->"4893e7dd-ab93-4b1f-87e7-0dafeba3ac2f"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gR[\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gR[", 5, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[55]:=",ExpressionUUID->"865ac51d-998b-48a2-9a0d-52fc46c52e06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gR[\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gR[", 4, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[55]:=",ExpressionUUID->"12c047ec-6cc0-481b-9bca-a98fde7b8e09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gR[\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gR[", 3, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[55]:=",ExpressionUUID->"917cbce6-751a-4d76-ac23-418c80e127d1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gR[\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gR[", 2, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[55]:=",ExpressionUUID->"ff216474-d58e-425f-b110-a5c857fc4b7b"]
}, Open  ]],

Cell[BoxData["422"], "Output",
 CellLabel->"Out[55]=",ExpressionUUID->"b7d62492-c585-41ce-8572-25abe13f706c"]
}, Open  ]],

Cell[TextData[{
 "This appears fairly straightforward. We enter ",
 StyleBox["gR[5]", "Code"],
 ", and since this has not been stored as a down value, the function body is \
evaluated, causing the print statement to be executed. Then, since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "5", ")"}], TraditionalForm]],ExpressionUUID->
  "27abb441-9a7f-4e09-9662-082017bf40db"],
 " depends on ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "4", ")"}], TraditionalForm]],ExpressionUUID->
  "20661195-cea4-4403-b876-dd6006b1e35c"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "3", ")"}], TraditionalForm]],ExpressionUUID->
  "5cb98268-3712-41f3-aad2-3615aec78ee3"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needs to know, first, the value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "4", ")"}], TraditionalForm]],ExpressionUUID->
  "48270d40-2628-40a7-89ea-0e9051865461"],
 ". Since this has not been previously computed, again the formula needs to \
be invoked causing ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to print \[OpenCurlyDoubleQuote]",
 StyleBox["Computing gR[4]", "Code"],
 "\[CloseCurlyDoubleQuote]. Computing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "4", ")"}], TraditionalForm]],ExpressionUUID->
  "57c02cb3-d74f-4efb-933c-f748d1d58fb3"],
 " requires the values for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "3", ")"}], TraditionalForm]],ExpressionUUID->
  "52251fea-de48-4830-9226-e9a9b80d1bed"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "2", ")"}], TraditionalForm]],ExpressionUUID->
  "9724f950-e73f-4ff9-81e1-732d71569032"],
 ". Again, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "3", ")"}], TraditionalForm]],ExpressionUUID->
  "ddaf67fb-1fd3-4e95-8663-526ec6044cf3"],
 " is needed first, so ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " executes ",
 StyleBox["gR[3]", "Code"],
 ". This requires ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "2", ")"}], TraditionalForm]],ExpressionUUID->
  "753aa41f-fb02-4b2c-abb1-38df74acc13f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "1", ")"}], TraditionalForm]],ExpressionUUID->
  "cece0d8e-7de3-4d2c-9a74-0c3844b73dcf"],
 ". To obtain the value for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "2", ")"}], TraditionalForm]],ExpressionUUID->
  "557fd029-95c0-4e5e-87f1-3e4229cc25f9"],
 ", the formula must be invoked once again. "
}], "Text",ExpressionUUID->"c226853d-fe48-4b4f-8772-6f065c078eba"],

Cell[TextData[{
 "After printing \[OpenCurlyDoubleQuote]",
 StyleBox["Computing gR[2]", "Code"],
 "\[CloseCurlyDoubleQuote], ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needs to evaluate the expression ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"gR", "[", "2", "]"}], "=", "2", "*", 
   RowBox[{"gR", "[", "1", "]"}], "+", "3", "*", 
   RowBox[{"gR", "[", "0", "]"}]}]], "myCode",ExpressionUUID->
  "b38c8fd7-f447-457d-8c41-3eba11ea36e6"],
 ". This time, it can look to the stored values of ",
 StyleBox["gR[1]", "Code"],
 " and ",
 StyleBox["gR[0]", "Code"],
 " to compute that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "2", ")"}], "=", "19"}], TraditionalForm]],
  ExpressionUUID->"107a9fd0-36d7-45af-93f0-90b1ff99f489"],
 ". This value is stored as a down value of ",
 StyleBox["gR", "Code"],
 ", and we begin unwinding. ",
 StyleBox["gR[2]", "Code"],
 " was called when attempting to compute ",
 StyleBox["gR[3]", "Code"],
 ", which depends on values for 2 and 1. Since ",
 StyleBox["gR[2]", "Code"],
 " was just returned and ",
 StyleBox["gR[1]", "Code"],
 " is stored, ",
 StyleBox["gR[3]", "Code"],
 " can be computed and stored. The value of ",
 StyleBox["gR[3]", "Code"],
 " is sent back up to the computation of ",
 StyleBox["gR[4]", "Code"],
 ". ",
 StyleBox["gR[4]", "Code"],
 " depends on values of 3 and 2 and both of those values are now available, \
so ",
 StyleBox["gR[4]", "Code"],
 " can be computed. Likewise, ",
 StyleBox["gR[5]", "Code"],
 " can be determined using the values of ",
 StyleBox["gR[4]", "Code"],
 " and ",
 StyleBox["gR[3]", "Code"],
 "."
}], "Text",ExpressionUUID->"e3b303de-059d-4377-8a03-9d6e4feaea71"],

Cell[TextData[{
 "Contrast that with what happens for ",
 StyleBox["gF[5]", "Code"],
 "."
}], "Text",ExpressionUUID->"c2b9efe5-b214-4c23-9e27-9508ef8f8cbd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gF", "[", "5", "]"}]], "Input",
 CellLabel->"In[56]:=",ExpressionUUID->"5bce7d72-53ef-4c30-bbfa-3dd3d19c0286"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 5, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"6d1ffc0f-cee9-4908-9435-be9f61b3295d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 4, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"d61f2678-440e-4a89-bb5e-f3b9143830bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 3, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"3b62cd9c-7a86-4652-b930-4af8b319ceee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 2, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"e68c4e57-028f-49e4-89b1-2858f1f385dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 2, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"3caba6c7-fcba-418f-bb98-42d58d7c11a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 3, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"4381fea8-faf0-479e-bd29-478690fa4bfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Computing gF[\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"]\"\>"}],
  SequenceForm["Computing gF[", 2, "]"],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"e599ac23-0e75-47d3-b472-0db1bc9a15e8"]
}, Open  ]],

Cell[BoxData["422"], "Output",
 CellLabel->"Out[56]=",ExpressionUUID->"a0db8ae5-c3c2-40fe-b2c3-2213861c9f3c"]
}, Open  ]],

Cell[TextData[{
 "Things begin the same. We execute ",
 StyleBox["gF[5]", "Code"],
 " causing the print statement to report the fact that we are computing that \
value. To obtain ",
 StyleBox["gF[5]", "Code"],
 ", we need the values of ",
 StyleBox["gF[4]", "Code"],
 " and ",
 StyleBox["gF[3]", "Code"],
 ". ",
 StyleBox["gF[4]", "Code"],
 " is computed first, since it is leftmost in the formula and \
\[OpenCurlyDoubleQuote]",
 StyleBox["Computing gF[4]", "Code"],
 "\[CloseCurlyDoubleQuote] is displayed. To obtain the value for 4, we need \
the values for 3 and 2, and so ",
 StyleBox["gF[3]", "Code"],
 " is executed. This requires the values for ",
 StyleBox["gF[2]", "Code"],
 " and ",
 StyleBox["gF[1]", "Code"],
 ". Again, since it is leftmost, ",
 StyleBox["gF[2]", "Code"],
 " is tackled first, causing \[OpenCurlyDoubleQuote]",
 StyleBox["Computing gF[2]", "Code"],
 "\[CloseCurlyDoubleQuote] to be displayed. "
}], "Text",ExpressionUUID->"06c698ff-c667-4a5e-8988-9f2eef6faa30"],

Cell[TextData[{
 "This value can be computed from the stored values ",
 StyleBox["gF[1]", "Code"],
 " and ",
 StyleBox["gF[0]", "Code"],
 ". That means that ",
 StyleBox["gF[2]", "Code"],
 ", which was invoked in the attempt to compute ",
 StyleBox["gF[3]", "Code"],
 ", is complete and we move back up to the computation of ",
 StyleBox["gF[3]", "Code"],
 ". Since ",
 StyleBox["gF[3]", "Code"],
 " depends on the recently computed ",
 StyleBox["gF[2]", "Code"],
 " and on ",
 StyleBox["gF[1]", "Code"],
 ", which was stored as an initial condition, ",
 StyleBox["gF[3]", "Code"],
 " can be computed as well."
}], "Text",ExpressionUUID->"8942ea12-fc53-4638-a744-8a1983f356f3"],

Cell[TextData[{
 "This means that ",
 StyleBox["gF[4]", "Code"],
 " now knows the value of ",
 StyleBox["gF[3]", "Code"],
 ". You can think about it as if the formula ",
 StyleBox["gF[4]", "Code"],
 " is working with is now ",
 Cell[BoxData[
  RowBox[{"2", "*", "44", "+", "3", "*", 
   RowBox[{"gF", "[", "2", "]"}]}]], "myCode",ExpressionUUID->
  "c7efb5a2-cf8b-4041-bc99-570b4696a03d"],
 ". To complete the calculation, ",
 StyleBox["gF[4]", "Code"],
 " now just needs the value of ",
 StyleBox["gF[2]", "Code"],
 ". The ",
 StyleBox["gR", "Code"],
 " implementation could just look that value up, since it had recorded the \
value ",
 StyleBox["gR[2]", "Code"],
 " when it was first computed. In contrast, ",
 StyleBox["gF", "Code"],
 " is not storing values that are computed, so it must apply the formula to \
compute ",
 StyleBox["gF[2]", "Code"],
 " again. Thus, \[OpenCurlyDoubleQuote]",
 StyleBox["Computing gF[2]", "Code"],
 "\[CloseCurlyDoubleQuote] is displayed a second time. Once the formula has \
been used again to compute ",
 StyleBox["gF[2]", "Code"],
 ", then this value is available to ",
 StyleBox["gF[4]", "Code"],
 " to complete its computation."
}], "Text",ExpressionUUID->"47a9948b-2a24-421d-b642-3e36004cec1b"],

Cell[TextData[{
 "Once ",
 StyleBox["gF[4]", "Code"],
 " has finished computing, that value is sent up. That means ",
 StyleBox["gF[5]", "Code"],
 ", which required ",
 StyleBox["gF[4]", "Code"],
 " and ",
 StyleBox["gF[3]", "Code"],
 ", now knows one of the two values it required. But again, ",
 StyleBox["gF[3]", "Code"],
 ", which was computed as part of ",
 StyleBox["gF[4]", "Code"],
 ", must be computed all over again. Consequently, you see the message \
\[OpenCurlyDoubleQuote]",
 StyleBox["Computing gF[3]", "Code"],
 "\[CloseCurlyDoubleQuote] again. And ",
 StyleBox["gF[3]", "Code"],
 " requires the value for 2, so ",
 StyleBox["gF[2]", "Code"],
 " must be executed a third time. "
}], "Text",ExpressionUUID->"538d5cf4-b340-4051-8e44-b5c219a587e3"],

Cell["\<\
As you can imagine, the difference between storing values and not is even \
more extreme for larger input values. When values are stored, once the \
recursion starts working its way back up the ladder, it remembers all the \
results from the lower values. When values are not stored, the chain of \
recursive calls has to keep recomputing the results from lower valued inputs.\
\
\>", "Text",ExpressionUUID->"84a18173-070f-4df8-97d4-0797013dcda2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Recursive Function with Two Parameters", "Subsection",
 CellTags->"Section3d",ExpressionUUID->"85773493-3e26-4a68-8bfd-98c3f51828fa"],

Cell[TextData[{
 "In Example 13 of Section 5.3 of the text, the sequence ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "8793795e-52f0-4d77-aa09-4c8824837143"],
 " is defined. We will define a function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", 
    RowBox[{"m", ",", "n"}], ")"}], TraditionalForm]],ExpressionUUID->
  "c1354d2e-ea60-4d23-afc7-2dbb279115ff"],
 " that models the sequence ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "a673fbb3-9fa0-4376-ac5f-f9e607dc700b"],
 ". The basis value is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"A", "(", 
     RowBox[{"0", ",", "0"}], ")"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"423b71a8-db8f-4d07-b38d-ac2d771370ac"],
 ", and the recursion formula is"
}], "Text",ExpressionUUID->"8c513f6d-a79e-4c01-ac5d-3b3197494e2d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"A", "(", 
    RowBox[{"m", ",", "n"}], ")"}], "=", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{"A", "(", 
            RowBox[{
             RowBox[{"m", "-", "1"}], ",", "n"}], ")"}], "+", "1"}], 
          RowBox[{
           RowBox[{"if", " ", "n"}], "=", 
           RowBox[{
            RowBox[{"0", " ", "and", " ", "m"}], ">", "0"}]}]},
         {
          RowBox[{
           RowBox[{"A", "(", 
            RowBox[{"m", ",", 
             RowBox[{"n", "-", "1"}]}], ")"}], "+", "n"}], 
          RowBox[{
           RowBox[{"if", " ", "n"}], ">", "0"}]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], TraditionalForm]], "Equation",ExpressionUUID->\
"06a28f02-b3f1-4aa0-90ac-9fa6ab970122"],

Cell["\<\
As with the previous example, we will define the function so as to store \
values. The initial value is as follows.\
\>", "Text",ExpressionUUID->"0a2c533e-4138-4249-b0ea-b42b3f578f79"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"0", ",", "0"}], "]"}], "=", "0"}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[57]:=",ExpressionUUID->"d5f87922-b6cd-4515-b321-8a160895b594"],

Cell[TextData[{
 "We will define the recursive formula using a ",
 StyleBox[ButtonBox["Which",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Which"], "FunctionLink"],
 ". Recall that the ",
 StyleBox[ButtonBox["Which",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Which"], "FunctionLink"],
 " function accepts an even number of arguments, with the first in each pair \
a condition and the second in the pair evaluated if the condition holds."
}], "Text",ExpressionUUID->"74a9969f-9eb9-43df-bfb5-65c9d4fbcccc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"A", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"n", "\[Equal]", "0"}], "&&", 
      RowBox[{"m", ">", "0"}]}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{
        RowBox[{"m", "-", "1"}], ",", "n"}], "]"}], "+", "1"}], ",", 
     RowBox[{"n", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"A", "[", 
       RowBox[{"m", ",", 
        RowBox[{"n", "-", "1"}]}], "]"}], "+", "n"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[58]:=",ExpressionUUID->"f440e5ef-b948-4af4-b3b9-3e8f93b79da4"],

Cell[TextData[{
 "We can now compute some values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "ac87d5a1-3070-45ba-a3d0-21af795e5159"],
 "."
}], "Text",ExpressionUUID->"8c13c252-5089-4cce-a7ee-f3a44ae8099f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "[", 
  RowBox[{"3", ",", "2"}], "]"}]], "Input",
 CellLabel->"In[59]:=",ExpressionUUID->"a825eb8e-5359-4bf6-8517-1f7e51f7afb1"],

Cell[BoxData["6"], "Output",
 CellLabel->"Out[59]=",ExpressionUUID->"f1789ea4-5995-4fc4-9553-8063bc30f69f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A", "[", 
  RowBox[{"5", ",", "3"}], "]"}]], "Input",
 CellLabel->"In[60]:=",ExpressionUUID->"b5baba4b-ae0f-4ec6-8222-0f8c55a89760"],

Cell[BoxData["11"], "Output",
 CellLabel->"Out[60]=",ExpressionUUID->"511193d1-0647-4433-afe1-a0b9569a19ff"]
}, Open  ]],

Cell[TextData[{
 "To get a better idea of what the values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", 
    RowBox[{"m", ",", "n"}]], TraditionalForm]],ExpressionUUID->
  "18aded4e-2260-4fc4-a188-a4ba274fb04e"],
 " are, we can display a ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " of them using ",
 StyleBox[ButtonBox["TableForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TableForm"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"28740364-0524-407c-803b-651b98622eee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"m", ",", "n"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "0", ",", "10"}], "}"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellLabel->"In[61]:=",ExpressionUUID->"bf972878-1983-42ca-bf6c-38ec56d0ad9e"],

Cell[BoxData[
 TagBox[GridBox[{
    {"0", "1", "3", "6", "10", "15", "21", "28", "36", "45", "55"},
    {"1", "2", "4", "7", "11", "16", "22", "29", "37", "46", "56"},
    {"2", "3", "5", "8", "12", "17", "23", "30", "38", "47", "57"},
    {"3", "4", "6", "9", "13", "18", "24", "31", "39", "48", "58"},
    {"4", "5", "7", "10", "14", "19", "25", "32", "40", "49", "59"},
    {"5", "6", "8", "11", "15", "20", "26", "33", "41", "50", "60"},
    {"6", "7", "9", "12", "16", "21", "27", "34", "42", "51", "61"},
    {"7", "8", "10", "13", "17", "22", "28", "35", "43", "52", "62"},
    {"8", "9", "11", "14", "18", "23", "29", "36", "44", "53", "63"},
    {"9", "10", "12", "15", "19", "24", "30", "37", "45", "54", "64"},
    {"10", "11", "13", "16", "20", "25", "31", "38", "46", "55", "65"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellLabel->
  "Out[61]//TableForm=",ExpressionUUID->"c8663912-51a8-4d9f-a66e-\
70f2b715e136"]
}, Open  ]],

Cell[TextData[{
 "Note that the first variable to be specified is shown in rows. That is, the \
first row corresponds to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "0"}], TraditionalForm]],ExpressionUUID->
  "600f59c4-84fd-4045-b845-9400f62f4078"],
 ", the second row has ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "da9217bb-7497-4ada-a877-25156597324c"],
 ", etc.",
 Cell[BoxData[
  FormBox[
  Cell["",ExpressionUUID->"c0684800-e93a-4405-b271-3062d4d9ef29"], 
   TraditionalForm]],ExpressionUUID->"1d159482-a013-4abd-9277-93c6fc956a2a"]
}], "Text",ExpressionUUID->"b187f112-bf09-48d8-864a-7805167fb220"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Recursively Defined Set", "Subsection",
 CellTags->"Section3e",ExpressionUUID->"0ec5e852-727e-4b2e-96fa-1d963cdc75de"],

Cell["\<\
Example 5 of the text illustrates a recursive definition of a set. Here, we \
will consider a slightly more complicated example. \
\>", "Text",ExpressionUUID->"81ed7a51-7f4a-429c-a1bb-0796c7cc76ee"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox["S", TraditionalForm]],ExpressionUUID->
  "3ce522a0-0e30-45f0-a0c3-8b46751d8d10"],
 " be the subset of the integers defined by:"
}], "Text",ExpressionUUID->"36d23279-a949-4aae-a0ac-3e07f36141bb"],

Cell[TextData[{
 "Basis step: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "\[Element]", "S"}], TraditionalForm]],ExpressionUUID->
  "ed9e5e68-c587-4897-908a-dded96ce32c3"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"7", "\[Element]", "S"}], TraditionalForm]],ExpressionUUID->
  "7389d5f3-8c3a-43ea-853a-c01f6af96515"],
 "."
}], "Text",
 CellMargins->{{24, 10}, {3, 
  0}},ExpressionUUID->"d3814a22-b8df-461c-8c27-ebdbe66b8237"],

Cell[TextData[{
 "Recursive step: if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[Element]", "S"}], TraditionalForm]],ExpressionUUID->
  "16d76c93-b8a8-42c3-b596-80a52f72121c"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "\[Element]", "S"}], TraditionalForm]],ExpressionUUID->
  "c53ab7bc-f5fb-4466-8494-0d67160dbad8"],
 ", then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "+", "y"}], "\[Element]", "S"}], TraditionalForm]],
  ExpressionUUID->"0bbf43b8-4b05-4444-89e5-126622f53613"],
 "."
}], "Text",
 CellMargins->{{24, 10}, {3, 
  0}},ExpressionUUID->"00b54168-75a3-4f84-8a2f-35b86e413554"],

Cell["\<\
(Note that this is the set of all postage that can be formed with 4- and \
7-cent stamps.)\
\>", "Text",ExpressionUUID->"c4950207-eae4-4e15-bbee-d3270187bad0"],

Cell[TextData[{
 "To model ",
 Cell[BoxData[
  FormBox["S", TraditionalForm]],ExpressionUUID->
  "734b93f5-baa6-4554-9358-bc124d8a81e4"],
 " in the Wolfram Language, we will define a list that includes the elements \
called for in the basis step. For the recursive step, we will define a \
function that applies the recursion to the set."
}], "Text",ExpressionUUID->"389cfaa7-5984-4f24-ab41-8fa51b75a3c0"],

Cell[TextData[{
 "The basis step requires that 4 and 7 are members of ",
 Cell[BoxData[
  FormBox["S", TraditionalForm]],ExpressionUUID->
  "4ae0c551-6424-409d-a945-f6c23bfe8008"],
 ", so we define ",
 StyleBox["S", "Code"],
 " to be the list consisting of 4 and 7."
}], "Text",ExpressionUUID->"18e635bf-2e0c-4004-b3bc-eec142b743d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "=", 
  RowBox[{"{", 
   RowBox[{"4", ",", "7"}], "}"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[62]:=",ExpressionUUID->"49e4bf31-bcbe-47a5-86c5-2cb2ca506c5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "7"}], "}"}]], "Output",
 CellLabel->"Out[62]=",ExpressionUUID->"05d258d2-10ae-4a30-b7bd-62bea920fa37"]
}, Open  ]],

Cell[TextData[{
 "To implement the recursive step, we will create a function ",
 StyleBox["recurseS", "Code"],
 ". This function will accept as input the current ",
 StyleBox["S", "Code"],
 " and will return the list obtained after applying the recursive rule. For \
instance, in the first application of ",
 StyleBox["recurseS", "Code"],
 ", the procedure needs to add ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "+", "4"}], TraditionalForm]],ExpressionUUID->
  "4c686899-3601-4e39-ad27-fccf0b8dac68"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "+", "7"}], TraditionalForm]],ExpressionUUID->
  "881d35d0-e21f-4af6-b71d-f2e7e6cbe87c"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"7", "+", "4"}], TraditionalForm]],ExpressionUUID->
  "a3e38e38-3e10-4d54-b559-f313553d5ed1"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"7", "+", "7"}], TraditionalForm]],ExpressionUUID->
  "646eec2f-d751-4b86-97d1-309c6cb19695"],
 ". (We will eliminate duplication by applying the ",
 StyleBox[ButtonBox["Union",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Union"], "FunctionLink"],
 " function.)"
}], "Text",ExpressionUUID->"6d1f16df-108d-4409-9dd6-db16b2d2ce1d"],

Cell[TextData[{
 "We will use a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop. Recall that in a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop, the first argument is the expression that is evaluated. Subsequent \
arguments specify the loop variables. Also recall that a variable \
specification of the form ",
 Cell[BoxData[
  RowBox[{"{", 
   StyleBox["i", "CodeVar"], ",", 
   StyleBox["list", "CodeVar"], "}"}]], "myCode",ExpressionUUID->
  "4a02dbb5-db60-4e98-a3e9-c2940973b733"],
 " causes ",
 StyleBox["i", "CodeVar"],
 " to take on each element of the ",
 StyleBox["list", "CodeVar"],
 "."
}], "Text",ExpressionUUID->"f211502f-eb86-4352-bb18-816e741fd2c8"],

Cell["Here is the function.", "Text",ExpressionUUID->"85e5d70d-7cbc-4876-b547-e2f6c8cc55f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"recurseS", "[", "S_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", 
      RowBox[{"T", "=", "S"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"T", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"T", ",", 
          RowBox[{"{", 
           RowBox[{"x", "+", "y"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "S"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "S"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "T"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[63]:=",ExpressionUUID->"7a591fbd-efd1-4c27-9939-756bcb666e5b"],

Cell[TextData[{
 "Now, apply this function to ",
 StyleBox["S", "Code"],
 "."
}], "Text",ExpressionUUID->"90353718-3a8b-4587-a588-d7d8826033a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "=", 
  RowBox[{"recurseS", "[", "S", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[64]:=",ExpressionUUID->"8afd1e7e-4e8a-4c34-ba10-571d303ba712"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4", ",", "7", ",", "8", ",", "11", ",", "14"}], "}"}]], "Output",
 CellLabel->"Out[64]=",ExpressionUUID->"228bcfb2-107b-412d-99f8-7290a1fae06f"]
}, Open  ]],

Cell["After a second iteration:", "Text",ExpressionUUID->"52a90d46-03d4-47ec-93ef-e47a41e45878"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "=", 
  RowBox[{"recurseS", "[", "S", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[65]:=",ExpressionUUID->"8f9d06f1-7d90-47a5-a224-1bf2d15421b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "7", ",", "8", ",", "11", ",", "12", ",", "14", ",", "15", ",", 
   "16", ",", "18", ",", "19", ",", "21", ",", "22", ",", "25", ",", "28"}], 
  "}"}]], "Output",
 CellLabel->"Out[65]=",ExpressionUUID->"80e20233-c76d-4422-a661-7f4d59bce130"]
}, Open  ]],

Cell["A third:", "Text",ExpressionUUID->"3091bf33-8caa-4d92-b1b7-ed5af663ef0b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "=", 
  RowBox[{"recurseS", "[", "S", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[66]:=",ExpressionUUID->"3cc2645e-2915-40e2-b744-604689bae2bb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "7", ",", "8", ",", "11", ",", "12", ",", "14", ",", "15", ",", 
   "16", ",", "18", ",", "19", ",", "20", ",", "21", ",", "22", ",", "23", 
   ",", "24", ",", "25", ",", "26", ",", "27", ",", "28", ",", "29", ",", 
   "30", ",", "31", ",", "32", ",", "33", ",", "34", ",", "35", ",", "36", 
   ",", "37", ",", "38", ",", "39", ",", "40", ",", "41", ",", "42", ",", 
   "43", ",", "44", ",", "46", ",", "47", ",", "49", ",", "50", ",", "53", 
   ",", "56"}], "}"}]], "Output",
 CellLabel->"Out[66]=",ExpressionUUID->"9b67bea2-6226-4310-8220-ed067626a3d9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Set of Strings", "Subsection",
 CellTags->"Section3f",ExpressionUUID->"8c06c1de-403c-4d66-8667-6827ffe6c624"],

Cell["\<\
As the final example in this section, we will look at how to generate sets of \
strings over a finite alphabet, as described in Definition 1 of Section 5.3. \
\
\>", "Text",ExpressionUUID->"060b5714-b366-4c95-a5af-1c3e9fc38d5a"],

Cell[TextData[{
 "The alphabet we will use is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", 
     ",", "\<\"d\"\>"}], "}"}], TraditionalForm]],ExpressionUUID->
  "74600932-9146-4c7b-9985-e565dec5d7e4"],
 ". We begin by assigning this to a name."
}], "Text",ExpressionUUID->"b6c24856-1081-47b6-a803-669bb7db50c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alphabet", "=", 
  RowBox[{"{", 
   RowBox[{
   "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\""}], 
   "}"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[67]:=",ExpressionUUID->"764d6a97-4e2e-4084-920f-137aaeaaa4e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", ",", "\<\"d\"\>"}],
   "}"}]], "Output",
 CellLabel->"Out[67]=",ExpressionUUID->"4293a9ad-850d-474b-ba33-9f8be6961694"]
}, Open  ]],

Cell[TextData[{
 "According to Definition 1, the basis step is that our set of strings must \
contain the empty string. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", the empty string is given by ",
 StyleBox["\"\"", "Code"],
 ". We will use the name ",
 StyleBox["S2", "Code"],
 " for our set of strings, since ",
 StyleBox["S", "Code"],
 " is used above."
}], "Text",ExpressionUUID->"eb520403-dc37-4c0c-b2ff-307b53cbe869"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2", "=", 
  RowBox[{"{", "\"\<\>\"", "}"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[68]:=",ExpressionUUID->"5bf6d696-06b8-4437-b650-cc5e0e03a2c8"],

Cell[BoxData[
 RowBox[{"{", "\<\"\"\>", "}"}]], "Output",
 CellLabel->"Out[68]=",ExpressionUUID->"d602b7b2-ea4e-4b41-a7bd-fdb4e524210e"]
}, Open  ]],

Cell[TextData[{
 "Note that while the output makes this appear to be an empty list, applying ",
 StyleBox[ButtonBox["FullForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FullForm"], "FunctionLink"],
 " reveals that it does in fact contain the empty string."
}], "Text",ExpressionUUID->"1bd8f753-4943-41a3-8ca6-7ef05b4d8625"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2", "//", "FullForm"}]], "Input",
 CellLabel->"In[69]:=",ExpressionUUID->"fcf0ca88-1d33-479f-a6bc-14af4bc42f89"],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"List", "[", "\"\<\>\"", "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 CellLabel->
  "Out[69]//FullForm=",ExpressionUUID->"716ed446-170a-4dc1-a531-e4e8e2ac1ded"]
}, Open  ]],

Cell[TextData[{
 "Like the previous example, we will create a function to build the set of \
strings. The recursive step in the definition tells us that we build the set \
by combining every element of ",
 StyleBox["S2", "Code"],
 " with every letter in the alphabet. Again we will use a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop with two loop variables. We will define the function to accept the \
current version of the set and the alphabet as arguments."
}], "Text",ExpressionUUID->"e6a6f82f-6ffe-476f-b449-b2a7f22d7193"],

Cell[TextData[{
 "To combine two strings, we apply the ",
 StyleBox[ButtonBox["StringJoin",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringJoin"], "FunctionLink"],
 " (",
 StyleBox["<>", "Code"],
 ") operator. Here is the function."
}], "Text",ExpressionUUID->"62fb5421-d900-4537-b51e-a700f070eae5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"buildStrings", "[", 
   RowBox[{"S_List", ",", "A_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"T", "=", "S"}], ",", "w", ",", "x"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"T", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"T", ",", 
          RowBox[{"{", 
           RowBox[{"w", "<>", "x"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "S"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "A"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     "T"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[70]:=",ExpressionUUID->"8c7a6364-1fac-4cf1-96dd-ddb9e8101af7"],

Cell["\<\
The first application of the recursion adds the alphabet to the set. \
\>", "Text",ExpressionUUID->"a7f04abc-ff61-4ecb-af62-fdebce36272a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2", "=", 
  RowBox[{"buildStrings", "[", 
   RowBox[{"S2", ",", "alphabet"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[71]:=",ExpressionUUID->"af533175-373f-4fb2-a2e7-639ecc2f88ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"d\"\>"}], "}"}]], "Output",
 CellLabel->"Out[71]=",ExpressionUUID->"4de9572d-52d4-4c7d-abb7-cc1cdf7f0bee"]
}, Open  ]],

Cell[TextData[{
 "Again, since ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not display the enclosing quotation marks of strings in its output, \
the initial comma in the output above is separating the empty string from \
\[OpenCurlyDoubleQuote]a\[CloseCurlyDoubleQuote]. The second application adds \
all the two-character strings."
}], "Text",ExpressionUUID->"af04de4c-cbbb-4b06-93bf-580b5cd7de67"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2", "=", 
  RowBox[{"buildStrings", "[", 
   RowBox[{"S2", ",", "alphabet"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[72]:=",ExpressionUUID->"80a807e9-83e9-48b3-81ed-399b9c026a97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\"\>", ",", "\<\"a\"\>", ",", "\<\"aa\"\>", ",", "\<\"ab\"\>", 
   ",", "\<\"ac\"\>", ",", "\<\"ad\"\>", ",", "\<\"b\"\>", ",", "\<\"ba\"\>", 
   ",", "\<\"bb\"\>", ",", "\<\"bc\"\>", ",", "\<\"bd\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"ca\"\>", ",", "\<\"cb\"\>", ",", "\<\"cc\"\>", ",", "\<\"cd\"\>",
    ",", "\<\"d\"\>", ",", "\<\"da\"\>", ",", "\<\"db\"\>", ",", "\<\"dc\"\>",
    ",", "\<\"dd\"\>"}], "}"}]], "Output",
 CellLabel->"Out[72]=",ExpressionUUID->"6cecfcf8-bbb7-4ebe-8b79-f3baf8cfb9d5"]
}, Open  ]],

Cell["The third application includes the three-character strings.", "Text",ExpressionUUID->"7cfbba8d-0a7c-4198-9c84-d34dc1cc27a6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S2", "=", 
  RowBox[{"buildStrings", "[", 
   RowBox[{"S2", ",", "alphabet"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[73]:=",ExpressionUUID->"977c98ef-7988-481e-aaa0-c7a43a00c010"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\"\>", ",", "\<\"a\"\>", ",", "\<\"aa\"\>", ",", "\<\"aaa\"\>",
    ",", "\<\"aab\"\>", ",", "\<\"aac\"\>", ",", "\<\"aad\"\>", 
   ",", "\<\"ab\"\>", ",", "\<\"aba\"\>", ",", "\<\"abb\"\>", 
   ",", "\<\"abc\"\>", ",", "\<\"abd\"\>", ",", "\<\"ac\"\>", 
   ",", "\<\"aca\"\>", ",", "\<\"acb\"\>", ",", "\<\"acc\"\>", 
   ",", "\<\"acd\"\>", ",", "\<\"ad\"\>", ",", "\<\"ada\"\>", 
   ",", "\<\"adb\"\>", ",", "\<\"adc\"\>", ",", "\<\"add\"\>", 
   ",", "\<\"b\"\>", ",", "\<\"ba\"\>", ",", "\<\"baa\"\>", 
   ",", "\<\"bab\"\>", ",", "\<\"bac\"\>", ",", "\<\"bad\"\>", 
   ",", "\<\"bb\"\>", ",", "\<\"bba\"\>", ",", "\<\"bbb\"\>", 
   ",", "\<\"bbc\"\>", ",", "\<\"bbd\"\>", ",", "\<\"bc\"\>", 
   ",", "\<\"bca\"\>", ",", "\<\"bcb\"\>", ",", "\<\"bcc\"\>", 
   ",", "\<\"bcd\"\>", ",", "\<\"bd\"\>", ",", "\<\"bda\"\>", 
   ",", "\<\"bdb\"\>", ",", "\<\"bdc\"\>", ",", "\<\"bdd\"\>", 
   ",", "\<\"c\"\>", ",", "\<\"ca\"\>", ",", "\<\"caa\"\>", 
   ",", "\<\"cab\"\>", ",", "\<\"cac\"\>", ",", "\<\"cad\"\>", 
   ",", "\<\"cb\"\>", ",", "\<\"cba\"\>", ",", "\<\"cbb\"\>", 
   ",", "\<\"cbc\"\>", ",", "\<\"cbd\"\>", ",", "\<\"cc\"\>", 
   ",", "\<\"cca\"\>", ",", "\<\"ccb\"\>", ",", "\<\"ccc\"\>", 
   ",", "\<\"ccd\"\>", ",", "\<\"cd\"\>", ",", "\<\"cda\"\>", 
   ",", "\<\"cdb\"\>", ",", "\<\"cdc\"\>", ",", "\<\"cdd\"\>", 
   ",", "\<\"d\"\>", ",", "\<\"da\"\>", ",", "\<\"daa\"\>", 
   ",", "\<\"dab\"\>", ",", "\<\"dac\"\>", ",", "\<\"dad\"\>", 
   ",", "\<\"db\"\>", ",", "\<\"dba\"\>", ",", "\<\"dbb\"\>", 
   ",", "\<\"dbc\"\>", ",", "\<\"dbd\"\>", ",", "\<\"dc\"\>", 
   ",", "\<\"dca\"\>", ",", "\<\"dcb\"\>", ",", "\<\"dcc\"\>", 
   ",", "\<\"dcd\"\>", ",", "\<\"dd\"\>", ",", "\<\"dda\"\>", 
   ",", "\<\"ddb\"\>", ",", "\<\"ddc\"\>", ",", "\<\"ddd\"\>"}], 
  "}"}]], "Output",
 CellLabel->"Out[73]=",ExpressionUUID->"87da3f1a-a3f0-433b-9616-0be827e24947"]
}, Open  ]],

Cell[CellGroupData[{

Cell["A General Function", "Subsubsection",ExpressionUUID->"ae0f4ac8-f3d1-4c69-abcc-6d698ed708f8"],

Cell["\<\
We can put this process all together in one function. Given a set of strings \
representing the alphabet and a positive integer indicating the number of \
iterations desired, the following function will return the set of strings \
obtained after the given number of iterations. \
\>", "Text",ExpressionUUID->"3e611438-d76a-4852-9ca3-98140c176062"],

Cell[BoxData[
 RowBox[{
  RowBox[{"allStrings", "[", 
   RowBox[{"A_List", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"S", "=", 
       RowBox[{"{", "\"\<\>\"", "}"}]}], ",", "i"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "n"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"S", "=", 
        RowBox[{"buildStrings", "[", 
         RowBox[{"S", ",", "A"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "S"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[74]:=",ExpressionUUID->"2c6813a8-966b-483f-9eae-a4398a9c51b3"],

Cell[TextData[{
 "Below, we apply this function to the alphabet consisting of the strings \
\[OpenCurlyDoubleQuote]ab\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]",
 StyleBox["ba",
  IgnoreSpellCheck->True],
 "\[CloseCurlyDoubleQuote] (in discrete mathematics, an alphabet does not \
have to consist of individual letters)."
}], "Text",ExpressionUUID->"fa235849-12af-4653-ae73-0083e472c580"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allStrings", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<ab\>\"", ",", "\"\<ba\>\""}], "}"}], ",", "4"}], 
  "]"}]], "Input",
 CellLabel->"In[75]:=",ExpressionUUID->"550bd813-ffd8-4da5-a180-73c8363c24f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\"\>", ",", "\<\"ab\"\>", ",", "\<\"abab\"\>", 
   ",", "\<\"ababab\"\>", ",", "\<\"abababab\"\>", ",", "\<\"abababba\"\>", 
   ",", "\<\"ababba\"\>", ",", "\<\"ababbaab\"\>", ",", "\<\"ababbaba\"\>", 
   ",", "\<\"abba\"\>", ",", "\<\"abbaab\"\>", ",", "\<\"abbaabab\"\>", 
   ",", "\<\"abbaabba\"\>", ",", "\<\"abbaba\"\>", ",", "\<\"abbabaab\"\>", 
   ",", "\<\"abbababa\"\>", ",", "\<\"ba\"\>", ",", "\<\"baab\"\>", 
   ",", "\<\"baabab\"\>", ",", "\<\"baababab\"\>", ",", "\<\"baababba\"\>", 
   ",", "\<\"baabba\"\>", ",", "\<\"baabbaab\"\>", ",", "\<\"baabbaba\"\>", 
   ",", "\<\"baba\"\>", ",", "\<\"babaab\"\>", ",", "\<\"babaabab\"\>", 
   ",", "\<\"babaabba\"\>", ",", "\<\"bababa\"\>", ",", "\<\"bababaab\"\>", 
   ",", "\<\"babababa\"\>"}], "}"}]], "Output",
 CellLabel->"Out[75]=",ExpressionUUID->"6044a972-be8c-410e-ab7e-48b9c2b26b5f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4 Recursive Algorithms", "Section",
 CellTags->"Section4",ExpressionUUID->"2180dab6-1e74-4757-a5a0-cc74cfda0950"],

Cell[TextData[{
 "In this section, we will use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to implement several different recursive algorithms. First, we will look \
at two different recursive implementations of modular exponentiation and \
compare their performance. Then, we will contrast a recursive approach to \
computing factorial with an iterative approach. And finally, we will provide \
an implementation of merge sort."
}], "Text",ExpressionUUID->"87207367-32aa-4616-b617-e78e7c039807"],

Cell[CellGroupData[{

Cell["Modular Exponentiation", "Subsection",
 CellTags->"Section4a",ExpressionUUID->"de33e1a3-92e2-487d-a047-25efa50a43f2"],

Cell[TextData[{
 "Example 4 of Section 5.4 of the text describes two recursive approaches to \
computing ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["b", "n"], "mod", " ", "m"}], TraditionalForm]],
  ExpressionUUID->"ac69ebf6-64a3-4ab2-8ea5-370bec0b39c8"],
 ". Both of these use the initial condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "0"], "mod", " ", "m"}], "=", "1"}], 
   TraditionalForm]],ExpressionUUID->"6f474a2a-50e8-4627-9d49-bb8d50adfb7a"],
 ". The first approach is based on the fact that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "n"], "mod", " ", "m"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "\[CenterDot]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", 
          RowBox[{"n", "-", "1"}]], "mod", " ", "m"}], ")"}]}], ")"}], "mod", 
     " ", "m"}]}], TraditionalForm]],ExpressionUUID->
  "4c3e226f-0452-4d1c-bee4-fff1cba50b6a"],
 "."
}], "Text",ExpressionUUID->"fb3b652e-79a7-4c6d-8a15-0dcb070f66da"],

Cell[TextData[{
 "The second approach is based on the observation that for even exponents, we \
can compute via the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "n"], "mod", " ", "m"}], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", 
         RowBox[{"n", "/", "2"}]], "mod", " ", "m"}], ")"}], "2"], " ", "mod",
      " ", "m"}]}], TraditionalForm]],ExpressionUUID->
  "df6d5f3f-2f35-4685-9394-557e80603fbe"],
 ". On the other hand, if the exponent is odd, we can use the identity ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "n"], "mod", " ", "m"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", 
            RowBox[{"\[LeftFloor]", 
             RowBox[{"n", "/", "2"}], "\[RightFloor]"}]], "mod", " ", "m"}], 
          ")"}], "2"], "mod", " ", "m"}], ")"}], "\[CenterDot]", 
      RowBox[{"(", 
       RowBox[{"b", " ", "mod", " ", "m"}], ")"}]}], " ", "mod", " ", "m"}]}],
    TraditionalForm]],ExpressionUUID->
  "bb5756f4-35a8-4371-940c-f52b9db323ba"],
 "."
}], "Text",ExpressionUUID->"be4e1048-019f-450c-a3ab-c067dacd74ef"],

Cell[CellGroupData[{

Cell["Approach 1", "Subsubsection",ExpressionUUID->"c1ed22ea-25b2-4112-8bf9-6cd8f74bea23"],

Cell[TextData[{
 "First, we will implement exponentiation based on the initial condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "0"], "mod", " ", "m"}], "=", "1"}], 
   TraditionalForm]],ExpressionUUID->"8a72a0c4-be7e-4172-bb2e-1e84271cf833"],
 " and the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "n"], "mod", " ", "m"}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "\[CenterDot]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", 
          RowBox[{"n", "-", "1"}]], "mod", " ", "m"}], ")"}]}], ")"}], "mod", 
     " ", "m"}]}], TraditionalForm]],ExpressionUUID->
  "8ae22326-8d1c-46a8-a68f-8776ac6eeb92"],
 ". The function ",
 StyleBox["power1", "Code"],
 " will accept three arguments: the base ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]],ExpressionUUID->
  "5bebf6f7-62de-421f-8b26-1dc8f903131c"],
 ", the exponent ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "a21917d7-9347-43cd-8428-1dd41d3de906"],
 ", and the modulus ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "ba435ad7-d3b1-4569-b3a2-1b53d81fa56c"],
 "."
}], "Text",ExpressionUUID->"e373fffa-646b-4898-915e-54c3dec99dbb"],

Cell["\<\
If the exponent is 0, then regardless of the base or the modulus, the \
function returns 1. We can specify that behavior as follows. Observe that it \
is not necessary to give names to the other two arguments, since their \
specific values are irrelevant.\
\>", "Text",ExpressionUUID->"6737ef7f-fba4-45c5-bdc6-e446b00c5fde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"power1", "[", 
   RowBox[{"_Integer", ",", "0", ",", "_Integer"}], "]"}], ":=", 
  "1"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[76]:=",ExpressionUUID->"34525948-7b11-4e72-a770-8afea90a7966"],

Cell[TextData[{
 "In the Wolfram Language, you are allowed to provide multiple definitions \
for the same function, provided the arguments have different forms. If two \
definitions both match a particular set of arguments, then the definition \
that is issued first, and is thus first in the list of down values, is the \
one applied. However, it is generally a good idea to ensure that the two \
patterns do not overlap. Consequently, for the recursive part of ",
 StyleBox["power1", "Code"],
 ", we will explicitly insist that the exponent be positive."
}], "Text",ExpressionUUID->"e991be3e-f140-4a2e-9a79-b04f24903c28"],

Cell[TextData[{
 "If the exponent is greater than 0, then we compute the product of the base \
with the function applied to the same base and modulus but the power \
decreased by 1. To ensure that the exponent is in fact positive, we will \
impose a ",
 StyleBox[ButtonBox["Condition",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Condition"], "FunctionLink"],
 " (",
 StyleBox["/;", "Code"],
 ") by entering the operator ",
 StyleBox["/;", "Code"],
 " following by the proposition ",
 StyleBox["n>0", "Code"],
 " between the argument list and the ",
 StyleBox[ButtonBox["SetDelayed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SetDelayed"], "FunctionLink"],
 " (",
 StyleBox[":=", "Code"],
 ") operator."
}], "Text",ExpressionUUID->"ddb40c19-ead6-483f-9a25-843eec994a18"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"power1", "[", 
    RowBox[{"b_Integer", ",", "n_Integer", ",", "m_Integer"}], "]"}], "/;", 
   RowBox[{"n", ">", "0"}]}], ":=", 
  RowBox[{"Mod", "[", 
   RowBox[{
    RowBox[{"b", "*", 
     RowBox[{"power1", "[", 
      RowBox[{"b", ",", 
       RowBox[{"n", "-", "1"}], ",", "m"}], "]"}]}], ",", "m"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[77]:=",ExpressionUUID->"1427705a-6638-4b96-af57-f467c35740e9"],

Cell[TextData[{
 "Notice that the down values of the symbol ",
 StyleBox["power1", "Code"],
 " now includes both definitions."
}], "Text",ExpressionUUID->"3d4cfade-c515-451b-9655-143231991a7a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DownValues", "[", "power1", "]"}]], "Input",
 CellLabel->"In[78]:=",ExpressionUUID->"c4f32f2c-2eaa-44c3-b2b6-cf33b19508ae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{"power1", "[", 
      RowBox[{"_Integer", ",", "0", ",", "_Integer"}], "]"}], "]"}], 
    "\[RuleDelayed]", "1"}], ",", 
   RowBox[{
    RowBox[{"HoldPattern", "[", 
     RowBox[{
      RowBox[{"power1", "[", 
       RowBox[{"b_Integer", ",", "n_Integer", ",", "m_Integer"}], "]"}], "/;", 
      RowBox[{"n", ">", "0"}]}], "]"}], "\[RuleDelayed]", 
    RowBox[{"Mod", "[", 
     RowBox[{
      RowBox[{"b", " ", 
       RowBox[{"power1", "[", 
        RowBox[{"b", ",", 
         RowBox[{"n", "-", "1"}], ",", "m"}], "]"}]}], ",", "m"}], "]"}]}]}], 
  "}"}]], "Output",
 CellLabel->"Out[78]=",ExpressionUUID->"bcbd5d35-9590-4ac0-9533-b1e568c4a93d"]
}, Open  ]],

Cell[TextData[{
 "Note that we did not store computed values in this function. The reason for \
this is that each iteration of the function only depends on one other call to \
the function. This is in contrast with the ",
 StyleBox["gR", "Code"],
 " and ",
 StyleBox["gF", "Code"],
 " functions from the previous section. Those functions called themselves \
twice in each iteration. As a result, those functions made use of the same \
value multiple times. When deciding whether or not to store values, you must \
weigh its potential benefit for not unnecessarily repeating computations with \
the cost of storage requirements."
}], "Text",ExpressionUUID->"11739da3-3a95-412e-84aa-119cd24e103e"],

Cell[TextData[{
 "We can use ",
 StyleBox["power1", "Code"],
 " to compute ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", "6"], "mod", " ", "7"}], TraditionalForm]],
  ExpressionUUID->"b2fb169d-e498-4014-80a3-cb6987477fe4"],
 " and compare the result to a naive computation of the same expression."
}], "Text",ExpressionUUID->"d84a6d28-c08a-4d86-b315-3734a01b15d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"power1", "[", 
  RowBox[{"3", ",", "6", ",", "7"}], "]"}]], "Input",
 CellLabel->"In[79]:=",ExpressionUUID->"7a33e1f9-0d58-4aa2-8239-44b5ed8f9e71"],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[79]=",ExpressionUUID->"e4a39ea5-cb7f-4bf4-b5cd-581aa6ec172f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mod", "[", 
  RowBox[{
   RowBox[{"3", "^", "6"}], ",", "7"}], "]"}]], "Input",
 CellLabel->"In[80]:=",ExpressionUUID->"e2af6ead-e7a0-4d85-a8e4-862538b69af1"],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[80]=",ExpressionUUID->"e9da2365-bade-40f1-afc8-cf12ead0a631"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Approach 2", "Subsubsection",ExpressionUUID->"1eed1bef-1541-447d-b975-5bc15530a182"],

Cell[TextData[{
 "The second approach computes the power based on Algorithm 4 from Section \
5.4. For exponent 0, it returns 1, just as before. If the exponent is even, \
then the algorithm uses the formula ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "n"], "mod", " ", "m"}], "=", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", 
         RowBox[{"n", "/", "2"}]], "mod", " ", "m"}], ")"}], "2"], " ", "mod",
      " ", "m"}]}], TraditionalForm]],ExpressionUUID->
  "4eac2cd3-281e-4e19-a687-c7011fef8d7f"],
 ", and for odd powers, it computes the power using the identity ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["b", "n"], "mod", " ", "m"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", 
            RowBox[{"\[LeftFloor]", 
             RowBox[{"n", "/", "2"}], "\[RightFloor]"}]], "mod", " ", "m"}], 
          ")"}], "2"], "mod", " ", "m"}], ")"}], "\[CenterDot]", 
      RowBox[{"(", 
       RowBox[{"b", " ", "mod", " ", "m"}], ")"}]}], " ", "mod", " ", "m"}]}],
    TraditionalForm]],ExpressionUUID->
  "372e5cc7-915d-448b-a661-881e65a46e87"],
 "."
}], "Text",ExpressionUUID->"13f7f130-ad90-4446-993b-3b1cf0842aea"],

Cell["\<\
Since there are three possibilities, 0, even, or odd, we give the definition \
in three parts. \
\>", "Text",ExpressionUUID->"cc02c598-c46c-4d18-b304-2ab530de4b93"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"power2", "[", 
    RowBox[{"_Integer", ",", "0", ",", "_Integer"}], "]"}], ":=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"power2", "[", 
     RowBox[{"b_Integer", ",", "n_Integer", ",", "m_Integer"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"n", ">", "0"}], "&&", 
     RowBox[{"EvenQ", "[", "n", "]"}]}]}], ":=", 
   RowBox[{"Mod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"power2", "[", 
       RowBox[{"b", ",", 
        RowBox[{"n", "/", "2"}], ",", "m"}], "]"}], "^", "2"}], ",", "m"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"power2", "[", 
     RowBox[{"b_Integer", ",", "n_Integer", ",", "m_Integer"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"n", ">", "0"}], "&&", 
     RowBox[{"OddQ", "[", "n", "]"}]}]}], ":=", 
   RowBox[{"Mod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"power2", "[", 
          RowBox[{"b", ",", 
           RowBox[{"Floor", "[", 
            RowBox[{"n", "/", "2"}], "]"}], ",", "m"}], "]"}], "^", "2"}], 
        ",", "m"}], "]"}], "*", "b"}], ",", "m"}], "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[81]:=",ExpressionUUID->"eec132ce-c897-4276-ab6b-7af87a66ced8"],

Cell[TextData[{
 "We apply ",
 StyleBox["power2", "Code"],
 " to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["3", "6"], "mod", " ", "7"}], TraditionalForm]],
  ExpressionUUID->"e0e7b918-68ed-4b75-957b-527491b603f5"],
 " as well."
}], "Text",ExpressionUUID->"b3d01873-94a6-4527-872f-c5b6aa379cea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"power2", "[", 
  RowBox[{"3", ",", "6", ",", "7"}], "]"}]], "Input",
 CellLabel->"In[84]:=",ExpressionUUID->"fd788912-17b2-4a39-922f-1dcb4096a4c0"],

Cell[BoxData["1"], "Output",
 CellLabel->"Out[84]=",ExpressionUUID->"d6041eaa-0a96-45cb-aab7-11840e252952"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparing Performance of the Functions", "Subsubsection",ExpressionUUID->"27c0745d-eecc-45c0-8499-6079db3151c3"],

Cell["\<\
Now that we have implemented these two algorithms, we compare their \
performance on a variety of input values. \
\>", "Text",ExpressionUUID->"265570eb-f0f4-4bf5-9908-4cc1dca67b5b"],

Cell[TextData[{
 "We fix the base 3 and the modulus 7 and consider the exponents from 100 to \
1000 and compare the amount of time taken by each function. We use ",
 StyleBox[ButtonBox["Table",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Table"], "FunctionLink"],
 " to build the two lists consisting of the exponent/time pairs. Recall that ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " returns a list consisting of the time taken and the result, so we apply \
the ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Part"], "FunctionLink"],
 " (",
 StyleBox["[[\[Ellipsis]]]", "Code"],
 ") operator to extract the time."
}], "Text",ExpressionUUID->"a29ae294-f4f1-43a9-be77-e4fe30dc3d00"],

Cell[TextData[{
 "While not necessarily required in this case, in case you wish to \
substantially increase the exponent, we illustrate how to temporarily \
increase the variable ",
 StyleBox[ButtonBox["$RecursionLimit",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/$RecursionLimit"], "FunctionLink"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " normally restricts the depth to which a recursive algorithm can go. This \
is useful, as it helps prevent infinite loops and other potential \
computer-crashing events. When you are certain that your function will not \
cause such problems and need to allow deeper levels of recursion than usually \
allowed, you can override the built-in limit. It is, of course, highly \
recommended that you test the function with small values first. In the inputs \
below, we modify the recursion limit by setting the symbol ",
 StyleBox[ButtonBox["$RecursionLimit",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/$RecursionLimit"], "FunctionLink"],
 " to ",
 StyleBox[ButtonBox["Infinity",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Infinity"], "FunctionLink"],
 ". Doing so within a ",
 StyleBox[ButtonBox["Block",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Block"], "FunctionLink"],
 " ensures that this is only a temporary modification."
}], "Text",ExpressionUUID->"c3635610-6bac-42fd-bcfd-71c8c96f3b68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"times1", "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"$RecursionLimit", "=", "Infinity"}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{
          RowBox[{"Timing", "[", 
           RowBox[{"power1", "[", 
            RowBox[{"3", ",", "n", ",", "7"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "100", ",", "1000"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[85]:=",ExpressionUUID->"b839145e-a5d5-48b7-988d-a4afdf3a0ef2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"times2", "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"$RecursionLimit", "=", "Infinity"}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{
          RowBox[{"Timing", "[", 
           RowBox[{"power2", "[", 
            RowBox[{"3", ",", "n", ",", "7"}], "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "100", ",", "1000"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[86]:=",ExpressionUUID->"b5a3c581-48fc-4e03-ba4d-7f71a330907e"],

Cell[TextData[{
 "We have suppressed the output in the statements above, but now ",
 StyleBox["times1", "Code"],
 " and ",
 StyleBox["times2", "Code"],
 " contain the running times for ",
 StyleBox["power1", "Code"],
 " and ",
 StyleBox["power2", "Code"],
 ", respectively."
}], "Text",ExpressionUUID->"cd46b601-2c48-4c92-b20b-0bed35c7a04d"],

Cell[TextData[{
 "Next, we graph the time results. The ",
 StyleBox[ButtonBox["ListPlot",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ListPlot"], "FunctionLink"],
 " function can be used to plot multiple sets of data by giving as its \
argument a list whose elements are the lists of data. By placing the data \
lists inside of the ",
 StyleBox[ButtonBox["Tooltip",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Tooltip"], "FunctionLink"],
 " function, labels will appear when you hover your mouse pointer over the \
graph."
}], "Text",ExpressionUUID->"01881a51-e0a2-42e7-aada-4a888f67f543"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Tooltip", "[", 
    RowBox[{"{", 
     RowBox[{"times1", ",", "times2"}], "}"}], "]"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<power1\>\"", ",", "\"\<power2\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellLabel->"In[87]:=",ExpressionUUID->"69da7323-9d39-4302-9148-a707c66272ca"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.004583333333333334], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdm2dYFFcXx9ca7GsN9rVjBzWC/RiJYkHXDtYV6QgufemzvS8bNYrR6Fqi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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.004583333333333334], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdmluIJGcVx8tdV8eNxI6X0ASVXkFtAjHthdAQ2XwQlJa4WgkJ9M7eamZ2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         "]]}, {}}, {
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{100., 0.000212}}]}, 
         RowBox[{"{", 
           RowBox[{"100.`", ",", "0.000212`"}], "}"}]], 
        Annotation[#, {100., 0.000212}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{101., 0.000188}}]}, 
         RowBox[{"{", 
           RowBox[{"101.`", ",", "0.000188`"}], "}"}]], 
        Annotation[#, {101., 0.000188}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{102., 0.000189}}]}, 
         RowBox[{"{", 
           RowBox[{"102.`", ",", "0.000189`"}], "}"}]], 
        Annotation[#, {102., 0.000189}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{103., 0.000191}}]}, 
         RowBox[{"{", 
           RowBox[{"103.`", ",", "0.000191`"}], "}"}]], 
        Annotation[#, {103., 0.000191}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{104., 0.000193}}]}, 
         RowBox[{"{", 
           RowBox[{"104.`", ",", "0.000193`"}], "}"}]], 
        Annotation[#, {104., 0.000193}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{105., 0.000195}}]}, 
         RowBox[{"{", 
           RowBox[{"105.`", ",", "0.000195`"}], "}"}]], 
        Annotation[#, {105., 0.000195}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{106., 0.000218}}]}, 
         RowBox[{"{", 
           RowBox[{"106.`", ",", "0.000218`"}], "}"}]], 
        Annotation[#, {106., 0.000218}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{107., 0.0002}}]}, 
         RowBox[{"{", 
           RowBox[{"107.`", ",", "0.0002`"}], "}"}]], 
        Annotation[#, {107., 0.0002}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{108., 0.000205}}]}, 
         RowBox[{"{", 
           RowBox[{"108.`", ",", "0.000205`"}], "}"}]], 
        Annotation[#, {108., 0.000205}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{109., 0.000203}}]}, 
         RowBox[{"{", 
           RowBox[{"109.`", ",", "0.000203`"}], "}"}]], 
        Annotation[#, {109., 0.000203}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{110., 0.000218}}]}, 
         RowBox[{"{", 
           RowBox[{"110.`", ",", "0.000218`"}], "}"}]], 
        Annotation[#, {110., 0.000218}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{111., 0.000205}}]}, 
         RowBox[{"{", 
           RowBox[{"111.`", ",", "0.000205`"}], "}"}]], 
        Annotation[#, {111., 0.000205}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{112., 0.000259}}]}, 
         RowBox[{"{", 
           RowBox[{"112.`", ",", "0.000259`"}], "}"}]], 
        Annotation[#, {112., 0.000259}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{113., 0.000209}}]}, 
         RowBox[{"{", 
           RowBox[{"113.`", ",", "0.000209`"}], "}"}]], 
        Annotation[#, {113., 0.000209}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{114., 0.000209}}]}, 
         RowBox[{"{", 
           RowBox[{"114.`", ",", "0.000209`"}], "}"}]], 
        Annotation[#, {114., 0.000209}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{115., 0.000216}}]}, 
         RowBox[{"{", 
           RowBox[{"115.`", ",", "0.000216`"}], "}"}]], 
        Annotation[#, {115., 0.000216}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{116., 0.000215}}]}, 
         RowBox[{"{", 
           RowBox[{"116.`", ",", "0.000215`"}], "}"}]], 
        Annotation[#, {116., 0.000215}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{117., 0.000218}}]}, 
         RowBox[{"{", 
           RowBox[{"117.`", ",", "0.000218`"}], "}"}]], 
        Annotation[#, {117., 0.000218}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{118., 0.000219}}]}, 
         RowBox[{"{", 
           RowBox[{"118.`", ",", "0.000219`"}], "}"}]], 
        Annotation[#, {118., 0.000219}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{119., 0.000222}}]}, 
         RowBox[{"{", 
           RowBox[{"119.`", ",", "0.000222`"}], "}"}]], 
        Annotation[#, {119., 0.000222}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{120., 0.000219}}]}, 
         RowBox[{"{", 
           RowBox[{"120.`", ",", "0.000219`"}], "}"}]], 
        Annotation[#, {120., 0.000219}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{121., 0.000224}}]}, 
         RowBox[{"{", 
           RowBox[{"121.`", ",", "0.000224`"}], "}"}]], 
        Annotation[#, {121., 0.000224}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{122., 0.000224}}]}, 
         RowBox[{"{", 
           RowBox[{"122.`", ",", "0.000224`"}], "}"}]], 
        Annotation[#, {122., 0.000224}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{123., 0.000229}}]}, 
         RowBox[{"{", 
           RowBox[{"123.`", ",", "0.000229`"}], "}"}]], 
        Annotation[#, {123., 0.000229}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{124., 0.000228}}]}, 
         RowBox[{"{", 
           RowBox[{"124.`", ",", "0.000228`"}], "}"}]], 
        Annotation[#, {124., 0.000228}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{125., 0.000229}}]}, 
         RowBox[{"{", 
           RowBox[{"125.`", ",", "0.000229`"}], "}"}]], 
        Annotation[#, {125., 0.000229}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{126., 0.000234}}]}, 
         RowBox[{"{", 
           RowBox[{"126.`", ",", "0.000234`"}], "}"}]], 
        Annotation[#, {126., 0.000234}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{127., 0.000235}}]}, 
         RowBox[{"{", 
           RowBox[{"127.`", ",", "0.000235`"}], "}"}]], 
        Annotation[#, {127., 0.000235}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{128., 0.000235}}]}, 
         RowBox[{"{", 
           RowBox[{"128.`", ",", "0.000235`"}], "}"}]], 
        Annotation[#, {128., 0.000235}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{129., 0.000251}}]}, 
         RowBox[{"{", 
           RowBox[{"129.`", ",", "0.000251`"}], "}"}]], 
        Annotation[#, {129., 0.000251}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{130., 0.000253}}]}, 
         RowBox[{"{", 
           RowBox[{"130.`", ",", "0.000253`"}], "}"}]], 
        Annotation[#, {130., 0.000253}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{131., 0.000242}}]}, 
         RowBox[{"{", 
           RowBox[{"131.`", ",", "0.000242`"}], "}"}]], 
        Annotation[#, {131., 0.000242}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{132., 0.000241}}]}, 
         RowBox[{"{", 
           RowBox[{"132.`", ",", "0.000241`"}], "}"}]], 
        Annotation[#, {132., 0.000241}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{133., 0.000245}}]}, 
         RowBox[{"{", 
           RowBox[{"133.`", ",", "0.000245`"}], "}"}]], 
        Annotation[#, {133., 0.000245}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{134., 0.000286}}]}, 
         RowBox[{"{", 
           RowBox[{"134.`", ",", "0.000286`"}], "}"}]], 
        Annotation[#, {134., 0.000286}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{135., 0.000254}}]}, 
         RowBox[{"{", 
           RowBox[{"135.`", ",", "0.000254`"}], "}"}]], 
        Annotation[#, {135., 0.000254}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{136., 0.000254}}]}, 
         RowBox[{"{", 
           RowBox[{"136.`", ",", "0.000254`"}], "}"}]], 
        Annotation[#, {136., 0.000254}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{137., 0.000257}}]}, 
         RowBox[{"{", 
           RowBox[{"137.`", ",", "0.000257`"}], "}"}]], 
        Annotation[#, {137., 0.000257}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{138., 0.000256}}]}, 
         RowBox[{"{", 
           RowBox[{"138.`", ",", "0.000256`"}], "}"}]], 
        Annotation[#, {138., 0.000256}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{139., 0.000256}}]}, 
         RowBox[{"{", 
           RowBox[{"139.`", ",", "0.000256`"}], "}"}]], 
        Annotation[#, {139., 0.000256}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{140., 0.000256}}]}, 
         RowBox[{"{", 
           RowBox[{"140.`", ",", "0.000256`"}], "}"}]], 
        Annotation[#, {140., 0.000256}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{141., 0.000261}}]}, 
         RowBox[{"{", 
           RowBox[{"141.`", ",", "0.000261`"}], "}"}]], 
        Annotation[#, {141., 0.000261}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{142., 0.000262}}]}, 
         RowBox[{"{", 
           RowBox[{"142.`", ",", "0.000262`"}], "}"}]], 
        Annotation[#, {142., 0.000262}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{143., 0.000267}}]}, 
         RowBox[{"{", 
           RowBox[{"143.`", ",", "0.000267`"}], "}"}]], 
        Annotation[#, {143., 0.000267}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{144., 0.000263}}]}, 
         RowBox[{"{", 
           RowBox[{"144.`", ",", "0.000263`"}], "}"}]], 
        Annotation[#, {144., 0.000263}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{145., 0.000287}}]}, 
         RowBox[{"{", 
           RowBox[{"145.`", ",", "0.000287`"}], "}"}]], 
        Annotation[#, {145., 0.000287}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{146., 0.000275}}]}, 
         RowBox[{"{", 
           RowBox[{"146.`", ",", "0.000275`"}], "}"}]], 
        Annotation[#, {146., 0.000275}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{147., 0.000267}}]}, 
         RowBox[{"{", 
           RowBox[{"147.`", ",", "0.000267`"}], "}"}]], 
        Annotation[#, {147., 0.000267}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{148., 0.000296}}]}, 
         RowBox[{"{", 
           RowBox[{"148.`", ",", "0.000296`"}], "}"}]], 
        Annotation[#, {148., 0.000296}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{149., 0.000277}}]}, 
         RowBox[{"{", 
           RowBox[{"149.`", ",", "0.000277`"}], "}"}]], 
        Annotation[#, {149., 0.000277}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{150., 0.000273}}]}, 
         RowBox[{"{", 
           RowBox[{"150.`", ",", "0.000273`"}], "}"}]], 
        Annotation[#, {150., 0.000273}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{151., 0.000278}}]}, 
         RowBox[{"{", 
           RowBox[{"151.`", ",", "0.000278`"}], "}"}]], 
        Annotation[#, {151., 0.000278}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{152., 0.000283}}]}, 
         RowBox[{"{", 
           RowBox[{"152.`", ",", "0.000283`"}], "}"}]], 
        Annotation[#, {152., 0.000283}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{153., 0.00028}}]}, 
         RowBox[{"{", 
           RowBox[{"153.`", ",", "0.00028`"}], "}"}]], 
        Annotation[#, {153., 0.00028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{154., 0.000283}}]}, 
         RowBox[{"{", 
           RowBox[{"154.`", ",", "0.000283`"}], "}"}]], 
        Annotation[#, {154., 0.000283}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{155., 0.000282}}]}, 
         RowBox[{"{", 
           RowBox[{"155.`", ",", "0.000282`"}], "}"}]], 
        Annotation[#, {155., 0.000282}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{156., 0.000288}}]}, 
         RowBox[{"{", 
           RowBox[{"156.`", ",", "0.000288`"}], "}"}]], 
        Annotation[#, {156., 0.000288}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{157., 0.000289}}]}, 
         RowBox[{"{", 
           RowBox[{"157.`", ",", "0.000289`"}], "}"}]], 
        Annotation[#, {157., 0.000289}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{158., 0.00029}}]}, 
         RowBox[{"{", 
           RowBox[{"158.`", ",", "0.00029`"}], "}"}]], 
        Annotation[#, {158., 0.00029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{159., 0.000293}}]}, 
         RowBox[{"{", 
           RowBox[{"159.`", ",", "0.000293`"}], "}"}]], 
        Annotation[#, {159., 0.000293}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{160., 0.000295}}]}, 
         RowBox[{"{", 
           RowBox[{"160.`", ",", "0.000295`"}], "}"}]], 
        Annotation[#, {160., 0.000295}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{161., 0.000295}}]}, 
         RowBox[{"{", 
           RowBox[{"161.`", ",", "0.000295`"}], "}"}]], 
        Annotation[#, {161., 0.000295}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{162., 0.000294}}]}, 
         RowBox[{"{", 
           RowBox[{"162.`", ",", "0.000294`"}], "}"}]], 
        Annotation[#, {162., 0.000294}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{163., 0.000304}}]}, 
         RowBox[{"{", 
           RowBox[{"163.`", ",", "0.000304`"}], "}"}]], 
        Annotation[#, {163., 0.000304}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{164., 0.000301}}]}, 
         RowBox[{"{", 
           RowBox[{"164.`", ",", "0.000301`"}], "}"}]], 
        Annotation[#, {164., 0.000301}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{165., 0.000301}}]}, 
         RowBox[{"{", 
           RowBox[{"165.`", ",", "0.000301`"}], "}"}]], 
        Annotation[#, {165., 0.000301}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{166., 0.000305}}]}, 
         RowBox[{"{", 
           RowBox[{"166.`", ",", "0.000305`"}], "}"}]], 
        Annotation[#, {166., 0.000305}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{167., 0.000308}}]}, 
         RowBox[{"{", 
           RowBox[{"167.`", ",", "0.000308`"}], "}"}]], 
        Annotation[#, {167., 0.000308}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{168., 0.000305}}]}, 
         RowBox[{"{", 
           RowBox[{"168.`", ",", "0.000305`"}], "}"}]], 
        Annotation[#, {168., 0.000305}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{169., 0.00031}}]}, 
         RowBox[{"{", 
           RowBox[{"169.`", ",", "0.00031`"}], "}"}]], 
        Annotation[#, {169., 0.00031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{170., 0.000315}}]}, 
         RowBox[{"{", 
           RowBox[{"170.`", ",", "0.000315`"}], "}"}]], 
        Annotation[#, {170., 0.000315}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{171., 0.000311}}]}, 
         RowBox[{"{", 
           RowBox[{"171.`", ",", "0.000311`"}], "}"}]], 
        Annotation[#, {171., 0.000311}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{172., 0.00033}}]}, 
         RowBox[{"{", 
           RowBox[{"172.`", ",", "0.00033`"}], "}"}]], 
        Annotation[#, {172., 0.00033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{173., 0.000336}}]}, 
         RowBox[{"{", 
           RowBox[{"173.`", ",", "0.000336`"}], "}"}]], 
        Annotation[#, {173., 0.000336}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{174., 0.000322}}]}, 
         RowBox[{"{", 
           RowBox[{"174.`", ",", "0.000322`"}], "}"}]], 
        Annotation[#, {174., 0.000322}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{175., 0.000321}}]}, 
         RowBox[{"{", 
           RowBox[{"175.`", ",", "0.000321`"}], "}"}]], 
        Annotation[#, {175., 0.000321}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{176., 0.000321}}]}, 
         RowBox[{"{", 
           RowBox[{"176.`", ",", "0.000321`"}], "}"}]], 
        Annotation[#, {176., 0.000321}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{177., 0.000321}}]}, 
         RowBox[{"{", 
           RowBox[{"177.`", ",", "0.000321`"}], "}"}]], 
        Annotation[#, {177., 0.000321}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{178., 0.000331}}]}, 
         RowBox[{"{", 
           RowBox[{"178.`", ",", "0.000331`"}], "}"}]], 
        Annotation[#, {178., 0.000331}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{179., 0.000327}}]}, 
         RowBox[{"{", 
           RowBox[{"179.`", ",", "0.000327`"}], "}"}]], 
        Annotation[#, {179., 0.000327}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{180., 0.000327}}]}, 
         RowBox[{"{", 
           RowBox[{"180.`", ",", "0.000327`"}], "}"}]], 
        Annotation[#, {180., 0.000327}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{181., 0.000335}}]}, 
         RowBox[{"{", 
           RowBox[{"181.`", ",", "0.000335`"}], "}"}]], 
        Annotation[#, {181., 0.000335}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{182., 0.000332}}]}, 
         RowBox[{"{", 
           RowBox[{"182.`", ",", "0.000332`"}], "}"}]], 
        Annotation[#, {182., 0.000332}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{183., 0.000332}}]}, 
         RowBox[{"{", 
           RowBox[{"183.`", ",", "0.000332`"}], "}"}]], 
        Annotation[#, {183., 0.000332}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{184., 0.000337}}]}, 
         RowBox[{"{", 
           RowBox[{"184.`", ",", "0.000337`"}], "}"}]], 
        Annotation[#, {184., 0.000337}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{185., 0.00034}}]}, 
         RowBox[{"{", 
           RowBox[{"185.`", ",", "0.00034`"}], "}"}]], 
        Annotation[#, {185., 0.00034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{186., 0.000338}}]}, 
         RowBox[{"{", 
           RowBox[{"186.`", ",", "0.000338`"}], "}"}]], 
        Annotation[#, {186., 0.000338}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{187., 0.000341}}]}, 
         RowBox[{"{", 
           RowBox[{"187.`", ",", "0.000341`"}], "}"}]], 
        Annotation[#, {187., 0.000341}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{188., 0.000461}}]}, 
         RowBox[{"{", 
           RowBox[{"188.`", ",", "0.000461`"}], "}"}]], 
        Annotation[#, {188., 0.000461}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{189., 0.000437}}]}, 
         RowBox[{"{", 
           RowBox[{"189.`", ",", "0.000437`"}], "}"}]], 
        Annotation[#, {189., 0.000437}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{190., 0.000354}}]}, 
         RowBox[{"{", 
           RowBox[{"190.`", ",", "0.000354`"}], "}"}]], 
        Annotation[#, {190., 0.000354}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{191., 0.00042}}]}, 
         RowBox[{"{", 
           RowBox[{"191.`", ",", "0.00042`"}], "}"}]], 
        Annotation[#, {191., 0.00042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{192., 0.000357}}]}, 
         RowBox[{"{", 
           RowBox[{"192.`", ",", "0.000357`"}], "}"}]], 
        Annotation[#, {192., 0.000357}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{193., 0.000356}}]}, 
         RowBox[{"{", 
           RowBox[{"193.`", ",", "0.000356`"}], "}"}]], 
        Annotation[#, {193., 0.000356}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{194., 0.000357}}]}, 
         RowBox[{"{", 
           RowBox[{"194.`", ",", "0.000357`"}], "}"}]], 
        Annotation[#, {194., 0.000357}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{195., 0.000361}}]}, 
         RowBox[{"{", 
           RowBox[{"195.`", ",", "0.000361`"}], "}"}]], 
        Annotation[#, {195., 0.000361}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{196., 0.00037}}]}, 
         RowBox[{"{", 
           RowBox[{"196.`", ",", "0.00037`"}], "}"}]], 
        Annotation[#, {196., 0.00037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{197., 0.00039}}]}, 
         RowBox[{"{", 
           RowBox[{"197.`", ",", "0.00039`"}], "}"}]], 
        Annotation[#, {197., 0.00039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{198., 0.000361}}]}, 
         RowBox[{"{", 
           RowBox[{"198.`", ",", "0.000361`"}], "}"}]], 
        Annotation[#, {198., 0.000361}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{199., 0.000363}}]}, 
         RowBox[{"{", 
           RowBox[{"199.`", ",", "0.000363`"}], "}"}]], 
        Annotation[#, {199., 0.000363}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{200., 0.000377}}]}, 
         RowBox[{"{", 
           RowBox[{"200.`", ",", "0.000377`"}], "}"}]], 
        Annotation[#, {200., 0.000377}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{201., 0.00037}}]}, 
         RowBox[{"{", 
           RowBox[{"201.`", ",", "0.00037`"}], "}"}]], 
        Annotation[#, {201., 0.00037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{202., 0.00037}}]}, 
         RowBox[{"{", 
           RowBox[{"202.`", ",", "0.00037`"}], "}"}]], 
        Annotation[#, {202., 0.00037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{203., 0.000374}}]}, 
         RowBox[{"{", 
           RowBox[{"203.`", ",", "0.000374`"}], "}"}]], 
        Annotation[#, {203., 0.000374}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{204., 0.000369}}]}, 
         RowBox[{"{", 
           RowBox[{"204.`", ",", "0.000369`"}], "}"}]], 
        Annotation[#, {204., 0.000369}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{205., 0.000374}}]}, 
         RowBox[{"{", 
           RowBox[{"205.`", ",", "0.000374`"}], "}"}]], 
        Annotation[#, {205., 0.000374}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{206., 0.000375}}]}, 
         RowBox[{"{", 
           RowBox[{"206.`", ",", "0.000375`"}], "}"}]], 
        Annotation[#, {206., 0.000375}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{207., 0.00038}}]}, 
         RowBox[{"{", 
           RowBox[{"207.`", ",", "0.00038`"}], "}"}]], 
        Annotation[#, {207., 0.00038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{208., 0.000381}}]}, 
         RowBox[{"{", 
           RowBox[{"208.`", ",", "0.000381`"}], "}"}]], 
        Annotation[#, {208., 0.000381}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{209., 0.000379}}]}, 
         RowBox[{"{", 
           RowBox[{"209.`", ",", "0.000379`"}], "}"}]], 
        Annotation[#, {209., 0.000379}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{210., 0.000381}}]}, 
         RowBox[{"{", 
           RowBox[{"210.`", ",", "0.000381`"}], "}"}]], 
        Annotation[#, {210., 0.000381}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{211., 0.000461}}]}, 
         RowBox[{"{", 
           RowBox[{"211.`", ",", "0.000461`"}], "}"}]], 
        Annotation[#, {211., 0.000461}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{212., 0.000385}}]}, 
         RowBox[{"{", 
           RowBox[{"212.`", ",", "0.000385`"}], "}"}]], 
        Annotation[#, {212., 0.000385}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{213., 0.000385}}]}, 
         RowBox[{"{", 
           RowBox[{"213.`", ",", "0.000385`"}], "}"}]], 
        Annotation[#, {213., 0.000385}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{214., 0.000396}}]}, 
         RowBox[{"{", 
           RowBox[{"214.`", ",", "0.000396`"}], "}"}]], 
        Annotation[#, {214., 0.000396}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{215., 0.000391}}]}, 
         RowBox[{"{", 
           RowBox[{"215.`", ",", "0.000391`"}], "}"}]], 
        Annotation[#, {215., 0.000391}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{216., 0.000392}}]}, 
         RowBox[{"{", 
           RowBox[{"216.`", ",", "0.000392`"}], "}"}]], 
        Annotation[#, {216., 0.000392}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{217., 0.000396}}]}, 
         RowBox[{"{", 
           RowBox[{"217.`", ",", "0.000396`"}], "}"}]], 
        Annotation[#, {217., 0.000396}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{218., 0.0004}}]}, 
         RowBox[{"{", 
           RowBox[{"218.`", ",", "0.0004`"}], "}"}]], 
        Annotation[#, {218., 0.0004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{219., 0.000395}}]}, 
         RowBox[{"{", 
           RowBox[{"219.`", ",", "0.000395`"}], "}"}]], 
        Annotation[#, {219., 0.000395}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{220., 0.000461}}]}, 
         RowBox[{"{", 
           RowBox[{"220.`", ",", "0.000461`"}], "}"}]], 
        Annotation[#, {220., 0.000461}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{221., 0.000408}}]}, 
         RowBox[{"{", 
           RowBox[{"221.`", ",", "0.000408`"}], "}"}]], 
        Annotation[#, {221., 0.000408}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{222., 0.000402}}]}, 
         RowBox[{"{", 
           RowBox[{"222.`", ",", "0.000402`"}], "}"}]], 
        Annotation[#, {222., 0.000402}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{223., 0.000408}}]}, 
         RowBox[{"{", 
           RowBox[{"223.`", ",", "0.000408`"}], "}"}]], 
        Annotation[#, {223., 0.000408}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{224., 0.000408}}]}, 
         RowBox[{"{", 
           RowBox[{"224.`", ",", "0.000408`"}], "}"}]], 
        Annotation[#, {224., 0.000408}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{225., 0.000411}}]}, 
         RowBox[{"{", 
           RowBox[{"225.`", ",", "0.000411`"}], "}"}]], 
        Annotation[#, {225., 0.000411}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{226., 0.000413}}]}, 
         RowBox[{"{", 
           RowBox[{"226.`", ",", "0.000413`"}], "}"}]], 
        Annotation[#, {226., 0.000413}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{227., 0.000412}}]}, 
         RowBox[{"{", 
           RowBox[{"227.`", ",", "0.000412`"}], "}"}]], 
        Annotation[#, {227., 0.000412}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{228., 0.000426}}]}, 
         RowBox[{"{", 
           RowBox[{"228.`", ",", "0.000426`"}], "}"}]], 
        Annotation[#, {228., 0.000426}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{229., 0.000408}}]}, 
         RowBox[{"{", 
           RowBox[{"229.`", ",", "0.000408`"}], "}"}]], 
        Annotation[#, {229., 0.000408}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{230., 0.000402}}]}, 
         RowBox[{"{", 
           RowBox[{"230.`", ",", "0.000402`"}], "}"}]], 
        Annotation[#, {230., 0.000402}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{231., 0.000403}}]}, 
         RowBox[{"{", 
           RowBox[{"231.`", ",", "0.000403`"}], "}"}]], 
        Annotation[#, {231., 0.000403}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{232., 0.000413}}]}, 
         RowBox[{"{", 
           RowBox[{"232.`", ",", "0.000413`"}], "}"}]], 
        Annotation[#, {232., 0.000413}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{233., 0.000408}}]}, 
         RowBox[{"{", 
           RowBox[{"233.`", ",", "0.000408`"}], "}"}]], 
        Annotation[#, {233., 0.000408}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{234., 0.000409}}]}, 
         RowBox[{"{", 
           RowBox[{"234.`", ",", "0.000409`"}], "}"}]], 
        Annotation[#, {234., 0.000409}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{235., 0.000415}}]}, 
         RowBox[{"{", 
           RowBox[{"235.`", ",", "0.000415`"}], "}"}]], 
        Annotation[#, {235., 0.000415}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{236., 0.000419}}]}, 
         RowBox[{"{", 
           RowBox[{"236.`", ",", "0.000419`"}], "}"}]], 
        Annotation[#, {236., 0.000419}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{237., 0.000399}}]}, 
         RowBox[{"{", 
           RowBox[{"237.`", ",", "0.000399`"}], "}"}]], 
        Annotation[#, {237., 0.000399}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{238., 0.000556}}]}, 
         RowBox[{"{", 
           RowBox[{"238.`", ",", "0.000556`"}], "}"}]], 
        Annotation[#, {238., 0.000556}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{239., 0.000419}}]}, 
         RowBox[{"{", 
           RowBox[{"239.`", ",", "0.000419`"}], "}"}]], 
        Annotation[#, {239., 0.000419}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{240., 0.000424}}]}, 
         RowBox[{"{", 
           RowBox[{"240.`", ",", "0.000424`"}], "}"}]], 
        Annotation[#, {240., 0.000424}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{241., 0.000425}}]}, 
         RowBox[{"{", 
           RowBox[{"241.`", ",", "0.000425`"}], "}"}]], 
        Annotation[#, {241., 0.000425}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{242., 0.000424}}]}, 
         RowBox[{"{", 
           RowBox[{"242.`", ",", "0.000424`"}], "}"}]], 
        Annotation[#, {242., 0.000424}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{243., 0.000432}}]}, 
         RowBox[{"{", 
           RowBox[{"243.`", ",", "0.000432`"}], "}"}]], 
        Annotation[#, {243., 0.000432}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{244., 0.000431}}]}, 
         RowBox[{"{", 
           RowBox[{"244.`", ",", "0.000431`"}], "}"}]], 
        Annotation[#, {244., 0.000431}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{245., 0.000432}}]}, 
         RowBox[{"{", 
           RowBox[{"245.`", ",", "0.000432`"}], "}"}]], 
        Annotation[#, {245., 0.000432}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{246., 0.000414}}]}, 
         RowBox[{"{", 
           RowBox[{"246.`", ",", "0.000414`"}], "}"}]], 
        Annotation[#, {246., 0.000414}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{247., 0.000424}}]}, 
         RowBox[{"{", 
           RowBox[{"247.`", ",", "0.000424`"}], "}"}]], 
        Annotation[#, {247., 0.000424}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{248., 0.000419}}]}, 
         RowBox[{"{", 
           RowBox[{"248.`", ",", "0.000419`"}], "}"}]], 
        Annotation[#, {248., 0.000419}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{249., 0.00042}}]}, 
         RowBox[{"{", 
           RowBox[{"249.`", ",", "0.00042`"}], "}"}]], 
        Annotation[#, {249., 0.00042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{250., 0.000426}}]}, 
         RowBox[{"{", 
           RowBox[{"250.`", ",", "0.000426`"}], "}"}]], 
        Annotation[#, {250., 0.000426}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{251., 0.000429}}]}, 
         RowBox[{"{", 
           RowBox[{"251.`", ",", "0.000429`"}], "}"}]], 
        Annotation[#, {251., 0.000429}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{252., 0.000428}}]}, 
         RowBox[{"{", 
           RowBox[{"252.`", ",", "0.000428`"}], "}"}]], 
        Annotation[#, {252., 0.000428}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{253., 0.000416}}]}, 
         RowBox[{"{", 
           RowBox[{"253.`", ",", "0.000416`"}], "}"}]], 
        Annotation[#, {253., 0.000416}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{254., 0.000419}}]}, 
         RowBox[{"{", 
           RowBox[{"254.`", ",", "0.000419`"}], "}"}]], 
        Annotation[#, {254., 0.000419}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{255., 0.000415}}]}, 
         RowBox[{"{", 
           RowBox[{"255.`", ",", "0.000415`"}], "}"}]], 
        Annotation[#, {255., 0.000415}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{256., 0.000421}}]}, 
         RowBox[{"{", 
           RowBox[{"256.`", ",", "0.000421`"}], "}"}]], 
        Annotation[#, {256., 0.000421}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{257., 0.000444}}]}, 
         RowBox[{"{", 
           RowBox[{"257.`", ",", "0.000444`"}], "}"}]], 
        Annotation[#, {257., 0.000444}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{258., 0.000426}}]}, 
         RowBox[{"{", 
           RowBox[{"258.`", ",", "0.000426`"}], "}"}]], 
        Annotation[#, {258., 0.000426}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{259., 0.000427}}]}, 
         RowBox[{"{", 
           RowBox[{"259.`", ",", "0.000427`"}], "}"}]], 
        Annotation[#, {259., 0.000427}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{260., 0.000425}}]}, 
         RowBox[{"{", 
           RowBox[{"260.`", ",", "0.000425`"}], "}"}]], 
        Annotation[#, {260., 0.000425}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{261., 0.000426}}]}, 
         RowBox[{"{", 
           RowBox[{"261.`", ",", "0.000426`"}], "}"}]], 
        Annotation[#, {261., 0.000426}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{262., 0.000435}}]}, 
         RowBox[{"{", 
           RowBox[{"262.`", ",", "0.000435`"}], "}"}]], 
        Annotation[#, {262., 0.000435}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{263., 0.000441}}]}, 
         RowBox[{"{", 
           RowBox[{"263.`", ",", "0.000441`"}], "}"}]], 
        Annotation[#, {263., 0.000441}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{264., 0.000416}}]}, 
         RowBox[{"{", 
           RowBox[{"264.`", ",", "0.000416`"}], "}"}]], 
        Annotation[#, {264., 0.000416}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{265., 0.000426}}]}, 
         RowBox[{"{", 
           RowBox[{"265.`", ",", "0.000426`"}], "}"}]], 
        Annotation[#, {265., 0.000426}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{266., 0.000422}}]}, 
         RowBox[{"{", 
           RowBox[{"266.`", ",", "0.000422`"}], "}"}]], 
        Annotation[#, {266., 0.000422}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{267., 0.000421}}]}, 
         RowBox[{"{", 
           RowBox[{"267.`", ",", "0.000421`"}], "}"}]], 
        Annotation[#, {267., 0.000421}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{268., 0.000427}}]}, 
         RowBox[{"{", 
           RowBox[{"268.`", ",", "0.000427`"}], "}"}]], 
        Annotation[#, {268., 0.000427}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{269., 0.000431}}]}, 
         RowBox[{"{", 
           RowBox[{"269.`", ",", "0.000431`"}], "}"}]], 
        Annotation[#, {269., 0.000431}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{270., 0.000427}}]}, 
         RowBox[{"{", 
           RowBox[{"270.`", ",", "0.000427`"}], "}"}]], 
        Annotation[#, {270., 0.000427}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{271., 0.000433}}]}, 
         RowBox[{"{", 
           RowBox[{"271.`", ",", "0.000433`"}], "}"}]], 
        Annotation[#, {271., 0.000433}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{272., 0.000431}}]}, 
         RowBox[{"{", 
           RowBox[{"272.`", ",", "0.000431`"}], "}"}]], 
        Annotation[#, {272., 0.000431}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{273., 0.000435}}]}, 
         RowBox[{"{", 
           RowBox[{"273.`", ",", "0.000435`"}], "}"}]], 
        Annotation[#, {273., 0.000435}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{274., 0.000436}}]}, 
         RowBox[{"{", 
           RowBox[{"274.`", ",", "0.000436`"}], "}"}]], 
        Annotation[#, {274., 0.000436}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{275., 0.000435}}]}, 
         RowBox[{"{", 
           RowBox[{"275.`", ",", "0.000435`"}], "}"}]], 
        Annotation[#, {275., 0.000435}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{276., 0.000441}}]}, 
         RowBox[{"{", 
           RowBox[{"276.`", ",", "0.000441`"}], "}"}]], 
        Annotation[#, {276., 0.000441}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{277., 0.000517}}]}, 
         RowBox[{"{", 
           RowBox[{"277.`", ",", "0.000517`"}], "}"}]], 
        Annotation[#, {277., 0.000517}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{278., 0.00045}}]}, 
         RowBox[{"{", 
           RowBox[{"278.`", ",", "0.00045`"}], "}"}]], 
        Annotation[#, {278., 0.00045}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{279., 0.000427}}]}, 
         RowBox[{"{", 
           RowBox[{"279.`", ",", "0.000427`"}], "}"}]], 
        Annotation[#, {279., 0.000427}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{280., 0.000446}}]}, 
         RowBox[{"{", 
           RowBox[{"280.`", ",", "0.000446`"}], "}"}]], 
        Annotation[#, {280., 0.000446}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{281., 0.000431}}]}, 
         RowBox[{"{", 
           RowBox[{"281.`", ",", "0.000431`"}], "}"}]], 
        Annotation[#, {281., 0.000431}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{282., 0.000432}}]}, 
         RowBox[{"{", 
           RowBox[{"282.`", ",", "0.000432`"}], "}"}]], 
        Annotation[#, {282., 0.000432}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{283., 0.000437}}]}, 
         RowBox[{"{", 
           RowBox[{"283.`", ",", "0.000437`"}], "}"}]], 
        Annotation[#, {283., 0.000437}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{284., 0.000438}}]}, 
         RowBox[{"{", 
           RowBox[{"284.`", ",", "0.000438`"}], "}"}]], 
        Annotation[#, {284., 0.000438}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{285., 0.000436}}]}, 
         RowBox[{"{", 
           RowBox[{"285.`", ",", "0.000436`"}], "}"}]], 
        Annotation[#, {285., 0.000436}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{286., 0.000443}}]}, 
         RowBox[{"{", 
           RowBox[{"286.`", ",", "0.000443`"}], "}"}]], 
        Annotation[#, {286., 0.000443}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{287., 0.000447}}]}, 
         RowBox[{"{", 
           RowBox[{"287.`", ",", "0.000447`"}], "}"}]], 
        Annotation[#, {287., 0.000447}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{288., 0.000441}}]}, 
         RowBox[{"{", 
           RowBox[{"288.`", ",", "0.000441`"}], "}"}]], 
        Annotation[#, {288., 0.000441}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{289., 0.000446}}]}, 
         RowBox[{"{", 
           RowBox[{"289.`", ",", "0.000446`"}], "}"}]], 
        Annotation[#, {289., 0.000446}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{290., 0.000445}}]}, 
         RowBox[{"{", 
           RowBox[{"290.`", ",", "0.000445`"}], "}"}]], 
        Annotation[#, {290., 0.000445}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{291., 0.000448}}]}, 
         RowBox[{"{", 
           RowBox[{"291.`", ",", "0.000448`"}], "}"}]], 
        Annotation[#, {291., 0.000448}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{292., 0.000452}}]}, 
         RowBox[{"{", 
           RowBox[{"292.`", ",", "0.000452`"}], "}"}]], 
        Annotation[#, {292., 0.000452}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{293., 0.000449}}]}, 
         RowBox[{"{", 
           RowBox[{"293.`", ",", "0.000449`"}], "}"}]], 
        Annotation[#, {293., 0.000449}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{294., 0.000449}}]}, 
         RowBox[{"{", 
           RowBox[{"294.`", ",", "0.000449`"}], "}"}]], 
        Annotation[#, {294., 0.000449}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{295., 0.000459}}]}, 
         RowBox[{"{", 
           RowBox[{"295.`", ",", "0.000459`"}], "}"}]], 
        Annotation[#, {295., 0.000459}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{296., 0.000452}}]}, 
         RowBox[{"{", 
           RowBox[{"296.`", ",", "0.000452`"}], "}"}]], 
        Annotation[#, {296., 0.000452}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{297., 0.000453}}]}, 
         RowBox[{"{", 
           RowBox[{"297.`", ",", "0.000453`"}], "}"}]], 
        Annotation[#, {297., 0.000453}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{298., 0.000463}}]}, 
         RowBox[{"{", 
           RowBox[{"298.`", ",", "0.000463`"}], "}"}]], 
        Annotation[#, {298., 0.000463}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{299., 0.000456}}]}, 
         RowBox[{"{", 
           RowBox[{"299.`", ",", "0.000456`"}], "}"}]], 
        Annotation[#, {299., 0.000456}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{300., 0.000457}}]}, 
         RowBox[{"{", 
           RowBox[{"300.`", ",", "0.000457`"}], "}"}]], 
        Annotation[#, {300., 0.000457}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{301., 0.000463}}]}, 
         RowBox[{"{", 
           RowBox[{"301.`", ",", "0.000463`"}], "}"}]], 
        Annotation[#, {301., 0.000463}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{302., 0.000468}}]}, 
         RowBox[{"{", 
           RowBox[{"302.`", ",", "0.000468`"}], "}"}]], 
        Annotation[#, {302., 0.000468}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{303., 0.000463}}]}, 
         RowBox[{"{", 
           RowBox[{"303.`", ",", "0.000463`"}], "}"}]], 
        Annotation[#, {303., 0.000463}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{304., 0.00047}}]}, 
         RowBox[{"{", 
           RowBox[{"304.`", ",", "0.00047`"}], "}"}]], 
        Annotation[#, {304., 0.00047}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{305., 0.000467}}]}, 
         RowBox[{"{", 
           RowBox[{"305.`", ",", "0.000467`"}], "}"}]], 
        Annotation[#, {305., 0.000467}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{306., 0.000471}}]}, 
         RowBox[{"{", 
           RowBox[{"306.`", ",", "0.000471`"}], "}"}]], 
        Annotation[#, {306., 0.000471}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{307., 0.000474}}]}, 
         RowBox[{"{", 
           RowBox[{"307.`", ",", "0.000474`"}], "}"}]], 
        Annotation[#, {307., 0.000474}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{308., 0.000472}}]}, 
         RowBox[{"{", 
           RowBox[{"308.`", ",", "0.000472`"}], "}"}]], 
        Annotation[#, {308., 0.000472}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{309., 0.000476}}]}, 
         RowBox[{"{", 
           RowBox[{"309.`", ",", "0.000476`"}], "}"}]], 
        Annotation[#, {309., 0.000476}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{310., 0.000478}}]}, 
         RowBox[{"{", 
           RowBox[{"310.`", ",", "0.000478`"}], "}"}]], 
        Annotation[#, {310., 0.000478}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{311., 0.00048}}]}, 
         RowBox[{"{", 
           RowBox[{"311.`", ",", "0.00048`"}], "}"}]], 
        Annotation[#, {311., 0.00048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{312., 0.000477}}]}, 
         RowBox[{"{", 
           RowBox[{"312.`", ",", "0.000477`"}], "}"}]], 
        Annotation[#, {312., 0.000477}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{313., 0.000487}}]}, 
         RowBox[{"{", 
           RowBox[{"313.`", ",", "0.000487`"}], "}"}]], 
        Annotation[#, {313., 0.000487}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{314., 0.000481}}]}, 
         RowBox[{"{", 
           RowBox[{"314.`", ",", "0.000481`"}], "}"}]], 
        Annotation[#, {314., 0.000481}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{315., 0.00048}}]}, 
         RowBox[{"{", 
           RowBox[{"315.`", ",", "0.00048`"}], "}"}]], 
        Annotation[#, {315., 0.00048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{316., 0.000487}}]}, 
         RowBox[{"{", 
           RowBox[{"316.`", ",", "0.000487`"}], "}"}]], 
        Annotation[#, {316., 0.000487}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{317., 0.000488}}]}, 
         RowBox[{"{", 
           RowBox[{"317.`", ",", "0.000488`"}], "}"}]], 
        Annotation[#, {317., 0.000488}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{318., 0.000485}}]}, 
         RowBox[{"{", 
           RowBox[{"318.`", ",", "0.000485`"}], "}"}]], 
        Annotation[#, {318., 0.000485}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{319., 0.000491}}]}, 
         RowBox[{"{", 
           RowBox[{"319.`", ",", "0.000491`"}], "}"}]], 
        Annotation[#, {319., 0.000491}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{320., 0.000501}}]}, 
         RowBox[{"{", 
           RowBox[{"320.`", ",", "0.000501`"}], "}"}]], 
        Annotation[#, {320., 0.000501}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{321., 0.000492}}]}, 
         RowBox[{"{", 
           RowBox[{"321.`", ",", "0.000492`"}], "}"}]], 
        Annotation[#, {321., 0.000492}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{322., 0.000497}}]}, 
         RowBox[{"{", 
           RowBox[{"322.`", ",", "0.000497`"}], "}"}]], 
        Annotation[#, {322., 0.000497}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{323., 0.000498}}]}, 
         RowBox[{"{", 
           RowBox[{"323.`", ",", "0.000498`"}], "}"}]], 
        Annotation[#, {323., 0.000498}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{324., 0.000499}}]}, 
         RowBox[{"{", 
           RowBox[{"324.`", ",", "0.000499`"}], "}"}]], 
        Annotation[#, {324., 0.000499}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{325., 0.000501}}]}, 
         RowBox[{"{", 
           RowBox[{"325.`", ",", "0.000501`"}], "}"}]], 
        Annotation[#, {325., 0.000501}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{326., 0.000588}}]}, 
         RowBox[{"{", 
           RowBox[{"326.`", ",", "0.000588`"}], "}"}]], 
        Annotation[#, {326., 0.000588}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{327., 0.000502}}]}, 
         RowBox[{"{", 
           RowBox[{"327.`", ",", "0.000502`"}], "}"}]], 
        Annotation[#, {327., 0.000502}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{328., 0.000514}}]}, 
         RowBox[{"{", 
           RowBox[{"328.`", ",", "0.000514`"}], "}"}]], 
        Annotation[#, {328., 0.000514}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{329., 0.000505}}]}, 
         RowBox[{"{", 
           RowBox[{"329.`", ",", "0.000505`"}], "}"}]], 
        Annotation[#, {329., 0.000505}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{330., 0.000504}}]}, 
         RowBox[{"{", 
           RowBox[{"330.`", ",", "0.000504`"}], "}"}]], 
        Annotation[#, {330., 0.000504}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{331., 0.000517}}]}, 
         RowBox[{"{", 
           RowBox[{"331.`", ",", "0.000517`"}], "}"}]], 
        Annotation[#, {331., 0.000517}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{332., 0.000509}}]}, 
         RowBox[{"{", 
           RowBox[{"332.`", ",", "0.000509`"}], "}"}]], 
        Annotation[#, {332., 0.000509}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{333., 0.000511}}]}, 
         RowBox[{"{", 
           RowBox[{"333.`", ",", "0.000511`"}], "}"}]], 
        Annotation[#, {333., 0.000511}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{334., 0.000517}}]}, 
         RowBox[{"{", 
           RowBox[{"334.`", ",", "0.000517`"}], "}"}]], 
        Annotation[#, {334., 0.000517}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{335., 0.000519}}]}, 
         RowBox[{"{", 
           RowBox[{"335.`", ",", "0.000519`"}], "}"}]], 
        Annotation[#, {335., 0.000519}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{336., 0.000515}}]}, 
         RowBox[{"{", 
           RowBox[{"336.`", ",", "0.000515`"}], "}"}]], 
        Annotation[#, {336., 0.000515}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{337., 0.000521}}]}, 
         RowBox[{"{", 
           RowBox[{"337.`", ",", "0.000521`"}], "}"}]], 
        Annotation[#, {337., 0.000521}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{338., 0.000518}}]}, 
         RowBox[{"{", 
           RowBox[{"338.`", ",", "0.000518`"}], "}"}]], 
        Annotation[#, {338., 0.000518}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{339., 0.000523}}]}, 
         RowBox[{"{", 
           RowBox[{"339.`", ",", "0.000523`"}], "}"}]], 
        Annotation[#, {339., 0.000523}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{340., 0.000526}}]}, 
         RowBox[{"{", 
           RowBox[{"340.`", ",", "0.000526`"}], "}"}]], 
        Annotation[#, {340., 0.000526}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{341., 0.000524}}]}, 
         RowBox[{"{", 
           RowBox[{"341.`", ",", "0.000524`"}], "}"}]], 
        Annotation[#, {341., 0.000524}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{342., 0.000528}}]}, 
         RowBox[{"{", 
           RowBox[{"342.`", ",", "0.000528`"}], "}"}]], 
        Annotation[#, {342., 0.000528}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{343., 0.000531}}]}, 
         RowBox[{"{", 
           RowBox[{"343.`", ",", "0.000531`"}], "}"}]], 
        Annotation[#, {343., 0.000531}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{344., 0.000529}}]}, 
         RowBox[{"{", 
           RowBox[{"344.`", ",", "0.000529`"}], "}"}]], 
        Annotation[#, {344., 0.000529}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{345., 0.000533}}]}, 
         RowBox[{"{", 
           RowBox[{"345.`", ",", "0.000533`"}], "}"}]], 
        Annotation[#, {345., 0.000533}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{346., 0.00054}}]}, 
         RowBox[{"{", 
           RowBox[{"346.`", ",", "0.00054`"}], "}"}]], 
        Annotation[#, {346., 0.00054}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{347., 0.000536}}]}, 
         RowBox[{"{", 
           RowBox[{"347.`", ",", "0.000536`"}], "}"}]], 
        Annotation[#, {347., 0.000536}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{348., 0.000529}}]}, 
         RowBox[{"{", 
           RowBox[{"348.`", ",", "0.000529`"}], "}"}]], 
        Annotation[#, {348., 0.000529}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{349., 0.000542}}]}, 
         RowBox[{"{", 
           RowBox[{"349.`", ",", "0.000542`"}], "}"}]], 
        Annotation[#, {349., 0.000542}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{350., 0.000535}}]}, 
         RowBox[{"{", 
           RowBox[{"350.`", ",", "0.000535`"}], "}"}]], 
        Annotation[#, {350., 0.000535}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{351., 0.000536}}]}, 
         RowBox[{"{", 
           RowBox[{"351.`", ",", "0.000536`"}], "}"}]], 
        Annotation[#, {351., 0.000536}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{352., 0.000543}}]}, 
         RowBox[{"{", 
           RowBox[{"352.`", ",", "0.000543`"}], "}"}]], 
        Annotation[#, {352., 0.000543}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{353., 0.000543}}]}, 
         RowBox[{"{", 
           RowBox[{"353.`", ",", "0.000543`"}], "}"}]], 
        Annotation[#, {353., 0.000543}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{354., 0.00054}}]}, 
         RowBox[{"{", 
           RowBox[{"354.`", ",", "0.00054`"}], "}"}]], 
        Annotation[#, {354., 0.00054}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{355., 0.000547}}]}, 
         RowBox[{"{", 
           RowBox[{"355.`", ",", "0.000547`"}], "}"}]], 
        Annotation[#, {355., 0.000547}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{356., 0.000544}}]}, 
         RowBox[{"{", 
           RowBox[{"356.`", ",", "0.000544`"}], "}"}]], 
        Annotation[#, {356., 0.000544}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{357., 0.000548}}]}, 
         RowBox[{"{", 
           RowBox[{"357.`", ",", "0.000548`"}], "}"}]], 
        Annotation[#, {357., 0.000548}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{358., 0.000552}}]}, 
         RowBox[{"{", 
           RowBox[{"358.`", ",", "0.000552`"}], "}"}]], 
        Annotation[#, {358., 0.000552}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{359., 0.000548}}]}, 
         RowBox[{"{", 
           RowBox[{"359.`", ",", "0.000548`"}], "}"}]], 
        Annotation[#, {359., 0.000548}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{360., 0.000551}}]}, 
         RowBox[{"{", 
           RowBox[{"360.`", ",", "0.000551`"}], "}"}]], 
        Annotation[#, {360., 0.000551}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{361., 0.000555}}]}, 
         RowBox[{"{", 
           RowBox[{"361.`", ",", "0.000555`"}], "}"}]], 
        Annotation[#, {361., 0.000555}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{362., 0.000553}}]}, 
         RowBox[{"{", 
           RowBox[{"362.`", ",", "0.000553`"}], "}"}]], 
        Annotation[#, {362., 0.000553}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{363., 0.000557}}]}, 
         RowBox[{"{", 
           RowBox[{"363.`", ",", "0.000557`"}], "}"}]], 
        Annotation[#, {363., 0.000557}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{364., 0.000564}}]}, 
         RowBox[{"{", 
           RowBox[{"364.`", ",", "0.000564`"}], "}"}]], 
        Annotation[#, {364., 0.000564}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{365., 0.000557}}]}, 
         RowBox[{"{", 
           RowBox[{"365.`", ",", "0.000557`"}], "}"}]], 
        Annotation[#, {365., 0.000557}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{366., 0.000557}}]}, 
         RowBox[{"{", 
           RowBox[{"366.`", ",", "0.000557`"}], "}"}]], 
        Annotation[#, {366., 0.000557}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{367., 0.000564}}]}, 
         RowBox[{"{", 
           RowBox[{"367.`", ",", "0.000564`"}], "}"}]], 
        Annotation[#, {367., 0.000564}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{368., 0.000565}}]}, 
         RowBox[{"{", 
           RowBox[{"368.`", ",", "0.000565`"}], "}"}]], 
        Annotation[#, {368., 0.000565}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{369., 0.000562}}]}, 
         RowBox[{"{", 
           RowBox[{"369.`", ",", "0.000562`"}], "}"}]], 
        Annotation[#, {369., 0.000562}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{370., 0.00057}}]}, 
         RowBox[{"{", 
           RowBox[{"370.`", ",", "0.00057`"}], "}"}]], 
        Annotation[#, {370., 0.00057}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{371., 0.000571}}]}, 
         RowBox[{"{", 
           RowBox[{"371.`", ",", "0.000571`"}], "}"}]], 
        Annotation[#, {371., 0.000571}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{372., 0.000567}}]}, 
         RowBox[{"{", 
           RowBox[{"372.`", ",", "0.000567`"}], "}"}]], 
        Annotation[#, {372., 0.000567}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{373., 0.000575}}]}, 
         RowBox[{"{", 
           RowBox[{"373.`", ",", "0.000575`"}], "}"}]], 
        Annotation[#, {373., 0.000575}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{374., 0.000571}}]}, 
         RowBox[{"{", 
           RowBox[{"374.`", ",", "0.000571`"}], "}"}]], 
        Annotation[#, {374., 0.000571}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{375., 0.000575}}]}, 
         RowBox[{"{", 
           RowBox[{"375.`", ",", "0.000575`"}], "}"}]], 
        Annotation[#, {375., 0.000575}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{376., 0.000583}}]}, 
         RowBox[{"{", 
           RowBox[{"376.`", ",", "0.000583`"}], "}"}]], 
        Annotation[#, {376., 0.000583}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{377., 0.000576}}]}, 
         RowBox[{"{", 
           RowBox[{"377.`", ",", "0.000576`"}], "}"}]], 
        Annotation[#, {377., 0.000576}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{378., 0.000575}}]}, 
         RowBox[{"{", 
           RowBox[{"378.`", ",", "0.000575`"}], "}"}]], 
        Annotation[#, {378., 0.000575}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{379., 0.000588}}]}, 
         RowBox[{"{", 
           RowBox[{"379.`", ",", "0.000588`"}], "}"}]], 
        Annotation[#, {379., 0.000588}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{380., 0.000582}}]}, 
         RowBox[{"{", 
           RowBox[{"380.`", ",", "0.000582`"}], "}"}]], 
        Annotation[#, {380., 0.000582}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{381., 0.000584}}]}, 
         RowBox[{"{", 
           RowBox[{"381.`", ",", "0.000584`"}], "}"}]], 
        Annotation[#, {381., 0.000584}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{382., 0.000592}}]}, 
         RowBox[{"{", 
           RowBox[{"382.`", ",", "0.000592`"}], "}"}]], 
        Annotation[#, {382., 0.000592}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{383., 0.000585}}]}, 
         RowBox[{"{", 
           RowBox[{"383.`", ",", "0.000585`"}], "}"}]], 
        Annotation[#, {383., 0.000585}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{384., 0.000586}}]}, 
         RowBox[{"{", 
           RowBox[{"384.`", ",", "0.000586`"}], "}"}]], 
        Annotation[#, {384., 0.000586}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{385., 0.000593}}]}, 
         RowBox[{"{", 
           RowBox[{"385.`", ",", "0.000593`"}], "}"}]], 
        Annotation[#, {385., 0.000593}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{386., 0.000595}}]}, 
         RowBox[{"{", 
           RowBox[{"386.`", ",", "0.000595`"}], "}"}]], 
        Annotation[#, {386., 0.000595}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{387., 0.00059}}]}, 
         RowBox[{"{", 
           RowBox[{"387.`", ",", "0.00059`"}], "}"}]], 
        Annotation[#, {387., 0.00059}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{388., 0.000597}}]}, 
         RowBox[{"{", 
           RowBox[{"388.`", ",", "0.000597`"}], "}"}]], 
        Annotation[#, {388., 0.000597}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{389., 0.000594}}]}, 
         RowBox[{"{", 
           RowBox[{"389.`", ",", "0.000594`"}], "}"}]], 
        Annotation[#, {389., 0.000594}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{390., 0.000598}}]}, 
         RowBox[{"{", 
           RowBox[{"390.`", ",", "0.000598`"}], "}"}]], 
        Annotation[#, {390., 0.000598}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{391., 0.000602}}]}, 
         RowBox[{"{", 
           RowBox[{"391.`", ",", "0.000602`"}], "}"}]], 
        Annotation[#, {391., 0.000602}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{392., 0.000599}}]}, 
         RowBox[{"{", 
           RowBox[{"392.`", ",", "0.000599`"}], "}"}]], 
        Annotation[#, {392., 0.000599}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{393., 0.000602}}]}, 
         RowBox[{"{", 
           RowBox[{"393.`", ",", "0.000602`"}], "}"}]], 
        Annotation[#, {393., 0.000602}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{394., 0.000605}}]}, 
         RowBox[{"{", 
           RowBox[{"394.`", ",", "0.000605`"}], "}"}]], 
        Annotation[#, {394., 0.000605}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{395., 0.000603}}]}, 
         RowBox[{"{", 
           RowBox[{"395.`", ",", "0.000603`"}], "}"}]], 
        Annotation[#, {395., 0.000603}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{396., 0.000602}}]}, 
         RowBox[{"{", 
           RowBox[{"396.`", ",", "0.000602`"}], "}"}]], 
        Annotation[#, {396., 0.000602}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{397., 0.000616}}]}, 
         RowBox[{"{", 
           RowBox[{"397.`", ",", "0.000616`"}], "}"}]], 
        Annotation[#, {397., 0.000616}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{398., 0.000608}}]}, 
         RowBox[{"{", 
           RowBox[{"398.`", ",", "0.000608`"}], "}"}]], 
        Annotation[#, {398., 0.000608}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{399., 0.000608}}]}, 
         RowBox[{"{", 
           RowBox[{"399.`", ",", "0.000608`"}], "}"}]], 
        Annotation[#, {399., 0.000608}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{400., 0.000615}}]}, 
         RowBox[{"{", 
           RowBox[{"400.`", ",", "0.000615`"}], "}"}]], 
        Annotation[#, {400., 0.000615}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{401., 0.000617}}]}, 
         RowBox[{"{", 
           RowBox[{"401.`", ",", "0.000617`"}], "}"}]], 
        Annotation[#, {401., 0.000617}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{402., 0.000611}}]}, 
         RowBox[{"{", 
           RowBox[{"402.`", ",", "0.000611`"}], "}"}]], 
        Annotation[#, {402., 0.000611}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{403., 0.00062}}]}, 
         RowBox[{"{", 
           RowBox[{"403.`", ",", "0.00062`"}], "}"}]], 
        Annotation[#, {403., 0.00062}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{404., 0.00062}}]}, 
         RowBox[{"{", 
           RowBox[{"404.`", ",", "0.00062`"}], "}"}]], 
        Annotation[#, {404., 0.00062}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{405., 0.000621}}]}, 
         RowBox[{"{", 
           RowBox[{"405.`", ",", "0.000621`"}], "}"}]], 
        Annotation[#, {405., 0.000621}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{406., 0.000627}}]}, 
         RowBox[{"{", 
           RowBox[{"406.`", ",", "0.000627`"}], "}"}]], 
        Annotation[#, {406., 0.000627}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{407., 0.000621}}]}, 
         RowBox[{"{", 
           RowBox[{"407.`", ",", "0.000621`"}], "}"}]], 
        Annotation[#, {407., 0.000621}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{408., 0.000625}}]}, 
         RowBox[{"{", 
           RowBox[{"408.`", ",", "0.000625`"}], "}"}]], 
        Annotation[#, {408., 0.000625}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{409., 0.00063}}]}, 
         RowBox[{"{", 
           RowBox[{"409.`", ",", "0.00063`"}], "}"}]], 
        Annotation[#, {409., 0.00063}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{410., 0.000628}}]}, 
         RowBox[{"{", 
           RowBox[{"410.`", ",", "0.000628`"}], "}"}]], 
        Annotation[#, {410., 0.000628}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{411., 0.000629}}]}, 
         RowBox[{"{", 
           RowBox[{"411.`", ",", "0.000629`"}], "}"}]], 
        Annotation[#, {411., 0.000629}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{412., 0.000641}}]}, 
         RowBox[{"{", 
           RowBox[{"412.`", ",", "0.000641`"}], "}"}]], 
        Annotation[#, {412., 0.000641}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{413., 0.000634}}]}, 
         RowBox[{"{", 
           RowBox[{"413.`", ",", "0.000634`"}], "}"}]], 
        Annotation[#, {413., 0.000634}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{414., 0.00063}}]}, 
         RowBox[{"{", 
           RowBox[{"414.`", ",", "0.00063`"}], "}"}]], 
        Annotation[#, {414., 0.00063}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{415., 0.000743}}]}, 
         RowBox[{"{", 
           RowBox[{"415.`", ",", "0.000743`"}], "}"}]], 
        Annotation[#, {415., 0.000743}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{416., 0.000636}}]}, 
         RowBox[{"{", 
           RowBox[{"416.`", ",", "0.000636`"}], "}"}]], 
        Annotation[#, {416., 0.000636}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{417., 0.000634}}]}, 
         RowBox[{"{", 
           RowBox[{"417.`", ",", "0.000634`"}], "}"}]], 
        Annotation[#, {417., 0.000634}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{418., 0.000643}}]}, 
         RowBox[{"{", 
           RowBox[{"418.`", ",", "0.000643`"}], "}"}]], 
        Annotation[#, {418., 0.000643}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{419., 0.000643}}]}, 
         RowBox[{"{", 
           RowBox[{"419.`", ",", "0.000643`"}], "}"}]], 
        Annotation[#, {419., 0.000643}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{420., 0.000639}}]}, 
         RowBox[{"{", 
           RowBox[{"420.`", ",", "0.000639`"}], "}"}]], 
        Annotation[#, {420., 0.000639}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{421., 0.000648}}]}, 
         RowBox[{"{", 
           RowBox[{"421.`", ",", "0.000648`"}], "}"}]], 
        Annotation[#, {421., 0.000648}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{422., 0.000645}}]}, 
         RowBox[{"{", 
           RowBox[{"422.`", ",", "0.000645`"}], "}"}]], 
        Annotation[#, {422., 0.000645}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{423., 0.000648}}]}, 
         RowBox[{"{", 
           RowBox[{"423.`", ",", "0.000648`"}], "}"}]], 
        Annotation[#, {423., 0.000648}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{424., 0.000652}}]}, 
         RowBox[{"{", 
           RowBox[{"424.`", ",", "0.000652`"}], "}"}]], 
        Annotation[#, {424., 0.000652}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{425., 0.000649}}]}, 
         RowBox[{"{", 
           RowBox[{"425.`", ",", "0.000649`"}], "}"}]], 
        Annotation[#, {425., 0.000649}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{426., 0.000652}}]}, 
         RowBox[{"{", 
           RowBox[{"426.`", ",", "0.000652`"}], "}"}]], 
        Annotation[#, {426., 0.000652}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{427., 0.000656}}]}, 
         RowBox[{"{", 
           RowBox[{"427.`", ",", "0.000656`"}], "}"}]], 
        Annotation[#, {427., 0.000656}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{428., 0.000653}}]}, 
         RowBox[{"{", 
           RowBox[{"428.`", ",", "0.000653`"}], "}"}]], 
        Annotation[#, {428., 0.000653}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{429., 0.000653}}]}, 
         RowBox[{"{", 
           RowBox[{"429.`", ",", "0.000653`"}], "}"}]], 
        Annotation[#, {429., 0.000653}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{430., 0.000679}}]}, 
         RowBox[{"{", 
           RowBox[{"430.`", ",", "0.000679`"}], "}"}]], 
        Annotation[#, {430., 0.000679}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{431., 0.000658}}]}, 
         RowBox[{"{", 
           RowBox[{"431.`", ",", "0.000658`"}], "}"}]], 
        Annotation[#, {431., 0.000658}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{432., 0.000656}}]}, 
         RowBox[{"{", 
           RowBox[{"432.`", ",", "0.000656`"}], "}"}]], 
        Annotation[#, {432., 0.000656}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{433., 0.000673}}]}, 
         RowBox[{"{", 
           RowBox[{"433.`", ",", "0.000673`"}], "}"}]], 
        Annotation[#, {433., 0.000673}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{434., 0.000646}}]}, 
         RowBox[{"{", 
           RowBox[{"434.`", ",", "0.000646`"}], "}"}]], 
        Annotation[#, {434., 0.000646}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{435., 0.000642}}]}, 
         RowBox[{"{", 
           RowBox[{"435.`", ",", "0.000642`"}], "}"}]], 
        Annotation[#, {435., 0.000642}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{436., 0.000648}}]}, 
         RowBox[{"{", 
           RowBox[{"436.`", ",", "0.000648`"}], "}"}]], 
        Annotation[#, {436., 0.000648}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{437., 0.000649}}]}, 
         RowBox[{"{", 
           RowBox[{"437.`", ",", "0.000649`"}], "}"}]], 
        Annotation[#, {437., 0.000649}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{438., 0.000645}}]}, 
         RowBox[{"{", 
           RowBox[{"438.`", ",", "0.000645`"}], "}"}]], 
        Annotation[#, {438., 0.000645}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{439., 0.000759}}]}, 
         RowBox[{"{", 
           RowBox[{"439.`", ",", "0.000759`"}], "}"}]], 
        Annotation[#, {439., 0.000759}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{440., 0.000705}}]}, 
         RowBox[{"{", 
           RowBox[{"440.`", ",", "0.000705`"}], "}"}]], 
        Annotation[#, {440., 0.000705}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{441., 0.000654}}]}, 
         RowBox[{"{", 
           RowBox[{"441.`", ",", "0.000654`"}], "}"}]], 
        Annotation[#, {441., 0.000654}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{442., 0.000658}}]}, 
         RowBox[{"{", 
           RowBox[{"442.`", ",", "0.000658`"}], "}"}]], 
        Annotation[#, {442., 0.000658}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{443., 0.000655}}]}, 
         RowBox[{"{", 
           RowBox[{"443.`", ",", "0.000655`"}], "}"}]], 
        Annotation[#, {443., 0.000655}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{444., 0.000661}}]}, 
         RowBox[{"{", 
           RowBox[{"444.`", ",", "0.000661`"}], "}"}]], 
        Annotation[#, {444., 0.000661}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{445., 0.000669}}]}, 
         RowBox[{"{", 
           RowBox[{"445.`", ",", "0.000669`"}], "}"}]], 
        Annotation[#, {445., 0.000669}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{446., 0.000658}}]}, 
         RowBox[{"{", 
           RowBox[{"446.`", ",", "0.000658`"}], "}"}]], 
        Annotation[#, {446., 0.000658}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{447., 0.000657}}]}, 
         RowBox[{"{", 
           RowBox[{"447.`", ",", "0.000657`"}], "}"}]], 
        Annotation[#, {447., 0.000657}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{448., 0.000669}}]}, 
         RowBox[{"{", 
           RowBox[{"448.`", ",", "0.000669`"}], "}"}]], 
        Annotation[#, {448., 0.000669}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{449., 0.000662}}]}, 
         RowBox[{"{", 
           RowBox[{"449.`", ",", "0.000662`"}], "}"}]], 
        Annotation[#, {449., 0.000662}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{450., 0.000662}}]}, 
         RowBox[{"{", 
           RowBox[{"450.`", ",", "0.000662`"}], "}"}]], 
        Annotation[#, {450., 0.000662}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{451., 0.000671}}]}, 
         RowBox[{"{", 
           RowBox[{"451.`", ",", "0.000671`"}], "}"}]], 
        Annotation[#, {451., 0.000671}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{452., 0.000678}}]}, 
         RowBox[{"{", 
           RowBox[{"452.`", ",", "0.000678`"}], "}"}]], 
        Annotation[#, {452., 0.000678}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{453., 0.000669}}]}, 
         RowBox[{"{", 
           RowBox[{"453.`", ",", "0.000669`"}], "}"}]], 
        Annotation[#, {453., 0.000669}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{454., 0.000677}}]}, 
         RowBox[{"{", 
           RowBox[{"454.`", ",", "0.000677`"}], "}"}]], 
        Annotation[#, {454., 0.000677}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{455., 0.000785}}]}, 
         RowBox[{"{", 
           RowBox[{"455.`", ",", "0.000785`"}], "}"}]], 
        Annotation[#, {455., 0.000785}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{456., 0.000676}}]}, 
         RowBox[{"{", 
           RowBox[{"456.`", ",", "0.000676`"}], "}"}]], 
        Annotation[#, {456., 0.000676}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{457., 0.000681}}]}, 
         RowBox[{"{", 
           RowBox[{"457.`", ",", "0.000681`"}], "}"}]], 
        Annotation[#, {457., 0.000681}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{458., 0.000677}}]}, 
         RowBox[{"{", 
           RowBox[{"458.`", ",", "0.000677`"}], "}"}]], 
        Annotation[#, {458., 0.000677}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{459., 0.000679}}]}, 
         RowBox[{"{", 
           RowBox[{"459.`", ",", "0.000679`"}], "}"}]], 
        Annotation[#, {459., 0.000679}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{460., 0.000688}}]}, 
         RowBox[{"{", 
           RowBox[{"460.`", ",", "0.000688`"}], "}"}]], 
        Annotation[#, {460., 0.000688}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{461., 0.000682}}]}, 
         RowBox[{"{", 
           RowBox[{"461.`", ",", "0.000682`"}], "}"}]], 
        Annotation[#, {461., 0.000682}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{462., 0.000682}}]}, 
         RowBox[{"{", 
           RowBox[{"462.`", ",", "0.000682`"}], "}"}]], 
        Annotation[#, {462., 0.000682}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{463., 0.000694}}]}, 
         RowBox[{"{", 
           RowBox[{"463.`", ",", "0.000694`"}], "}"}]], 
        Annotation[#, {463., 0.000694}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{464., 0.000686}}]}, 
         RowBox[{"{", 
           RowBox[{"464.`", ",", "0.000686`"}], "}"}]], 
        Annotation[#, {464., 0.000686}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{465., 0.000773}}]}, 
         RowBox[{"{", 
           RowBox[{"465.`", ",", "0.000773`"}], "}"}]], 
        Annotation[#, {465., 0.000773}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{466., 0.000694}}]}, 
         RowBox[{"{", 
           RowBox[{"466.`", ",", "0.000694`"}], "}"}]], 
        Annotation[#, {466., 0.000694}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{467., 0.000742}}]}, 
         RowBox[{"{", 
           RowBox[{"467.`", ",", "0.000742`"}], "}"}]], 
        Annotation[#, {467., 0.000742}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{468., 0.000689}}]}, 
         RowBox[{"{", 
           RowBox[{"468.`", ",", "0.000689`"}], "}"}]], 
        Annotation[#, {468., 0.000689}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{469., 0.000698}}]}, 
         RowBox[{"{", 
           RowBox[{"469.`", ",", "0.000698`"}], "}"}]], 
        Annotation[#, {469., 0.000698}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{470., 0.000696}}]}, 
         RowBox[{"{", 
           RowBox[{"470.`", ",", "0.000696`"}], "}"}]], 
        Annotation[#, {470., 0.000696}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{471., 0.000694}}]}, 
         RowBox[{"{", 
           RowBox[{"471.`", ",", "0.000694`"}], "}"}]], 
        Annotation[#, {471., 0.000694}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{472., 0.000702}}]}, 
         RowBox[{"{", 
           RowBox[{"472.`", ",", "0.000702`"}], "}"}]], 
        Annotation[#, {472., 0.000702}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{473., 0.000698}}]}, 
         RowBox[{"{", 
           RowBox[{"473.`", ",", "0.000698`"}], "}"}]], 
        Annotation[#, {473., 0.000698}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{474., 0.000705}}]}, 
         RowBox[{"{", 
           RowBox[{"474.`", ",", "0.000705`"}], "}"}]], 
        Annotation[#, {474., 0.000705}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{475., 0.000707}}]}, 
         RowBox[{"{", 
           RowBox[{"475.`", ",", "0.000707`"}], "}"}]], 
        Annotation[#, {475., 0.000707}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{476., 0.000703}}]}, 
         RowBox[{"{", 
           RowBox[{"476.`", ",", "0.000703`"}], "}"}]], 
        Annotation[#, {476., 0.000703}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{477., 0.000769}}]}, 
         RowBox[{"{", 
           RowBox[{"477.`", ",", "0.000769`"}], "}"}]], 
        Annotation[#, {477., 0.000769}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{478., 0.000712}}]}, 
         RowBox[{"{", 
           RowBox[{"478.`", ",", "0.000712`"}], "}"}]], 
        Annotation[#, {478., 0.000712}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{479., 0.000708}}]}, 
         RowBox[{"{", 
           RowBox[{"479.`", ",", "0.000708`"}], "}"}]], 
        Annotation[#, {479., 0.000708}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{480., 0.000707}}]}, 
         RowBox[{"{", 
           RowBox[{"480.`", ",", "0.000707`"}], "}"}]], 
        Annotation[#, {480., 0.000707}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{481., 0.000719}}]}, 
         RowBox[{"{", 
           RowBox[{"481.`", ",", "0.000719`"}], "}"}]], 
        Annotation[#, {481., 0.000719}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{482., 0.000748}}]}, 
         RowBox[{"{", 
           RowBox[{"482.`", ",", "0.000748`"}], "}"}]], 
        Annotation[#, {482., 0.000748}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{483., 0.000711}}]}, 
         RowBox[{"{", 
           RowBox[{"483.`", ",", "0.000711`"}], "}"}]], 
        Annotation[#, {483., 0.000711}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{484., 0.000721}}]}, 
         RowBox[{"{", 
           RowBox[{"484.`", ",", "0.000721`"}], "}"}]], 
        Annotation[#, {484., 0.000721}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{485., 0.00076}}]}, 
         RowBox[{"{", 
           RowBox[{"485.`", ",", "0.00076`"}], "}"}]], 
        Annotation[#, {485., 0.00076}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{486., 0.000715}}]}, 
         RowBox[{"{", 
           RowBox[{"486.`", ",", "0.000715`"}], "}"}]], 
        Annotation[#, {486., 0.000715}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{487., 0.000724}}]}, 
         RowBox[{"{", 
           RowBox[{"487.`", ",", "0.000724`"}], "}"}]], 
        Annotation[#, {487., 0.000724}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{488., 0.000754}}]}, 
         RowBox[{"{", 
           RowBox[{"488.`", ",", "0.000754`"}], "}"}]], 
        Annotation[#, {488., 0.000754}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{489., 0.000783}}]}, 
         RowBox[{"{", 
           RowBox[{"489.`", ",", "0.000783`"}], "}"}]], 
        Annotation[#, {489., 0.000783}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{490., 0.00073}}]}, 
         RowBox[{"{", 
           RowBox[{"490.`", ",", "0.00073`"}], "}"}]], 
        Annotation[#, {490., 0.00073}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{491., 0.000725}}]}, 
         RowBox[{"{", 
           RowBox[{"491.`", ",", "0.000725`"}], "}"}]], 
        Annotation[#, {491., 0.000725}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{492., 0.000728}}]}, 
         RowBox[{"{", 
           RowBox[{"492.`", ",", "0.000728`"}], "}"}]], 
        Annotation[#, {492., 0.000728}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{493., 0.000733}}]}, 
         RowBox[{"{", 
           RowBox[{"493.`", ",", "0.000733`"}], "}"}]], 
        Annotation[#, {493., 0.000733}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{494., 0.000728}}]}, 
         RowBox[{"{", 
           RowBox[{"494.`", ",", "0.000728`"}], "}"}]], 
        Annotation[#, {494., 0.000728}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{495., 0.000786}}]}, 
         RowBox[{"{", 
           RowBox[{"495.`", ",", "0.000786`"}], "}"}]], 
        Annotation[#, {495., 0.000786}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{496., 0.000743}}]}, 
         RowBox[{"{", 
           RowBox[{"496.`", ",", "0.000743`"}], "}"}]], 
        Annotation[#, {496., 0.000743}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{497., 0.000734}}]}, 
         RowBox[{"{", 
           RowBox[{"497.`", ",", "0.000734`"}], "}"}]], 
        Annotation[#, {497., 0.000734}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{498., 0.000734}}]}, 
         RowBox[{"{", 
           RowBox[{"498.`", ",", "0.000734`"}], "}"}]], 
        Annotation[#, {498., 0.000734}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{499., 0.000749}}]}, 
         RowBox[{"{", 
           RowBox[{"499.`", ",", "0.000749`"}], "}"}]], 
        Annotation[#, {499., 0.000749}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{500., 0.000739}}]}, 
         RowBox[{"{", 
           RowBox[{"500.`", ",", "0.000739`"}], "}"}]], 
        Annotation[#, {500., 0.000739}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{501., 0.000743}}]}, 
         RowBox[{"{", 
           RowBox[{"501.`", ",", "0.000743`"}], "}"}]], 
        Annotation[#, {501., 0.000743}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{502., 0.000747}}]}, 
         RowBox[{"{", 
           RowBox[{"502.`", ",", "0.000747`"}], "}"}]], 
        Annotation[#, {502., 0.000747}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{503., 0.000747}}]}, 
         RowBox[{"{", 
           RowBox[{"503.`", ",", "0.000747`"}], "}"}]], 
        Annotation[#, {503., 0.000747}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{504., 0.000742}}]}, 
         RowBox[{"{", 
           RowBox[{"504.`", ",", "0.000742`"}], "}"}]], 
        Annotation[#, {504., 0.000742}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{505., 0.000752}}]}, 
         RowBox[{"{", 
           RowBox[{"505.`", ",", "0.000752`"}], "}"}]], 
        Annotation[#, {505., 0.000752}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{506., 0.000747}}]}, 
         RowBox[{"{", 
           RowBox[{"506.`", ",", "0.000747`"}], "}"}]], 
        Annotation[#, {506., 0.000747}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{507., 0.000752}}]}, 
         RowBox[{"{", 
           RowBox[{"507.`", ",", "0.000752`"}], "}"}]], 
        Annotation[#, {507., 0.000752}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{508., 0.000835}}]}, 
         RowBox[{"{", 
           RowBox[{"508.`", ",", "0.000835`"}], "}"}]], 
        Annotation[#, {508., 0.000835}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{509., 0.000752}}]}, 
         RowBox[{"{", 
           RowBox[{"509.`", ",", "0.000752`"}], "}"}]], 
        Annotation[#, {509., 0.000752}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{510., 0.000757}}]}, 
         RowBox[{"{", 
           RowBox[{"510.`", ",", "0.000757`"}], "}"}]], 
        Annotation[#, {510., 0.000757}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{511., 0.000796}}]}, 
         RowBox[{"{", 
           RowBox[{"511.`", ",", "0.000796`"}], "}"}]], 
        Annotation[#, {511., 0.000796}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{512., 0.000756}}]}, 
         RowBox[{"{", 
           RowBox[{"512.`", ",", "0.000756`"}], "}"}]], 
        Annotation[#, {512., 0.000756}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{513., 0.000756}}]}, 
         RowBox[{"{", 
           RowBox[{"513.`", ",", "0.000756`"}], "}"}]], 
        Annotation[#, {513., 0.000756}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{514., 0.000772}}]}, 
         RowBox[{"{", 
           RowBox[{"514.`", ",", "0.000772`"}], "}"}]], 
        Annotation[#, {514., 0.000772}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{515., 0.00076}}]}, 
         RowBox[{"{", 
           RowBox[{"515.`", ",", "0.00076`"}], "}"}]], 
        Annotation[#, {515., 0.00076}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{516., 0.000761}}]}, 
         RowBox[{"{", 
           RowBox[{"516.`", ",", "0.000761`"}], "}"}]], 
        Annotation[#, {516., 0.000761}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{517., 0.00077}}]}, 
         RowBox[{"{", 
           RowBox[{"517.`", ",", "0.00077`"}], "}"}]], 
        Annotation[#, {517., 0.00077}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{518., 0.000867}}]}, 
         RowBox[{"{", 
           RowBox[{"518.`", ",", "0.000867`"}], "}"}]], 
        Annotation[#, {518., 0.000867}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{519., 0.000766}}]}, 
         RowBox[{"{", 
           RowBox[{"519.`", ",", "0.000766`"}], "}"}]], 
        Annotation[#, {519., 0.000766}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{520., 0.000774}}]}, 
         RowBox[{"{", 
           RowBox[{"520.`", ",", "0.000774`"}], "}"}]], 
        Annotation[#, {520., 0.000774}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{521., 0.000775}}]}, 
         RowBox[{"{", 
           RowBox[{"521.`", ",", "0.000775`"}], "}"}]], 
        Annotation[#, {521., 0.000775}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{522., 0.000773}}]}, 
         RowBox[{"{", 
           RowBox[{"522.`", ",", "0.000773`"}], "}"}]], 
        Annotation[#, {522., 0.000773}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{523., 0.000777}}]}, 
         RowBox[{"{", 
           RowBox[{"523.`", ",", "0.000777`"}], "}"}]], 
        Annotation[#, {523., 0.000777}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{524., 0.000772}}]}, 
         RowBox[{"{", 
           RowBox[{"524.`", ",", "0.000772`"}], "}"}]], 
        Annotation[#, {524., 0.000772}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{525., 0.000777}}]}, 
         RowBox[{"{", 
           RowBox[{"525.`", ",", "0.000777`"}], "}"}]], 
        Annotation[#, {525., 0.000777}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{526., 0.000782}}]}, 
         RowBox[{"{", 
           RowBox[{"526.`", ",", "0.000782`"}], "}"}]], 
        Annotation[#, {526., 0.000782}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{527., 0.000777}}]}, 
         RowBox[{"{", 
           RowBox[{"527.`", ",", "0.000777`"}], "}"}]], 
        Annotation[#, {527., 0.000777}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{528., 0.000778}}]}, 
         RowBox[{"{", 
           RowBox[{"528.`", ",", "0.000778`"}], "}"}]], 
        Annotation[#, {528., 0.000778}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{529., 0.000832}}]}, 
         RowBox[{"{", 
           RowBox[{"529.`", ",", "0.000832`"}], "}"}]], 
        Annotation[#, {529., 0.000832}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{530., 0.000787}}]}, 
         RowBox[{"{", 
           RowBox[{"530.`", ",", "0.000787`"}], "}"}]], 
        Annotation[#, {530., 0.000787}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{531., 0.000783}}]}, 
         RowBox[{"{", 
           RowBox[{"531.`", ",", "0.000783`"}], "}"}]], 
        Annotation[#, {531., 0.000783}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{532., 0.000838}}]}, 
         RowBox[{"{", 
           RowBox[{"532.`", ",", "0.000838`"}], "}"}]], 
        Annotation[#, {532., 0.000838}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{533., 0.001105}}]}, 
         RowBox[{"{", 
           RowBox[{"533.`", ",", "0.001105`"}], "}"}]], 
        Annotation[#, {533., 0.001105}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{534., 0.00079}}]}, 
         RowBox[{"{", 
           RowBox[{"534.`", ",", "0.00079`"}], "}"}]], 
        Annotation[#, {534., 0.00079}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{535., 0.000798}}]}, 
         RowBox[{"{", 
           RowBox[{"535.`", ",", "0.000798`"}], "}"}]], 
        Annotation[#, {535., 0.000798}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{536., 0.000798}}]}, 
         RowBox[{"{", 
           RowBox[{"536.`", ",", "0.000798`"}], "}"}]], 
        Annotation[#, {536., 0.000798}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{537., 0.000797}}]}, 
         RowBox[{"{", 
           RowBox[{"537.`", ",", "0.000797`"}], "}"}]], 
        Annotation[#, {537., 0.000797}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{538., 0.000803}}]}, 
         RowBox[{"{", 
           RowBox[{"538.`", ",", "0.000803`"}], "}"}]], 
        Annotation[#, {538., 0.000803}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{539., 0.00085}}]}, 
         RowBox[{"{", 
           RowBox[{"539.`", ",", "0.00085`"}], "}"}]], 
        Annotation[#, {539., 0.00085}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{540., 0.000802}}]}, 
         RowBox[{"{", 
           RowBox[{"540.`", ",", "0.000802`"}], "}"}]], 
        Annotation[#, {540., 0.000802}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{541., 0.000806}}]}, 
         RowBox[{"{", 
           RowBox[{"541.`", ",", "0.000806`"}], "}"}]], 
        Annotation[#, {541., 0.000806}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{542., 0.000843}}]}, 
         RowBox[{"{", 
           RowBox[{"542.`", ",", "0.000843`"}], "}"}]], 
        Annotation[#, {542., 0.000843}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{543., 0.000807}}]}, 
         RowBox[{"{", 
           RowBox[{"543.`", ",", "0.000807`"}], "}"}]], 
        Annotation[#, {543., 0.000807}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{544., 0.000817}}]}, 
         RowBox[{"{", 
           RowBox[{"544.`", ",", "0.000817`"}], "}"}]], 
        Annotation[#, {544., 0.000817}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{545., 0.000809}}]}, 
         RowBox[{"{", 
           RowBox[{"545.`", ",", "0.000809`"}], "}"}]], 
        Annotation[#, {545., 0.000809}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{546., 0.000805}}]}, 
         RowBox[{"{", 
           RowBox[{"546.`", ",", "0.000805`"}], "}"}]], 
        Annotation[#, {546., 0.000805}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{547., 0.000823}}]}, 
         RowBox[{"{", 
           RowBox[{"547.`", ",", "0.000823`"}], "}"}]], 
        Annotation[#, {547., 0.000823}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{548., 0.000811}}]}, 
         RowBox[{"{", 
           RowBox[{"548.`", ",", "0.000811`"}], "}"}]], 
        Annotation[#, {548., 0.000811}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{549., 0.000811}}]}, 
         RowBox[{"{", 
           RowBox[{"549.`", ",", "0.000811`"}], "}"}]], 
        Annotation[#, {549., 0.000811}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{550., 0.000872}}]}, 
         RowBox[{"{", 
           RowBox[{"550.`", ",", "0.000872`"}], "}"}]], 
        Annotation[#, {550., 0.000872}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{551., 0.00088}}]}, 
         RowBox[{"{", 
           RowBox[{"551.`", ",", "0.00088`"}], "}"}]], 
        Annotation[#, {551., 0.00088}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{552., 0.000814}}]}, 
         RowBox[{"{", 
           RowBox[{"552.`", ",", "0.000814`"}], "}"}]], 
        Annotation[#, {552., 0.000814}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{553., 0.000848}}]}, 
         RowBox[{"{", 
           RowBox[{"553.`", ",", "0.000848`"}], "}"}]], 
        Annotation[#, {553., 0.000848}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{554., 0.000824}}]}, 
         RowBox[{"{", 
           RowBox[{"554.`", ",", "0.000824`"}], "}"}]], 
        Annotation[#, {554., 0.000824}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{555., 0.000818}}]}, 
         RowBox[{"{", 
           RowBox[{"555.`", ",", "0.000818`"}], "}"}]], 
        Annotation[#, {555., 0.000818}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{556., 0.000882}}]}, 
         RowBox[{"{", 
           RowBox[{"556.`", ",", "0.000882`"}], "}"}]], 
        Annotation[#, {556., 0.000882}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{557., 0.000825}}]}, 
         RowBox[{"{", 
           RowBox[{"557.`", ",", "0.000825`"}], "}"}]], 
        Annotation[#, {557., 0.000825}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{558., 0.000827}}]}, 
         RowBox[{"{", 
           RowBox[{"558.`", ",", "0.000827`"}], "}"}]], 
        Annotation[#, {558., 0.000827}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{559., 0.000832}}]}, 
         RowBox[{"{", 
           RowBox[{"559.`", ",", "0.000832`"}], "}"}]], 
        Annotation[#, {559., 0.000832}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{560., 0.000827}}]}, 
         RowBox[{"{", 
           RowBox[{"560.`", ",", "0.000827`"}], "}"}]], 
        Annotation[#, {560., 0.000827}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{561., 0.000865}}]}, 
         RowBox[{"{", 
           RowBox[{"561.`", ",", "0.000865`"}], "}"}]], 
        Annotation[#, {561., 0.000865}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{562., 0.000897}}]}, 
         RowBox[{"{", 
           RowBox[{"562.`", ",", "0.000897`"}], "}"}]], 
        Annotation[#, {562., 0.000897}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{563., 0.000832}}]}, 
         RowBox[{"{", 
           RowBox[{"563.`", ",", "0.000832`"}], "}"}]], 
        Annotation[#, {563., 0.000832}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{564., 0.000832}}]}, 
         RowBox[{"{", 
           RowBox[{"564.`", ",", "0.000832`"}], "}"}]], 
        Annotation[#, {564., 0.000832}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{565., 0.000847}}]}, 
         RowBox[{"{", 
           RowBox[{"565.`", ",", "0.000847`"}], "}"}]], 
        Annotation[#, {565., 0.000847}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{566., 0.000837}}]}, 
         RowBox[{"{", 
           RowBox[{"566.`", ",", "0.000837`"}], "}"}]], 
        Annotation[#, {566., 0.000837}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{567., 0.000837}}]}, 
         RowBox[{"{", 
           RowBox[{"567.`", ",", "0.000837`"}], "}"}]], 
        Annotation[#, {567., 0.000837}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{568., 0.000855}}]}, 
         RowBox[{"{", 
           RowBox[{"568.`", ",", "0.000855`"}], "}"}]], 
        Annotation[#, {568., 0.000855}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{569., 0.000845}}]}, 
         RowBox[{"{", 
           RowBox[{"569.`", ",", "0.000845`"}], "}"}]], 
        Annotation[#, {569., 0.000845}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{570., 0.000908}}]}, 
         RowBox[{"{", 
           RowBox[{"570.`", ",", "0.000908`"}], "}"}]], 
        Annotation[#, {570., 0.000908}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{571., 0.000856}}]}, 
         RowBox[{"{", 
           RowBox[{"571.`", ",", "0.000856`"}], "}"}]], 
        Annotation[#, {571., 0.000856}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{572., 0.000845}}]}, 
         RowBox[{"{", 
           RowBox[{"572.`", ",", "0.000845`"}], "}"}]], 
        Annotation[#, {572., 0.000845}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{573., 0.00085}}]}, 
         RowBox[{"{", 
           RowBox[{"573.`", ",", "0.00085`"}], "}"}]], 
        Annotation[#, {573., 0.00085}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{574., 0.000855}}]}, 
         RowBox[{"{", 
           RowBox[{"574.`", ",", "0.000855`"}], "}"}]], 
        Annotation[#, {574., 0.000855}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{575., 0.000849}}]}, 
         RowBox[{"{", 
           RowBox[{"575.`", ",", "0.000849`"}], "}"}]], 
        Annotation[#, {575., 0.000849}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{576., 0.000854}}]}, 
         RowBox[{"{", 
           RowBox[{"576.`", ",", "0.000854`"}], "}"}]], 
        Annotation[#, {576., 0.000854}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{577., 0.000909}}]}, 
         RowBox[{"{", 
           RowBox[{"577.`", ",", "0.000909`"}], "}"}]], 
        Annotation[#, {577., 0.000909}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{578., 0.000852}}]}, 
         RowBox[{"{", 
           RowBox[{"578.`", ",", "0.000852`"}], "}"}]], 
        Annotation[#, {578., 0.000852}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{579., 0.000853}}]}, 
         RowBox[{"{", 
           RowBox[{"579.`", ",", "0.000853`"}], "}"}]], 
        Annotation[#, {579., 0.000853}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{580., 0.000873}}]}, 
         RowBox[{"{", 
           RowBox[{"580.`", ",", "0.000873`"}], "}"}]], 
        Annotation[#, {580., 0.000873}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{581., 0.000903}}]}, 
         RowBox[{"{", 
           RowBox[{"581.`", ",", "0.000903`"}], "}"}]], 
        Annotation[#, {581., 0.000903}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{582., 0.000923}}]}, 
         RowBox[{"{", 
           RowBox[{"582.`", ",", "0.000923`"}], "}"}]], 
        Annotation[#, {582., 0.000923}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{583., 0.000867}}]}, 
         RowBox[{"{", 
           RowBox[{"583.`", ",", "0.000867`"}], "}"}]], 
        Annotation[#, {583., 0.000867}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{584., 0.000866}}]}, 
         RowBox[{"{", 
           RowBox[{"584.`", ",", "0.000866`"}], "}"}]], 
        Annotation[#, {584., 0.000866}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{585., 0.000862}}]}, 
         RowBox[{"{", 
           RowBox[{"585.`", ",", "0.000862`"}], "}"}]], 
        Annotation[#, {585., 0.000862}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{586., 0.000873}}]}, 
         RowBox[{"{", 
           RowBox[{"586.`", ",", "0.000873`"}], "}"}]], 
        Annotation[#, {586., 0.000873}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{587., 0.000873}}]}, 
         RowBox[{"{", 
           RowBox[{"587.`", ",", "0.000873`"}], "}"}]], 
        Annotation[#, {587., 0.000873}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{588., 0.000868}}]}, 
         RowBox[{"{", 
           RowBox[{"588.`", ",", "0.000868`"}], "}"}]], 
        Annotation[#, {588., 0.000868}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{589., 0.000876}}]}, 
         RowBox[{"{", 
           RowBox[{"589.`", ",", "0.000876`"}], "}"}]], 
        Annotation[#, {589., 0.000876}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{590., 0.00088}}]}, 
         RowBox[{"{", 
           RowBox[{"590.`", ",", "0.00088`"}], "}"}]], 
        Annotation[#, {590., 0.00088}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{591., 0.001007}}]}, 
         RowBox[{"{", 
           RowBox[{"591.`", ",", "0.001007`"}], "}"}]], 
        Annotation[#, {591., 0.001007}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{592., 0.000884}}]}, 
         RowBox[{"{", 
           RowBox[{"592.`", ",", "0.000884`"}], "}"}]], 
        Annotation[#, {592., 0.000884}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{593., 0.000878}}]}, 
         RowBox[{"{", 
           RowBox[{"593.`", ",", "0.000878`"}], "}"}]], 
        Annotation[#, {593., 0.000878}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{594., 0.000877}}]}, 
         RowBox[{"{", 
           RowBox[{"594.`", ",", "0.000877`"}], "}"}]], 
        Annotation[#, {594., 0.000877}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{595., 0.000893}}]}, 
         RowBox[{"{", 
           RowBox[{"595.`", ",", "0.000893`"}], "}"}]], 
        Annotation[#, {595., 0.000893}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{596., 0.000881}}]}, 
         RowBox[{"{", 
           RowBox[{"596.`", ",", "0.000881`"}], "}"}]], 
        Annotation[#, {596., 0.000881}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{597., 0.000882}}]}, 
         RowBox[{"{", 
           RowBox[{"597.`", ",", "0.000882`"}], "}"}]], 
        Annotation[#, {597., 0.000882}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{598., 0.000897}}]}, 
         RowBox[{"{", 
           RowBox[{"598.`", ",", "0.000897`"}], "}"}]], 
        Annotation[#, {598., 0.000897}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{599., 0.000915}}]}, 
         RowBox[{"{", 
           RowBox[{"599.`", ",", "0.000915`"}], "}"}]], 
        Annotation[#, {599., 0.000915}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{600., 0.000966}}]}, 
         RowBox[{"{", 
           RowBox[{"600.`", ",", "0.000966`"}], "}"}]], 
        Annotation[#, {600., 0.000966}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{601., 0.000894}}]}, 
         RowBox[{"{", 
           RowBox[{"601.`", ",", "0.000894`"}], "}"}]], 
        Annotation[#, {601., 0.000894}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{602., 0.000895}}]}, 
         RowBox[{"{", 
           RowBox[{"602.`", ",", "0.000895`"}], "}"}]], 
        Annotation[#, {602., 0.000895}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{603., 0.000886}}]}, 
         RowBox[{"{", 
           RowBox[{"603.`", ",", "0.000886`"}], "}"}]], 
        Annotation[#, {603., 0.000886}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{604., 0.000897}}]}, 
         RowBox[{"{", 
           RowBox[{"604.`", ",", "0.000897`"}], "}"}]], 
        Annotation[#, {604., 0.000897}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{605., 0.000896}}]}, 
         RowBox[{"{", 
           RowBox[{"605.`", ",", "0.000896`"}], "}"}]], 
        Annotation[#, {605., 0.000896}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{606., 0.000891}}]}, 
         RowBox[{"{", 
           RowBox[{"606.`", ",", "0.000891`"}], "}"}]], 
        Annotation[#, {606., 0.000891}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{607., 0.000901}}]}, 
         RowBox[{"{", 
           RowBox[{"607.`", ",", "0.000901`"}], "}"}]], 
        Annotation[#, {607., 0.000901}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{608., 0.000895}}]}, 
         RowBox[{"{", 
           RowBox[{"608.`", ",", "0.000895`"}], "}"}]], 
        Annotation[#, {608., 0.000895}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{609., 0.000924}}]}, 
         RowBox[{"{", 
           RowBox[{"609.`", ",", "0.000924`"}], "}"}]], 
        Annotation[#, {609., 0.000924}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{610., 0.000906}}]}, 
         RowBox[{"{", 
           RowBox[{"610.`", ",", "0.000906`"}], "}"}]], 
        Annotation[#, {610., 0.000906}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{611., 0.000922}}]}, 
         RowBox[{"{", 
           RowBox[{"611.`", ",", "0.000922`"}], "}"}]], 
        Annotation[#, {611., 0.000922}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{612., 0.000899}}]}, 
         RowBox[{"{", 
           RowBox[{"612.`", ",", "0.000899`"}], "}"}]], 
        Annotation[#, {612., 0.000899}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{613., 0.001009}}]}, 
         RowBox[{"{", 
           RowBox[{"613.`", ",", "0.001009`"}], "}"}]], 
        Annotation[#, {613., 0.001009}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{614., 0.000917}}]}, 
         RowBox[{"{", 
           RowBox[{"614.`", ",", "0.000917`"}], "}"}]], 
        Annotation[#, {614., 0.000917}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{615., 0.000904}}]}, 
         RowBox[{"{", 
           RowBox[{"615.`", ",", "0.000904`"}], "}"}]], 
        Annotation[#, {615., 0.000904}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{616., 0.00092}}]}, 
         RowBox[{"{", 
           RowBox[{"616.`", ",", "0.00092`"}], "}"}]], 
        Annotation[#, {616., 0.00092}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{617., 0.000908}}]}, 
         RowBox[{"{", 
           RowBox[{"617.`", ",", "0.000908`"}], "}"}]], 
        Annotation[#, {617., 0.000908}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{618., 0.000983}}]}, 
         RowBox[{"{", 
           RowBox[{"618.`", ",", "0.000983`"}], "}"}]], 
        Annotation[#, {618., 0.000983}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{619., 0.00092}}]}, 
         RowBox[{"{", 
           RowBox[{"619.`", ",", "0.00092`"}], "}"}]], 
        Annotation[#, {619., 0.00092}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{620., 0.000918}}]}, 
         RowBox[{"{", 
           RowBox[{"620.`", ",", "0.000918`"}], "}"}]], 
        Annotation[#, {620., 0.000918}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{621., 0.000913}}]}, 
         RowBox[{"{", 
           RowBox[{"621.`", ",", "0.000913`"}], "}"}]], 
        Annotation[#, {621., 0.000913}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{622., 0.000924}}]}, 
         RowBox[{"{", 
           RowBox[{"622.`", ",", "0.000924`"}], "}"}]], 
        Annotation[#, {622., 0.000924}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{623., 0.000917}}]}, 
         RowBox[{"{", 
           RowBox[{"623.`", ",", "0.000917`"}], "}"}]], 
        Annotation[#, {623., 0.000917}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{624., 0.000926}}]}, 
         RowBox[{"{", 
           RowBox[{"624.`", ",", "0.000926`"}], "}"}]], 
        Annotation[#, {624., 0.000926}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{625., 0.000929}}]}, 
         RowBox[{"{", 
           RowBox[{"625.`", ",", "0.000929`"}], "}"}]], 
        Annotation[#, {625., 0.000929}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{626., 0.000963}}]}, 
         RowBox[{"{", 
           RowBox[{"626.`", ",", "0.000963`"}], "}"}]], 
        Annotation[#, {626., 0.000963}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{627., 0.000926}}]}, 
         RowBox[{"{", 
           RowBox[{"627.`", ",", "0.000926`"}], "}"}]], 
        Annotation[#, {627., 0.000926}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{628., 0.000932}}]}, 
         RowBox[{"{", 
           RowBox[{"628.`", ",", "0.000932`"}], "}"}]], 
        Annotation[#, {628., 0.000932}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{629., 0.000927}}]}, 
         RowBox[{"{", 
           RowBox[{"629.`", ",", "0.000927`"}], "}"}]], 
        Annotation[#, {629., 0.000927}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{630., 0.000926}}]}, 
         RowBox[{"{", 
           RowBox[{"630.`", ",", "0.000926`"}], "}"}]], 
        Annotation[#, {630., 0.000926}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{631., 0.000943}}]}, 
         RowBox[{"{", 
           RowBox[{"631.`", ",", "0.000943`"}], "}"}]], 
        Annotation[#, {631., 0.000943}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{632., 0.000931}}]}, 
         RowBox[{"{", 
           RowBox[{"632.`", ",", "0.000931`"}], "}"}]], 
        Annotation[#, {632., 0.000931}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{633., 0.000932}}]}, 
         RowBox[{"{", 
           RowBox[{"633.`", ",", "0.000932`"}], "}"}]], 
        Annotation[#, {633., 0.000932}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{634., 0.000941}}]}, 
         RowBox[{"{", 
           RowBox[{"634.`", ",", "0.000941`"}], "}"}]], 
        Annotation[#, {634., 0.000941}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{635., 0.000996}}]}, 
         RowBox[{"{", 
           RowBox[{"635.`", ",", "0.000996`"}], "}"}]], 
        Annotation[#, {635., 0.000996}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{636., 0.000935}}]}, 
         RowBox[{"{", 
           RowBox[{"636.`", ",", "0.000935`"}], "}"}]], 
        Annotation[#, {636., 0.000935}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{637., 0.000946}}]}, 
         RowBox[{"{", 
           RowBox[{"637.`", ",", "0.000946`"}], "}"}]], 
        Annotation[#, {637., 0.000946}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{638., 0.000944}}]}, 
         RowBox[{"{", 
           RowBox[{"638.`", ",", "0.000944`"}], "}"}]], 
        Annotation[#, {638., 0.000944}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{639., 0.00094}}]}, 
         RowBox[{"{", 
           RowBox[{"639.`", ",", "0.00094`"}], "}"}]], 
        Annotation[#, {639., 0.00094}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{640., 0.001039}}]}, 
         RowBox[{"{", 
           RowBox[{"640.`", ",", "0.001039`"}], "}"}]], 
        Annotation[#, {640., 0.001039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{641., 0.000946}}]}, 
         RowBox[{"{", 
           RowBox[{"641.`", ",", "0.000946`"}], "}"}]], 
        Annotation[#, {641., 0.000946}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{642., 0.000953}}]}, 
         RowBox[{"{", 
           RowBox[{"642.`", ",", "0.000953`"}], "}"}]], 
        Annotation[#, {642., 0.000953}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{643., 0.000958}}]}, 
         RowBox[{"{", 
           RowBox[{"643.`", ",", "0.000958`"}], "}"}]], 
        Annotation[#, {643., 0.000958}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{644., 0.001045}}]}, 
         RowBox[{"{", 
           RowBox[{"644.`", ",", "0.001045`"}], "}"}]], 
        Annotation[#, {644., 0.001045}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{645., 0.00101}}]}, 
         RowBox[{"{", 
           RowBox[{"645.`", ",", "0.00101`"}], "}"}]], 
        Annotation[#, {645., 0.00101}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{646., 0.000973}}]}, 
         RowBox[{"{", 
           RowBox[{"646.`", ",", "0.000973`"}], "}"}]], 
        Annotation[#, {646., 0.000973}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{647., 0.000957}}]}, 
         RowBox[{"{", 
           RowBox[{"647.`", ",", "0.000957`"}], "}"}]], 
        Annotation[#, {647., 0.000957}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{648., 0.000958}}]}, 
         RowBox[{"{", 
           RowBox[{"648.`", ",", "0.000958`"}], "}"}]], 
        Annotation[#, {648., 0.000958}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{649., 0.000975}}]}, 
         RowBox[{"{", 
           RowBox[{"649.`", ",", "0.000975`"}], "}"}]], 
        Annotation[#, {649., 0.000975}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{650., 0.000961}}]}, 
         RowBox[{"{", 
           RowBox[{"650.`", ",", "0.000961`"}], "}"}]], 
        Annotation[#, {650., 0.000961}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{651., 0.000963}}]}, 
         RowBox[{"{", 
           RowBox[{"651.`", ",", "0.000963`"}], "}"}]], 
        Annotation[#, {651., 0.000963}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{652., 0.001098}}]}, 
         RowBox[{"{", 
           RowBox[{"652.`", ",", "0.001098`"}], "}"}]], 
        Annotation[#, {652., 0.001098}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{653., 0.000972}}]}, 
         RowBox[{"{", 
           RowBox[{"653.`", ",", "0.000972`"}], "}"}]], 
        Annotation[#, {653., 0.000972}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{654., 0.000966}}]}, 
         RowBox[{"{", 
           RowBox[{"654.`", ",", "0.000966`"}], "}"}]], 
        Annotation[#, {654., 0.000966}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{655., 0.00105}}]}, 
         RowBox[{"{", 
           RowBox[{"655.`", ",", "0.00105`"}], "}"}]], 
        Annotation[#, {655., 0.00105}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{656., 0.000971}}]}, 
         RowBox[{"{", 
           RowBox[{"656.`", ",", "0.000971`"}], "}"}]], 
        Annotation[#, {656., 0.000971}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{657., 0.000979}}]}, 
         RowBox[{"{", 
           RowBox[{"657.`", ",", "0.000979`"}], "}"}]], 
        Annotation[#, {657., 0.000979}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{658., 0.001048}}]}, 
         RowBox[{"{", 
           RowBox[{"658.`", ",", "0.001048`"}], "}"}]], 
        Annotation[#, {658., 0.001048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{659., 0.00097}}]}, 
         RowBox[{"{", 
           RowBox[{"659.`", ",", "0.00097`"}], "}"}]], 
        Annotation[#, {659., 0.00097}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{660., 0.001033}}]}, 
         RowBox[{"{", 
           RowBox[{"660.`", ",", "0.001033`"}], "}"}]], 
        Annotation[#, {660., 0.001033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{661., 0.000981}}]}, 
         RowBox[{"{", 
           RowBox[{"661.`", ",", "0.000981`"}], "}"}]], 
        Annotation[#, {661., 0.000981}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{662., 0.001004}}]}, 
         RowBox[{"{", 
           RowBox[{"662.`", ",", "0.001004`"}], "}"}]], 
        Annotation[#, {662., 0.001004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{663., 0.000975}}]}, 
         RowBox[{"{", 
           RowBox[{"663.`", ",", "0.000975`"}], "}"}]], 
        Annotation[#, {663., 0.000975}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{664., 0.001017}}]}, 
         RowBox[{"{", 
           RowBox[{"664.`", ",", "0.001017`"}], "}"}]], 
        Annotation[#, {664., 0.001017}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{665., 0.000984}}]}, 
         RowBox[{"{", 
           RowBox[{"665.`", ",", "0.000984`"}], "}"}]], 
        Annotation[#, {665., 0.000984}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{666., 0.000979}}]}, 
         RowBox[{"{", 
           RowBox[{"666.`", ",", "0.000979`"}], "}"}]], 
        Annotation[#, {666., 0.000979}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{667., 0.00099}}]}, 
         RowBox[{"{", 
           RowBox[{"667.`", ",", "0.00099`"}], "}"}]], 
        Annotation[#, {667., 0.00099}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{668., 0.000989}}]}, 
         RowBox[{"{", 
           RowBox[{"668.`", ",", "0.000989`"}], "}"}]], 
        Annotation[#, {668., 0.000989}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{669., 0.000986}}]}, 
         RowBox[{"{", 
           RowBox[{"669.`", ",", "0.000986`"}], "}"}]], 
        Annotation[#, {669., 0.000986}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{670., 0.001061}}]}, 
         RowBox[{"{", 
           RowBox[{"670.`", ",", "0.001061`"}], "}"}]], 
        Annotation[#, {670., 0.001061}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{671., 0.000995}}]}, 
         RowBox[{"{", 
           RowBox[{"671.`", ",", "0.000995`"}], "}"}]], 
        Annotation[#, {671., 0.000995}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{672., 0.000986}}]}, 
         RowBox[{"{", 
           RowBox[{"672.`", ",", "0.000986`"}], "}"}]], 
        Annotation[#, {672., 0.000986}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{673., 0.001031}}]}, 
         RowBox[{"{", 
           RowBox[{"673.`", ",", "0.001031`"}], "}"}]], 
        Annotation[#, {673., 0.001031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{674., 0.000993}}]}, 
         RowBox[{"{", 
           RowBox[{"674.`", ",", "0.000993`"}], "}"}]], 
        Annotation[#, {674., 0.000993}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{675., 0.000997}}]}, 
         RowBox[{"{", 
           RowBox[{"675.`", ",", "0.000997`"}], "}"}]], 
        Annotation[#, {675., 0.000997}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{676., 0.001004}}]}, 
         RowBox[{"{", 
           RowBox[{"676.`", ",", "0.001004`"}], "}"}]], 
        Annotation[#, {676., 0.001004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{677., 0.001038}}]}, 
         RowBox[{"{", 
           RowBox[{"677.`", ",", "0.001038`"}], "}"}]], 
        Annotation[#, {677., 0.001038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{678., 0.001155}}]}, 
         RowBox[{"{", 
           RowBox[{"678.`", ",", "0.001155`"}], "}"}]], 
        Annotation[#, {678., 0.001155}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{679., 0.00102}}]}, 
         RowBox[{"{", 
           RowBox[{"679.`", ",", "0.00102`"}], "}"}]], 
        Annotation[#, {679., 0.00102}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{680., 0.001}}]}, 
         RowBox[{"{", 
           RowBox[{"680.`", ",", "0.001`"}], "}"}]], 
        Annotation[#, {680., 0.001}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{681., 0.000999}}]}, 
         RowBox[{"{", 
           RowBox[{"681.`", ",", "0.000999`"}], "}"}]], 
        Annotation[#, {681., 0.000999}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{682., 0.001017}}]}, 
         RowBox[{"{", 
           RowBox[{"682.`", ",", "0.001017`"}], "}"}]], 
        Annotation[#, {682., 0.001017}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{683., 0.001005}}]}, 
         RowBox[{"{", 
           RowBox[{"683.`", ",", "0.001005`"}], "}"}]], 
        Annotation[#, {683., 0.001005}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{684., 0.001004}}]}, 
         RowBox[{"{", 
           RowBox[{"684.`", ",", "0.001004`"}], "}"}]], 
        Annotation[#, {684., 0.001004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{685., 0.001015}}]}, 
         RowBox[{"{", 
           RowBox[{"685.`", ",", "0.001015`"}], "}"}]], 
        Annotation[#, {685., 0.001015}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{686., 0.001015}}]}, 
         RowBox[{"{", 
           RowBox[{"686.`", ",", "0.001015`"}], "}"}]], 
        Annotation[#, {686., 0.001015}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{687., 0.00101}}]}, 
         RowBox[{"{", 
           RowBox[{"687.`", ",", "0.00101`"}], "}"}]], 
        Annotation[#, {687., 0.00101}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{688., 0.001021}}]}, 
         RowBox[{"{", 
           RowBox[{"688.`", ",", "0.001021`"}], "}"}]], 
        Annotation[#, {688., 0.001021}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{689., 0.001085}}]}, 
         RowBox[{"{", 
           RowBox[{"689.`", ",", "0.001085`"}], "}"}]], 
        Annotation[#, {689., 0.001085}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{690., 0.001019}}]}, 
         RowBox[{"{", 
           RowBox[{"690.`", ",", "0.001019`"}], "}"}]], 
        Annotation[#, {690., 0.001019}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{691., 0.001025}}]}, 
         RowBox[{"{", 
           RowBox[{"691.`", ",", "0.001025`"}], "}"}]], 
        Annotation[#, {691., 0.001025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{692., 0.00109}}]}, 
         RowBox[{"{", 
           RowBox[{"692.`", ",", "0.00109`"}], "}"}]], 
        Annotation[#, {692., 0.00109}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{693., 0.001023}}]}, 
         RowBox[{"{", 
           RowBox[{"693.`", ",", "0.001023`"}], "}"}]], 
        Annotation[#, {693., 0.001023}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{694., 0.001031}}]}, 
         RowBox[{"{", 
           RowBox[{"694.`", ",", "0.001031`"}], "}"}]], 
        Annotation[#, {694., 0.001031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{695., 0.001023}}]}, 
         RowBox[{"{", 
           RowBox[{"695.`", ",", "0.001023`"}], "}"}]], 
        Annotation[#, {695., 0.001023}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{696., 0.001022}}]}, 
         RowBox[{"{", 
           RowBox[{"696.`", ",", "0.001022`"}], "}"}]], 
        Annotation[#, {696., 0.001022}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{697., 0.001041}}]}, 
         RowBox[{"{", 
           RowBox[{"697.`", ",", "0.001041`"}], "}"}]], 
        Annotation[#, {697., 0.001041}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{698., 0.001202}}]}, 
         RowBox[{"{", 
           RowBox[{"698.`", ",", "0.001202`"}], "}"}]], 
        Annotation[#, {698., 0.001202}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{699., 0.001029}}]}, 
         RowBox[{"{", 
           RowBox[{"699.`", ",", "0.001029`"}], "}"}]], 
        Annotation[#, {699., 0.001029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{700., 0.001039}}]}, 
         RowBox[{"{", 
           RowBox[{"700.`", ",", "0.001039`"}], "}"}]], 
        Annotation[#, {700., 0.001039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{701., 0.001039}}]}, 
         RowBox[{"{", 
           RowBox[{"701.`", ",", "0.001039`"}], "}"}]], 
        Annotation[#, {701., 0.001039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{702., 0.001032}}]}, 
         RowBox[{"{", 
           RowBox[{"702.`", ",", "0.001032`"}], "}"}]], 
        Annotation[#, {702., 0.001032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{703., 0.001042}}]}, 
         RowBox[{"{", 
           RowBox[{"703.`", ",", "0.001042`"}], "}"}]], 
        Annotation[#, {703., 0.001042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{704., 0.001081}}]}, 
         RowBox[{"{", 
           RowBox[{"704.`", ",", "0.001081`"}], "}"}]], 
        Annotation[#, {704., 0.001081}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{705., 0.001037}}]}, 
         RowBox[{"{", 
           RowBox[{"705.`", ",", "0.001037`"}], "}"}]], 
        Annotation[#, {705., 0.001037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{706., 0.001048}}]}, 
         RowBox[{"{", 
           RowBox[{"706.`", ",", "0.001048`"}], "}"}]], 
        Annotation[#, {706., 0.001048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{707., 0.001098}}]}, 
         RowBox[{"{", 
           RowBox[{"707.`", ",", "0.001098`"}], "}"}]], 
        Annotation[#, {707., 0.001098}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{708., 0.001048}}]}, 
         RowBox[{"{", 
           RowBox[{"708.`", ",", "0.001048`"}], "}"}]], 
        Annotation[#, {708., 0.001048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{709., 0.001051}}]}, 
         RowBox[{"{", 
           RowBox[{"709.`", ",", "0.001051`"}], "}"}]], 
        Annotation[#, {709., 0.001051}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{710., 0.00105}}]}, 
         RowBox[{"{", 
           RowBox[{"710.`", ",", "0.00105`"}], "}"}]], 
        Annotation[#, {710., 0.00105}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{711., 0.001069}}]}, 
         RowBox[{"{", 
           RowBox[{"711.`", ",", "0.001069`"}], "}"}]], 
        Annotation[#, {711., 0.001069}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{712., 0.001066}}]}, 
         RowBox[{"{", 
           RowBox[{"712.`", ",", "0.001066`"}], "}"}]], 
        Annotation[#, {712., 0.001066}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{713., 0.001072}}]}, 
         RowBox[{"{", 
           RowBox[{"713.`", ",", "0.001072`"}], "}"}]], 
        Annotation[#, {713., 0.001072}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{714., 0.001049}}]}, 
         RowBox[{"{", 
           RowBox[{"714.`", ",", "0.001049`"}], "}"}]], 
        Annotation[#, {714., 0.001049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{715., 0.001065}}]}, 
         RowBox[{"{", 
           RowBox[{"715.`", ",", "0.001065`"}], "}"}]], 
        Annotation[#, {715., 0.001065}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{716., 0.001054}}]}, 
         RowBox[{"{", 
           RowBox[{"716.`", ",", "0.001054`"}], "}"}]], 
        Annotation[#, {716., 0.001054}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{717., 0.001119}}]}, 
         RowBox[{"{", 
           RowBox[{"717.`", ",", "0.001119`"}], "}"}]], 
        Annotation[#, {717., 0.001119}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{718., 0.001066}}]}, 
         RowBox[{"{", 
           RowBox[{"718.`", ",", "0.001066`"}], "}"}]], 
        Annotation[#, {718., 0.001066}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{719., 0.001063}}]}, 
         RowBox[{"{", 
           RowBox[{"719.`", ",", "0.001063`"}], "}"}]], 
        Annotation[#, {719., 0.001063}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{720., 0.001057}}]}, 
         RowBox[{"{", 
           RowBox[{"720.`", ",", "0.001057`"}], "}"}]], 
        Annotation[#, {720., 0.001057}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{721., 0.001069}}]}, 
         RowBox[{"{", 
           RowBox[{"721.`", ",", "0.001069`"}], "}"}]], 
        Annotation[#, {721., 0.001069}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{722., 0.001062}}]}, 
         RowBox[{"{", 
           RowBox[{"722.`", ",", "0.001062`"}], "}"}]], 
        Annotation[#, {722., 0.001062}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{723., 0.001068}}]}, 
         RowBox[{"{", 
           RowBox[{"723.`", ",", "0.001068`"}], "}"}]], 
        Annotation[#, {723., 0.001068}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{724., 0.001074}}]}, 
         RowBox[{"{", 
           RowBox[{"724.`", ",", "0.001074`"}], "}"}]], 
        Annotation[#, {724., 0.001074}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{725., 0.001152}}]}, 
         RowBox[{"{", 
           RowBox[{"725.`", ",", "0.001152`"}], "}"}]], 
        Annotation[#, {725., 0.001152}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{726., 0.001075}}]}, 
         RowBox[{"{", 
           RowBox[{"726.`", ",", "0.001075`"}], "}"}]], 
        Annotation[#, {726., 0.001075}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{727., 0.001078}}]}, 
         RowBox[{"{", 
           RowBox[{"727.`", ",", "0.001078`"}], "}"}]], 
        Annotation[#, {727., 0.001078}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{728., 0.001072}}]}, 
         RowBox[{"{", 
           RowBox[{"728.`", ",", "0.001072`"}], "}"}]], 
        Annotation[#, {728., 0.001072}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{729., 0.00107}}]}, 
         RowBox[{"{", 
           RowBox[{"729.`", ",", "0.00107`"}], "}"}]], 
        Annotation[#, {729., 0.00107}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{730., 0.001092}}]}, 
         RowBox[{"{", 
           RowBox[{"730.`", ",", "0.001092`"}], "}"}]], 
        Annotation[#, {730., 0.001092}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{731., 0.001077}}]}, 
         RowBox[{"{", 
           RowBox[{"731.`", ",", "0.001077`"}], "}"}]], 
        Annotation[#, {731., 0.001077}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{732., 0.001076}}]}, 
         RowBox[{"{", 
           RowBox[{"732.`", ",", "0.001076`"}], "}"}]], 
        Annotation[#, {732., 0.001076}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{733., 0.001182}}]}, 
         RowBox[{"{", 
           RowBox[{"733.`", ",", "0.001182`"}], "}"}]], 
        Annotation[#, {733., 0.001182}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{734., 0.001081}}]}, 
         RowBox[{"{", 
           RowBox[{"734.`", ",", "0.001081`"}], "}"}]], 
        Annotation[#, {734., 0.001081}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{735., 0.001082}}]}, 
         RowBox[{"{", 
           RowBox[{"735.`", ",", "0.001082`"}], "}"}]], 
        Annotation[#, {735., 0.001082}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{736., 0.001094}}]}, 
         RowBox[{"{", 
           RowBox[{"736.`", ",", "0.001094`"}], "}"}]], 
        Annotation[#, {736., 0.001094}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{737., 0.00109}}]}, 
         RowBox[{"{", 
           RowBox[{"737.`", ",", "0.00109`"}], "}"}]], 
        Annotation[#, {737., 0.00109}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{738., 0.001086}}]}, 
         RowBox[{"{", 
           RowBox[{"738.`", ",", "0.001086`"}], "}"}]], 
        Annotation[#, {738., 0.001086}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{739., 0.001158}}]}, 
         RowBox[{"{", 
           RowBox[{"739.`", ",", "0.001158`"}], "}"}]], 
        Annotation[#, {739., 0.001158}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{740., 0.001108}}]}, 
         RowBox[{"{", 
           RowBox[{"740.`", ",", "0.001108`"}], "}"}]], 
        Annotation[#, {740., 0.001108}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{741., 0.001095}}]}, 
         RowBox[{"{", 
           RowBox[{"741.`", ",", "0.001095`"}], "}"}]], 
        Annotation[#, {741., 0.001095}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{742., 0.001107}}]}, 
         RowBox[{"{", 
           RowBox[{"742.`", ",", "0.001107`"}], "}"}]], 
        Annotation[#, {742., 0.001107}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{743., 0.001141}}]}, 
         RowBox[{"{", 
           RowBox[{"743.`", ",", "0.001141`"}], "}"}]], 
        Annotation[#, {743., 0.001141}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{744., 0.001139}}]}, 
         RowBox[{"{", 
           RowBox[{"744.`", ",", "0.001139`"}], "}"}]], 
        Annotation[#, {744., 0.001139}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{745., 0.001106}}]}, 
         RowBox[{"{", 
           RowBox[{"745.`", ",", "0.001106`"}], "}"}]], 
        Annotation[#, {745., 0.001106}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{746., 0.0011}}]}, 
         RowBox[{"{", 
           RowBox[{"746.`", ",", "0.0011`"}], "}"}]], 
        Annotation[#, {746., 0.0011}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{747., 0.001099}}]}, 
         RowBox[{"{", 
           RowBox[{"747.`", ",", "0.001099`"}], "}"}]], 
        Annotation[#, {747., 0.001099}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{748., 0.001119}}]}, 
         RowBox[{"{", 
           RowBox[{"748.`", ",", "0.001119`"}], "}"}]], 
        Annotation[#, {748., 0.001119}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{749., 0.001104}}]}, 
         RowBox[{"{", 
           RowBox[{"749.`", ",", "0.001104`"}], "}"}]], 
        Annotation[#, {749., 0.001104}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{750., 0.001103}}]}, 
         RowBox[{"{", 
           RowBox[{"750.`", ",", "0.001103`"}], "}"}]], 
        Annotation[#, {750., 0.001103}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{751., 0.00129}}]}, 
         RowBox[{"{", 
           RowBox[{"751.`", ",", "0.00129`"}], "}"}]], 
        Annotation[#, {751., 0.00129}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{752., 0.001113}}]}, 
         RowBox[{"{", 
           RowBox[{"752.`", ",", "0.001113`"}], "}"}]], 
        Annotation[#, {752., 0.001113}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{753., 0.001107}}]}, 
         RowBox[{"{", 
           RowBox[{"753.`", ",", "0.001107`"}], "}"}]], 
        Annotation[#, {753., 0.001107}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{754., 0.00112}}]}, 
         RowBox[{"{", 
           RowBox[{"754.`", ",", "0.00112`"}], "}"}]], 
        Annotation[#, {754., 0.00112}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{755., 0.001189}}]}, 
         RowBox[{"{", 
           RowBox[{"755.`", ",", "0.001189`"}], "}"}]], 
        Annotation[#, {755., 0.001189}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{756., 0.001117}}]}, 
         RowBox[{"{", 
           RowBox[{"756.`", ",", "0.001117`"}], "}"}]], 
        Annotation[#, {756., 0.001117}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{757., 0.001132}}]}, 
         RowBox[{"{", 
           RowBox[{"757.`", ",", "0.001132`"}], "}"}]], 
        Annotation[#, {757., 0.001132}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{758., 0.001149}}]}, 
         RowBox[{"{", 
           RowBox[{"758.`", ",", "0.001149`"}], "}"}]], 
        Annotation[#, {758., 0.001149}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{759., 0.001154}}]}, 
         RowBox[{"{", 
           RowBox[{"759.`", ",", "0.001154`"}], "}"}]], 
        Annotation[#, {759., 0.001154}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{760., 0.001134}}]}, 
         RowBox[{"{", 
           RowBox[{"760.`", ",", "0.001134`"}], "}"}]], 
        Annotation[#, {760., 0.001134}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{761., 0.001126}}]}, 
         RowBox[{"{", 
           RowBox[{"761.`", ",", "0.001126`"}], "}"}]], 
        Annotation[#, {761., 0.001126}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{762., 0.001172}}]}, 
         RowBox[{"{", 
           RowBox[{"762.`", ",", "0.001172`"}], "}"}]], 
        Annotation[#, {762., 0.001172}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{763., 0.001144}}]}, 
         RowBox[{"{", 
           RowBox[{"763.`", ",", "0.001144`"}], "}"}]], 
        Annotation[#, {763., 0.001144}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{764., 0.001135}}]}, 
         RowBox[{"{", 
           RowBox[{"764.`", ",", "0.001135`"}], "}"}]], 
        Annotation[#, {764., 0.001135}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{765., 0.00113}}]}, 
         RowBox[{"{", 
           RowBox[{"765.`", ",", "0.00113`"}], "}"}]], 
        Annotation[#, {765., 0.00113}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{766., 0.00115}}]}, 
         RowBox[{"{", 
           RowBox[{"766.`", ",", "0.00115`"}], "}"}]], 
        Annotation[#, {766., 0.00115}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{767., 0.001134}}]}, 
         RowBox[{"{", 
           RowBox[{"767.`", ",", "0.001134`"}], "}"}]], 
        Annotation[#, {767., 0.001134}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{768., 0.001187}}]}, 
         RowBox[{"{", 
           RowBox[{"768.`", ",", "0.001187`"}], "}"}]], 
        Annotation[#, {768., 0.001187}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{769., 0.001195}}]}, 
         RowBox[{"{", 
           RowBox[{"769.`", ",", "0.001195`"}], "}"}]], 
        Annotation[#, {769., 0.001195}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{770., 0.001223}}]}, 
         RowBox[{"{", 
           RowBox[{"770.`", ",", "0.001223`"}], "}"}]], 
        Annotation[#, {770., 0.001223}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{771., 0.001135}}]}, 
         RowBox[{"{", 
           RowBox[{"771.`", ",", "0.001135`"}], "}"}]], 
        Annotation[#, {771., 0.001135}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{772., 0.001146}}]}, 
         RowBox[{"{", 
           RowBox[{"772.`", ",", "0.001146`"}], "}"}]], 
        Annotation[#, {772., 0.001146}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{773., 0.001139}}]}, 
         RowBox[{"{", 
           RowBox[{"773.`", ",", "0.001139`"}], "}"}]], 
        Annotation[#, {773., 0.001139}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{774., 0.001144}}]}, 
         RowBox[{"{", 
           RowBox[{"774.`", ",", "0.001144`"}], "}"}]], 
        Annotation[#, {774., 0.001144}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{775., 0.001153}}]}, 
         RowBox[{"{", 
           RowBox[{"775.`", ",", "0.001153`"}], "}"}]], 
        Annotation[#, {775., 0.001153}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{776., 0.001144}}]}, 
         RowBox[{"{", 
           RowBox[{"776.`", ",", "0.001144`"}], "}"}]], 
        Annotation[#, {776., 0.001144}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{777., 0.001191}}]}, 
         RowBox[{"{", 
           RowBox[{"777.`", ",", "0.001191`"}], "}"}]], 
        Annotation[#, {777., 0.001191}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{778., 0.001157}}]}, 
         RowBox[{"{", 
           RowBox[{"778.`", ",", "0.001157`"}], "}"}]], 
        Annotation[#, {778., 0.001157}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{779., 0.001159}}]}, 
         RowBox[{"{", 
           RowBox[{"779.`", ",", "0.001159`"}], "}"}]], 
        Annotation[#, {779., 0.001159}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{780., 0.00115}}]}, 
         RowBox[{"{", 
           RowBox[{"780.`", ",", "0.00115`"}], "}"}]], 
        Annotation[#, {780., 0.00115}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{781., 0.001216}}]}, 
         RowBox[{"{", 
           RowBox[{"781.`", ",", "0.001216`"}], "}"}]], 
        Annotation[#, {781., 0.001216}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{782., 0.001154}}]}, 
         RowBox[{"{", 
           RowBox[{"782.`", ",", "0.001154`"}], "}"}]], 
        Annotation[#, {782., 0.001154}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{783., 0.001168}}]}, 
         RowBox[{"{", 
           RowBox[{"783.`", ",", "0.001168`"}], "}"}]], 
        Annotation[#, {783., 0.001168}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{784., 0.001167}}]}, 
         RowBox[{"{", 
           RowBox[{"784.`", ",", "0.001167`"}], "}"}]], 
        Annotation[#, {784., 0.001167}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{785., 0.001165}}]}, 
         RowBox[{"{", 
           RowBox[{"785.`", ",", "0.001165`"}], "}"}]], 
        Annotation[#, {785., 0.001165}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{786., 0.00116}}]}, 
         RowBox[{"{", 
           RowBox[{"786.`", ",", "0.00116`"}], "}"}]], 
        Annotation[#, {786., 0.00116}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{787., 0.001176}}]}, 
         RowBox[{"{", 
           RowBox[{"787.`", ",", "0.001176`"}], "}"}]], 
        Annotation[#, {787., 0.001176}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{788., 0.001169}}]}, 
         RowBox[{"{", 
           RowBox[{"788.`", ",", "0.001169`"}], "}"}]], 
        Annotation[#, {788., 0.001169}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{789., 0.001164}}]}, 
         RowBox[{"{", 
           RowBox[{"789.`", ",", "0.001164`"}], "}"}]], 
        Annotation[#, {789., 0.001164}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{790., 0.001174}}]}, 
         RowBox[{"{", 
           RowBox[{"790.`", ",", "0.001174`"}], "}"}]], 
        Annotation[#, {790., 0.001174}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{791., 0.001173}}]}, 
         RowBox[{"{", 
           RowBox[{"791.`", ",", "0.001173`"}], "}"}]], 
        Annotation[#, {791., 0.001173}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{792., 0.001173}}]}, 
         RowBox[{"{", 
           RowBox[{"792.`", ",", "0.001173`"}], "}"}]], 
        Annotation[#, {792., 0.001173}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{793., 0.001181}}]}, 
         RowBox[{"{", 
           RowBox[{"793.`", ",", "0.001181`"}], "}"}]], 
        Annotation[#, {793., 0.001181}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{794., 0.001172}}]}, 
         RowBox[{"{", 
           RowBox[{"794.`", ",", "0.001172`"}], "}"}]], 
        Annotation[#, {794., 0.001172}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{795., 0.001171}}]}, 
         RowBox[{"{", 
           RowBox[{"795.`", ",", "0.001171`"}], "}"}]], 
        Annotation[#, {795., 0.001171}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{796., 0.001267}}]}, 
         RowBox[{"{", 
           RowBox[{"796.`", ",", "0.001267`"}], "}"}]], 
        Annotation[#, {796., 0.001267}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{797., 0.001186}}]}, 
         RowBox[{"{", 
           RowBox[{"797.`", ",", "0.001186`"}], "}"}]], 
        Annotation[#, {797., 0.001186}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{798., 0.001176}}]}, 
         RowBox[{"{", 
           RowBox[{"798.`", ",", "0.001176`"}], "}"}]], 
        Annotation[#, {798., 0.001176}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{799., 0.001198}}]}, 
         RowBox[{"{", 
           RowBox[{"799.`", ",", "0.001198`"}], "}"}]], 
        Annotation[#, {799., 0.001198}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{800., 0.001181}}]}, 
         RowBox[{"{", 
           RowBox[{"800.`", ",", "0.001181`"}], "}"}]], 
        Annotation[#, {800., 0.001181}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{801., 0.00121}}]}, 
         RowBox[{"{", 
           RowBox[{"801.`", ",", "0.00121`"}], "}"}]], 
        Annotation[#, {801., 0.00121}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{802., 0.001325}}]}, 
         RowBox[{"{", 
           RowBox[{"802.`", ",", "0.001325`"}], "}"}]], 
        Annotation[#, {802., 0.001325}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{803., 0.001192}}]}, 
         RowBox[{"{", 
           RowBox[{"803.`", ",", "0.001192`"}], "}"}]], 
        Annotation[#, {803., 0.001192}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{804., 0.001193}}]}, 
         RowBox[{"{", 
           RowBox[{"804.`", ",", "0.001193`"}], "}"}]], 
        Annotation[#, {804., 0.001193}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{805., 0.001239}}]}, 
         RowBox[{"{", 
           RowBox[{"805.`", ",", "0.001239`"}], "}"}]], 
        Annotation[#, {805., 0.001239}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{806., 0.001188}}]}, 
         RowBox[{"{", 
           RowBox[{"806.`", ",", "0.001188`"}], "}"}]], 
        Annotation[#, {806., 0.001188}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{807., 0.001194}}]}, 
         RowBox[{"{", 
           RowBox[{"807.`", ",", "0.001194`"}], "}"}]], 
        Annotation[#, {807., 0.001194}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{808., 0.001202}}]}, 
         RowBox[{"{", 
           RowBox[{"808.`", ",", "0.001202`"}], "}"}]], 
        Annotation[#, {808., 0.001202}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{809., 0.001194}}]}, 
         RowBox[{"{", 
           RowBox[{"809.`", ",", "0.001194`"}], "}"}]], 
        Annotation[#, {809., 0.001194}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{810., 0.001198}}]}, 
         RowBox[{"{", 
           RowBox[{"810.`", ",", "0.001198`"}], "}"}]], 
        Annotation[#, {810., 0.001198}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{811., 0.001217}}]}, 
         RowBox[{"{", 
           RowBox[{"811.`", ",", "0.001217`"}], "}"}]], 
        Annotation[#, {811., 0.001217}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{812., 0.00126}}]}, 
         RowBox[{"{", 
           RowBox[{"812.`", ",", "0.00126`"}], "}"}]], 
        Annotation[#, {812., 0.00126}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{813., 0.001204}}]}, 
         RowBox[{"{", 
           RowBox[{"813.`", ",", "0.001204`"}], "}"}]], 
        Annotation[#, {813., 0.001204}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{814., 0.001225}}]}, 
         RowBox[{"{", 
           RowBox[{"814.`", ",", "0.001225`"}], "}"}]], 
        Annotation[#, {814., 0.001225}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{815., 0.001214}}]}, 
         RowBox[{"{", 
           RowBox[{"815.`", ",", "0.001214`"}], "}"}]], 
        Annotation[#, {815., 0.001214}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{816., 0.001206}}]}, 
         RowBox[{"{", 
           RowBox[{"816.`", ",", "0.001206`"}], "}"}]], 
        Annotation[#, {816., 0.001206}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{817., 0.00122}}]}, 
         RowBox[{"{", 
           RowBox[{"817.`", ",", "0.00122`"}], "}"}]], 
        Annotation[#, {817., 0.00122}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{818., 0.001222}}]}, 
         RowBox[{"{", 
           RowBox[{"818.`", ",", "0.001222`"}], "}"}]], 
        Annotation[#, {818., 0.001222}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{819., 0.001211}}]}, 
         RowBox[{"{", 
           RowBox[{"819.`", ",", "0.001211`"}], "}"}]], 
        Annotation[#, {819., 0.001211}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{820., 0.001229}}]}, 
         RowBox[{"{", 
           RowBox[{"820.`", ",", "0.001229`"}], "}"}]], 
        Annotation[#, {820., 0.001229}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{821., 0.001222}}]}, 
         RowBox[{"{", 
           RowBox[{"821.`", ",", "0.001222`"}], "}"}]], 
        Annotation[#, {821., 0.001222}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{822., 0.001216}}]}, 
         RowBox[{"{", 
           RowBox[{"822.`", ",", "0.001216`"}], "}"}]], 
        Annotation[#, {822., 0.001216}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{823., 0.001228}}]}, 
         RowBox[{"{", 
           RowBox[{"823.`", ",", "0.001228`"}], "}"}]], 
        Annotation[#, {823., 0.001228}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{824., 0.001314}}]}, 
         RowBox[{"{", 
           RowBox[{"824.`", ",", "0.001314`"}], "}"}]], 
        Annotation[#, {824., 0.001314}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{825., 0.001227}}]}, 
         RowBox[{"{", 
           RowBox[{"825.`", ",", "0.001227`"}], "}"}]], 
        Annotation[#, {825., 0.001227}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{826., 0.001277}}]}, 
         RowBox[{"{", 
           RowBox[{"826.`", ",", "0.001277`"}], "}"}]], 
        Annotation[#, {826., 0.001277}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{827., 0.001225}}]}, 
         RowBox[{"{", 
           RowBox[{"827.`", ",", "0.001225`"}], "}"}]], 
        Annotation[#, {827., 0.001225}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{828., 0.001229}}]}, 
         RowBox[{"{", 
           RowBox[{"828.`", ",", "0.001229`"}], "}"}]], 
        Annotation[#, {828., 0.001229}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{829., 0.001245}}]}, 
         RowBox[{"{", 
           RowBox[{"829.`", ",", "0.001245`"}], "}"}]], 
        Annotation[#, {829., 0.001245}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{830., 0.001227}}]}, 
         RowBox[{"{", 
           RowBox[{"830.`", ",", "0.001227`"}], "}"}]], 
        Annotation[#, {830., 0.001227}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{831., 0.001228}}]}, 
         RowBox[{"{", 
           RowBox[{"831.`", ",", "0.001228`"}], "}"}]], 
        Annotation[#, {831., 0.001228}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{832., 0.001461}}]}, 
         RowBox[{"{", 
           RowBox[{"832.`", ",", "0.001461`"}], "}"}]], 
        Annotation[#, {832., 0.001461}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{833., 0.001233}}]}, 
         RowBox[{"{", 
           RowBox[{"833.`", ",", "0.001233`"}], "}"}]], 
        Annotation[#, {833., 0.001233}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{834., 0.001233}}]}, 
         RowBox[{"{", 
           RowBox[{"834.`", ",", "0.001233`"}], "}"}]], 
        Annotation[#, {834., 0.001233}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{835., 0.001246}}]}, 
         RowBox[{"{", 
           RowBox[{"835.`", ",", "0.001246`"}], "}"}]], 
        Annotation[#, {835., 0.001246}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{836., 0.001247}}]}, 
         RowBox[{"{", 
           RowBox[{"836.`", ",", "0.001247`"}], "}"}]], 
        Annotation[#, {836., 0.001247}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{837., 0.001316}}]}, 
         RowBox[{"{", 
           RowBox[{"837.`", ",", "0.001316`"}], "}"}]], 
        Annotation[#, {837., 0.001316}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{838., 0.001275}}]}, 
         RowBox[{"{", 
           RowBox[{"838.`", ",", "0.001275`"}], "}"}]], 
        Annotation[#, {838., 0.001275}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{839., 0.001245}}]}, 
         RowBox[{"{", 
           RowBox[{"839.`", ",", "0.001245`"}], "}"}]], 
        Annotation[#, {839., 0.001245}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{840., 0.001318}}]}, 
         RowBox[{"{", 
           RowBox[{"840.`", ",", "0.001318`"}], "}"}]], 
        Annotation[#, {840., 0.001318}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{841., 0.001248}}]}, 
         RowBox[{"{", 
           RowBox[{"841.`", ",", "0.001248`"}], "}"}]], 
        Annotation[#, {841., 0.001248}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{842., 0.001263}}]}, 
         RowBox[{"{", 
           RowBox[{"842.`", ",", "0.001263`"}], "}"}]], 
        Annotation[#, {842., 0.001263}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{843., 0.001267}}]}, 
         RowBox[{"{", 
           RowBox[{"843.`", ",", "0.001267`"}], "}"}]], 
        Annotation[#, {843., 0.001267}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{844., 0.001253}}]}, 
         RowBox[{"{", 
           RowBox[{"844.`", ",", "0.001253`"}], "}"}]], 
        Annotation[#, {844., 0.001253}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{845., 0.001361}}]}, 
         RowBox[{"{", 
           RowBox[{"845.`", ",", "0.001361`"}], "}"}]], 
        Annotation[#, {845., 0.001361}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{846., 0.001244}}]}, 
         RowBox[{"{", 
           RowBox[{"846.`", ",", "0.001244`"}], "}"}]], 
        Annotation[#, {846., 0.001244}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{847., 0.001264}}]}, 
         RowBox[{"{", 
           RowBox[{"847.`", ",", "0.001264`"}], "}"}]], 
        Annotation[#, {847., 0.001264}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{848., 0.001247}}]}, 
         RowBox[{"{", 
           RowBox[{"848.`", ",", "0.001247`"}], "}"}]], 
        Annotation[#, {848., 0.001247}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{849., 0.001247}}]}, 
         RowBox[{"{", 
           RowBox[{"849.`", ",", "0.001247`"}], "}"}]], 
        Annotation[#, {849., 0.001247}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{850., 0.001288}}]}, 
         RowBox[{"{", 
           RowBox[{"850.`", ",", "0.001288`"}], "}"}]], 
        Annotation[#, {850., 0.001288}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{851., 0.001272}}]}, 
         RowBox[{"{", 
           RowBox[{"851.`", ",", "0.001272`"}], "}"}]], 
        Annotation[#, {851., 0.001272}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{852., 0.001328}}]}, 
         RowBox[{"{", 
           RowBox[{"852.`", ",", "0.001328`"}], "}"}]], 
        Annotation[#, {852., 0.001328}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{853., 0.001271}}]}, 
         RowBox[{"{", 
           RowBox[{"853.`", ",", "0.001271`"}], "}"}]], 
        Annotation[#, {853., 0.001271}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{854., 0.001263}}]}, 
         RowBox[{"{", 
           RowBox[{"854.`", ",", "0.001263`"}], "}"}]], 
        Annotation[#, {854., 0.001263}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{855., 0.001258}}]}, 
         RowBox[{"{", 
           RowBox[{"855.`", ",", "0.001258`"}], "}"}]], 
        Annotation[#, {855., 0.001258}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{856., 0.001271}}]}, 
         RowBox[{"{", 
           RowBox[{"856.`", ",", "0.001271`"}], "}"}]], 
        Annotation[#, {856., 0.001271}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{857., 0.001262}}]}, 
         RowBox[{"{", 
           RowBox[{"857.`", ",", "0.001262`"}], "}"}]], 
        Annotation[#, {857., 0.001262}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{858., 0.001425}}]}, 
         RowBox[{"{", 
           RowBox[{"858.`", ",", "0.001425`"}], "}"}]], 
        Annotation[#, {858., 0.001425}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{859., 0.001283}}]}, 
         RowBox[{"{", 
           RowBox[{"859.`", ",", "0.001283`"}], "}"}]], 
        Annotation[#, {859., 0.001283}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{860., 0.001272}}]}, 
         RowBox[{"{", 
           RowBox[{"860.`", ",", "0.001272`"}], "}"}]], 
        Annotation[#, {860., 0.001272}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{861., 0.001279}}]}, 
         RowBox[{"{", 
           RowBox[{"861.`", ",", "0.001279`"}], "}"}]], 
        Annotation[#, {861., 0.001279}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{862., 0.001285}}]}, 
         RowBox[{"{", 
           RowBox[{"862.`", ",", "0.001285`"}], "}"}]], 
        Annotation[#, {862., 0.001285}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{863., 0.001277}}]}, 
         RowBox[{"{", 
           RowBox[{"863.`", ",", "0.001277`"}], "}"}]], 
        Annotation[#, {863., 0.001277}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{864., 0.001275}}]}, 
         RowBox[{"{", 
           RowBox[{"864.`", ",", "0.001275`"}], "}"}]], 
        Annotation[#, {864., 0.001275}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{865., 0.001299}}]}, 
         RowBox[{"{", 
           RowBox[{"865.`", ",", "0.001299`"}], "}"}]], 
        Annotation[#, {865., 0.001299}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{866., 0.001279}}]}, 
         RowBox[{"{", 
           RowBox[{"866.`", ",", "0.001279`"}], "}"}]], 
        Annotation[#, {866., 0.001279}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{867., 0.00128}}]}, 
         RowBox[{"{", 
           RowBox[{"867.`", ",", "0.00128`"}], "}"}]], 
        Annotation[#, {867., 0.00128}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{868., 0.001294}}]}, 
         RowBox[{"{", 
           RowBox[{"868.`", ",", "0.001294`"}], "}"}]], 
        Annotation[#, {868., 0.001294}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{869., 0.001289}}]}, 
         RowBox[{"{", 
           RowBox[{"869.`", ",", "0.001289`"}], "}"}]], 
        Annotation[#, {869., 0.001289}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{870., 0.001284}}]}, 
         RowBox[{"{", 
           RowBox[{"870.`", ",", "0.001284`"}], "}"}]], 
        Annotation[#, {870., 0.001284}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{871., 0.001299}}]}, 
         RowBox[{"{", 
           RowBox[{"871.`", ",", "0.001299`"}], "}"}]], 
        Annotation[#, {871., 0.001299}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{872., 0.001296}}]}, 
         RowBox[{"{", 
           RowBox[{"872.`", ",", "0.001296`"}], "}"}]], 
        Annotation[#, {872., 0.001296}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{873., 0.001294}}]}, 
         RowBox[{"{", 
           RowBox[{"873.`", ",", "0.001294`"}], "}"}]], 
        Annotation[#, {873., 0.001294}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{874., 0.001301}}]}, 
         RowBox[{"{", 
           RowBox[{"874.`", ",", "0.001301`"}], "}"}]], 
        Annotation[#, {874., 0.001301}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{875., 0.001294}}]}, 
         RowBox[{"{", 
           RowBox[{"875.`", ",", "0.001294`"}], "}"}]], 
        Annotation[#, {875., 0.001294}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{876., 0.002464}}]}, 
         RowBox[{"{", 
           RowBox[{"876.`", ",", "0.002464`"}], "}"}]], 
        Annotation[#, {876., 0.002464}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{877., 0.001924}}]}, 
         RowBox[{"{", 
           RowBox[{"877.`", ",", "0.001924`"}], "}"}]], 
        Annotation[#, {877., 0.001924}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{878., 0.001581}}]}, 
         RowBox[{"{", 
           RowBox[{"878.`", ",", "0.001581`"}], "}"}]], 
        Annotation[#, {878., 0.001581}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{879., 0.001437}}]}, 
         RowBox[{"{", 
           RowBox[{"879.`", ",", "0.001437`"}], "}"}]], 
        Annotation[#, {879., 0.001437}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{880., 0.001354}}]}, 
         RowBox[{"{", 
           RowBox[{"880.`", ",", "0.001354`"}], "}"}]], 
        Annotation[#, {880., 0.001354}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{881., 0.001361}}]}, 
         RowBox[{"{", 
           RowBox[{"881.`", ",", "0.001361`"}], "}"}]], 
        Annotation[#, {881., 0.001361}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{882., 0.001352}}]}, 
         RowBox[{"{", 
           RowBox[{"882.`", ",", "0.001352`"}], "}"}]], 
        Annotation[#, {882., 0.001352}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{883., 0.001278}}]}, 
         RowBox[{"{", 
           RowBox[{"883.`", ",", "0.001278`"}], "}"}]], 
        Annotation[#, {883., 0.001278}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{884., 0.001264}}]}, 
         RowBox[{"{", 
           RowBox[{"884.`", ",", "0.001264`"}], "}"}]], 
        Annotation[#, {884., 0.001264}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{885., 0.001264}}]}, 
         RowBox[{"{", 
           RowBox[{"885.`", ",", "0.001264`"}], "}"}]], 
        Annotation[#, {885., 0.001264}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{886., 0.001278}}]}, 
         RowBox[{"{", 
           RowBox[{"886.`", ",", "0.001278`"}], "}"}]], 
        Annotation[#, {886., 0.001278}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{887., 0.001363}}]}, 
         RowBox[{"{", 
           RowBox[{"887.`", ",", "0.001363`"}], "}"}]], 
        Annotation[#, {887., 0.001363}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{888., 0.001277}}]}, 
         RowBox[{"{", 
           RowBox[{"888.`", ",", "0.001277`"}], "}"}]], 
        Annotation[#, {888., 0.001277}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{889., 0.001288}}]}, 
         RowBox[{"{", 
           RowBox[{"889.`", ",", "0.001288`"}], "}"}]], 
        Annotation[#, {889., 0.001288}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{890., 0.001331}}]}, 
         RowBox[{"{", 
           RowBox[{"890.`", ",", "0.001331`"}], "}"}]], 
        Annotation[#, {890., 0.001331}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{891., 0.001285}}]}, 
         RowBox[{"{", 
           RowBox[{"891.`", ",", "0.001285`"}], "}"}]], 
        Annotation[#, {891., 0.001285}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{892., 0.001292}}]}, 
         RowBox[{"{", 
           RowBox[{"892.`", ",", "0.001292`"}], "}"}]], 
        Annotation[#, {892., 0.001292}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{893., 0.001281}}]}, 
         RowBox[{"{", 
           RowBox[{"893.`", ",", "0.001281`"}], "}"}]], 
        Annotation[#, {893., 0.001281}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{894., 0.001414}}]}, 
         RowBox[{"{", 
           RowBox[{"894.`", ",", "0.001414`"}], "}"}]], 
        Annotation[#, {894., 0.001414}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{895., 0.001302}}]}, 
         RowBox[{"{", 
           RowBox[{"895.`", ",", "0.001302`"}], "}"}]], 
        Annotation[#, {895., 0.001302}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{896., 0.001287}}]}, 
         RowBox[{"{", 
           RowBox[{"896.`", ",", "0.001287`"}], "}"}]], 
        Annotation[#, {896., 0.001287}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{897., 0.001285}}]}, 
         RowBox[{"{", 
           RowBox[{"897.`", ",", "0.001285`"}], "}"}]], 
        Annotation[#, {897., 0.001285}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{898., 0.001307}}]}, 
         RowBox[{"{", 
           RowBox[{"898.`", ",", "0.001307`"}], "}"}]], 
        Annotation[#, {898., 0.001307}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{899., 0.001291}}]}, 
         RowBox[{"{", 
           RowBox[{"899.`", ",", "0.001291`"}], "}"}]], 
        Annotation[#, {899., 0.001291}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{900., 0.001403}}]}, 
         RowBox[{"{", 
           RowBox[{"900.`", ",", "0.001403`"}], "}"}]], 
        Annotation[#, {900., 0.001403}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{901., 0.001345}}]}, 
         RowBox[{"{", 
           RowBox[{"901.`", ",", "0.001345`"}], "}"}]], 
        Annotation[#, {901., 0.001345}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{902., 0.001297}}]}, 
         RowBox[{"{", 
           RowBox[{"902.`", ",", "0.001297`"}], "}"}]], 
        Annotation[#, {902., 0.001297}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{903., 0.001288}}]}, 
         RowBox[{"{", 
           RowBox[{"903.`", ",", "0.001288`"}], "}"}]], 
        Annotation[#, {903., 0.001288}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{904., 0.001304}}]}, 
         RowBox[{"{", 
           RowBox[{"904.`", ",", "0.001304`"}], "}"}]], 
        Annotation[#, {904., 0.001304}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{905., 0.001299}}]}, 
         RowBox[{"{", 
           RowBox[{"905.`", ",", "0.001299`"}], "}"}]], 
        Annotation[#, {905., 0.001299}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{906., 0.001293}}]}, 
         RowBox[{"{", 
           RowBox[{"906.`", ",", "0.001293`"}], "}"}]], 
        Annotation[#, {906., 0.001293}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{907., 0.001492}}]}, 
         RowBox[{"{", 
           RowBox[{"907.`", ",", "0.001492`"}], "}"}]], 
        Annotation[#, {907., 0.001492}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{908., 0.001297}}]}, 
         RowBox[{"{", 
           RowBox[{"908.`", ",", "0.001297`"}], "}"}]], 
        Annotation[#, {908., 0.001297}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{909., 0.001302}}]}, 
         RowBox[{"{", 
           RowBox[{"909.`", ",", "0.001302`"}], "}"}]], 
        Annotation[#, {909., 0.001302}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{910., 0.001381}}]}, 
         RowBox[{"{", 
           RowBox[{"910.`", ",", "0.001381`"}], "}"}]], 
        Annotation[#, {910., 0.001381}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{911., 0.001302}}]}, 
         RowBox[{"{", 
           RowBox[{"911.`", ",", "0.001302`"}], "}"}]], 
        Annotation[#, {911., 0.001302}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{912., 0.00137}}]}, 
         RowBox[{"{", 
           RowBox[{"912.`", ",", "0.00137`"}], "}"}]], 
        Annotation[#, {912., 0.00137}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{913., 0.001321}}]}, 
         RowBox[{"{", 
           RowBox[{"913.`", ",", "0.001321`"}], "}"}]], 
        Annotation[#, {913., 0.001321}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{914., 0.00131}}]}, 
         RowBox[{"{", 
           RowBox[{"914.`", ",", "0.00131`"}], "}"}]], 
        Annotation[#, {914., 0.00131}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{915., 0.00141}}]}, 
         RowBox[{"{", 
           RowBox[{"915.`", ",", "0.00141`"}], "}"}]], 
        Annotation[#, {915., 0.00141}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{916., 0.001427}}]}, 
         RowBox[{"{", 
           RowBox[{"916.`", ",", "0.001427`"}], "}"}]], 
        Annotation[#, {916., 0.001427}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{917., 0.00148}}]}, 
         RowBox[{"{", 
           RowBox[{"917.`", ",", "0.00148`"}], "}"}]], 
        Annotation[#, {917., 0.00148}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{918., 0.001311}}]}, 
         RowBox[{"{", 
           RowBox[{"918.`", ",", "0.001311`"}], "}"}]], 
        Annotation[#, {918., 0.001311}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{919., 0.001527}}]}, 
         RowBox[{"{", 
           RowBox[{"919.`", ",", "0.001527`"}], "}"}]], 
        Annotation[#, {919., 0.001527}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{920., 0.001321}}]}, 
         RowBox[{"{", 
           RowBox[{"920.`", ",", "0.001321`"}], "}"}]], 
        Annotation[#, {920., 0.001321}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{921., 0.001314}}]}, 
         RowBox[{"{", 
           RowBox[{"921.`", ",", "0.001314`"}], "}"}]], 
        Annotation[#, {921., 0.001314}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{922., 0.00138}}]}, 
         RowBox[{"{", 
           RowBox[{"922.`", ",", "0.00138`"}], "}"}]], 
        Annotation[#, {922., 0.00138}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{923., 0.00132}}]}, 
         RowBox[{"{", 
           RowBox[{"923.`", ",", "0.00132`"}], "}"}]], 
        Annotation[#, {923., 0.00132}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{924., 0.001429}}]}, 
         RowBox[{"{", 
           RowBox[{"924.`", ",", "0.001429`"}], "}"}]], 
        Annotation[#, {924., 0.001429}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{925., 0.001514}}]}, 
         RowBox[{"{", 
           RowBox[{"925.`", ",", "0.001514`"}], "}"}]], 
        Annotation[#, {925., 0.001514}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{926., 0.001332}}]}, 
         RowBox[{"{", 
           RowBox[{"926.`", ",", "0.001332`"}], "}"}]], 
        Annotation[#, {926., 0.001332}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{927., 0.001325}}]}, 
         RowBox[{"{", 
           RowBox[{"927.`", ",", "0.001325`"}], "}"}]], 
        Annotation[#, {927., 0.001325}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{928., 0.001386}}]}, 
         RowBox[{"{", 
           RowBox[{"928.`", ",", "0.001386`"}], "}"}]], 
        Annotation[#, {928., 0.001386}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{929., 0.001342}}]}, 
         RowBox[{"{", 
           RowBox[{"929.`", ",", "0.001342`"}], "}"}]], 
        Annotation[#, {929., 0.001342}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{930., 0.001332}}]}, 
         RowBox[{"{", 
           RowBox[{"930.`", ",", "0.001332`"}], "}"}]], 
        Annotation[#, {930., 0.001332}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{931., 0.001411}}]}, 
         RowBox[{"{", 
           RowBox[{"931.`", ",", "0.001411`"}], "}"}]], 
        Annotation[#, {931., 0.001411}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{932., 0.001338}}]}, 
         RowBox[{"{", 
           RowBox[{"932.`", ",", "0.001338`"}], "}"}]], 
        Annotation[#, {932., 0.001338}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{933., 0.001351}}]}, 
         RowBox[{"{", 
           RowBox[{"933.`", ",", "0.001351`"}], "}"}]], 
        Annotation[#, {933., 0.001351}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{934., 0.001339}}]}, 
         RowBox[{"{", 
           RowBox[{"934.`", ",", "0.001339`"}], "}"}]], 
        Annotation[#, {934., 0.001339}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{935., 0.001335}}]}, 
         RowBox[{"{", 
           RowBox[{"935.`", ",", "0.001335`"}], "}"}]], 
        Annotation[#, {935., 0.001335}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{936., 0.001338}}]}, 
         RowBox[{"{", 
           RowBox[{"936.`", ",", "0.001338`"}], "}"}]], 
        Annotation[#, {936., 0.001338}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{937., 0.00141}}]}, 
         RowBox[{"{", 
           RowBox[{"937.`", ",", "0.00141`"}], "}"}]], 
        Annotation[#, {937., 0.00141}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{938., 0.001349}}]}, 
         RowBox[{"{", 
           RowBox[{"938.`", ",", "0.001349`"}], "}"}]], 
        Annotation[#, {938., 0.001349}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{939., 0.001336}}]}, 
         RowBox[{"{", 
           RowBox[{"939.`", ",", "0.001336`"}], "}"}]], 
        Annotation[#, {939., 0.001336}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{940., 0.00145}}]}, 
         RowBox[{"{", 
           RowBox[{"940.`", ",", "0.00145`"}], "}"}]], 
        Annotation[#, {940., 0.00145}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{941., 0.001356}}]}, 
         RowBox[{"{", 
           RowBox[{"941.`", ",", "0.001356`"}], "}"}]], 
        Annotation[#, {941., 0.001356}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{942., 0.001355}}]}, 
         RowBox[{"{", 
           RowBox[{"942.`", ",", "0.001355`"}], "}"}]], 
        Annotation[#, {942., 0.001355}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{943., 0.001413}}]}, 
         RowBox[{"{", 
           RowBox[{"943.`", ",", "0.001413`"}], "}"}]], 
        Annotation[#, {943., 0.001413}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{944., 0.001421}}]}, 
         RowBox[{"{", 
           RowBox[{"944.`", ",", "0.001421`"}], "}"}]], 
        Annotation[#, {944., 0.001421}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{945., 0.001361}}]}, 
         RowBox[{"{", 
           RowBox[{"945.`", ",", "0.001361`"}], "}"}]], 
        Annotation[#, {945., 0.001361}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{946., 0.001358}}]}, 
         RowBox[{"{", 
           RowBox[{"946.`", ",", "0.001358`"}], "}"}]], 
        Annotation[#, {946., 0.001358}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{947., 0.00135}}]}, 
         RowBox[{"{", 
           RowBox[{"947.`", ",", "0.00135`"}], "}"}]], 
        Annotation[#, {947., 0.00135}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{948., 0.001352}}]}, 
         RowBox[{"{", 
           RowBox[{"948.`", ",", "0.001352`"}], "}"}]], 
        Annotation[#, {948., 0.001352}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{949., 0.00144}}]}, 
         RowBox[{"{", 
           RowBox[{"949.`", ",", "0.00144`"}], "}"}]], 
        Annotation[#, {949., 0.00144}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{950., 0.001359}}]}, 
         RowBox[{"{", 
           RowBox[{"950.`", ",", "0.001359`"}], "}"}]], 
        Annotation[#, {950., 0.001359}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{951., 0.001349}}]}, 
         RowBox[{"{", 
           RowBox[{"951.`", ",", "0.001349`"}], "}"}]], 
        Annotation[#, {951., 0.001349}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{952., 0.001357}}]}, 
         RowBox[{"{", 
           RowBox[{"952.`", ",", "0.001357`"}], "}"}]], 
        Annotation[#, {952., 0.001357}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{953., 0.00138}}]}, 
         RowBox[{"{", 
           RowBox[{"953.`", ",", "0.00138`"}], "}"}]], 
        Annotation[#, {953., 0.00138}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{954., 0.001498}}]}, 
         RowBox[{"{", 
           RowBox[{"954.`", ",", "0.001498`"}], "}"}]], 
        Annotation[#, {954., 0.001498}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{955., 0.001358}}]}, 
         RowBox[{"{", 
           RowBox[{"955.`", ",", "0.001358`"}], "}"}]], 
        Annotation[#, {955., 0.001358}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{956., 0.001562}}]}, 
         RowBox[{"{", 
           RowBox[{"956.`", ",", "0.001562`"}], "}"}]], 
        Annotation[#, {956., 0.001562}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{957., 0.001385}}]}, 
         RowBox[{"{", 
           RowBox[{"957.`", ",", "0.001385`"}], "}"}]], 
        Annotation[#, {957., 0.001385}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{958., 0.00137}}]}, 
         RowBox[{"{", 
           RowBox[{"958.`", ",", "0.00137`"}], "}"}]], 
        Annotation[#, {958., 0.00137}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{959., 0.001363}}]}, 
         RowBox[{"{", 
           RowBox[{"959.`", ",", "0.001363`"}], "}"}]], 
        Annotation[#, {959., 0.001363}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{960., 0.001525}}]}, 
         RowBox[{"{", 
           RowBox[{"960.`", ",", "0.001525`"}], "}"}]], 
        Annotation[#, {960., 0.001525}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{961., 0.001403}}]}, 
         RowBox[{"{", 
           RowBox[{"961.`", ",", "0.001403`"}], "}"}]], 
        Annotation[#, {961., 0.001403}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{962., 0.001378}}]}, 
         RowBox[{"{", 
           RowBox[{"962.`", ",", "0.001378`"}], "}"}]], 
        Annotation[#, {962., 0.001378}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{963., 0.001372}}]}, 
         RowBox[{"{", 
           RowBox[{"963.`", ",", "0.001372`"}], "}"}]], 
        Annotation[#, {963., 0.001372}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{964., 0.001388}}]}, 
         RowBox[{"{", 
           RowBox[{"964.`", ",", "0.001388`"}], "}"}]], 
        Annotation[#, {964., 0.001388}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{965., 0.00143}}]}, 
         RowBox[{"{", 
           RowBox[{"965.`", ",", "0.00143`"}], "}"}]], 
        Annotation[#, {965., 0.00143}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{966., 0.001384}}]}, 
         RowBox[{"{", 
           RowBox[{"966.`", ",", "0.001384`"}], "}"}]], 
        Annotation[#, {966., 0.001384}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{967., 0.001524}}]}, 
         RowBox[{"{", 
           RowBox[{"967.`", ",", "0.001524`"}], "}"}]], 
        Annotation[#, {967., 0.001524}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{968., 0.00139}}]}, 
         RowBox[{"{", 
           RowBox[{"968.`", ",", "0.00139`"}], "}"}]], 
        Annotation[#, {968., 0.00139}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{969., 0.001449}}]}, 
         RowBox[{"{", 
           RowBox[{"969.`", ",", "0.001449`"}], "}"}]], 
        Annotation[#, {969., 0.001449}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{970., 0.001621}}]}, 
         RowBox[{"{", 
           RowBox[{"970.`", ",", "0.001621`"}], "}"}]], 
        Annotation[#, {970., 0.001621}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{971., 0.00146}}]}, 
         RowBox[{"{", 
           RowBox[{"971.`", ",", "0.00146`"}], "}"}]], 
        Annotation[#, {971., 0.00146}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{972., 0.001488}}]}, 
         RowBox[{"{", 
           RowBox[{"972.`", ",", "0.001488`"}], "}"}]], 
        Annotation[#, {972., 0.001488}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{973., 0.001406}}]}, 
         RowBox[{"{", 
           RowBox[{"973.`", ",", "0.001406`"}], "}"}]], 
        Annotation[#, {973., 0.001406}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{974., 0.001402}}]}, 
         RowBox[{"{", 
           RowBox[{"974.`", ",", "0.001402`"}], "}"}]], 
        Annotation[#, {974., 0.001402}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{975., 0.001393}}]}, 
         RowBox[{"{", 
           RowBox[{"975.`", ",", "0.001393`"}], "}"}]], 
        Annotation[#, {975., 0.001393}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{976., 0.001398}}]}, 
         RowBox[{"{", 
           RowBox[{"976.`", ",", "0.001398`"}], "}"}]], 
        Annotation[#, {976., 0.001398}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{977., 0.001462}}]}, 
         RowBox[{"{", 
           RowBox[{"977.`", ",", "0.001462`"}], "}"}]], 
        Annotation[#, {977., 0.001462}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{978., 0.001401}}]}, 
         RowBox[{"{", 
           RowBox[{"978.`", ",", "0.001401`"}], "}"}]], 
        Annotation[#, {978., 0.001401}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{979., 0.001522}}]}, 
         RowBox[{"{", 
           RowBox[{"979.`", ",", "0.001522`"}], "}"}]], 
        Annotation[#, {979., 0.001522}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{980., 0.001402}}]}, 
         RowBox[{"{", 
           RowBox[{"980.`", ",", "0.001402`"}], "}"}]], 
        Annotation[#, {980., 0.001402}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{981., 0.001565}}]}, 
         RowBox[{"{", 
           RowBox[{"981.`", ",", "0.001565`"}], "}"}]], 
        Annotation[#, {981., 0.001565}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{982., 0.00142}}]}, 
         RowBox[{"{", 
           RowBox[{"982.`", ",", "0.00142`"}], "}"}]], 
        Annotation[#, {982., 0.00142}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{983., 0.001405}}]}, 
         RowBox[{"{", 
           RowBox[{"983.`", ",", "0.001405`"}], "}"}]], 
        Annotation[#, {983., 0.001405}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{984., 0.001464}}]}, 
         RowBox[{"{", 
           RowBox[{"984.`", ",", "0.001464`"}], "}"}]], 
        Annotation[#, {984., 0.001464}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{985., 0.001462}}]}, 
         RowBox[{"{", 
           RowBox[{"985.`", ",", "0.001462`"}], "}"}]], 
        Annotation[#, {985., 0.001462}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{986., 0.001453}}]}, 
         RowBox[{"{", 
           RowBox[{"986.`", ",", "0.001453`"}], "}"}]], 
        Annotation[#, {986., 0.001453}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{987., 0.001409}}]}, 
         RowBox[{"{", 
           RowBox[{"987.`", ",", "0.001409`"}], "}"}]], 
        Annotation[#, {987., 0.001409}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{988., 0.001422}}]}, 
         RowBox[{"{", 
           RowBox[{"988.`", ",", "0.001422`"}], "}"}]], 
        Annotation[#, {988., 0.001422}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{989., 0.001467}}]}, 
         RowBox[{"{", 
           RowBox[{"989.`", ",", "0.001467`"}], "}"}]], 
        Annotation[#, {989., 0.001467}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{990., 0.001548}}]}, 
         RowBox[{"{", 
           RowBox[{"990.`", ",", "0.001548`"}], "}"}]], 
        Annotation[#, {990., 0.001548}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{991., 0.001512}}]}, 
         RowBox[{"{", 
           RowBox[{"991.`", ",", "0.001512`"}], "}"}]], 
        Annotation[#, {991., 0.001512}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{992., 0.001488}}]}, 
         RowBox[{"{", 
           RowBox[{"992.`", ",", "0.001488`"}], "}"}]], 
        Annotation[#, {992., 0.001488}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{993., 0.001548}}]}, 
         RowBox[{"{", 
           RowBox[{"993.`", ",", "0.001548`"}], "}"}]], 
        Annotation[#, {993., 0.001548}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{994., 0.00147}}]}, 
         RowBox[{"{", 
           RowBox[{"994.`", ",", "0.00147`"}], "}"}]], 
        Annotation[#, {994., 0.00147}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{995., 0.001463}}]}, 
         RowBox[{"{", 
           RowBox[{"995.`", ",", "0.001463`"}], "}"}]], 
        Annotation[#, {995., 0.001463}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{996., 0.001422}}]}, 
         RowBox[{"{", 
           RowBox[{"996.`", ",", "0.001422`"}], "}"}]], 
        Annotation[#, {996., 0.001422}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{997., 0.001626}}]}, 
         RowBox[{"{", 
           RowBox[{"997.`", ",", "0.001626`"}], "}"}]], 
        Annotation[#, {997., 0.001626}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{998., 0.001564}}]}, 
         RowBox[{"{", 
           RowBox[{"998.`", ",", "0.001564`"}], "}"}]], 
        Annotation[#, {998., 0.001564}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{999., 0.001509}}]}, 
         RowBox[{"{", 
           RowBox[{"999.`", ",", "0.001509`"}], "}"}]], 
        Annotation[#, {999., 0.001509}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{1000., 0.001435}}]}, 
         RowBox[{"{", 
           RowBox[{"1000.`", ",", "0.001435`"}], "}"}]], 
        Annotation[#, {1000., 0.001435}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{100., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"100.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {100., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{101., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"101.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {101., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{102., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"102.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {102., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{103., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"103.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {103., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{104., 0.000024}}]}, 
         RowBox[{"{", 
           RowBox[{"104.`", ",", "0.000024`"}], "}"}]], 
        Annotation[#, {104., 0.000024}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{105., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"105.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {105., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{106., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"106.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {106., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{107., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"107.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {107., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{108., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"108.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {108., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{109., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"109.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {109., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{110., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"110.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {110., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{111., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"111.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {111., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{112., 0.000023}}]}, 
         RowBox[{"{", 
           RowBox[{"112.`", ",", "0.000023`"}], "}"}]], 
        Annotation[#, {112., 0.000023}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{113., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"113.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {113., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{114., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"114.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {114., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{115., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"115.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {115., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{116., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"116.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {116., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{117., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"117.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {117., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{118., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"118.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {118., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{119., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"119.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {119., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{120., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"120.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {120., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{121., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"121.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {121., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{122., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"122.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {122., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{123., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"123.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {123., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{124., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"124.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {124., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{125., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"125.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {125., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{126., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"126.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {126., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{127., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"127.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {127., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{128., 0.000023}}]}, 
         RowBox[{"{", 
           RowBox[{"128.`", ",", "0.000023`"}], "}"}]], 
        Annotation[#, {128., 0.000023}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{129., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"129.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {129., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{130., 0.000023}}]}, 
         RowBox[{"{", 
           RowBox[{"130.`", ",", "0.000023`"}], "}"}]], 
        Annotation[#, {130., 0.000023}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{131., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"131.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {131., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{132., 0.000024}}]}, 
         RowBox[{"{", 
           RowBox[{"132.`", ",", "0.000024`"}], "}"}]], 
        Annotation[#, {132., 0.000024}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{133., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"133.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {133., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{134., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"134.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {134., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{135., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"135.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {135., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{136., 0.000024}}]}, 
         RowBox[{"{", 
           RowBox[{"136.`", ",", "0.000024`"}], "}"}]], 
        Annotation[#, {136., 0.000024}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{137., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"137.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {137., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{138., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"138.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {138., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{139., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"139.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {139., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{140., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"140.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {140., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{141., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"141.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {141., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{142., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"142.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {142., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{143., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"143.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {143., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{144., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"144.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {144., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{145., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"145.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {145., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{146., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"146.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {146., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{147., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"147.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {147., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{148., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"148.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {148., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{149., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"149.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {149., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{150., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"150.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {150., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{151., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"151.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {151., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{152., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"152.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {152., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{153., 0.000047}}]}, 
         RowBox[{"{", 
           RowBox[{"153.`", ",", "0.000047`"}], "}"}]], 
        Annotation[#, {153., 0.000047}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{154., 0.000062}}]}, 
         RowBox[{"{", 
           RowBox[{"154.`", ",", "0.000062`"}], "}"}]], 
        Annotation[#, {154., 0.000062}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{155., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"155.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {155., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{156., 0.000041}}]}, 
         RowBox[{"{", 
           RowBox[{"156.`", ",", "0.000041`"}], "}"}]], 
        Annotation[#, {156., 0.000041}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{157., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"157.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {157., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{158., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"158.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {158., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{159., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"159.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {159., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{160., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"160.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {160., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{161., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"161.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {161., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{162., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"162.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {162., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{163., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"163.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {163., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{164., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"164.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {164., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{165., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"165.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {165., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{166., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"166.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {166., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{167., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"167.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {167., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{168., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"168.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {168., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{169., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"169.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {169., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{170., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"170.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {170., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{171., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"171.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {171., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{172., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"172.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {172., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{173., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"173.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {173., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{174., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"174.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {174., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{175., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"175.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {175., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{176., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"176.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {176., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{177., 0.000061}}]}, 
         RowBox[{"{", 
           RowBox[{"177.`", ",", "0.000061`"}], "}"}]], 
        Annotation[#, {177., 0.000061}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{178., 0.000074}}]}, 
         RowBox[{"{", 
           RowBox[{"178.`", ",", "0.000074`"}], "}"}]], 
        Annotation[#, {178., 0.000074}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{179., 0.000044}}]}, 
         RowBox[{"{", 
           RowBox[{"179.`", ",", "0.000044`"}], "}"}]], 
        Annotation[#, {179., 0.000044}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{180., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"180.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {180., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{181., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"181.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {181., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{182., 0.000048}}]}, 
         RowBox[{"{", 
           RowBox[{"182.`", ",", "0.000048`"}], "}"}]], 
        Annotation[#, {182., 0.000048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{183., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"183.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {183., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{184., 0.000043}}]}, 
         RowBox[{"{", 
           RowBox[{"184.`", ",", "0.000043`"}], "}"}]], 
        Annotation[#, {184., 0.000043}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{185., 0.000076}}]}, 
         RowBox[{"{", 
           RowBox[{"185.`", ",", "0.000076`"}], "}"}]], 
        Annotation[#, {185., 0.000076}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{186., 0.000067}}]}, 
         RowBox[{"{", 
           RowBox[{"186.`", ",", "0.000067`"}], "}"}]], 
        Annotation[#, {186., 0.000067}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{187., 0.000081}}]}, 
         RowBox[{"{", 
           RowBox[{"187.`", ",", "0.000081`"}], "}"}]], 
        Annotation[#, {187., 0.000081}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{188., 0.000053}}]}, 
         RowBox[{"{", 
           RowBox[{"188.`", ",", "0.000053`"}], "}"}]], 
        Annotation[#, {188., 0.000053}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{189., 0.000041}}]}, 
         RowBox[{"{", 
           RowBox[{"189.`", ",", "0.000041`"}], "}"}]], 
        Annotation[#, {189., 0.000041}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{190., 0.000047}}]}, 
         RowBox[{"{", 
           RowBox[{"190.`", ",", "0.000047`"}], "}"}]], 
        Annotation[#, {190., 0.000047}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{191., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"191.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {191., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{192., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"192.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {192., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{193., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"193.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {193., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{194., 0.000062}}]}, 
         RowBox[{"{", 
           RowBox[{"194.`", ",", "0.000062`"}], "}"}]], 
        Annotation[#, {194., 0.000062}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{195., 0.000044}}]}, 
         RowBox[{"{", 
           RowBox[{"195.`", ",", "0.000044`"}], "}"}]], 
        Annotation[#, {195., 0.000044}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{196., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"196.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {196., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{197., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"197.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {197., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{198., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"198.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {198., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{199., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"199.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {199., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{200., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"200.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {200., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{201., 0.000064}}]}, 
         RowBox[{"{", 
           RowBox[{"201.`", ",", "0.000064`"}], "}"}]], 
        Annotation[#, {201., 0.000064}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{202., 0.000042}}]}, 
         RowBox[{"{", 
           RowBox[{"202.`", ",", "0.000042`"}], "}"}]], 
        Annotation[#, {202., 0.000042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{203., 0.00007}}]}, 
         RowBox[{"{", 
           RowBox[{"203.`", ",", "0.00007`"}], "}"}]], 
        Annotation[#, {203., 0.00007}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{204., 0.000042}}]}, 
         RowBox[{"{", 
           RowBox[{"204.`", ",", "0.000042`"}], "}"}]], 
        Annotation[#, {204., 0.000042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{205., 0.000049}}]}, 
         RowBox[{"{", 
           RowBox[{"205.`", ",", "0.000049`"}], "}"}]], 
        Annotation[#, {205., 0.000049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{206., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"206.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {206., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{207., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"207.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {207., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{208., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"208.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {208., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{209., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"209.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {209., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{210., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"210.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {210., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{211., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"211.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {211., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{212., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"212.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {212., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{213., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"213.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {213., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{214., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"214.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {214., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{215., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"215.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {215., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{216., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"216.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {216., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{217., 0.000049}}]}, 
         RowBox[{"{", 
           RowBox[{"217.`", ",", "0.000049`"}], "}"}]], 
        Annotation[#, {217., 0.000049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{218., 0.000048}}]}, 
         RowBox[{"{", 
           RowBox[{"218.`", ",", "0.000048`"}], "}"}]], 
        Annotation[#, {218., 0.000048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{219., 0.000064}}]}, 
         RowBox[{"{", 
           RowBox[{"219.`", ",", "0.000064`"}], "}"}]], 
        Annotation[#, {219., 0.000064}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{220., 0.000044}}]}, 
         RowBox[{"{", 
           RowBox[{"220.`", ",", "0.000044`"}], "}"}]], 
        Annotation[#, {220., 0.000044}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{221., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"221.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {221., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{222., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"222.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {222., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{223., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"223.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {223., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{224., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"224.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {224., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{225., 0.000075}}]}, 
         RowBox[{"{", 
           RowBox[{"225.`", ",", "0.000075`"}], "}"}]], 
        Annotation[#, {225., 0.000075}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{226., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"226.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {226., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{227., 0.000043}}]}, 
         RowBox[{"{", 
           RowBox[{"227.`", ",", "0.000043`"}], "}"}]], 
        Annotation[#, {227., 0.000043}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{228., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"228.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {228., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{229., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"229.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {229., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{230., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"230.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {230., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{231., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"231.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {231., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{232., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"232.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {232., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{233., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"233.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {233., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{234., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"234.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {234., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{235., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"235.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {235., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{236., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"236.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {236., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{237., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"237.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {237., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{238., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"238.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {238., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{239., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"239.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {239., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{240., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"240.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {240., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{241., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"241.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {241., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{242., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"242.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {242., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{243., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"243.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {243., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{244., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"244.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {244., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{245., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"245.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {245., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{246., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"246.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {246., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{247., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"247.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {247., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{248., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"248.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {248., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{249., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"249.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {249., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{250., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"250.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {250., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{251., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"251.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {251., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{252., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"252.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {252., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{253., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"253.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {253., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{254., 0.000066}}]}, 
         RowBox[{"{", 
           RowBox[{"254.`", ",", "0.000066`"}], "}"}]], 
        Annotation[#, {254., 0.000066}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{255., 0.000048}}]}, 
         RowBox[{"{", 
           RowBox[{"255.`", ",", "0.000048`"}], "}"}]], 
        Annotation[#, {255., 0.000048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{256., 0.000025}}]}, 
         RowBox[{"{", 
           RowBox[{"256.`", ",", "0.000025`"}], "}"}]], 
        Annotation[#, {256., 0.000025}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{257., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"257.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {257., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{258., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"258.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {258., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{259., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"259.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {259., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{260., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"260.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {260., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{261., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"261.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {261., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{262., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"262.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {262., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{263., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"263.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {263., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{264., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"264.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {264., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{265., 0.000048}}]}, 
         RowBox[{"{", 
           RowBox[{"265.`", ",", "0.000048`"}], "}"}]], 
        Annotation[#, {265., 0.000048}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{266., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"266.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {266., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{267., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"267.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {267., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{268., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"268.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {268., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{269., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"269.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {269., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{270., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"270.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {270., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{271., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"271.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {271., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{272., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"272.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {272., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{273., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"273.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {273., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{274., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"274.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {274., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{275., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"275.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {275., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{276., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"276.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {276., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{277., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"277.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {277., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{278., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"278.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {278., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{279., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"279.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {279., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{280., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"280.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {280., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{281., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"281.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {281., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{282., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"282.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {282., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{283., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"283.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {283., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{284., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"284.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {284., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{285., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"285.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {285., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{286., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"286.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {286., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{287., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"287.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {287., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{288., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"288.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {288., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{289., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"289.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {289., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{290., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"290.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {290., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{291., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"291.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {291., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{292., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"292.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {292., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{293., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"293.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {293., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{294., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"294.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {294., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{295., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"295.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {295., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{296., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"296.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {296., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{297., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"297.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {297., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{298., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"298.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {298., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{299., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"299.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {299., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{300., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"300.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {300., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{301., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"301.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {301., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{302., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"302.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {302., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{303., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"303.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {303., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{304., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"304.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {304., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{305., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"305.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {305., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{306., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"306.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {306., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{307., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"307.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {307., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{308., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"308.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {308., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{309., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"309.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {309., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{310., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"310.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {310., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{311., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"311.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {311., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{312., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"312.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {312., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{313., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"313.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {313., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{314., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"314.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {314., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{315., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"315.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {315., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{316., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"316.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {316., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{317., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"317.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {317., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{318., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"318.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {318., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{319., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"319.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {319., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{320., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"320.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {320., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{321., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"321.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {321., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{322., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"322.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {322., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{323., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"323.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {323., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{324., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"324.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {324., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{325., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"325.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {325., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{326., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"326.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {326., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{327., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"327.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {327., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{328., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"328.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {328., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{329., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"329.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {329., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{330., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"330.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {330., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{331., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"331.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {331., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{332., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"332.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {332., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{333., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"333.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {333., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{334., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"334.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {334., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{335., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"335.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {335., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{336., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"336.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {336., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{337., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"337.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {337., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{338., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"338.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {338., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{339., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"339.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {339., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{340., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"340.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {340., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{341., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"341.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {341., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{342., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"342.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {342., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{343., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"343.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {343., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{344., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"344.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {344., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{345., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"345.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {345., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{346., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"346.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {346., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{347., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"347.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {347., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{348., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"348.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {348., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{349., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"349.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {349., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{350., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"350.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {350., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{351., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"351.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {351., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{352., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"352.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {352., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{353., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"353.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {353., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{354., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"354.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {354., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{355., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"355.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {355., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{356., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"356.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {356., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{357., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"357.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {357., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{358., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"358.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {358., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{359., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"359.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {359., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{360., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"360.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {360., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{361., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"361.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {361., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{362., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"362.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {362., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{363., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"363.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {363., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{364., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"364.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {364., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{365., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"365.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {365., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{366., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"366.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {366., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{367., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"367.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {367., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{368., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"368.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {368., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{369., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"369.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {369., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{370., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"370.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {370., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{371., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"371.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {371., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{372., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"372.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {372., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{373., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"373.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {373., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{374., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"374.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {374., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{375., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"375.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {375., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{376., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"376.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {376., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{377., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"377.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {377., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{378., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"378.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {378., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{379., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"379.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {379., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{380., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"380.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {380., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{381., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"381.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {381., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{382., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"382.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {382., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{383., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"383.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {383., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{384., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"384.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {384., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{385., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"385.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {385., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{386., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"386.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {386., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{387., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"387.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {387., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{388., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"388.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {388., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{389., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"389.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {389., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{390., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"390.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {390., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{391., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"391.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {391., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{392., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"392.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {392., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{393., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"393.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {393., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{394., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"394.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {394., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{395., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"395.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {395., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{396., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"396.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {396., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{397., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"397.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {397., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{398., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"398.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {398., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{399., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"399.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {399., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{400., 0.000027}}]}, 
         RowBox[{"{", 
           RowBox[{"400.`", ",", "0.000027`"}], "}"}]], 
        Annotation[#, {400., 0.000027}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{401., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"401.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {401., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{402., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"402.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {402., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{403., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"403.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {403., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{404., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"404.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {404., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{405., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"405.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {405., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{406., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"406.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {406., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{407., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"407.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {407., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{408., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"408.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {408., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{409., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"409.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {409., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{410., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"410.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {410., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{411., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"411.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {411., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{412., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"412.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {412., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{413., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"413.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {413., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{414., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"414.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {414., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{415., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"415.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {415., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{416., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"416.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {416., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{417., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"417.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {417., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{418., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"418.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {418., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{419., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"419.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {419., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{420., 0.000062}}]}, 
         RowBox[{"{", 
           RowBox[{"420.`", ",", "0.000062`"}], "}"}]], 
        Annotation[#, {420., 0.000062}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{421., 0.000046}}]}, 
         RowBox[{"{", 
           RowBox[{"421.`", ",", "0.000046`"}], "}"}]], 
        Annotation[#, {421., 0.000046}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{422., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"422.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {422., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{423., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"423.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {423., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{424., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"424.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {424., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{425., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"425.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {425., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{426., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"426.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {426., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{427., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"427.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {427., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{428., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"428.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {428., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{429., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"429.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {429., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{430., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"430.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {430., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{431., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"431.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {431., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{432., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"432.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {432., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{433., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"433.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {433., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{434., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"434.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {434., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{435., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"435.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {435., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{436., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"436.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {436., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{437., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"437.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {437., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{438., 0.000049}}]}, 
         RowBox[{"{", 
           RowBox[{"438.`", ",", "0.000049`"}], "}"}]], 
        Annotation[#, {438., 0.000049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{439., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"439.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {439., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{440., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"440.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {440., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{441., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"441.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {441., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{442., 0.00007}}]}, 
         RowBox[{"{", 
           RowBox[{"442.`", ",", "0.00007`"}], "}"}]], 
        Annotation[#, {442., 0.00007}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{443., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"443.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {443., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{444., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"444.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {444., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{445., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"445.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {445., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{446., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"446.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {446., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{447., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"447.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {447., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{448., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"448.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {448., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{449., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"449.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {449., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{450., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"450.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {450., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{451., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"451.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {451., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{452., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"452.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {452., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{453., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"453.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {453., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{454., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"454.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {454., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{455., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"455.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {455., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{456., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"456.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {456., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{457., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"457.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {457., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{458., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"458.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {458., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{459., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"459.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {459., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{460., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"460.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {460., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{461., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"461.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {461., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{462., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"462.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {462., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{463., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"463.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {463., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{464., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"464.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {464., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{465., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"465.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {465., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{466., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"466.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {466., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{467., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"467.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {467., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{468., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"468.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {468., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{469., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"469.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {469., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{470., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"470.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {470., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{471., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"471.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {471., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{472., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"472.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {472., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{473., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"473.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {473., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{474., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"474.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {474., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{475., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"475.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {475., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{476., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"476.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {476., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{477., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"477.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {477., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{478., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"478.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {478., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{479., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"479.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {479., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{480., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"480.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {480., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{481., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"481.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {481., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{482., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"482.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {482., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{483., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"483.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {483., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{484., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"484.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {484., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{485., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"485.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {485., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{486., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"486.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {486., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{487., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"487.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {487., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{488., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"488.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {488., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{489., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"489.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {489., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{490., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"490.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {490., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{491., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"491.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {491., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{492., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"492.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {492., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{493., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"493.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {493., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{494., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"494.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {494., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{495., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"495.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {495., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{496., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"496.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {496., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{497., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"497.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {497., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{498., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"498.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {498., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{499., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"499.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {499., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{500., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"500.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {500., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{501., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"501.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {501., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{502., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"502.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {502., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{503., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"503.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {503., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{504., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"504.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {504., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{505., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"505.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {505., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{506., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"506.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {506., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{507., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"507.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {507., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{508., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"508.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {508., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{509., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"509.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {509., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{510., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"510.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {510., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{511., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"511.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {511., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{512., 0.000026}}]}, 
         RowBox[{"{", 
           RowBox[{"512.`", ",", "0.000026`"}], "}"}]], 
        Annotation[#, {512., 0.000026}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{513., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"513.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {513., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{514., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"514.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {514., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{515., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"515.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {515., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{516., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"516.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {516., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{517., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"517.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {517., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{518., 0.000084}}]}, 
         RowBox[{"{", 
           RowBox[{"518.`", ",", "0.000084`"}], "}"}]], 
        Annotation[#, {518., 0.000084}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{519., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"519.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {519., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{520., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"520.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {520., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{521., 0.000064}}]}, 
         RowBox[{"{", 
           RowBox[{"521.`", ",", "0.000064`"}], "}"}]], 
        Annotation[#, {521., 0.000064}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{522., 0.000066}}]}, 
         RowBox[{"{", 
           RowBox[{"522.`", ",", "0.000066`"}], "}"}]], 
        Annotation[#, {522., 0.000066}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{523., 0.000046}}]}, 
         RowBox[{"{", 
           RowBox[{"523.`", ",", "0.000046`"}], "}"}]], 
        Annotation[#, {523., 0.000046}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{524., 0.000047}}]}, 
         RowBox[{"{", 
           RowBox[{"524.`", ",", "0.000047`"}], "}"}]], 
        Annotation[#, {524., 0.000047}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{525., 0.000047}}]}, 
         RowBox[{"{", 
           RowBox[{"525.`", ",", "0.000047`"}], "}"}]], 
        Annotation[#, {525., 0.000047}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{526., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"526.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {526., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{527., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"527.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {527., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{528., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"528.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {528., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{529., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"529.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {529., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{530., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"530.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {530., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{531., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"531.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {531., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{532., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"532.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {532., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{533., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"533.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {533., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{534., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"534.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {534., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{535., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"535.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {535., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{536., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"536.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {536., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{537., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"537.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {537., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{538., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"538.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {538., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{539., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"539.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {539., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{540., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"540.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {540., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{541., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"541.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {541., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{542., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"542.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {542., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{543., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"543.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {543., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{544., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"544.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {544., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{545., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"545.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {545., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{546., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"546.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {546., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{547., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"547.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {547., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{548., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"548.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {548., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{549., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"549.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {549., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{550., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"550.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {550., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{551., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"551.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {551., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{552., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"552.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {552., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{553., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"553.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {553., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{554., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"554.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {554., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{555., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"555.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {555., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{556., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"556.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {556., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{557., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"557.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {557., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{558., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"558.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {558., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{559., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"559.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {559., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{560., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"560.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {560., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{561., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"561.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {561., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{562., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"562.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {562., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{563., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"563.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {563., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{564., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"564.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {564., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{565., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"565.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {565., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{566., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"566.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {566., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{567., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"567.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {567., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{568., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"568.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {568., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{569., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"569.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {569., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{570., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"570.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {570., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{571., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"571.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {571., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{572., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"572.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {572., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{573., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"573.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {573., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{574., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"574.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {574., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{575., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"575.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {575., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{576., 0.000028}}]}, 
         RowBox[{"{", 
           RowBox[{"576.`", ",", "0.000028`"}], "}"}]], 
        Annotation[#, {576., 0.000028}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{577., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"577.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {577., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{578., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"578.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {578., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{579., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"579.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {579., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{580., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"580.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {580., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{581., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"581.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {581., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{582., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"582.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {582., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{583., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"583.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {583., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{584., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"584.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {584., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{585., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"585.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {585., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{586., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"586.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {586., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{587., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"587.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {587., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{588., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"588.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {588., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{589., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"589.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {589., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{590., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"590.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {590., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{591., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"591.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {591., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{592., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"592.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {592., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{593., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"593.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {593., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{594., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"594.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {594., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{595., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"595.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {595., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{596., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"596.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {596., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{597., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"597.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {597., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{598., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"598.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {598., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{599., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"599.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {599., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{600., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"600.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {600., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{601., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"601.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {601., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{602., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"602.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {602., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{603., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"603.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {603., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{604., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"604.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {604., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{605., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"605.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {605., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{606., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"606.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {606., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{607., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"607.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {607., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{608., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"608.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {608., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{609., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"609.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {609., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{610., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"610.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {610., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{611., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"611.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {611., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{612., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"612.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {612., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{613., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"613.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {613., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{614., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"614.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {614., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{615., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"615.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {615., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{616., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"616.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {616., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{617., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"617.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {617., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{618., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"618.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {618., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{619., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"619.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {619., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{620., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"620.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {620., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{621., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"621.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {621., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{622., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"622.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {622., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{623., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"623.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {623., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{624., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"624.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {624., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{625., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"625.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {625., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{626., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"626.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {626., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{627., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"627.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {627., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{628., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"628.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {628., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{629., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"629.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {629., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{630., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"630.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {630., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{631., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"631.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {631., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{632., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"632.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {632., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{633., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"633.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {633., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{634., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"634.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {634., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{635., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"635.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {635., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{636., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"636.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {636., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{637., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"637.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {637., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{638., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"638.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {638., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{639., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"639.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {639., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{640., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"640.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {640., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{641., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"641.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {641., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{642., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"642.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {642., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{643., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"643.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {643., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{644., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"644.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {644., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{645., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"645.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {645., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{646., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"646.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {646., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{647., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"647.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {647., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{648., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"648.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {648., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{649., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"649.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {649., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{650., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"650.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {650., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{651., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"651.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {651., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{652., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"652.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {652., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{653., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"653.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {653., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{654., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"654.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {654., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{655., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"655.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {655., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{656., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"656.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {656., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{657., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"657.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {657., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{658., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"658.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {658., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{659., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"659.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {659., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{660., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"660.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {660., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{661., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"661.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {661., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{662., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"662.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {662., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{663., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"663.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {663., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{664., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"664.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {664., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{665., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"665.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {665., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{666., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"666.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {666., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{667., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"667.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {667., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{668., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"668.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {668., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{669., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"669.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {669., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{670., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"670.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {670., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{671., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"671.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {671., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{672., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"672.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {672., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{673., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"673.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {673., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{674., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"674.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {674., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{675., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"675.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {675., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{676., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"676.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {676., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{677., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"677.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {677., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{678., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"678.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {678., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{679., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"679.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {679., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{680., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"680.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {680., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{681., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"681.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {681., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{682., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"682.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {682., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{683., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"683.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {683., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{684., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"684.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {684., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{685., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"685.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {685., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{686., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"686.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {686., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{687., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"687.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {687., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{688., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"688.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {688., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{689., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"689.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {689., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{690., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"690.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {690., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{691., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"691.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {691., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{692., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"692.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {692., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{693., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"693.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {693., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{694., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"694.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {694., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{695., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"695.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {695., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{696., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"696.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {696., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{697., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"697.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {697., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{698., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"698.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {698., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{699., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"699.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {699., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{700., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"700.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {700., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{701., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"701.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {701., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{702., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"702.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {702., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{703., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"703.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {703., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{704., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"704.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {704., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{705., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"705.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {705., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{706., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"706.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {706., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{707., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"707.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {707., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{708., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"708.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {708., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{709., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"709.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {709., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{710., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"710.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {710., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{711., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"711.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {711., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{712., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"712.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {712., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{713., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"713.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {713., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{714., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"714.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {714., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{715., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"715.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {715., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{716., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"716.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {716., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{717., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"717.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {717., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{718., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"718.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {718., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{719., 0.000077}}]}, 
         RowBox[{"{", 
           RowBox[{"719.`", ",", "0.000077`"}], "}"}]], 
        Annotation[#, {719., 0.000077}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{720., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"720.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {720., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{721., 0.000049}}]}, 
         RowBox[{"{", 
           RowBox[{"721.`", ",", "0.000049`"}], "}"}]], 
        Annotation[#, {721., 0.000049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{722., 0.000072}}]}, 
         RowBox[{"{", 
           RowBox[{"722.`", ",", "0.000072`"}], "}"}]], 
        Annotation[#, {722., 0.000072}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{723., 0.000049}}]}, 
         RowBox[{"{", 
           RowBox[{"723.`", ",", "0.000049`"}], "}"}]], 
        Annotation[#, {723., 0.000049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{724., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"724.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {724., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{725., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"725.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {725., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{726., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"726.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {726., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{727., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"727.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {727., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{728., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"728.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {728., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{729., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"729.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {729., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{730., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"730.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {730., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{731., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"731.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {731., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{732., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"732.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {732., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{733., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"733.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {733., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{734., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"734.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {734., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{735., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"735.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {735., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{736., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"736.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {736., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{737., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"737.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {737., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{738., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"738.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {738., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{739., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"739.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {739., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{740., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"740.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {740., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{741., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"741.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {741., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{742., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"742.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {742., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{743., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"743.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {743., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{744., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"744.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {744., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{745., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"745.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {745., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{746., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"746.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {746., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{747., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"747.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {747., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{748., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"748.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {748., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{749., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"749.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {749., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{750., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"750.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {750., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{751., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"751.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {751., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{752., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"752.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {752., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{753., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"753.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {753., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{754., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"754.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {754., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{755., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"755.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {755., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{756., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"756.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {756., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{757., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"757.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {757., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{758., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"758.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {758., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{759., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"759.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {759., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{760., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"760.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {760., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{761., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"761.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {761., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{762., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"762.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {762., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{763., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"763.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {763., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{764., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"764.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {764., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{765., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"765.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {765., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{766., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"766.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {766., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{767., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"767.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {767., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{768., 0.000029}}]}, 
         RowBox[{"{", 
           RowBox[{"768.`", ",", "0.000029`"}], "}"}]], 
        Annotation[#, {768., 0.000029}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{769., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"769.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {769., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{770., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"770.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {770., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{771., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"771.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {771., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{772., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"772.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {772., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{773., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"773.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {773., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{774., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"774.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {774., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{775., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"775.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {775., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{776., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"776.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {776., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{777., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"777.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {777., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{778., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"778.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {778., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{779., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"779.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {779., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{780., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"780.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {780., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{781., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"781.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {781., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{782., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"782.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {782., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{783., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"783.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {783., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{784., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"784.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {784., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{785., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"785.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {785., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{786., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"786.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {786., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{787., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"787.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {787., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{788., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"788.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {788., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{789., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"789.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {789., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{790., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"790.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {790., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{791., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"791.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {791., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{792., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"792.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {792., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{793., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"793.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {793., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{794., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"794.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {794., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{795., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"795.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {795., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{796., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"796.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {796., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{797., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"797.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {797., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{798., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"798.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {798., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{799., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"799.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {799., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{800., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"800.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {800., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{801., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"801.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {801., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{802., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"802.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {802., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{803., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"803.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {803., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{804., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"804.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {804., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{805., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"805.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {805., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{806., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"806.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {806., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{807., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"807.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {807., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{808., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"808.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {808., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{809., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"809.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {809., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{810., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"810.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {810., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{811., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"811.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {811., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{812., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"812.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {812., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{813., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"813.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {813., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{814., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"814.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {814., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{815., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"815.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {815., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{816., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"816.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {816., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{817., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"817.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {817., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{818., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"818.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {818., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{819., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"819.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {819., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{820., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"820.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {820., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{821., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"821.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {821., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{822., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"822.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {822., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{823., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"823.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {823., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{824., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"824.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {824., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{825., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"825.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {825., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{826., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"826.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {826., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{827., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"827.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {827., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{828., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"828.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {828., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{829., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"829.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {829., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{830., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"830.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {830., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{831., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"831.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {831., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{832., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"832.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {832., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{833., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"833.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {833., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{834., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"834.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {834., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{835., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"835.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {835., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{836., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"836.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {836., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{837., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"837.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {837., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{838., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"838.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {838., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{839., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"839.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {839., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{840., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"840.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {840., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{841., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"841.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {841., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{842., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"842.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {842., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{843., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"843.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {843., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{844., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"844.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {844., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{845., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"845.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {845., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{846., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"846.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {846., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{847., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"847.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {847., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{848., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"848.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {848., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{849., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"849.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {849., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{850., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"850.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {850., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{851., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"851.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {851., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{852., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"852.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {852., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{853., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"853.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {853., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{854., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"854.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {854., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{855., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"855.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {855., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{856., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"856.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {856., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{857., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"857.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {857., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{858., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"858.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {858., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{859., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"859.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {859., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{860., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"860.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {860., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{861., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"861.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {861., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{862., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"862.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {862., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{863., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"863.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {863., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{864., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"864.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {864., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{865., 0.000053}}]}, 
         RowBox[{"{", 
           RowBox[{"865.`", ",", "0.000053`"}], "}"}]], 
        Annotation[#, {865., 0.000053}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{866., 0.000051}}]}, 
         RowBox[{"{", 
           RowBox[{"866.`", ",", "0.000051`"}], "}"}]], 
        Annotation[#, {866., 0.000051}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{867., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"867.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {867., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{868., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"868.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {868., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{869., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"869.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {869., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{870., 0.000092}}]}, 
         RowBox[{"{", 
           RowBox[{"870.`", ",", "0.000092`"}], "}"}]], 
        Annotation[#, {870., 0.000092}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{871., 0.000042}}]}, 
         RowBox[{"{", 
           RowBox[{"871.`", ",", "0.000042`"}], "}"}]], 
        Annotation[#, {871., 0.000042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{872., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"872.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {872., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{873., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"873.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {873., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{874., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"874.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {874., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{875., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"875.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {875., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{876., 0.000052}}]}, 
         RowBox[{"{", 
           RowBox[{"876.`", ",", "0.000052`"}], "}"}]], 
        Annotation[#, {876., 0.000052}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{877., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"877.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {877., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{878., 0.000053}}]}, 
         RowBox[{"{", 
           RowBox[{"878.`", ",", "0.000053`"}], "}"}]], 
        Annotation[#, {878., 0.000053}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{879., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"879.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {879., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{880., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"880.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {880., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{881., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"881.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {881., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{882., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"882.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {882., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{883., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"883.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {883., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{884., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"884.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {884., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{885., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"885.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {885., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{886., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"886.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {886., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{887., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"887.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {887., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{888., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"888.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {888., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{889., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"889.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {889., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{890., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"890.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {890., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{891., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"891.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {891., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{892., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"892.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {892., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{893., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"893.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {893., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{894., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"894.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {894., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{895., 0.000041}}]}, 
         RowBox[{"{", 
           RowBox[{"895.`", ",", "0.000041`"}], "}"}]], 
        Annotation[#, {895., 0.000041}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{896., 0.00003}}]}, 
         RowBox[{"{", 
           RowBox[{"896.`", ",", "0.00003`"}], "}"}]], 
        Annotation[#, {896., 0.00003}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{897., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"897.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {897., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{898., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"898.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {898., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{899., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"899.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {899., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{900., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"900.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {900., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{901., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"901.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {901., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{902., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"902.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {902., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{903., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"903.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {903., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{904., 0.000031}}]}, 
         RowBox[{"{", 
           RowBox[{"904.`", ",", "0.000031`"}], "}"}]], 
        Annotation[#, {904., 0.000031}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{905., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"905.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {905., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{906., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"906.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {906., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{907., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"907.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {907., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{908., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"908.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {908., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{909., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"909.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {909., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{910., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"910.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {910., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{911., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"911.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {911., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{912., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"912.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {912., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{913., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"913.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {913., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{914., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"914.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {914., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{915., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"915.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {915., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{916., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"916.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {916., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{917., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"917.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {917., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{918., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"918.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {918., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{919., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"919.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {919., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{920., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"920.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {920., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{921., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"921.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {921., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{922., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"922.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {922., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{923., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"923.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {923., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{924., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"924.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {924., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{925., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"925.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {925., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{926., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"926.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {926., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{927., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"927.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {927., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{928., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"928.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {928., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{929., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"929.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {929., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{930., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"930.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {930., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{931., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"931.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {931., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{932., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"932.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {932., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{933., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"933.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {933., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{934., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"934.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {934., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{935., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"935.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {935., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{936., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"936.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {936., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{937., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"937.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {937., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{938., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"938.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {938., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{939., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"939.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {939., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{940., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"940.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {940., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{941., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"941.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {941., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{942., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"942.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {942., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{943., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"943.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {943., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{944., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"944.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {944., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{945., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"945.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {945., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{946., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"946.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {946., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{947., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"947.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {947., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{948., 0.000041}}]}, 
         RowBox[{"{", 
           RowBox[{"948.`", ",", "0.000041`"}], "}"}]], 
        Annotation[#, {948., 0.000041}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{949., 0.000125}}]}, 
         RowBox[{"{", 
           RowBox[{"949.`", ",", "0.000125`"}], "}"}]], 
        Annotation[#, {949., 0.000125}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{950., 0.000052}}]}, 
         RowBox[{"{", 
           RowBox[{"950.`", ",", "0.000052`"}], "}"}]], 
        Annotation[#, {950., 0.000052}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{951., 0.000054}}]}, 
         RowBox[{"{", 
           RowBox[{"951.`", ",", "0.000054`"}], "}"}]], 
        Annotation[#, {951., 0.000054}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{952., 0.000087}}]}, 
         RowBox[{"{", 
           RowBox[{"952.`", ",", "0.000087`"}], "}"}]], 
        Annotation[#, {952., 0.000087}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{953., 0.000055}}]}, 
         RowBox[{"{", 
           RowBox[{"953.`", ",", "0.000055`"}], "}"}]], 
        Annotation[#, {953., 0.000055}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{954., 0.000049}}]}, 
         RowBox[{"{", 
           RowBox[{"954.`", ",", "0.000049`"}], "}"}]], 
        Annotation[#, {954., 0.000049}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{955., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"955.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {955., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{956., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"956.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {956., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{957., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"957.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {957., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{958., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"958.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {958., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{959., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"959.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {959., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{960., 0.000032}}]}, 
         RowBox[{"{", 
           RowBox[{"960.`", ",", "0.000032`"}], "}"}]], 
        Annotation[#, {960., 0.000032}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{961., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"961.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {961., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{962., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"962.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {962., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{963., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"963.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {963., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{964., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"964.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {964., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{965., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"965.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {965., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{966., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"966.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {966., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{967., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"967.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {967., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{968., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"968.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {968., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{969., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"969.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {969., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{970., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"970.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {970., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{971., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"971.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {971., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{972., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"972.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {972., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{973., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"973.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {973., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{974., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"974.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {974., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{975., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"975.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {975., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{976., 0.000034}}]}, 
         RowBox[{"{", 
           RowBox[{"976.`", ",", "0.000034`"}], "}"}]], 
        Annotation[#, {976., 0.000034}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{977., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"977.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {977., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{978., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"978.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {978., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{979., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"979.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {979., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{980., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"980.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {980., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{981., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"981.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {981., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{982., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"982.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {982., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{983., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"983.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {983., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{984., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"984.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {984., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{985., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"985.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {985., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{986., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"986.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {986., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{987., 0.00004}}]}, 
         RowBox[{"{", 
           RowBox[{"987.`", ",", "0.00004`"}], "}"}]], 
        Annotation[#, {987., 0.00004}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{988., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"988.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {988., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{989., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"989.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {989., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{990., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"990.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {990., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{991., 0.000042}}]}, 
         RowBox[{"{", 
           RowBox[{"991.`", ",", "0.000042`"}], "}"}]], 
        Annotation[#, {991., 0.000042}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{992., 0.000033}}]}, 
         RowBox[{"{", 
           RowBox[{"992.`", ",", "0.000033`"}], "}"}]], 
        Annotation[#, {992., 0.000033}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{993., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"993.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {993., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{994., 0.000035}}]}, 
         RowBox[{"{", 
           RowBox[{"994.`", ",", "0.000035`"}], "}"}]], 
        Annotation[#, {994., 0.000035}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{995., 0.000038}}]}, 
         RowBox[{"{", 
           RowBox[{"995.`", ",", "0.000038`"}], "}"}]], 
        Annotation[#, {995., 0.000038}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{996., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"996.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {996., 0.000036}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{997., 0.000037}}]}, 
         RowBox[{"{", 
           RowBox[{"997.`", ",", "0.000037`"}], "}"}]], 
        Annotation[#, {997., 0.000037}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{998., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"998.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {998., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{999., 0.000039}}]}, 
         RowBox[{"{", 
           RowBox[{"999.`", ",", "0.000039`"}], "}"}]], 
        Annotation[#, {999., 0.000039}, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Opacity[0.], 
          PointBox[{{1000., 0.000036}}]}, 
         RowBox[{"{", 
           RowBox[{"1000.`", ",", "0.000036`"}], "}"}]], 
        Annotation[#, {1000., 0.000036}, "Tooltip"]& ]}}, {}, {}, {}, {}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 1000.}, {0, 0.002464}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 1000.}, {0, 0.002464}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"power1\"", "\"power2\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.004583333333333334`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.004583333333333334`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellLabel->"Out[87]=",ExpressionUUID->"f7e15a84-6fa1-4d45-998f-0db1b99ed1c0"]
}, Open  ]],

Cell[TextData[{
 "This gives us a visual comparison of the time complexity of the two \
algorithms. You can see that the second approach significantly outperforms \
the first. It is left to the reader to compare the functions we created to \
the Wolfram Language\[CloseCurlyQuote]s built-in ",
 StyleBox[ButtonBox["PowerMod",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PowerMod"], "FunctionLink"],
 " function."
}], "Text",ExpressionUUID->"1c393d23-192d-4683-b6ba-e9093b7d390a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Recursion and Iteration", "Subsection",
 CellTags->"Section4b",ExpressionUUID->"ead0cd15-0651-4117-9f09-0a2a14bcaa25"],

Cell["\<\
In this subsection, we compare recursive and iterative approaches for \
computing factorial. \
\>", "Text",ExpressionUUID->"da42bd57-c6d3-4b15-82a0-0b9d5f3b5db1"],

Cell[CellGroupData[{

Cell["Recursive Factorial", "Subsubsection",ExpressionUUID->"12f39aef-09c8-490e-ab28-e1afdcb4d23f"],

Cell[TextData[{
 "First, we will implement Algorithm 1 from Section 5.4, a recursive \
algorithm for computing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "!"}], TraditionalForm]],ExpressionUUID->
  "fc0fed58-875e-4d28-bb94-510f4dba4cb4"],
 ". This function accepts a nonnegative integer ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "fd90c576-9c7a-4dee-8789-3757082613dd"],
 " as its input. If the input value is ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "ff12d08f-f5a7-434b-a96a-f5990b7f5c64"],
 ", the function returns ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "710003f6-8604-446e-8541-db5127973381"],
 ". Otherwise, it multiplies ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "4dea7ad5-778c-428d-bc17-9afdc4eab2c7"],
 " by the value of the function applied to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "-", "1"}], TraditionalForm]],ExpressionUUID->
  "342b786a-8207-4f88-af62-eb1e3fe90830"],
 ". "
}], "Text",ExpressionUUID->"d6b0c54d-6cc2-4f8f-89da-5c3a3c43bbf8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"factorialR", "[", "n_Integer", "]"}], "/;", 
   RowBox[{"n", "\[GreaterEqual]", "0"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"n", "\[Equal]", "0"}], ",", "1", ",", 
      RowBox[{"n", "*", 
       RowBox[{"factorialR", "[", 
        RowBox[{"n", "-", "1"}], "]"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[88]:=",ExpressionUUID->"9e316b0f-d24c-4b6c-bd97-b838a89deca6"],

Cell[TextData[{
 "Note that, while we could have defined the function\[CloseCurlyQuote]s \
action on ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "0"}], TraditionalForm]],ExpressionUUID->
  "6ba3f88f-6991-49f5-9dd0-47a96857bbf7"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[NotEqual]", "0"}], TraditionalForm]],ExpressionUUID->
  "02d97e65-1d30-4544-8628-f67af42a2289"],
 " without using the ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 " structure, a ",
 StyleBox[ButtonBox["Module",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Module"], "FunctionLink"],
 " will be needed in the iterative version and in comparing performance of \
algorithms, it is important to keep as much of the implementations the same \
as possible."
}], "Text",ExpressionUUID->"bd020ff7-e3f3-4867-b630-e27c86872f12"],

Cell["\<\
We test this function on 10 and verify that it has the same result as the \
Wolfram Language\[CloseCurlyQuote]s built-in operator.\
\>", "Text",ExpressionUUID->"d4e03d39-418b-49b0-b5b4-76f2007cbf61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"factorialR", "[", "10", "]"}]], "Input",
 CellLabel->"In[89]:=",ExpressionUUID->"0786c9af-476e-4196-b676-da3e7e233fea"],

Cell[BoxData["3628800"], "Output",
 CellLabel->"Out[89]=",ExpressionUUID->"9e66503c-755c-46df-be49-3e59dafd8096"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"10", "!"}]], "Input",
 CellLabel->"In[90]:=",ExpressionUUID->"7a8b9ce1-3362-48be-afd7-19cd0ef3a6f9"],

Cell[BoxData["3628800"], "Output",
 CellLabel->"Out[90]=",ExpressionUUID->"39373eec-d364-4157-8bcd-25e479b79645"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Iterative Factorial", "Subsubsection",ExpressionUUID->"8615d788-6e0b-40ac-9ecf-635d3bb8bf18"],

Cell[TextData[{
 "Second, we implement factorial with an iterative algorithm. Our function \
will use a variable ",
 StyleBox["f", "Code"],
 ", initialized to 1, to store the value of the factorial. It will compute \
using a ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop with a loop variable running from 1 to ",
 StyleBox["n", "Code"],
 ". Within the loop, ",
 StyleBox["f", "Code"],
 " will be multiplied by the current value of the loop variable."
}], "Text",ExpressionUUID->"3e3caaee-bf6b-47b1-bb01-8cfb40249f61"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"factorialI", "[", "n_Integer", "]"}], "/;", 
   RowBox[{"n", "\[GreaterEqual]", "0"}]}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f", "=", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "n"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"f", "=", 
        RowBox[{"f", "*", "i"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "f"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True,
 CellLabel->"In[91]:=",ExpressionUUID->"456b435b-d9c2-4e3f-a553-63ffa74be5d4"],

Cell[TextData[{
 "We again check to make sure the result is correct on ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "10"}], TraditionalForm]],ExpressionUUID->
  "3a34cbc3-c9e4-4f94-9728-f09a3f507487"],
 "."
}], "Text",ExpressionUUID->"665b9347-4d84-4dc5-9003-29e4371a3cb9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"factorialI", "[", "10", "]"}]], "Input",
 CellLabel->"In[92]:=",ExpressionUUID->"0da463b4-772f-4325-875c-d371fc10cf29"],

Cell[BoxData["3628800"], "Output",
 CellLabel->"Out[92]=",ExpressionUUID->"f0d01dae-ec86-41ac-ab4b-b2222dcaee8b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparing Recursion and Iteration", "Subsubsection",ExpressionUUID->"95752a6b-e388-4ff1-a020-b20d0b855c56"],

Cell["\<\
Note that these two algorithms require exactly the same number of \
multiplications. From this point of view, their complexity is the same. \
\>", "Text",ExpressionUUID->"7470239a-3744-401b-8940-369580058260"],

Cell[TextData[{
 "However, let us look at their performance. We consider values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "1f283291-13b0-485d-8b4a-4daf692580bc"],
 " from 1 to 1500. We use the same approach as we did for ",
 StyleBox["power1", "Code"],
 " and ",
 StyleBox["power2", "Code"],
 " above to record and plot the time performance. "
}], "Text",ExpressionUUID->"66389fbb-b48b-476f-89c9-7e3a3d4ed056"],

Cell[BoxData[
 RowBox[{
  RowBox[{"timesR", "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"$RecursionLimit", "=", "Infinity"}], "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", ",", 
         RowBox[{
          RowBox[{"Timing", "[", 
           RowBox[{"factorialR", "[", "n", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1500"}], "}"}]}], "]"}]}], "]"}]}], ";"}]], "Input",\

 CellLabel->"In[93]:=",ExpressionUUID->"8c8aa2d1-4e32-4762-99c4-7ca3a70cde0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"timesI", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{
        RowBox[{"Timing", "[", 
         RowBox[{"factorialI", "[", "n", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1500"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[94]:=",ExpressionUUID->"89688a02-4bfb-4f54-a058-32500d243c54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"timesR", ",", "timesI"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<recursive\>\"", ",", "\"\<iterative\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellLabel->"In[95]:=",ExpressionUUID->"ebd9048e-5654-4e66-a6ac-1c1d44c5c5a8"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdnGd8TGkbxkePHgTRh1WiR49+IQiCIAiCERERwSTS66RP+vRk1bEssVhh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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.003666666666666667], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        PointBox[CompressedData["
1:eJxdnHl8jFcXx8fWhqKD0FDL2GOPpaTWo4IgGARBMCIitphEVol4sk/2Z9ak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         "]]}, {}}}, {}, {}, {}, {}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 1500.}, {0, 0.004328}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 1500.}, {0, 0.004328}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"recursive\"", "\"iterative\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.132], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.132], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.132], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.132], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], 
                    PointBox[
                    NCache[{
                    Scaled[{
                    Rational[1, 2], 
                    Rational[1, 2]}]}, {
                    Scaled[{0.5, 0.5}]}]]}}}, AspectRatio -> Full, 
                    ImageSize -> {10, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.003666666666666667`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"False", ",", "False"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellLabel->"Out[95]=",ExpressionUUID->"6bd41059-db61-41a7-abbc-0598152f0af3"]
}, Open  ]],

Cell[TextData[{
 "First, you might wonder about the outliers\[LongDash]values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "0b55c27e-f519-4465-b08a-c7c1133f4f06"],
 " for which one function or the other performs particularly poorly. These \
are essentially noise resulting from other processes on the computer. They \
are also inconsistent; running the commands again will produce slightly \
different results. "
}], "Text",ExpressionUUID->"79938572-d780-4d46-9971-01884795e8b8"],

Cell[TextData[{
 "However, it is clear that, despite the occasional peculiar value, the \
iterative function outperforms the recursive one for large values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "eab2efa2-c84e-46a2-ac29-220e3b993169"],
 ". This is in spite of the fact that the two algorithms involve the same \
number of multiplications. We must consider other sources of potential \
differences in complexity."
}], "Text",ExpressionUUID->"2a6d6cfa-a257-4b0a-88fc-d66e7f8e4f59"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop in the iterative function includes a comparison (",
 StyleBox["i", "Code"],
 " must be tested against ",
 StyleBox["n", "Code"],
 " to determine if the loop continues) and the recursive function makes the \
comparison in the ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement. Thus, the two functions are effectively equal in terms of the \
number of comparisons used."
}], "Text",ExpressionUUID->"0aa28949-1f45-4a2e-a0b2-840dcbc8bb06"],

Cell[TextData[{
 "The iterative function involves two assignments (the assignment of ",
 StyleBox["f", "Code"],
 " and the implicit assignment of ",
 StyleBox["i", "Code"],
 " when it is incremented) absent from the recursive version. However, two \
assignments are much less costly than a function call. Recursive function \
calls require ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to perform several operations in the background, both in order to execute \
the recursive call and to keep track of where ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is in the chain of recursive calls. All of which takes time and memory \
that the iterative approach does not require."
}], "Text",ExpressionUUID->"41109884-b450-47a1-bf5f-40549fb7599e"],

Cell["\<\
It is important to keep in mind the cost of recursion. When an iterative \
algorithm is available, it may be more efficient. On the other hand, \
recursive algorithms are often more natural to use and can better reveal the \
mathematical concepts. \
\>", "Text",ExpressionUUID->"a622aa28-5eb7-454d-a81e-fd5892f1b27f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Merge Sort", "Subsection",
 CellTags->"Section4c",ExpressionUUID->"c91b1a44-b74d-4892-9ba7-ac381e826d22"],

Cell["We conclude this section by implementing merge sort.", "Text",ExpressionUUID->"759b6051-0c50-4abf-aa01-31f8d3eb64de"],

Cell[TextData[{
 "The merge sort algorithm is described in Algorithm 9 of the text. The ",
 StyleBox["mergeSort", "Code"],
 " function will accept as its input a list of integers. Its main work is to \
split the single list it receives into two halves, unless the list contains \
only one element. The output of ",
 StyleBox["mergeSort", "Code"],
 " is the result of applying ",
 StyleBox["mergeSort", "Code"],
 " to both halves of the list and then recombining them with ",
 StyleBox["merge", "Code"],
 "."
}], "Text",ExpressionUUID->"7709d72e-6230-4032-a5b5-cbfe8357a2f2"],

Cell[TextData[{
 "The following implements Algorithm 9. Note that the ",
 StyleBox["merge", "Code"],
 " function will be written next. For now, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " simply accepts ",
 StyleBox["merge", "Code"],
 " as a symbol."
}], "Text",ExpressionUUID->"c630b379-5618-497b-9992-acf38e8b7ce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mergeSort", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "L1", ",", "L2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "L", "]"}], ">", "1"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"Floor", "[", 
         RowBox[{
          RowBox[{"Length", "[", "L", "]"}], "/", "2"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"L1", "=", 
        RowBox[{"L", "[", 
         RowBox[{"[", 
          RowBox[{";;", "m"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"L2", "=", 
        RowBox[{"L", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ";;"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"merge", "[", 
        RowBox[{
         RowBox[{"mergeSort", "[", "L1", "]"}], ",", 
         RowBox[{"mergeSort", "[", "L2", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", "L"}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 InitializationCell->True,
 CellLabel->"In[96]:=",ExpressionUUID->"95835695-b418-4d6b-bcba-564047c849d5"],

Cell[TextData[{
 "Note the use of the ",
 StyleBox[ButtonBox["Span",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Span"], "FunctionLink"],
 " (",
 StyleBox[";;", "Code"],
 ") operator to determine the two sublists. The syntax ",
 Cell[BoxData[
  RowBox[{
   StyleBox["a", "CodeVar"], ";;", 
   StyleBox["b", "CodeVar"]}]], "myCode",ExpressionUUID->
  "b559647d-ac10-41b4-a1dd-f5ac2ca5ec38"],
 ", within the ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Part"], "FunctionLink"],
 " (",
 StyleBox["[[\[Ellipsis]]]", "Code"],
 ") operator, is used to obtain the sublist of elements from position ",
 StyleBox["a", "CodeVar"],
 " to position ",
 StyleBox["b", "CodeVar"],
 ". Omitting ",
 StyleBox["a", "CodeVar"],
 ", as in ",
 StyleBox[";;5", "Code"],
 ", obtains the elements from the beginning to position 5. Omitting ",
 StyleBox["b", "CodeVar"],
 ", as in ",
 StyleBox["3;;", "Code"],
 ", obtains the elements from position 3 to the end of the list."
}], "Text",ExpressionUUID->"0dd4f473-bb62-4484-9659-eefbb46c649e"],

Cell[CellGroupData[{

Cell["Implementing Merge", "Subsubsection",ExpressionUUID->"e67d4f10-0d6f-45b6-a767-1b11a4498263"],

Cell[TextData[{
 "To complete the function, we need to define ",
 StyleBox["merge", "Code"],
 ". The ",
 StyleBox["merge", "Code"],
 " function accepts two lists, which it assumes are sorted, and returns a \
single list that contains all the elements of both of the inputs and that is \
sorted. The procedure is described in Algorithm 10 of the text."
}], "Text",ExpressionUUID->"34154513-78aa-422d-b103-339dd5e1e1a3"],

Cell[TextData[{
 "In implementing ",
 StyleBox["merge", "Code"],
 ", the first step is to duplicate the input lists. This is needed because \
the lists are emptied of their elements as the ",
 StyleBox["merge", "Code"],
 " proceeds, and arguments to a function cannot be modified. We also \
initialize to the empty list the symbol that will store the result."
}], "Text",ExpressionUUID->"82542118-ccd0-4e43-978a-46e7aae82eda"],

Cell[TextData[{
 "The main work of ",
 StyleBox["merge", "Code"],
 " is contained in a ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop conditioned on both lists being nonempty. Within this ",
 StyleBox[ButtonBox["While",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/While"], "FunctionLink"],
 " loop there are an ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement and a ",
 StyleBox[ButtonBox["Which",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Which"], "FunctionLink"],
 ". The ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement will implement the instruction to \[OpenCurlyDoubleQuote]remove \
smaller of first elements of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "7aca0ccd-9850-4ebb-af0a-d58ade9957ce"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "79ee0e8f-03b5-409f-b0e4-a8340bfb1638"],
 " from its list; put it at the right end of ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "872c1b9a-3abe-4103-abfc-045908eecd2f"],
 "\[CloseCurlyDoubleQuote] from Algorithm 10. This ",
 StyleBox[ButtonBox["If",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/If"], "FunctionLink"],
 " statement will test whether the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "ef3f875c-57b7-4e2a-8d38-09f1608c8669"],
 " is smaller than the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "75e64b25-4984-4d0a-b9db-084bc19c8629"],
 ". If so, then the first element is removed from ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "875d953f-ad9c-44a5-8df0-841fe7229dc2"],
 " and added to ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "5cf63978-12b1-4c8f-b423-b2dbd840b719"],
 ". If not, in the else clause, the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "f3ba6cbd-1ea8-4f85-89b4-e6a1267c6a38"],
 " is moved to ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "f0aa9e32-c207-47a6-9840-42d683ba0505"],
 "."
}], "Text",ExpressionUUID->"a9a3fee4-687f-4f45-ab6d-e99d58ffebf6"],

Cell[TextData[{
 "We use ",
 StyleBox[ButtonBox["AppendTo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AppendTo"], "FunctionLink"],
 " to add elements to the end of the list ",
 StyleBox["L", "Code"],
 ". Note that ",
 StyleBox[ButtonBox["AppendTo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AppendTo"], "FunctionLink"],
 ", when applied to the name of a list and an element, automatically replaces \
the list stored in the symbol. We use ",
 StyleBox[ButtonBox["Delete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Delete"], "FunctionLink"],
 " to remove the first element from the list. ",
 StyleBox[ButtonBox["Delete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Delete"], "FunctionLink"],
 " is applied to a list and a position and returns the list with the element \
in that position removed. Unlike ",
 StyleBox[ButtonBox["AppendTo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AppendTo"], "FunctionLink"],
 ", ",
 StyleBox[ButtonBox["Delete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Delete"], "FunctionLink"],
 " does not automatically update a symbol representing a list, so we must \
reassign the name of the list to the result of the ",
 StyleBox[ButtonBox["Delete",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Delete"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"fa11bdff-06d9-402b-aadd-b97454e21d40"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["Which",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Which"], "FunctionLink"],
 " statement will implement the if statement found in Algorithm 10. The first \
condition will be that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "1125d79d-1650-448d-b210-7105b9a26185"],
 " is empty, and if so the remainder of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "e46afe86-5aff-433a-9cb3-b1756bd59ad8"],
 " will be added to ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "bd88e738-493b-489b-942d-11e1bdde42a4"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "d464f979-1660-478b-95d7-0542faf8822e"],
 " will be emptied. In a second condition, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "c8b3467b-bc29-48ee-b6f3-b021eccaeb66"],
 " will be tested. Note that ",
 StyleBox[ButtonBox["Which",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Which"], "FunctionLink"],
 " is the Wolfram Language\[CloseCurlyQuote]s form of the else-if \
construction. ",
 StyleBox[ButtonBox["Join",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Join"], "FunctionLink"],
 " is used to combine two lists."
}], "Text",ExpressionUUID->"a1beebcc-614d-44db-840b-b2d1706c4a0b"],

Cell[TextData[{
 "Here is the implementation of ",
 StyleBox["merge", "Code"],
 "."
}], "Text",ExpressionUUID->"75093958-8905-4dfa-8f79-ba89f0033935"],

Cell[BoxData[
 RowBox[{
  RowBox[{"merge", "[", 
   RowBox[{
    RowBox[{"l1", ":", 
     RowBox[{"{", "__Integer", "}"}]}], ",", 
    RowBox[{"l2", ":", 
     RowBox[{"{", "__Integer", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"L", "=", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"L1", "=", "l1"}], ",", 
      RowBox[{"L2", "=", "l2"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"L1", "=!=", 
          RowBox[{"{", "}"}]}], ")"}], "&&", 
        RowBox[{"(", 
         RowBox[{"L2", "=!=", 
          RowBox[{"{", "}"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"L1", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "<", 
           RowBox[{"L2", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"L", ",", 
             RowBox[{"L1", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"L1", "=", 
            RowBox[{"Delete", "[", 
             RowBox[{"L1", ",", "1"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
          
          RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"L", ",", 
             RowBox[{"L2", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"L2", "=", 
            RowBox[{"Delete", "[", 
             RowBox[{"L2", ",", "1"}], "]"}]}]}]}], "\[IndentingNewLine]", 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Which", "[", 
         RowBox[{
          RowBox[{"L1", "===", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"L", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"L", ",", "L2"}], "]"}]}], ";", 
           RowBox[{"L2", "=", 
            RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"L2", "===", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"L", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"L", ",", "L1"}], "]"}]}], ";", 
           RowBox[{"L1", "=", 
            RowBox[{"{", "}"}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "L"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[97]:=",ExpressionUUID->"5bfa3ee1-2f9f-4736-bd7e-ded00ac623d9"],

Cell[TextData[{
 "We apply ",
 StyleBox["mergeSort", "Code"],
 " to a list as follows."
}], "Text",ExpressionUUID->"f2245291-97d5-4509-9399-f6714ddb7321"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mergeSort", "[", 
  RowBox[{"{", 
   RowBox[{"7", ",", "4", ",", "1", ",", "5", ",", "2", ",", "3", ",", "6"}], 
   "}"}], "]"}]], "Input",
 CellLabel->"In[98]:=",ExpressionUUID->"c6731548-f134-43b3-8932-2b7a4c69406f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], 
  "}"}]], "Output",
 CellLabel->"Out[98]=",ExpressionUUID->"00f5a0e5-c358-451e-a023-9a23726ee1e7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tracing Merge Sort", "Subsubsection",ExpressionUUID->"b67ce10b-fceb-47ec-8ed9-567a31923425"],

Cell[TextData[{
 "To better understand how functions work, it is sometimes useful to create \
\[OpenCurlyDoubleQuote]verbose\[CloseCurlyDoubleQuote] versions of them. That \
is, versions of the functions that report on what it is that they are doing. \
The Wolfram Language includes ",
 StyleBox[ButtonBox["Echo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Echo"], "FunctionLink"],
 " as a way to track the operation of a function. With a single argument, ",
 StyleBox[ButtonBox["Echo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Echo"], "FunctionLink"],
 " will display the value of the argument. A string can be given as a second \
argument, which will label the value being displayed. Note that, within the \
function, ",
 StyleBox[ButtonBox["Echo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Echo"], "FunctionLink"],
 " returns the value of the expression. This means that ",
 StyleBox[ButtonBox["Echo",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Echo"], "FunctionLink"],
 " can be wrapped around expressions within the function definition and do \
not need to be made additional commands, like inserting ",
 StyleBox[ButtonBox["Print",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Print"], "FunctionLink"],
 " statements."
}], "Text",ExpressionUUID->"b586d393-f11f-4501-ab5d-c6819e49575c"],

Cell[TextData[{
 "We provide a verbose version of ",
 StyleBox["mergeSort", "Code"],
 " and apply it to the list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "2"}], "}"}], TraditionalForm]],
  ExpressionUUID->"88533737-0d1b-4fe4-97fd-7bce7950ea4e"],
 "."
}], "Text",ExpressionUUID->"c220c0af-2895-4df7-bd51-8d7382766e6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mergeSortVerbose", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "L1", ",", "L2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<mergeSort called on \>\"", ",", "L"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "L", "]"}], ">", "1"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"m", "=", 
         RowBox[{"Echo", "[", 
          RowBox[{
           RowBox[{"Floor", "[", 
            RowBox[{
             RowBox[{"Length", "[", "L", "]"}], "/", "2"}], "]"}], ",", 
           "\"\<m= \>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"L1", "=", 
         RowBox[{"Echo", "[", 
          RowBox[{
           RowBox[{"L", "[", 
            RowBox[{"[", 
             RowBox[{";;", "m"}], "]"}], "]"}], ",", "\"\<L1= \>\""}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"L2", "=", 
         RowBox[{"Echo", "[", 
          RowBox[{
           RowBox[{"L", "[", 
            RowBox[{"[", 
             RowBox[{
              RowBox[{"m", "+", "1"}], ";;"}], "]"}], "]"}], ",", 
           "\"\<L2= \>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"merge", "[", 
         RowBox[{
          RowBox[{"mergeSortVerbose", "[", "L1", "]"}], ",", 
          RowBox[{"mergeSortVerbose", "[", "L2", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<length=1\>\"", "]"}], ";", 
        "\[IndentingNewLine]", "L"}]}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[99]:=",ExpressionUUID->"be627b95-96bd-4bf0-b691-595961ab713b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mergeSortVerbose", "[", 
  RowBox[{"{", 
   RowBox[{"3", ",", "1", ",", "2"}], "}"}], "]"}]], "Input",
 CellLabel->
  "In[100]:=",ExpressionUUID->"3427157c-47f0-4edc-99a1-eb1427edac9d"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mergeSort called on \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1", ",", "2"}], "}"}]}],
  SequenceForm["mergeSort called on ", {3, 1, 2}],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"a5f0736d-2a4d-45fa-b389-984f89cbebef"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"m= \"\>",
   "EchoLabel"], " ", "1"}]], "Echo",ExpressionUUID->"3019da94-ec4b-45a3-943d-\
8fcaa2143868"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"L1= \"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", "3", "}"}]}]], "Echo",ExpressionUUID->"65191b76-0c2b-42a9-ab6b-\
63783e5d1330"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"L2= \"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2"}], "}"}]}]], "Echo",ExpressionUUID->"de955a6c-8eb4-\
4e6d-b18d-e97f2f87d2a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mergeSort called on \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "3", "}"}]}],
  SequenceForm["mergeSort called on ", {3}],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"764c0bb9-4c90-49c5-82ad-1a99c93d2533"],

Cell[BoxData["\<\"length=1\"\>"], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"74043086-2a67-4988-b166-e356f105705c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mergeSort called on \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}],
  SequenceForm["mergeSort called on ", {1, 2}],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"58abaaf7-092e-49bb-bdde-8eb5c0a26dba"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"m= \"\>",
   "EchoLabel"], " ", "1"}]], "Echo",ExpressionUUID->"9116b2df-8f47-4bd9-8663-\
18b9005715de"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"L1= \"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", "1", "}"}]}]], "Echo",ExpressionUUID->"8c430f49-7b6f-43c6-b2f7-\
2d5e4bc05177"],

Cell[BoxData[
 RowBox[{
  TagBox["\<\"L2= \"\>",
   "EchoLabel"], " ", 
  RowBox[{"{", "2", "}"}]}]], "Echo",ExpressionUUID->"ea858364-1428-4353-9d71-\
ba2dc845efe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mergeSort called on \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "1", "}"}]}],
  SequenceForm["mergeSort called on ", {1}],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"dcd5287f-6161-45ee-934c-699d7c35a5a1"],

Cell[BoxData["\<\"length=1\"\>"], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"09a9792e-2c0d-43f2-87f0-db5ae62e62fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"mergeSort called on \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "2", "}"}]}],
  SequenceForm["mergeSort called on ", {2}],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"83df6c33-0480-4164-89f8-e241fcaee16d"],

Cell[BoxData["\<\"length=1\"\>"], "Print",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"9d78aed7-f574-423f-9964-e9cd68eb56d5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellLabel->
  "Out[100]=",ExpressionUUID->"74bd1e28-1b50-4f4e-b774-974b751311eb"]
}, Open  ]],

Cell[TextData[{
 "We recommend reading through the output. Then, try it with a larger \
example, say with seven elements, to make sure that you understand how merge \
sort works. You can also create a verbose version of ",
 StyleBox["merge", "Code"],
 " to see the details of how that function works."
}], "Text",ExpressionUUID->"328c4484-74c1-46a3-9df4-613c6892b67e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5 Program Correctness", "Section",
 CellTags->"Section5",ExpressionUUID->"69df7f65-366b-4a08-83c9-f2a06830f7b9"],

Cell[TextData[{
 "In this section, we will prove the correctness of the merge sort program \
that we implemented in the last section. This will require that we prove the \
correctness of ",
 StyleBox["merge", "Code"],
 " as well as ",
 StyleBox["mergeSort", "Code"],
 ". We begin with ",
 StyleBox["merge", "Code"],
 "."
}], "Text",ExpressionUUID->"3f70ec44-0aac-44c4-9218-31b05fae8034"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["merge", "Code"]], "Subsection",
 CellTags->"Section5a",ExpressionUUID->"9a92cf9b-fe4b-46de-ade5-03992d4017ab"],

Cell[TextData[{
 "For convenience, we will repeat the definition of ",
 StyleBox["merge", "Code"],
 ", with comments added to indicate where we have broken the procedure into \
three segments: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "1"], TraditionalForm]],ExpressionUUID->
  "48258613-1e59-42ee-a805-f83e3d8f99bf"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "50705e87-e0c7-4d12-a41c-5ac8fe82f68c"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],ExpressionUUID->
  "5b31920b-7a2b-4dcb-88bd-db6b7831383f"],
 "."
}], "Text",ExpressionUUID->"3b9d8d11-ce6d-4358-8d4a-f7bf796e6be3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"merge", "[", 
   RowBox[{
    RowBox[{"l1", ":", 
     RowBox[{"{", "__Integer", "}"}]}], ",", 
    RowBox[{"l2", ":", 
     RowBox[{"{", "__Integer", "}"}]}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"L", ",", "L1", ",", "L2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"begin", " ", "S1"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"L", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L1", "=", "l1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"L2", "=", "l2"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"end", " ", "S1"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"L1", "=!=", 
          RowBox[{"{", "}"}]}], ")"}], "&&", 
        RowBox[{"(", 
         RowBox[{"L2", "=!=", 
          RowBox[{"{", "}"}]}], ")"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"begin", " ", "S2"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"L1", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "<", 
           RowBox[{"L2", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"L", ",", 
             RowBox[{"L1", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"L1", "=", 
            RowBox[{"Delete", "[", 
             RowBox[{"L1", ",", "1"}], "]"}]}]}], ",", "\[IndentingNewLine]", 
          
          RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"L", ",", 
             RowBox[{"L2", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"L2", "=", 
            RowBox[{"Delete", "[", 
             RowBox[{"L2", ",", "1"}], "]"}]}]}]}], "\[IndentingNewLine]", 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"end", " ", "S2"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"(*", 
         RowBox[{"begin", " ", "S3"}], "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Which", "[", 
         RowBox[{
          RowBox[{"L1", "===", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"L", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"L", ",", "L2"}], "]"}]}], ";", 
           RowBox[{"L2", "=", 
            RowBox[{"{", "}"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"L2", "===", 
           RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"L", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"L", ",", "L1"}], "]"}]}], ";", 
           RowBox[{"L1", "=", 
            RowBox[{"{", "}"}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"end", " ", "S3"}], "*)"}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", "L"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 CellLabel->
  "In[101]:=",ExpressionUUID->"a40bc630-cdff-4d29-9a67-db06eeef24cc"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "ec1b99cc-576a-4aee-812b-e3df7dd884c3"],
 " be the assertion that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "39b69121-b189-44d7-9f7e-8bc4ec3349b8"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "5c5946b4-9c4e-4a03-978c-182600fc6289"],
 " (the inputs to the function) are ordered, nonempty, and disjoint lists of \
integers. Let ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "417ce594-510b-49be-ab56-3892a4e89c17"],
 " be the proposition that ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "81571f0d-e0d2-46d2-b628-d06483649913"],
 " (the output) is an ordered list and that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"L", "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "071dd925-c639-4c62-9c6c-b211aab6e4e2"],
 " as sets (that is, the set of integers appearing in ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "051af94e-4d1d-4ee1-878e-0e2b4edc3c6f"],
 " is equal to the union of the set of integers appearing in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "c50a9c3e-7e5e-465a-a315-e0cc6cc8d73e"],
 " and the set of integers in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "9e280bbf-5059-4abb-bcb8-4b17c03b4cc2"],
 "). We claim that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     StyleBox["merge", "Code"], "}"}], "q"}], TraditionalForm]],
  ExpressionUUID->"4f110f76-acdf-4d68-88df-f40db67f9d5b"],
 ", that is, ",
 StyleBox["merge", "Code"],
 " is partially correct with respect to the initial condition ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "7f554097-5655-489c-88bb-1531e6782300"],
 " and the final assertion ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "b163413c-d77d-49c8-a0aa-cdcfc2c24dcc"],
 "."
}], "Text",ExpressionUUID->"36d46b9e-dde6-44d9-ab67-befee856e145"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["q", "1"], TraditionalForm]],ExpressionUUID->
  "7fbe9add-fa3e-4930-bd3f-e7b6fa0bc24a"],
 " be the proposition that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", "1"], "=", 
    SubscriptBox["l", "1"]}], TraditionalForm]],ExpressionUUID->
  "f4629c85-6221-4189-b3c3-ae7587e77469"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", "2"], "=", 
    SubscriptBox["l", "2"]}], TraditionalForm]],ExpressionUUID->
  "4dec3f8b-0f00-45dc-8d05-d977110bac86"],
 ", and ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "f17a663f-746e-4aee-a46d-184534e56623"],
 " is the empty list. It is clear that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", 
     RowBox[{"{", 
      SubscriptBox["S", "1"], "}"}], "p"}], "\[And]", 
    SubscriptBox["q", "1"]}], TraditionalForm]],ExpressionUUID->
  "a38cd4c0-fee8-4bc9-9c94-525a9099e36f"],
 "."
}], "Text",ExpressionUUID->"274e38e8-de4c-4e80-8871-8006a2fe7cdb"],

Cell["Define the following propositional variables:", "Text",ExpressionUUID->"09cf17e4-3fbc-4b8b-8da7-d8b5148489bb"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],ExpressionUUID->
  "bce5ccf3-e568-4321-83f8-d51557ff26d9"],
 " is the proposition that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "afb9a9bd-31d0-4777-8a05-b1d20d493f3b"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "5f5367f5-a7ca-499d-8fe1-0667d597dad5"],
 "; that is, the set of elements appearing in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "f7328482-daaa-493a-a9b8-f08fe15d98c8"],
 " is a subset of the set of elements appearing in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "6605d863-a5c3-464a-83af-8a8ac78a51fb"],
 ", and the order of the elements in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "53f23b20-a6df-4652-a4b0-b22c4d2742c0"],
 " is the same as their order in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "3d323203-21b2-4355-b710-481e05566fb3"],
 ". Note that it immediately follows from ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "f979fdb2-c2e6-44fc-a5f8-cf686e19d0fd"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],ExpressionUUID->
  "55b010ec-8a3c-4e8a-a2ea-84a360745d29"],
 " that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "d406920a-411e-46e1-815f-f7303b41f854"],
 " is ordered."
}], "Item1",ExpressionUUID->"3a5b47ae-9464-4287-b5e2-264b99732297"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],ExpressionUUID->
  "0410744e-7c93-406d-8c96-fa202e2b87b9"],
 " is the proposition that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "4f8eb2ed-9347-4d06-92c8-91bab3378ec0"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "0023f949-2cb2-460b-86a7-14399fadd508"],
 " (and thus ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "6a5f072f-b56e-4c37-a230-18ec346fbb1e"],
 " is ordered)."
}], "Item1",ExpressionUUID->"8c41a300-f2c0-40a9-b4e6-e4d5b4e0fcbc"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "3"], TraditionalForm]],ExpressionUUID->
  "44ac1221-662e-4389-b165-78faf3dfbcb8"],
 " is the assertion that ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "b8858635-02db-48ac-8128-6e12c7a1b3e8"],
 " is ordered."
}], "Item1",ExpressionUUID->"ede84d95-35a4-415d-be45-ead35f6a01b5"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "4"], TraditionalForm]],ExpressionUUID->
  "1c246051-c7d1-4d15-b8df-390ec576ffba"],
 " is the assertion that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "\[Union]", 
     SubscriptBox["L", "1"], "\[Union]", 
     SubscriptBox["L", "2"]}], "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "765e6167-2b1e-45f4-a37f-2009c20e2e82"],
 " as sets."
}], "Item1",ExpressionUUID->"c420c354-1735-45c8-91a6-82b2611a25d1"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "6752a5cb-41ab-49d5-80a1-53eb7a82f165"],
 " is the proposition that all members of ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "83bfc906-64b4-465f-b180-76449af1f970"],
 " are smaller than all members of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "d824ca10-b81b-4731-9982-8f4c4817f8fa"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "0f0e58c0-5ba1-4e87-a463-eb7501a3078b"],
 ". That is, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[ForAll]", 
      RowBox[{"x", "\[Element]", "L"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"\[ForAll]", 
      RowBox[{"y", "\[Element]", 
       RowBox[{
        SubscriptBox["L", "1"], "\[Union]", 
        SubscriptBox["L", "2"]}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"x", "<", "y"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "b8dc12e6-4c9c-4a60-a1c7-48f6e8f93cb6"],
 "."
}], "Item1",ExpressionUUID->"c846f398-ff30-4909-9772-379577cf5b83"],

Cell[TextData[{
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "413c7605-763a-49f0-ac42-057fe7fb1fc6"],
 " is the proposition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "1"], "\[And]", 
    SubscriptBox["r", "2"], "\[And]", 
    SubscriptBox["r", "3"], "\[And]", 
    SubscriptBox["r", "4"], "\[And]", 
    SubscriptBox["r", "5"]}], TraditionalForm]],ExpressionUUID->
  "25a29014-c641-404e-b8a7-43b7bdf3f72d"],
 "."
}], "Item1",ExpressionUUID->"abe961a1-5bf2-4dce-8b3c-7fe7b154232a"]
}, Open  ]],

Cell[TextData[{
 "We claim that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", "\[And]", 
     SubscriptBox["q", "1"]}], "\[Rule]", "r"}], TraditionalForm]],
  ExpressionUUID->"fd771097-3472-4072-ad65-2b1c9769e73a"],
 ". Assume ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "\[And]", 
    SubscriptBox["q", "1"]}], TraditionalForm]],ExpressionUUID->
  "45589764-e8ac-4209-8a63-80b6398572d9"],
 ". That is, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "0aa6ffc8-41c6-4b8c-8127-1955b1c20dff"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "03d6c8f7-e4ca-411a-9d14-566d364cbe18"],
 " are ordered, nonempty, and disjoint lists of integers. In addition, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", "1"], "=", 
    SubscriptBox["l", "1"]}], TraditionalForm]],ExpressionUUID->
  "ff721622-8e88-4198-a047-97b59643016d"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", "2"], "=", 
    SubscriptBox["l", "2"]}], TraditionalForm]],ExpressionUUID->
  "99c6bdc6-36a5-4e3d-b64e-e0e8998a07b9"],
 ", and ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "ba16a75f-9016-444e-877b-b736692acaae"],
 " is empty. Then, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],ExpressionUUID->
  "0613c9f0-31b8-4c8f-ba01-b89fd72f6990"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],ExpressionUUID->
  "18bd5cc1-097c-4876-b4a6-68f55e836de9"],
 " hold since a list is a sublist of itself. Proposition ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "3"], TraditionalForm]],ExpressionUUID->
  "d5de234c-288f-411c-835d-31d102c118ba"],
 " holds since ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "77e40e12-5c3e-4647-bca2-ecdc3f49a03f"],
 " is empty and thus is ordered vacuously. That ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "4"], TraditionalForm]],ExpressionUUID->
  "ea54ce77-8d1b-4f4e-b5d1-925316001e42"],
 " is true follows from substituting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "91e0c0c3-2cbf-4660-aecb-fe9d9e88196f"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "5df9a56a-7512-4fbe-b8a0-c1c81470afd4"],
 ", and ",
 Cell[BoxData[
  FormBox["\[EmptySet]", TraditionalForm]],ExpressionUUID->
  "540bf446-2f66-466a-9617-8cb8f8f49c7a"],
 " for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "0c4ec842-9b34-4dbf-90f1-4c4312739c4c"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "1ac46d61-826b-4108-9845-3bcd60d6e942"],
 ", and ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "372ed272-3fcb-4f54-90c6-76bfe185c9b3"],
 ". Moreover, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "60b4ec23-2718-44e6-a5df-bd8f27adfbab"],
 " is vacuous since ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "7fa095d4-f7b4-4130-bd7d-37d9b222c29e"],
 " is empty. From ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"p", 
     RowBox[{"{", 
      SubscriptBox["S", "1"], "}"}], "p"}], "\[And]", 
    SubscriptBox["q", "1"]}], TraditionalForm]],ExpressionUUID->
  "439b59d7-4213-414b-bc08-e411b5b00556"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p", "\[And]", 
      SubscriptBox["q", "1"]}], ")"}], "\[Rule]", "r"}], TraditionalForm]],
  ExpressionUUID->"b6df21f3-91f2-41e8-9662-c073698040d3"],
 ", we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     SubscriptBox["S", "1"], "}"}], "r"}], TraditionalForm]],ExpressionUUID->
  "6c12e882-1174-42a9-8c77-d38d50e50537"],
 "."
}], "Text",ExpressionUUID->"c41a4ec3-f909-49fd-a706-76413aa4d5bb"],

Cell[TextData[{
 "Next, we will show that ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "64bbe1be-63da-4ea9-b6be-d2e7de1109d8"],
 " is a loop invariant for the loop ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"while", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["L", "1"], "\[NotEqual]", 
       RowBox[{
        RowBox[{"{", "}"}], " ", "and", " ", 
        SubscriptBox["L", "2"]}], "\[NotEqual]", 
       RowBox[{"{", "}"}]}], ")"}], 
     SubscriptBox["S", "2"]}], ";", 
    SubscriptBox["S", "3"]}], TraditionalForm]],ExpressionUUID->
  "ad793a3a-c2e4-41f1-ab58-f080010b27a4"],
 ". Denote by ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],ExpressionUUID->
  "f96d2d34-bc5a-42b5-92ef-cf3e035a1b3e"],
 " the condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["L", "1"], "\[NotEqual]", 
     RowBox[{"{", "}"}]}], "\[And]", 
    RowBox[{
     SubscriptBox["L", "2"], "\[NotEqual]", 
     RowBox[{"{", "}"}]}]}], TraditionalForm]],ExpressionUUID->
  "8ea40a44-5264-4b41-ad92-10c60588911d"],
 ". We must show that if ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "eb78bb3c-1159-4bec-8623-8e812c332166"],
 " and ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]],ExpressionUUID->
  "39664203-6861-44a3-a39f-00bfc681b1c7"],
 " hold, then ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "7fa657dd-6cdb-4fc8-b931-813f84978b7a"],
 " is true after ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["S", "2"], ";", 
    SubscriptBox["S", "3"]}], TraditionalForm]],ExpressionUUID->
  "4509aa27-308b-4abb-8501-1cc4f54f0667"],
 " is executed. First, we will show ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[And]", 
    RowBox[{"c", 
     RowBox[{"{", 
      SubscriptBox["S", "2"], "}"}], "r"}]}], TraditionalForm]],
  ExpressionUUID->"ac09259a-f022-4b78-b5ad-7ce03e1f6fc1"],
 " and then that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", 
    RowBox[{"{", 
     SubscriptBox["S", "3"], "}"}], "r"}], TraditionalForm]],ExpressionUUID->
  "4bde47cd-967f-4aa3-bb3b-69509d88c3c6"],
 "."
}], "Text",ExpressionUUID->"2542fcef-9491-49b0-acfa-79e5f9f464ce"],

Cell[TextData[{
 "To show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[And]", 
    RowBox[{"c", 
     RowBox[{"{", 
      SubscriptBox["S", "2"], "}"}], "r"}]}], TraditionalForm]],
  ExpressionUUID->"1a2ece77-eed6-4f71-90c0-f65ef852669a"],
 ", assume ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[And]", "c"}], TraditionalForm]],ExpressionUUID->
  "e06577f4-0c44-4116-86fb-c547ee2fbea4"],
 ". That is, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "2032ca44-3880-431e-ab0f-61caa419e89c"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "cc8e1df0-d098-43e7-bd77-8ddea2d1a836"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "aa86eea0-6f88-4d46-bb6a-d312f268562b"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "e5f8ceba-19a1-4f12-92f4-41d8207f9165"],
 ", ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "739a8e7b-bc55-4cdf-ad5c-6c587e6d964f"],
 " is ordered, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "\[Union]", 
     SubscriptBox["L", "1"], "\[Union]", 
     SubscriptBox["L", "2"]}], "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "6f1ef917-79b4-4433-9efd-c3ac27ef8949"],
 ", and all members of ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "28aa028b-724c-40df-8431-7f4b7ec6d3ac"],
 " are smaller than every member of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "60a7352b-27ee-43fc-9f51-8e2d62aa3758"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "bb0358fe-ebbf-4032-9299-d665dc87499f"],
 ". Also, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "4287ab5d-48a5-4cf0-a1a5-50fc224187ab"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "56873c4f-2ef6-4b35-a423-78e3913623f8"],
 " are nonempty. Thus, both ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "553ceb42-0860-4757-98f3-e4a7ac5d1ecb"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "456b9966-9e80-401a-85b8-03bcf5f61fde"],
 " have first elements. Assume that the if condition of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "e03bf514-ddc5-4490-9bad-db7312f107fd"],
 " holds. That is, the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "5e67eb69-ebba-40d8-8157-e154afa2675c"],
 " is smaller than the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "bc986cdd-e708-42f6-9a75-9b4253e146b9"],
 ". Then, the two commands in the then clause of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "4d05c55c-c3ba-4bfb-9592-bc0a85e9f67c"],
 " are executed: the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "a3e12dbc-c227-481a-b6d8-b8660e395876"],
 " is added to the end of ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "0b331728-45e3-4ac7-9f2b-64bcd3c18d8a"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "8a7994f2-795c-4eab-a500-27111b9dbf54"],
 " has its first element removed."
}], "Text",ExpressionUUID->"85eebabc-c60f-4720-987b-e352b05c3d34"],

Cell[TextData[{
 "We need to show that ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "b6735f5c-7938-4201-b7c9-8bb29abc8360"],
 " holds following the execution of the then clause of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "3517fc51-a85e-4f8e-80d4-a34b7e1788a5"],
 "."
}], "Text",ExpressionUUID->"86a4fc5b-1ea5-437b-8788-6dbb8f30dfe0"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],ExpressionUUID->
  "0e4557ae-d6ff-4532-a109-45292201fefe"],
 ": the new ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "4d63314e-cc21-4a8b-b1bb-16c576dd6746"],
 " is a sublist of the old ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "fd790fe2-3198-41d8-ae54-049f660888c1"],
 " since an element was removed meaning that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", 
     RowBox[{"1", "new"}]], "\[Subset]", 
    SubscriptBox["L", 
     RowBox[{"1", "old"}]]}], TraditionalForm]],ExpressionUUID->
  "88f28372-f542-46e4-91d0-4ee04bedb69f"],
 " as sets and the order of the remaining elements was not modified. Since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "new"}]], TraditionalForm]],ExpressionUUID->
  "4b4229e7-298e-41a5-b7a0-cfbf36ee9a86"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "old"}]], TraditionalForm]],ExpressionUUID->
  "dd434e33-d8f5-43fe-9e02-938749d0cac3"],
 ", which was a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "5701370a-ea84-4c9e-9d41-181c97c9da91"],
 ", the new ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "a02dce6f-995a-4ac9-92ed-3fe1d0e25082"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "e715532e-d144-4d18-87fc-b43f6cfbb69a"],
 "."
}], "Item1",ExpressionUUID->"9db89ea1-980a-4ffb-90a4-676168f8a3f6"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],ExpressionUUID->
  "f52ef1bf-e1a7-4cff-8511-5061664590a3"],
 ": the new ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "e70dc652-5111-4c45-9428-b07376683e44"],
 " is identical to the old ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "17504379-7d17-46d3-ad03-ade4dc636b67"],
 " and thus remains a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "7adff0c6-4567-42aa-8446-d6303825cdec"],
 "."
}], "Item1",ExpressionUUID->"1b2c1bb1-095d-42bb-a233-f39edaedc551"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "3"], TraditionalForm]],ExpressionUUID->
  "953f9783-3551-4475-89e3-05049c200b5b"],
 ": the old ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "b74283fc-b3a4-40ce-bc65-871173efddc1"],
 " was ordered, and, since we assume that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "fb002660-f65c-4af1-9281-48756ff671b1"],
 " held before execution of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "227ec85c-9322-4dee-acf2-127a61c4083e"],
 ", every element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "e4c80c82-fdfe-4d82-b527-da163bff0733"],
 " was smaller than every element of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", 
     RowBox[{"1", "old"}]], "\[Union]", 
    SubscriptBox["L", 
     RowBox[{"2", "old"}]]}], TraditionalForm]],ExpressionUUID->
  "197610b0-e7fc-4bfd-96be-78bb97a0aa49"],
 ". In particular, the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "old"}]], TraditionalForm]],ExpressionUUID->
  "a7f9ca07-93f7-4abd-9d60-955dc2aba6d4"],
 " was larger than all elements of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "a3b2b9f5-cde4-4d68-afef-704413fc9792"],
 ". And so ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "new"], TraditionalForm]],ExpressionUUID->
  "86adfbf8-46aa-41c7-95be-3bb359fe4583"],
 " is ordered."
}], "Item1",ExpressionUUID->"ae1c4ace-81b9-4561-99ca-c30b4023c11a"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "4"], TraditionalForm]],ExpressionUUID->
  "766c8264-c336-472e-8a46-e6f3ba51889b"],
 ": The smallest element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "61c91ea1-2d9c-4c8e-ba5d-f32c22d3bc10"],
 " was removed from ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "e059d073-135e-4a28-ac25-d7a46faeb391"],
 " and added to ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "36780907-b705-45a0-abb0-eefcc166a490"],
 ". Thus, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["L", "new"], "\[Union]", 
     SubscriptBox["L", 
      RowBox[{"1", "new"}]]}], "=", 
    RowBox[{
     SubscriptBox["L", "old"], "\[Union]", 
     SubscriptBox["L", 
      RowBox[{"1", "old"}]]}]}], TraditionalForm]],ExpressionUUID->
  "d2eff8b9-c1f3-4eb1-a238-ad43b2324fbc"],
 " and hence ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "\[Union]", 
     SubscriptBox["L", "1"], "\[Union]", 
     SubscriptBox["L", "2"]}], "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "f01fe50e-26cd-4582-9972-bfc87927c01f"],
 "."
}], "Item1",ExpressionUUID->"47a6db3e-9551-4054-850e-2c69756bde81"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "33900823-50bc-40f5-835c-d0b1559e9f9f"],
 ": We must show that all members of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "new"], TraditionalForm]],ExpressionUUID->
  "977edcc2-ad69-42d7-bfa2-a90a9f2e46c2"],
 " are smaller than all members of both ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "new"}]], TraditionalForm]],ExpressionUUID->
  "6cce7767-b1b1-4878-92ca-7928a5cc8710"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"2", "new"}]], TraditionalForm]],ExpressionUUID->
  "55a8a63b-640e-4353-81c8-0500f4221e8b"],
 ". Let ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "533eb1e5-094d-4f73-94e4-8a70b97549bf"],
 " be an arbitrary element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "new"], TraditionalForm]],ExpressionUUID->
  "c8e8c665-43bb-400d-aa16-bbc376c85372"],
 ". Either ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "9382c821-6422-4952-9406-815953ff72e8"],
 " was a member of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "e3015dd5-79fc-49c6-92ec-b2b8ef663121"],
 " or ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "8f5fe26e-962e-4eaf-a096-c8e0d03ce718"],
 " was the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "old"}]], TraditionalForm]],ExpressionUUID->
  "3a9efef2-ac0d-4bc4-a7f4-83ace69b09bb"],
 ". If ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "817152aa-a3b8-48b5-8620-d180cbc577ca"],
 " was a member of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "7a847b9e-917a-48cf-9bea-f9f0a4d0a766"],
 " then the assumption that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "4209cdc1-8e83-4dfd-99d0-0609d1528ef9"],
 " held before execution of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "a62136a9-a51e-45d2-8c5d-fc1369fb4a19"],
 " guarantees that ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "bf1d72ad-3968-41ee-b71a-f8a41f4c347a"],
 " is smaller than all elements of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", 
     RowBox[{"1", "new"}]], "\[Union]", 
    SubscriptBox["L", 
     RowBox[{"2", "new"}]]}], TraditionalForm]],ExpressionUUID->
  "41271bcc-d244-42b0-8c6f-2c43048c5704"],
 ". On the other hand, assume ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "3988aed1-ea8e-4e4d-b62d-770a751db020"],
 " was the first element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "old"}]], TraditionalForm]],ExpressionUUID->
  "ee5efda9-3287-4dd6-9527-12cfd2804fc1"],
 ". Since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "old"}]], TraditionalForm]],ExpressionUUID->
  "ef5f3588-9b3e-4fd8-a78b-16f63e10c483"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "174eb797-8699-434a-8f12-9858a4f746ea"],
 ", it is ordered and thus ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "a70c1093-3c40-49bb-89ef-d0ae12d25075"],
 " was also the smallest element of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "old"}]], TraditionalForm]],ExpressionUUID->
  "b112d474-02d2-4fab-a627-f8c5a2738347"],
 " and hence is less than all elements of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"1", "new"}]], TraditionalForm]],ExpressionUUID->
  "92212f42-69f7-4e01-8415-07dd75d68eb0"],
 ". Also, by the assumption that the if condition of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "7958f9bd-daa8-41d7-b675-aa824fadfe81"],
 " evaluated true, ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "5ad9c07e-0db4-4d8a-b328-c7f9098215a7"],
 " is smaller than the first (and smallest) element of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", 
     RowBox[{"2", "old"}]], "=", 
    SubscriptBox["L", 
     RowBox[{"2", "new"}]]}], TraditionalForm]],ExpressionUUID->
  "80a1328e-92b8-477b-a82b-158fc589a971"],
 " as well. Therefore, ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "46ce7ff6-781c-4241-93fb-130675ded6bc"],
 " is smaller than all members of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", 
     RowBox[{"1", "new"}]], "\[Union]", 
    SubscriptBox["L", 
     RowBox[{"2", "new"}]]}], TraditionalForm]],ExpressionUUID->
  "a22bcfe5-a4cc-4adc-b65d-6686190ecf48"],
 "."
}], "Item1",ExpressionUUID->"f42909cc-9a09-496e-aa3d-262d1cf1e4f1"]
}, Open  ]],

Cell[TextData[{
 "The above shows that if the if condition of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],ExpressionUUID->
  "32a3bf31-7cbb-4420-9f3b-89faa08f0a6b"],
 " holds, then ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "71c8e2c7-7dc4-4bd0-86cc-9c7b176b7fff"],
 " holds after executing the then clause. In case the condition fails and the \
else clause executes, the proof is similar. We conclude that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[And]", 
    RowBox[{"c", 
     RowBox[{"{", 
      SubscriptBox["S", "2"], "}"}], "r"}]}], TraditionalForm]],
  ExpressionUUID->"c567ad62-a06e-460c-b48c-f6ebee74eb0f"],
 "."
}], "Text",ExpressionUUID->"4b8de131-ff4d-4058-ba70-06afbbce8331"],

Cell[TextData[{
 "Next we will show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", 
    RowBox[{"{", 
     SubscriptBox["S", "3"], "}"}], "r"}], TraditionalForm]],ExpressionUUID->
  "0e3b7b4f-e614-4df3-9616-e1c1ad547ae8"],
 ". Assume ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "a7dbf93d-3f30-4238-8934-a7111753f95e"],
 " holds. Consider the case that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "64f6f6d1-cbd0-4d81-b79b-723d5171953e"],
 " is empty. Then, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "4ab5e150-d23c-427c-b12b-3310a7fdc51f"],
 " is appended onto the end of ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "ed99ae1e-b5e6-4f90-9a39-5af4d63b4c74"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "fcb96593-00f0-48dd-b682-f3a0fdc7491d"],
 " is set to the empty list."
}], "Text",ExpressionUUID->"68a033b5-bcf0-4f99-8cf5-471e834041b7"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "1"], TraditionalForm]],ExpressionUUID->
  "02345cc4-867a-4d70-a9fe-2f213593ebe0"],
 ": ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "9620e88d-c7c8-46ca-aa36-95fc80953dc2"],
 " is, since we assume the if condition, empty and thus a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "1"], TraditionalForm]],ExpressionUUID->
  "0d6f27af-0f07-40a3-8516-62e346468bfa"],
 "."
}], "Item1",ExpressionUUID->"19ee1541-51d5-447d-b501-f00f83295e5e"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],ExpressionUUID->
  "55ef0476-e8e9-4a91-b2dc-4e2cd8c386df"],
 ": the second statement in the then clause sets ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "779a1008-d90b-480a-b6f4-436bdaf5b9c5"],
 " equal to the empty list, which is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "9ffd1de4-5a3c-49eb-8c01-a0b9882fee93"],
 "."
}], "Item1",ExpressionUUID->"0f300f8b-f462-4422-89e0-21139a8d8e3b"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "3"], TraditionalForm]],ExpressionUUID->
  "7f174315-a928-4519-88c8-878f5a044eba"],
 ": we assume that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "3479196e-2dd3-4fb0-93a7-54fe105c2a99"],
 " is ordered, that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"2", "old"}]], TraditionalForm]],ExpressionUUID->
  "655864ef-dd00-4845-8aa3-31704186bd3b"],
 " is a sublist of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "2"], TraditionalForm]],ExpressionUUID->
  "88663243-8b0e-4502-9d2d-7e3dbd30d3a5"],
 " and thus is ordered, and that all members of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "124424d2-1db7-448f-a9c3-8c055f11b43c"],
 " are smaller than all members of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"2", "old"}]], TraditionalForm]],ExpressionUUID->
  "d01a04a0-4d95-4b82-b471-3107e61fe9bd"],
 ". Thus, adding ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", 
    RowBox[{"2", "old"}]], TraditionalForm]],ExpressionUUID->
  "25d17af6-9c9e-4552-9661-2854f58cd2d7"],
 " to the end of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "old"], TraditionalForm]],ExpressionUUID->
  "35727b44-8fbb-41a7-af41-9ad73e28b0ed"],
 " to produce ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "new"], TraditionalForm]],ExpressionUUID->
  "5171d4e6-2f81-4ed8-bde7-f3f9673d3601"],
 " results in an ordered list."
}], "Item1",ExpressionUUID->"0896fb99-8337-433f-937f-038a7947ef27"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "4"], TraditionalForm]],ExpressionUUID->
  "daf4df94-d71b-4ec8-81d5-1db3f4262c87"],
 ": as sets, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["L", "new"], "=", 
    RowBox[{
     SubscriptBox["L", "old"], "\[Union]", 
     SubscriptBox["L", 
      RowBox[{"2", "old"}]]}]}], TraditionalForm]],ExpressionUUID->
  "ba2b5085-bcde-4a7d-8211-81e8b2055b40"],
 ", so ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["L", "new"], "\[Union]", 
     SubscriptBox["L", 
      RowBox[{"1", "new"}]], "\[Union]", 
     SubscriptBox["L", 
      RowBox[{"2", "new"}]]}], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["L", "old"], "\[Union]", 
       SubscriptBox["L", 
        RowBox[{"2", "old"}]]}], ")"}], "\[Union]", 
     SubscriptBox["L", 
      RowBox[{"1", "old"}]], "\[Union]", "\[EmptySet]"}]}], TraditionalForm]],
  ExpressionUUID->"2fed77fe-6268-472c-81d1-9ca7f29cc634"],
 ". This is equal to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["l", "1"], "\[Union]", 
    SubscriptBox["l", "2"]}], TraditionalForm]],ExpressionUUID->
  "1fa1a3c8-8476-4a20-a7d9-0a1f426a6a47"],
 " by the assumption that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "4"], TraditionalForm]],ExpressionUUID->
  "a44066bc-1124-4373-8468-dc830d693ad3"],
 " held before execution."
}], "Item1",ExpressionUUID->"787f1691-5977-496c-b57a-84eb0ed5617e"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "7b8767eb-47f9-4c07-8a3b-413b03ef096b"],
 ": after execution of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],ExpressionUUID->
  "21a65061-c680-4f92-b8d9-06af5a291c73"],
 ", both ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "94a032f3-8e9f-47cb-87df-acc8b1dad4a0"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "34a08866-f1ad-4d56-aeca-08e350da30b1"],
 " are empty and assertion ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "5"], TraditionalForm]],ExpressionUUID->
  "53d6fe1b-482a-458f-8bb8-044b7737ea8c"],
 " is true vacuously."
}], "Item1",ExpressionUUID->"d2a0fa53-f5f7-4bc8-86f5-7515e1e0428b"]
}, Open  ]],

Cell[TextData[{
 "The case that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "30bff26f-242e-418f-b639-c98d35f0c809"],
 " is empty is similar. Thus, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", 
    RowBox[{"{", 
     SubscriptBox["S", "3"], "}"}], "r"}], TraditionalForm]],ExpressionUUID->
  "b3531534-6f67-42e0-bbfa-e0457d89447b"],
 "."
}], "Text",ExpressionUUID->"32cd8c95-2e51-4354-aa66-a968d072f58f"],

Cell[TextData[{
 "We have shown ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[And]", 
    RowBox[{"c", 
     RowBox[{"{", 
      SubscriptBox["S", "2"], "}"}], "r"}]}], TraditionalForm]],
  ExpressionUUID->"892e5dd1-86c7-4435-baf7-23007613fe3f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", 
    RowBox[{"{", 
     SubscriptBox["S", "3"], "}"}], "r"}], TraditionalForm]],ExpressionUUID->
  "bd0bf100-2bc8-4769-b4b2-66dad37a2701"],
 ", and thus ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "\[And]", 
    RowBox[{"c", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["S", "2"], ";", 
       SubscriptBox["S", "3"]}], "}"}], "r"}]}], TraditionalForm]],
  ExpressionUUID->"3370a8d4-bb25-4e02-b19a-3b241f8721f0"],
 ". Hence ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "cf1ad215-4538-4144-b0ad-26bf500e5298"],
 " is a loop invariant for the while loop. By the inference rule for while \
loops, we have that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"while", " ", "c", " ", 
       SubscriptBox["S", "2"]}], ";", 
      SubscriptBox["S", "3"]}], "}"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Not]", "c"}], "\[And]", "r"}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"720dc96f-d3bc-48c5-9b88-512793fbbceb"],
 "."
}], "Text",ExpressionUUID->"6dfcfa55-ca46-4ee5-8c18-fc365cb8655a"],

Cell[TextData[{
 "Combining this result with the conclusion that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     SubscriptBox["S", "1"], "}"}], "r"}], TraditionalForm]],ExpressionUUID->
  "fc177bdf-afdf-47bf-8219-a9144b3cb0f6"],
 " from the paragraph immediately following the definition of ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "b09b43d2-6544-477b-96cd-9395b5a8843f"],
 ", we have that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     StyleBox["merge", "Code"], "}"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Not]", "c"}], "\[And]", "r"}], ")"}]}], TraditionalForm]],
  ExpressionUUID->"2319fe5c-7bea-4e7b-8f7f-b045dacfb5b2"],
 "."
}], "Text",ExpressionUUID->"6c19541d-142f-4e9e-ac4d-2bb0197825d8"],

Cell[TextData[{
 "We conclude by claiming ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Not]", "c"}], "\[And]", "r"}], "\[Rule]", "q"}], 
   TraditionalForm]],ExpressionUUID->"35c9e430-9a61-4a7e-bd7d-5770922d18d9"],
 ". Recall that ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "9988626d-84e0-4c9e-800a-e4d8f45bb813"],
 " was the final assertion that ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "a50ac94d-8551-44e9-bbf4-718377a050a7"],
 " is ordered and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"L", "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "e05c8349-3656-4833-b840-5455804b620f"],
 " as sets. Assume ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Not]", "c"}], "\[And]", "r"}], TraditionalForm]],
  ExpressionUUID->"747d12a3-1d32-4414-9730-0407034335c4"],
 ". That ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "25c04438-687f-421c-8d95-cb8881ccc089"],
 " is ordered is the claim of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "3"], TraditionalForm]],ExpressionUUID->
  "5eccc2c6-c76e-4b80-bf28-b8974dfaebc8"],
 ". By ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "4"], TraditionalForm]],ExpressionUUID->
  "2642a118-be9a-473d-bf12-23e43965801d"],
 ", we have that, as sets, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "\[Union]", 
     SubscriptBox["L", "1"], "\[Union]", 
     SubscriptBox["L", "2"]}], "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "ce29deaa-9a63-4d9d-a987-964e23c9ed37"],
 ". However, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Not]", "c"}], TraditionalForm]],ExpressionUUID->
  "16ae70c8-3e71-493f-9636-0cb25609fca0"],
 " implies that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "e9664517-7a56-43bb-b765-8df4b8c3646a"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "47d1b7ff-b81a-404a-ac31-36ff0c1af8da"],
 " are empty. Hence, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"L", "=", 
    RowBox[{
     SubscriptBox["l", "1"], "\[Union]", 
     SubscriptBox["l", "2"]}]}], TraditionalForm]],ExpressionUUID->
  "3362c77d-9dca-4f12-a703-5b96433f9a2e"],
 ". Thus, ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "a478cbdd-3d65-40db-8b6e-876c3df6ced1"],
 " holds and we have completed the proof that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     StyleBox["merge", "Code"], "}"}], "q"}], TraditionalForm]],
  ExpressionUUID->"265d164d-a906-4445-b6c1-11f3d05ef5a0"],
 " and hence ",
 StyleBox["merge", "Code"],
 " is partially correct."
}], "Text",ExpressionUUID->"740b2e8e-47ce-48ac-9fce-1d4f0428424e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["mergeSort", "Code"]], "Subsection",
 CellTags->"Section5b",ExpressionUUID->"11ef5f4a-1134-4cc4-832f-0b4f9756b712"],

Cell[TextData[{
 "Now, we turn to the ",
 StyleBox["mergeSort", "Code"],
 " function. We repeat its definition below."
}], "Text",ExpressionUUID->"5f027565-bf61-4ddd-9d1b-b2b6b41fe6b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"mergeSort", "[", 
   RowBox[{"L", ":", 
    RowBox[{"{", "__Integer", "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "L1", ",", "L2"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "L", "]"}], ">", "1"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{"Floor", "[", 
         RowBox[{
          RowBox[{"Length", "[", "L", "]"}], "/", "2"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"L1", "=", 
        RowBox[{"L", "[", 
         RowBox[{"[", 
          RowBox[{";;", "m"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"L2", "=", 
        RowBox[{"L", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"m", "+", "1"}], ";;"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"merge", "[", 
        RowBox[{
         RowBox[{"mergeSort", "[", "L1", "]"}], ",", 
         RowBox[{"mergeSort", "[", "L2", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", "L"}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 CellLabel->
  "In[102]:=",ExpressionUUID->"e8ff54e6-2770-4deb-a809-5c41c5d6a5a4"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "d1605f74-dc54-44c9-821b-56bd8e4ec37c"],
 " be the assertion that ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "8acf2927-04f9-46da-bf15-9602835dd704"],
 " is a nonempty list of distinct integers, and let ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "9956eab9-e757-4617-aec8-7723ce6cb56b"],
 " be the assertion that the function returns a list which has the same \
elements as ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "50f269c3-7fdb-4d3b-86ea-fb0a5235c346"],
 " and is ordered. Our claim is that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     StyleBox["mergeSort", "Code"], "}"}], "q"}], TraditionalForm]],
  ExpressionUUID->"64d3d997-6d71-4a7e-b2cb-5bea758651c6"],
 ". Since ",
 StyleBox["mergeSort", "Code"],
 " is recursive, our proof will be by strong induction on the length of the \
list ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "12eec159-0246-4936-a579-7d4cb59db491"],
 "."
}], "Text",ExpressionUUID->"c038f9b0-4d3e-48f3-bed6-518afd473758"],

Cell[TextData[{
 "For the basis case, assume that ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "dc811dde-7131-4d53-b397-744c472dd94c"],
 " has only one element. Also assume ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "45b20e45-924d-4973-b0a6-9c7843b5f908"],
 ". Then, the if condition of ",
 StyleBox["mergeSort", "Code"],
 " fails and the program terminates by returning ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "0c0f94d6-ccb6-4182-8464-983ca739145b"],
 " unmodified. However, since ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "6b9d41c1-fae6-4e9f-b96d-4a02eaddf7f2"],
 " has only one element, it is trivially ordered. Thus, under the basis \
assumption that ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "1f01887a-717a-4ea5-a155-3ab3c1376d2f"],
 " has only one element, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     StyleBox["mergeSort", "Code"], "}"}], "q"}], TraditionalForm]],
  ExpressionUUID->"95fd88dc-35d2-426d-ade5-09525fa15524"],
 "."
}], "Text",ExpressionUUID->"36744417-bdd6-417e-9cad-3dae7ea279d2"],

Cell[TextData[{
 "For the inductive case, we make the inductive assumption that for all ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "\[LessEqual]", "n"}], TraditionalForm]],ExpressionUUID->
  "8eea4e52-c8b3-4aa6-a118-5e6e34fd250b"],
 ", if a list has length ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "e29fd1fd-e36a-490b-9042-b33a84c358cf"],
 " then ",
 StyleBox["mergeSort", "Code"],
 " returns the list sorted. Assume ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "79e850bf-3289-432d-9261-2ab3eb13a559"],
 " has ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "+", "1"}], TraditionalForm]],ExpressionUUID->
  "80232031-e2a3-4deb-a12a-e0f14ad1507c"],
 " elements. Also assume ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]],ExpressionUUID->
  "f90ff18a-94b0-465f-b3c3-16b674849fad"],
 ". Under these assumptions, the if condition is satisfied."
}], "Text",ExpressionUUID->"0351849d-73b8-45da-9b31-9c145906570a"],

Cell[TextData[{
 "The first command in the then clause assigns ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", 
    RowBox[{"\[LeftFloor]", 
     FractionBox[
      RowBox[{"n", "+", "1"}], "2"], "\[RightFloor]"}]}], TraditionalForm]],
  ExpressionUUID->"cfa861ca-33f5-4a7f-bee8-e34452404035"],
 ". Note that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "<", 
    RowBox[{"n", "+", "1"}]}], TraditionalForm]],ExpressionUUID->
  "3a1bd31c-e5c0-4232-9473-c02b5f018513"],
 " and, since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", ">", "1"}], TraditionalForm]],ExpressionUUID->
  "2034c7fd-0821-4b30-b7ff-c82ac2c00839"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", ">", "0"}], TraditionalForm]],ExpressionUUID->
  "11c981c7-05f7-4268-a404-341748741af4"],
 ". All of the inequalities are strict."
}], "Text",ExpressionUUID->"3252ac65-1bf9-4777-a3ea-0b6b9e5656cc"],

Cell[TextData[{
 "The next two commands assign ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "9b441393-bb99-4e4b-bec5-f46fffff376c"],
 " to the list consisting of the first ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "0abad7d1-38bf-422a-b86f-35d7aa6bc35e"],
 " elements in ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "cd66aa1c-a809-46a1-ab26-13ba81ea0029"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "814c1ca9-8231-4e84-b19c-07dd2eb795bf"],
 " to the remainder. Note that since ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "<", "m", "<", 
    RowBox[{"n", "+", "1"}]}], TraditionalForm]],ExpressionUUID->
  "c4058369-11fb-482a-b6aa-ec3d5cbb3e9d"],
 ", both of these lists are nonempty with at most ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "1a04eb54-1e93-45e8-a466-dc9d7278e1be"],
 " elements."
}], "Text",ExpressionUUID->"ee76f3a0-8ac9-4ca9-86b9-a290880941fb"],

Cell[TextData[{
 "In the final statement of the if clause, ",
 StyleBox["mergeSort", "Code"],
 " is applied to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "2e1bca95-956e-403e-9516-3bdc1ef2e418"],
 " and to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "636ad8b3-f919-4125-bb97-3d109c147b13"],
 ". Since both these lists have length at most ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "aad9cf8c-f4a6-4487-a515-863b1b33f09d"],
 ", the inductive assumption implies that the results of ",
 StyleBox["mergeSort", "Code"],
 " on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],ExpressionUUID->
  "16e6c673-89cf-4363-84db-05e8ffdefeeb"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],ExpressionUUID->
  "c4b1f677-2646-4ccd-9d96-1c6e596bf3e2"],
 " are lists with the same elements and ordered. Since ",
 StyleBox["merge", "Code"],
 " is partially correct, as shown in the previous subsection, the result of \
",
 StyleBox["merge", "Code"],
 " is an ordered list consisting of the elements of its input lists. Hence, \
the result of ",
 StyleBox["mergeSort", "Code"],
 " is an ordered list consisting of the same elements as ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "abc3524a-6cc4-447d-bf42-9262524cf3f1"],
 ". That is, ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "d822089d-9067-4b06-a64d-757832a6d11b"],
 " holds."
}], "Text",ExpressionUUID->"cd658a4c-37a4-4936-a2c5-00c7f80be716"],

Cell[TextData[{
 "This concludes the inductive step and we conclude ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", 
    RowBox[{"{", 
     StyleBox["mergeSort", "Code"], "}"}], "q"}], TraditionalForm]],
  ExpressionUUID->"eca43012-863b-4d27-a323-fcbef17b26ff"],
 " for all lengths of ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "d964cb2b-8868-4a14-b692-4495c0f8ed0e"],
 ". Hence, ",
 StyleBox["mergeSort", "Code"],
 " is partially correct."
}], "Text",ExpressionUUID->"3fbb5714-50ac-4065-ab2a-11c482efbc7c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solutions to Computer Projects and Computations and Explorations\
\>", "Section",
 CellTags->"Solutions",ExpressionUUID->"6d1006d9-494f-46e3-93d5-734ef38c08ec"],

Cell[CellGroupData[{

Cell["Computer Projects 2", "Subsection",
 CellTags->
  "SolutionsCP2",ExpressionUUID->"79a55584-88c3-45d2-8b7f-6b3b1c2b4c1e"],

Cell[TextData[{
 "Generate all well-formed formulae for expressions involving the variables \
",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "0145ebea-301b-4c16-b0e1-f3ad5ecb3f16"],
 ", ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "17355f38-9753-40f5-baee-4b30e7c0aaaa"],
 ", and ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "d0679f73-e5b5-4e88-ae41-9c5d9fc09805"],
 " and the operators ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"+", 
     RowBox[{",", 
      RowBox[{"\[CenterDot]", 
       RowBox[{",", 
        RowBox[{"/", 
         RowBox[{",", "-"}]}]}]}]}]}], "}"}], TraditionalForm]],
  ExpressionUUID->"be45a528-97df-4df5-b6d4-3260a750db1a"],
 " with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f68ae18f-942d-4a93-a311-d829944e94d7"],
 " or fewer symbols."
}], "Problem",ExpressionUUID->"fb0545bd-04c4-4f33-9733-df0f882c7f20"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " This problem asks us to not only generate well-formed formulae, but to \
generate ",
 StyleBox["all",
  FontSlant->"Italic"],
 " such formulae subject to a limitation on the number of symbols."
}], "Text",ExpressionUUID->"b03b8b1e-24ab-43cf-9020-23648b204c4c"],

Cell["\<\
To begin, we present a recursive definition of the set of well-formed \
formulae on the symbols.\
\>", "Text",ExpressionUUID->"defe1263-6afb-4c8d-84b2-4d331d380644"],

Cell[TextData[{
 "Basis step: ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "f449c624-70d7-453b-a14b-4e07add7359c"],
 ", ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "c57bcf53-f653-4d55-9b0a-0e090b761984"],
 ", and ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "b777e465-38ef-4535-9f0e-6c974613d83f"],
 " are well-formed formulae."
}], "Text",
 CellMargins->{{24, 10}, {3, 
  0}},ExpressionUUID->"8f3277ae-0197-49b4-9436-6d62dcbf86c6"],

Cell[TextData[{
 "Recursive step: If ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]],ExpressionUUID->
  "9393e45a-1d6b-459b-9184-4029d88647f1"],
 " and ",
 Cell[BoxData[
  FormBox["G", TraditionalForm]],ExpressionUUID->
  "0ce312f5-6c42-408e-86ae-e921f861f446"],
 " are well-formed formulae, then so are: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"-", "F"}], ")"}], TraditionalForm]],ExpressionUUID->
  "bcef7319-96b1-4399-85bf-966036f52feb"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"F", "+", "G"}], ")"}], TraditionalForm]],ExpressionUUID->
  "8f5810b6-ec3e-457f-84ae-be43875f64a5"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"F", "-", "G"}], ")"}], TraditionalForm]],ExpressionUUID->
  "4f443017-68be-4346-80fc-1f91428de1b4"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"F", "\[CenterDot]", "G"}], ")"}], TraditionalForm]],
  ExpressionUUID->"26a9700b-eea1-4e9d-ae25-c77a97c97a7c"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"F", "/", "G"}], ")"}], TraditionalForm]],ExpressionUUID->
  "8082902d-fcb4-4828-84a1-dbc94c14b81f"],
 "."
}], "Text",
 CellMargins->{{24, 10}, {3, 
  0}},ExpressionUUID->"f1d36bbb-7c35-4fdb-a897-b3b259c356ca"],

Cell["\<\
Note that we will fully parenthesize the well-formed formulae so as to avoid \
ambiguity, but parentheses will not be considered symbols for the purpose of \
counting symbols in the formula.\
\>", "Text",ExpressionUUID->"fbbc27af-2fb7-46e7-b8bf-7e63929b5774"],

Cell[TextData[{
 "Also note that we will implement the well-formed formulae as strings, not \
as algebraic expressions. The reason for this is that if we build algebraic \
expressions, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will perform unwanted simplification. For example, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"-", "x"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "c3afd298-9d2e-47f3-a02f-cc5a96ba2757"],
 " is a well-formed formula distinct from ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "0a434fad-97be-446b-99ab-c85b12895ab9"],
 ", but if we enter ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"-", "x"}], ")"}]}], TraditionalForm]],ExpressionUUID->
  "109508fb-e89f-463e-bcb5-ff15212f0639"],
 " as a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expression, it will be simplified to ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "7a1c8313-fb14-40c3-a40f-07d8daf7b44a"],
 "."
}], "Text",ExpressionUUID->"ffdab81f-59be-4aad-8803-f660dcf97b61"],

Cell[TextData[{
 "We will approach this problem in two steps. First, we generate well-formed \
formulae using a function with sufficiently many applications of the \
recursive step to guarantee that every well-formed formula of length ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "0627c995-9d20-42c9-a87d-a08d590edd98"],
 " or less is produced. Second, we will prune the well-formed formulae with \
greater than ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "01868a49-b753-4353-935e-10e8b44847e0"],
 " symbols. This will leave us with all well-formed formulae involving at \
most ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "259e1834-44f7-47a1-91a2-5e7a6de0e82e"],
 " symbols."
}], "Text",ExpressionUUID->"9a9fa9d7-78d5-4b27-a1e5-ba81f4baa141"],

Cell[CellGroupData[{

Cell["Generating Formulae", "Subsubsection",ExpressionUUID->"3f2dd951-ff12-4a63-9343-f854f2463685"],

Cell[TextData[{
 "The first step is to generate well-formed formulae. For this, we will \
create a pair of functions, similar to ",
 StyleBox["allStrings", "Code"],
 " and ",
 StyleBox["buildStrings", "Code"],
 " from Section 5.3 of this manual."
}], "Text",ExpressionUUID->"446ac732-fd73-40ce-b7f3-0cbb86d92acb"],

Cell[TextData[{
 "The function ",
 StyleBox["buildWFFs", "Code"],
 " will accept a single argument, a list of well-formed formulae. It will \
apply the recursive step to the existing set. The function first makes a copy \
of the input set, since arguments cannot be modified. Second, using a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop over the input set, it applies unary negation. Then, with a ",
 StyleBox[ButtonBox["Do",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Do"], "FunctionLink"],
 " loop over the input set and over the binary operations, the function adds \
the rest of the well-formed formulae."
}], "Text",ExpressionUUID->"02fd0597-5f30-425a-bc80-0c98e64bd0eb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"buildWFFs", "[", "S_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"T", "=", "S"}], ",", "f", ",", "g", ",", "o"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"T", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"T", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<(-\>\"", "<>", "f", "<>", "\"\<)\>\""}], "}"}]}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"f", ",", "S"}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"T", "=", 
        RowBox[{"Union", "[", 
         RowBox[{"T", ",", 
          RowBox[{"{", 
           RowBox[{
           "\"\<(\>\"", "<>", "f", "<>", "o", "<>", "g", "<>", "\"\<)\>\""}], 
           "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"f", ",", "S"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"g", ",", "S"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"o", ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<+\>\"", ",", "\"\<-\>\"", ",", "\"\<*\>\"", ",", "\"\</\>\""}],
           "}"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", "T"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[103]:=",ExpressionUUID->"7ba40fa5-b46f-4bb8-942f-f048a97a222b"],

Cell[TextData[{
 "We confirm that this works as expected by applying it to the basis set ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"\<\"x\"\>", ",", "\<\"y\"\>", ",", "\<\"z\"\>"}], "}"}], 
   TraditionalForm]],ExpressionUUID->"c684da5b-2869-4e27-8cf6-390ae7024506"],
 "."
}], "Text",ExpressionUUID->"141a2b51-e6c1-4183-8091-949b588b266b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"buildWFFs", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}], 
  "]"}]], "Input",
 CellLabel->
  "In[104]:=",ExpressionUUID->"e2b0d2d4-df40-48ee-ae41-cb62c00ed4c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(-x)\"\>", ",", "\<\"x\"\>", ",", "\<\"(x*x)\"\>", 
   ",", "\<\"(x-x)\"\>", ",", "\<\"(x+x)\"\>", ",", "\<\"(x/x)\"\>", 
   ",", "\<\"(x*y)\"\>", ",", "\<\"(x-y)\"\>", ",", "\<\"(x+y)\"\>", 
   ",", "\<\"(x/y)\"\>", ",", "\<\"(x*z)\"\>", ",", "\<\"(x-z)\"\>", 
   ",", "\<\"(x+z)\"\>", ",", "\<\"(x/z)\"\>", ",", "\<\"(-y)\"\>", 
   ",", "\<\"y\"\>", ",", "\<\"(y*x)\"\>", ",", "\<\"(y-x)\"\>", 
   ",", "\<\"(y+x)\"\>", ",", "\<\"(y/x)\"\>", ",", "\<\"(y*y)\"\>", 
   ",", "\<\"(y-y)\"\>", ",", "\<\"(y+y)\"\>", ",", "\<\"(y/y)\"\>", 
   ",", "\<\"(y*z)\"\>", ",", "\<\"(y-z)\"\>", ",", "\<\"(y+z)\"\>", 
   ",", "\<\"(y/z)\"\>", ",", "\<\"(-z)\"\>", ",", "\<\"z\"\>", 
   ",", "\<\"(z*x)\"\>", ",", "\<\"(z-x)\"\>", ",", "\<\"(z+x)\"\>", 
   ",", "\<\"(z/x)\"\>", ",", "\<\"(z*y)\"\>", ",", "\<\"(z-y)\"\>", 
   ",", "\<\"(z+y)\"\>", ",", "\<\"(z/y)\"\>", ",", "\<\"(z*z)\"\>", 
   ",", "\<\"(z-z)\"\>", ",", "\<\"(z+z)\"\>", ",", "\<\"(z/z)\"\>"}], 
  "}"}]], "Output",
 CellLabel->
  "Out[104]=",ExpressionUUID->"8c9f05dd-ebe7-4c4c-b4a0-3a3ccb9a9f88"]
}, Open  ]],

Cell[TextData[{
 "Note that the order is not the order in which the well-formed formulae are \
added, it is the order that ",
 StyleBox[ButtonBox["Union",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Union"], "FunctionLink"],
 " imposes on the set."
}], "Text",ExpressionUUID->"a0726de4-dc1b-4ef4-b200-0aecfdd24182"],

Cell[TextData[{
 "The other component is the function that calls ",
 StyleBox["buildWFFs", "Code"],
 ". This is nearly identical to ",
 StyleBox["allStrings", "Code"],
 ". ",
 StyleBox["allWFFs", "Code"],
 " accepts a positive integer ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]],ExpressionUUID->
  "410c8892-19b8-45d2-b66b-c0ee80c6b381"],
 " representing the number of applications of the recursive step that are to \
be performed. It initializes the set of formulae to the basis set and applies \
",
 StyleBox["buildWFFs", "Code"],
 " as many times as is called for."
}], "Text",ExpressionUUID->"49281815-7b62-4a44-9528-193c6045aa9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"allWFFs", "[", "m_Integer", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"S", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"S", "=", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], "}"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "m"}], ",", 
       RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{"S", "=", 
        RowBox[{"buildWFFs", "[", "S", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "S"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[105]:=",ExpressionUUID->"4b7ccf4c-19c5-4ef8-b3e1-ce17f862e92a"],

Cell[TextData[{
 "Now the question is: how many applications of the recursive step are needed \
to be sure that the result contains all well-formed formulae of length at \
most ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "099bd09d-1efe-41db-876c-d5528014ae31"],
 "? Clearly, 0 applications of ",
 StyleBox["buildWFFs", "Code"],
 " are needed to obtain all formulae consisting of 1 symbol, as this is the \
basis step. In addition, the formulae produced by an application of ",
 StyleBox["buildWFFs", "Code"],
 " contain at least one symbol more than was present in the previous step \
(from the unary negation). Therefore, after ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "-", "1"}], TraditionalForm]],ExpressionUUID->
  "9a07985a-94b1-452f-b192-37ee151ab337"],
 " applications of ",
 StyleBox["buildWFFs", "Code"],
 ", we are guaranteed to have all well-formed formulae with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "c6ac3c8a-fca3-4f6b-8e44-a1b51a3cb0c3"],
 " symbols or fewer."
}], "Text",ExpressionUUID->"a05d6901-fa3a-477f-93df-851ffe08d973"],

Cell[TextData[{
 "To illustrate, we will find all well-formed formulae of length at most 3. \
Apply ",
 StyleBox["AllWFFs", "Code"],
 " to 2."
}], "Text",ExpressionUUID->"00aa2b7a-ff80-4812-afa9-3a0e2ffb98e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"allWFF3", "=", 
   RowBox[{"allWFFs", "[", "2", "]"}]}], ";"}]], "Input",
 CellLabel->
  "In[106]:=",ExpressionUUID->"91c1a5c4-35aa-4f13-b2d9-3fce59be18ce"],

Cell["We suppressed the output since the output would be lengthy.", "Text",ExpressionUUID->"68e46185-2dd5-4178-bb1d-1d560c013e44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "allWFF3", "]"}]], "Input",
 CellLabel->
  "In[107]:=",ExpressionUUID->"83bc8438-783c-433b-b871-00a63e75477f"],

Cell[BoxData["7101"], "Output",
 CellLabel->
  "Out[107]=",ExpressionUUID->"5c433fb6-1338-4f84-a98d-fb9dd8c405b9"]
}, Open  ]],

Cell["Here is the list of every 300th formula. ", "Text",ExpressionUUID->"dd8d4772-1773-44bb-b31b-f78e962d0edc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"allWFF3", "[", 
    RowBox[{"[", "i", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "7101", ",", "300"}], "}"}]}], "]"}]], "Input",\

 CellLabel->
  "In[108]:=",ExpressionUUID->"2894c1f1-5edf-4117-99b2-d984f547bc67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(-(-x))\"\>", ",", "\<\"((x-x)-(-y))\"\>", 
   ",", "\<\"((x*x)*(z-x))\"\>", ",", "\<\"((x-y)+(x-x))\"\>", 
   ",", "\<\"((x*y)-(y-y))\"\>", ",", "\<\"((x/y)*(z-y))\"\>", 
   ",", "\<\"((x*z)+(x-z))\"\>", ",", "\<\"((x/z)-(y-z))\"\>", 
   ",", "\<\"((-y)+(x+x))\"\>", ",", "\<\"(y-(x+y))\"\>", 
   ",", "\<\"((y+x)*(z+x))\"\>", ",", "\<\"((y/y)+(x+x))\"\>", 
   ",", "\<\"((y+y)-(y+y))\"\>", ",", "\<\"((y-y)*(z+z))\"\>", 
   ",", "\<\"((y+z)+(x+z))\"\>", ",", "\<\"((y-z)+(-z))\"\>", 
   ",", "\<\"((z+x)/x)\"\>", ",", "\<\"((z-x)-(y/x))\"\>", 
   ",", "\<\"((z*x)*(z/y))\"\>", ",", "\<\"((z-y)+(x/y))\"\>", 
   ",", "\<\"((z*y)-(y/z))\"\>", ",", "\<\"((z/y)*(z/z))\"\>", 
   ",", "\<\"((-z)+(z/y))\"\>", ",", "\<\"(z-(z/z))\"\>"}], "}"}]], "Output",
 CellLabel->
  "Out[108]=",ExpressionUUID->"39ab553d-2f2b-4cdc-864d-8ba0e20117fa"]
}, Open  ]],

Cell["\<\
Note that these involve up to seven symbols. Since we want the formulae with \
at most three symbols, we must remove from this set all the formulae with \
more than three. For this, we will need a function that calculates the number \
of symbols in a formula. \
\>", "Text",ExpressionUUID->"a11ecf32-e635-47f3-8f36-41e1af19b93d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pruning the Set", "Subsubsection",ExpressionUUID->"1ccc45cc-2255-4447-9cef-b678b73940e1"],

Cell[TextData[{
 "To count the number of characters in a string, the Wolfram Language \
provides the ",
 StyleBox[ButtonBox["StringLength",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringLength"], "FunctionLink"],
 " function. If you apply ",
 StyleBox[ButtonBox["StringLength",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringLength"], "FunctionLink"],
 " to a string, the command returns the number of characters in the string."
}], "Text",ExpressionUUID->"6adf0bb9-04d5-4918-972f-29c1ec788122"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringLength", "[", "\"\<abcde\>\"", "]"}]], "Input",
 CellLabel->
  "In[109]:=",ExpressionUUID->"ac37ac49-d2ba-48c7-897e-d548fbcbae37"],

Cell[BoxData["5"], "Output",
 CellLabel->
  "Out[109]=",ExpressionUUID->"c6329e18-8271-406f-a636-fc13492a92d8"]
}, Open  ]],

Cell[TextData[{
 "However, the number of symbols in a well-formed formula is not equal to its \
length, since parentheses are not considered symbols. Fortunately, the \
Wolfram Language also provides the function ",
 StyleBox[ButtonBox["StringCount",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringCount"], "FunctionLink"],
 ". This function takes two arguments. The first is the string. The second is \
a substring or a list of substrings that you wish to count within the first. \
For example, to determine the number of ",
 StyleBox["a\[CloseCurlyQuote]s",
  IgnoreSpellCheck->True],
 " and ",
 StyleBox["b\[CloseCurlyQuote]s",
  IgnoreSpellCheck->True],
 " within the string \[OpenCurlyDoubleQuote]",
 StyleBox["abcccbabbcab",
  IgnoreSpellCheck->True],
 "\[CloseCurlyDoubleQuote], you enter the following."
}], "Text",ExpressionUUID->"81dd1126-c27b-46bf-b730-863d0b43d7d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCount", "[", 
  RowBox[{"\"\<abcccbabbcab\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}]}], "]"}]], "Input",
 CellLabel->
  "In[110]:=",ExpressionUUID->"c6b9448e-4bad-4f90-b00b-a722c5e52679"],

Cell[BoxData["8"], "Output",
 CellLabel->
  "Out[110]=",ExpressionUUID->"90aad99e-8249-416a-830c-dfbc499004bd"]
}, Open  ]],

Cell[TextData[{
 "To count the number of symbols in a well-formed formula, we apply ",
 StyleBox[ButtonBox["StringCount",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringCount"], "FunctionLink"],
 " with second argument the list of all symbols: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"\<\"x\"\>", ",", "\<\"y\"\>", ",", "\<\"z\"\>", ",", "\<\"+\"\>",
      ",", "\<\"-\"\>", ",", "\<\"*\"\>", ",", "\<\"/\"\>"}], "}"}], 
   TraditionalForm]],ExpressionUUID->"3259c693-1b3e-484d-bc2d-c2b34369d3a7"],
 ". For example, the number of symbols in \[OpenCurlyDoubleQuote]",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"z", "-", "x"}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"z", "*", "x"}], ")"}]}]}], TraditionalForm]],ExpressionUUID->
  "d832d629-41ab-41be-862a-f89d83f614c4"],
 "\[CloseCurlyDoubleQuote] is:"
}], "Text",ExpressionUUID->"5bda99ae-335b-489c-bef5-5e21e965378d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCount", "[", 
  RowBox[{"\"\<((z-x)-(z*x))\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", ",", "\"\<+\>\"", ",", 
     "\"\<-\>\"", ",", "\"\<*\>\"", ",", "\"\</\>\""}], "}"}]}], 
  "]"}]], "Input",
 CellLabel->
  "In[111]:=",ExpressionUUID->"db086c90-dd75-4d18-95b6-a659db4217ac"],

Cell[BoxData["7"], "Output",
 CellLabel->
  "Out[111]=",ExpressionUUID->"30198521-c992-4bd9-8f08-4672a631282e"]
}, Open  ]],

Cell[TextData[{
 "In order to prune the set ",
 StyleBox["allWFF3", "Code"],
 " so that it contains only the formulae with three or fewer symbols, we use ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 ". The ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 " function can be used to find the subset of a given set consisting of those \
elements satisfying a given condition. ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 " requires two arguments. The first is the original list. The second is a \
Boolean-valued function of one argument that can be applied to the elements \
of the list and returns ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " for those elements that should be selected. The result is the list of \
elements of the original list for which the function returned true. "
}], "Text",ExpressionUUID->"688867e8-14ea-4ee0-a5d0-2899f8cf34d1"],

Cell[TextData[{
 "In our case, the Boolean-valued function should return true if the \
well-formed formula has three or fewer symbols. We will create a function to \
test the result of ",
 StyleBox[ButtonBox["StringCount",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/StringCount"], "FunctionLink"],
 " against 3."
}], "Text",ExpressionUUID->"cf077518-7c6b-4be9-9dfe-f1705a659420"],

Cell[BoxData[
 RowBox[{
  RowBox[{"testWFF3", "[", "s_String", "]"}], ":=", 
  RowBox[{
   RowBox[{"StringCount", "[", 
    RowBox[{"s", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\"", ",", "\"\<+\>\"", ",", 
       "\"\<-\>\"", ",", "\"\<*\>\"", ",", "\"\</\>\""}], "}"}]}], "]"}], "<=",
    "3"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[112]:=",ExpressionUUID->"b13f3693-6a95-4e4e-b623-3b24076b25e2"],

Cell[TextData[{
 "We can now use the name of this function as the second argument to ",
 StyleBox[ButtonBox["Select",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Select"], "FunctionLink"],
 "."
}], "Text",ExpressionUUID->"aff77890-5120-44c3-9689-7e6d63231d5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{"allWFF3", ",", "testWFF3"}], "]"}]], "Input",
 CellLabel->
  "In[113]:=",ExpressionUUID->"dfe3141a-fb21-4f20-9471-9dfdb427608d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(-(-x))\"\>", ",", "\<\"(-x)\"\>", ",", "\<\"x\"\>", 
   ",", "\<\"(x*x)\"\>", ",", "\<\"(x-x)\"\>", ",", "\<\"(x+x)\"\>", 
   ",", "\<\"(x/x)\"\>", ",", "\<\"(x*y)\"\>", ",", "\<\"(x-y)\"\>", 
   ",", "\<\"(x+y)\"\>", ",", "\<\"(x/y)\"\>", ",", "\<\"(x*z)\"\>", 
   ",", "\<\"(x-z)\"\>", ",", "\<\"(x+z)\"\>", ",", "\<\"(x/z)\"\>", 
   ",", "\<\"(-(-y))\"\>", ",", "\<\"(-y)\"\>", ",", "\<\"y\"\>", 
   ",", "\<\"(y*x)\"\>", ",", "\<\"(y-x)\"\>", ",", "\<\"(y+x)\"\>", 
   ",", "\<\"(y/x)\"\>", ",", "\<\"(y*y)\"\>", ",", "\<\"(y-y)\"\>", 
   ",", "\<\"(y+y)\"\>", ",", "\<\"(y/y)\"\>", ",", "\<\"(y*z)\"\>", 
   ",", "\<\"(y-z)\"\>", ",", "\<\"(y+z)\"\>", ",", "\<\"(y/z)\"\>", 
   ",", "\<\"(-(-z))\"\>", ",", "\<\"(-z)\"\>", ",", "\<\"z\"\>", 
   ",", "\<\"(z*x)\"\>", ",", "\<\"(z-x)\"\>", ",", "\<\"(z+x)\"\>", 
   ",", "\<\"(z/x)\"\>", ",", "\<\"(z*y)\"\>", ",", "\<\"(z-y)\"\>", 
   ",", "\<\"(z+y)\"\>", ",", "\<\"(z/y)\"\>", ",", "\<\"(z*z)\"\>", 
   ",", "\<\"(z-z)\"\>", ",", "\<\"(z+z)\"\>", ",", "\<\"(z/z)\"\>"}], 
  "}"}]], "Output",
 CellLabel->
  "Out[113]=",ExpressionUUID->"5ee56659-76b6-4654-8ccb-3712768929e6"]
}, Open  ]],

Cell[TextData[{
 "It is left to the reader to generalize and combine these functions into a \
single function that accepts ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "2dd6cd88-3e1e-418a-882c-aa88c164d2cb"],
 " as an argument and returns the list of all well-formed formulae with ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "49ec5a47-34c2-4986-af7a-d23e61ea36f1"],
 " or fewer symbols."
}], "Text",ExpressionUUID->"2f327cbc-33ed-4c4c-835b-16e32b6789ff"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computations and Explorations 2", "Subsection",
 CellTags->
  "SolutionsCE2",ExpressionUUID->"057e37e3-7b28-45b6-a635-346d212839eb"],

Cell["\<\
Determine which Fibonacci numbers are divisible by 5, which are divisible by \
7, and which are divisible by 11. Prove that your conjectures are correct. \
\>", "Problem",ExpressionUUID->"1d4c9ec9-1906-4014-98a0-3e2f58f2f682"],

Cell[TextData[{
 StyleBox["Solution:",
  FontSlant->"Italic"],
 " We use the ",
 StyleBox[ButtonBox["Fibonacci",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Fibonacci"], "FunctionLink"],
 " function to determine the Fibonacci numbers. This function applied to an \
integer ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8b961d6b-65db-4386-907a-1ebd55f36cba"],
 " returns the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "076e45f0-9a59-40c5-9baf-35f2d6cb4e66"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " Fibonacci number."
}], "Text",ExpressionUUID->"e53f87d5-5666-492b-8176-35ba1a9f52f0"],

Cell[TextData[{
 "To answer the first part of the question, we want to know which Fibonacci \
numbers are divisible by 5. That is, we want to determine for which ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "b7b29ce9-62eb-4b7b-be33-6d7ee1d7b273"],
 " is the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8dc2bc92-7ad8-4303-a15a-a33666fcd8d4"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " Fibonacci divisible by 5. We will construct a list consisting of those \
indices between 1 and 50 for which the corresponding Fibonacci number is \
divisible by 5."
}], "Text",ExpressionUUID->"b05d905d-cf83-48fb-ba5b-d028441981a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reap", "[", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"n", "=", "1"}], ",", 
    RowBox[{"n", "\[LessEqual]", "50"}], ",", 
    RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"Divisible", "[", 
       RowBox[{
        RowBox[{"Fibonacci", "[", "n", "]"}], ",", "5"}], "]"}], ",", 
      RowBox[{"Sow", "[", "n", "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}],
   "]"}]], "Input",
 CellLabel->
  "In[114]:=",ExpressionUUID->"272d77ee-ccb6-4857-bee8-6d74f6a435d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"Null", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
     "5", ",", "10", ",", "15", ",", "20", ",", "25", ",", "30", ",", "35", 
      ",", "40", ",", "45", ",", "50"}], "}"}], "}"}]}], "}"}]], "Output",
 CellLabel->
  "Out[114]=",ExpressionUUID->"dfb1b27d-a1a6-4510-9a28-de1d6d1b629c"]
}, Open  ]],

Cell[TextData[{
 "This list suggests that the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "6cb14353-09ad-4fcc-b2a8-aa202fd5df37"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " Fibonacci number is divisible by 5 when ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "3ae11661-4da6-4304-a5df-baa3a2f48a08"],
 " is. To obtain more evidence, we will design a function to look for \
counterexamples to the assertion: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "n"], TraditionalForm]],ExpressionUUID->
  "dccbfb70-ac34-45e7-9067-d0d897cad473"],
 " is divisible by 5 if and only if ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "4833d2dc-d6c5-4026-bf93-1f37d19e8f9e"],
 " is divisible by 5."
}], "Text",ExpressionUUID->"3ba67443-3e77-48cc-9ef1-a05bc74a967c"],

Cell[TextData[{
 "We first create a function that accepts a positive integer ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "a3be50c5-cc68-4471-8a90-0a35993060b4"],
 " and checks whether or not ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "4abbc020-c507-493f-b6a1-9247e3cab780"],
 " is a counterexample of the assertion that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "n"], TraditionalForm]],ExpressionUUID->
  "8fd43e3d-033c-419a-9406-cdcf8a2f6636"],
 " is divisible by 5 if and only if ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "99593018-55bf-4ed0-bd05-34129c72606e"],
 " is divisible by 5. If either ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "n"], TraditionalForm]],ExpressionUUID->
  "027745d0-ded7-472e-8737-28b0c04bc79f"],
 " is not divisible by 5 when ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "4c3bb664-765c-4541-9c51-6113a95933bd"],
 " is, or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "n"], TraditionalForm]],ExpressionUUID->
  "d42467f8-4bcc-4ee1-b9b3-95fc45a65e29"],
 " is divisible by 5 when ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f4d215b1-991e-47b9-bd6a-841b30997c3c"],
 " is not, then this function will print a message to that effect. "
}], "Text",ExpressionUUID->"631c7b9d-44cc-4606-be82-25deff731c7e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"checkFib5", "[", "n_Integer", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "F", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"F", "=", 
      RowBox[{"Fibonacci", "[", "n", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Divisible", "[", 
         RowBox[{"F", ",", "5"}], "]"}], "&&", 
        RowBox[{"Not", "[", 
         RowBox[{"Divisible", "[", 
          RowBox[{"n", ",", "5"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Fn=\>\"", ",", "F", ",", 
         "\"\< is not divisible by 5, but n=\>\"", ",", "n", ",", 
         "\"\< is\>\""}], "]"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Divisible", "[", 
         RowBox[{"n", ",", "5"}], "]"}], "&&", 
        RowBox[{"Not", "[", 
         RowBox[{"Divisible", "[", 
          RowBox[{"F", ",", "5"}], "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Fn=\>\"", ",", "F", ",", "\"\< is divisible by 5, but n=\>\"", 
         ",", "n", ",", "\"\< is not\>\""}], "]"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->
  "In[115]:=",ExpressionUUID->"5e1d5f33-d106-4009-ac3f-4cb65af54ea6"],

Cell[TextData[{
 "In order to check as many Fibonacci numbers as possible, while not spending \
too much time on the process, we will apply the ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " function. The first argument to ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " is an expression to be evaluated. In this case, the expression will be an \
infinite ",
 StyleBox[ButtonBox["For",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/For"], "FunctionLink"],
 " loop that applies ",
 StyleBox["checkFib5", "Code"],
 ". We make the loop infinite by entering ",
 StyleBox[ButtonBox["True",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/True"], "FunctionLink"],
 " for the test. The second argument to ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " is the time, in seconds, that the expression should be allowed to run. ",
 StyleBox[ButtonBox["TimeConstrained",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TimeConstrained"], "FunctionLink"],
 " also accepts a third, optional, argument, that is evaluated if the first \
expression fails to finish. If the third argument is not given, the output in \
case the time runs out will be ",
 StyleBox[ButtonBox["$Aborted",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/$Aborted"], "FunctionLink"],
 ". We will use a ",
 StyleBox[ButtonBox["Print",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Print"], "FunctionLink"],
 " statement as the third argument to report the largest value of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "9d97d969-4afe-47bd-a1ee-0975214803c8"],
 " for which ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "n"], TraditionalForm]],ExpressionUUID->
  "265a9781-1973-4a60-b8cc-73d9bc50a69c"],
 " was checked. Note that we subtract one from the value of the loop variable \
since we cannot be certain whether the current value was in fact checked or \
if it was aborted."
}], "Text",ExpressionUUID->"159dbad7-f6c5-4b4f-8b47-ef5761b82330"],

Cell["Below, we allow the test to run for 3 seconds.", "Text",ExpressionUUID->"24e8cf95-f507-4ef4-86bf-44322e374568"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimeConstrained", "[", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"n", "=", "1"}], ",", "True", ",", 
     RowBox[{"n", "++"}], ",", 
     RowBox[{"checkFib5", "[", "n", "]"}]}], "]"}], ",", "3", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Checked through n=\>\"", ",", 
     RowBox[{"n", "-", "1"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->
  "In[116]:=",ExpressionUUID->"fa4b0c97-4386-42d7-b2b1-8f77073c452d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Checked through n=\"\>", "\[InvisibleSpace]", "74373"}],
  SequenceForm["Checked through n=", 74373],
  Editable->False]], "Print",
 CellLabel->
  "During evaluation of \
In[116]:=",ExpressionUUID->"ee2c19fc-f4cc-4574-a73d-be93b317e314"]
}, Open  ]],

Cell["\<\
How many Fibonacci numbers can be checked will depend on your computer. \
Proving the conjecture, as well as forming and proving conjectures for 7 and \
11, is left to the reader.\
\>", "Text",ExpressionUUID->"900d79ec-223d-4072-91f9-eb1002622371"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "Section",
 CellTags->"Exercises",ExpressionUUID->"03f9cf8b-2e77-4139-9d94-7ef15e26e7b2"],

Cell[CellGroupData[{

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to find and prove formulas for the sum of the first ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "03c9c85d-469f-414c-932c-349fc6830926"],
 " ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f11c8f6b-03ea-4df8-88cd-49e32b011cdb"],
 StyleBox["th",
  IgnoreSpellCheck->True],
 " powers of positive integers for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"n", "=", "4"}], ",", "5", ",", "6", ",", "7", ",", "8", ",", "9",
     ",", "10"}], TraditionalForm]],ExpressionUUID->
  "7bdfae11-5098-4ea7-b6d3-76f2973ee960"],
 "."
}], "Item1Exercise",ExpressionUUID->"de208d8b-d141-4aad-a4c8-6892dd5d3829"],

Cell[TextData[{
 "For what positive integers ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "d2fd2a88-41bd-4c2e-be01-7ba8af1546b2"],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["n", "k"], "-", "n"}], TraditionalForm]],ExpressionUUID->
  "f9f4503b-cfe3-44c5-9e3c-6eca23d1d1ff"],
 " divisible by ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "69f75363-d8ee-44ab-9b87-daeff8a3c050"],
 " for all positive integers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "d9ae824a-1833-49dd-98cc-9d9a028f9865"],
 "?"
}], "Item1Exercise",ExpressionUUID->"8b5169c4-8b7b-4a74-b6b7-81c8aca95a48"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to help you find and prove the formulas sought in Exercises 9, 10, and 11 \
of Section 5.1 of the text. Do not use the symbolic capabilities of the ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " command to form your conjectures."
}], "Item1Exercise",ExpressionUUID->"6113f672-331f-4eec-9a81-b6a9fcecc313"],

Cell[TextData[{
 "Find integers ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]],ExpressionUUID->
  "798eb7cc-c325-44d5-803e-0e92d8814661"],
 " and ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],ExpressionUUID->
  "7692001a-e8bb-482d-b074-450f21be3aa4"],
 " such that ",
 Cell[BoxData[
  FormBox["d", TraditionalForm]],ExpressionUUID->
  "c7b1f8d4-2596-4c3c-a5e5-ab29d06a6fd5"],
 " divides ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["a", 
     RowBox[{"n", "+", "1"}]], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "+", "1"}], ")"}], 
     RowBox[{
      RowBox[{"2", "n"}], "-", "1"}]]}], TraditionalForm]],ExpressionUUID->
  "ad8c3f34-6376-4d64-8338-9476eea7b239"],
 " for all positive integers ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "f5f713aa-b277-436a-a91e-51128ac5bcb9"],
 ". (Exercises 36 and 37 in Section 5.1 indicate that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "=", "4"}], ",", 
    RowBox[{"d", "=", "21"}]}], TraditionalForm]],ExpressionUUID->
  "a3243b60-e593-4248-ae4c-829fa50f3eba"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"a", "=", "11"}], ",", 
    RowBox[{"d", "=", "133"}]}], TraditionalForm]],ExpressionUUID->
  "e34198ed-e39a-4e52-b7be-6df6f9c1924a"],
 " are two such pairs.)"
}], "Item1Exercise",ExpressionUUID->"5c84fafc-8b93-415f-8279-6fc69b54aca6"],

Cell[TextData[{
 "The results of Supplementary Exercises 4 and 5 of the text suggest a more \
general conjecture. Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["Sum",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Sum"], "FunctionLink"],
 " function to produce evidence for this conjecture."
}], "Item1Exercise",ExpressionUUID->"69a79f3a-7c4d-4058-ae5f-4d3cf6ec5d05"],

Cell[TextData[{
 "Use the ",
 StyleBox["postageBasis", "Code"],
 " algorithm from Section 5.2 of this manual to find the smallest ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "8ceba588-488e-47ba-8b62-ec73d9f9a838"],
 " such that every amount of postage of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "70ad614e-bda1-4c08-b377-f1f9ae95489f"],
 " cents or more can be made from stamps worth 78 cents and $5.95."
}], "Item1Exercise",ExpressionUUID->"fee1b00f-a640-4681-bacc-9f3a87a8e7c5"],

Cell[TextData[{
 "Write a function that accepts two stamp denominations as input and returns \
the smallest ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "616d1c99-ed24-4793-8e1f-6513f338b52d"],
 " such that every amount of postage of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "ee4f5a03-f035-4c19-b767-803da838497f"],
 " cents or more can be made from the given denominations, or returns ",
 StyleBox[ButtonBox["$Failed",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/$Failed"], "FunctionLink"],
 " if it cannot find such an ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "20886ca0-943b-4939-96db-7a6b7df0938d"],
 ". Use your function to make a conjecture that describes for which pairs of \
denominations such an ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "4c617c1c-0540-4969-8455-38504c16a9e4"],
 " exists and for which there is no such ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "5d021487-dfa1-4cce-83f4-833820e3632b"],
 "."
}], "Item1Exercise",ExpressionUUID->"b31ce5d3-1628-43e0-83f9-ef3ff00225a5"],

Cell[TextData[{
 "Write a function to recursively build a set from the following definition: \
basis step: 2 and 3 belong to the set; recursive step: if ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],ExpressionUUID->
  "cbdbd98f-7c9b-4b07-9fb6-cf23aaf95483"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "de85d1de-14de-48a0-b5fa-396b3cbad083"],
 " are members, then ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[CenterDot]", "y"}], TraditionalForm]],ExpressionUUID->
  "2f0cebe4-1861-43ef-b035-83c42979b3f0"],
 " is a member."
}], "Item1Exercise",ExpressionUUID->"1a492b81-8661-476d-87e7-42a5087073ca"],

Cell[TextData[{
 "Use the ",
 StyleBox[ButtonBox["Timing",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Timing"], "FunctionLink"],
 " function to compare the performance of ",
 StyleBox["gR", "Code"],
 " and ",
 StyleBox["gF", "Code"],
 " from Section 5.3. Graph the time performance for the two functions. (Be \
sure to ",
 StyleBox[ButtonBox["Clear",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Clear"], "FunctionLink"],
 " ",
 StyleBox["gR", "Code"],
 " prior to every execution so that the comparison is fair.)"
}], "Item1Exercise",ExpressionUUID->"5e810a98-89ad-46d1-9fa7-6d10830f82f9"],

Cell[TextData[{
 "Write a function that accepts two stamp denominations and returns all \
amounts of postage that can be paid with up to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "4c02169a-5638-423c-9d50-d15ab8635539"],
 " stamps."
}], "Item1Exercise",ExpressionUUID->"e1a03736-b0bd-48ec-9f3c-7ed2a1a994b4"],

Cell[TextData[{
 "The solution provided for Computer Projects 2 is inefficient as a means of \
finding all well-formed formulae involving at most ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "7aaf7a38-8715-4887-97da-48adec3016a6"],
 " symbols. This is because formulae which already have more symbols than the \
maximum are retained and used to produce even longer formulae. In particular, \
after ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "de963e1b-f02f-4376-a9dc-b6189d9d099a"],
 " iterations, the resulting set includes formulae of up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"n", "+", "1"}]], "-", "1"}], TraditionalForm]],ExpressionUUID->
  "84efe0b8-6181-4654-adf8-7fd2774512fe"],
 " symbols (but not all such formulae). Modify the approach taken in the \
solution to Computer Projects 2 so that strings that include more than ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "7b8a9977-e38c-4c7f-b5d8-d5632b18bf71"],
 " symbols are pruned at each step of the recursion."
}], "Item1Exercise",ExpressionUUID->"0ed4aa49-8e01-4548-b415-efcfe367c009"],

Cell["\<\
Write a function to compute the number of partitions of a positive integer \
(see Exercise 49 in Section 5.3 of the text).\
\>", "Item1Exercise",ExpressionUUID->"6faa76ad-fcc3-4f8e-ad7b-717795b3c57a"],

Cell["\<\
Write a function to compute Ackermann\[CloseCurlyQuote]s function (see the \
prelude to Exercise 50 in Section 5.3).\
\>", "Item1Exercise",ExpressionUUID->"25b801d7-08db-47df-900e-f070ad2e45bb"],

Cell[TextData[{
 "Implement Algorithm 3 for computing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"gcd", "(", 
    RowBox[{"a", ",", "b"}], ")"}], TraditionalForm]],ExpressionUUID->
  "3d904b42-3cde-49cd-83ce-d01cd39d21d3"],
 " from Section 5.4 of the text."
}], "Item1Exercise",ExpressionUUID->"352b7548-28c4-41f3-814f-c8b35b382603"],

Cell["\<\
Implement Algorithm 5, the recursive linear search algorithm, from Section \
5.4 of the text. \
\>", "Item1Exercise",ExpressionUUID->"3ea49edc-efa6-4085-b8cc-95e854d72945"],

Cell["\<\
Implement Algorithm 6, the recursive binary search algorithm, from Section \
5.4 of the text. \
\>", "Item1Exercise",ExpressionUUID->"e3ce4af2-61ef-4f48-8306-02a055efc770"],

Cell[TextData[{
 "Compare the performance of your implementations of Algorithm 5 and \
Algorithm 6 as follows: for a variety of values of ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "af908d40-4aeb-4386-a3a3-51cbff7b2995"],
 ", let ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]],ExpressionUUID->
  "0bc1442a-2ddd-42e4-a31a-38786c849259"],
 " be the list of integers from 1 to ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "7d18f8f9-2942-4cfa-af1b-140ba416133a"],
 ". Randomly choose 100 integers between 1 and ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "b53a4869-8318-42d8-b753-1b53af332d74"],
 " and measure the average of the times taken for each algorithm to find the \
randomly chosen integers. Graph ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "11c16817-ec90-4270-850e-ea8b7a2e2ffd"],
 " versus the average times. (",
 Cell[BoxData[
  RowBox[{
   RowBox[{"RandomInteger", "[", "{"}], 
   StyleBox["min", "CodeVar"], ",", 
   StyleBox["max", "CodeVar"], "}", ",", 
   StyleBox["count", "CodeVar"], "]"}]], "myCode",ExpressionUUID->
  "87d30bd4-c8af-43d6-8468-105335aee8c0"],
 " will output a list of ",
 StyleBox["count", "CodeVar"],
 " randomly chosen integers between ",
 StyleBox["min", "CodeVar"],
 " and ",
 StyleBox["max", "CodeVar"],
 ".)"
}], "Item1Exercise",ExpressionUUID->"3223ab2a-abd6-4f8e-b9ab-cc6fe17d2eb5"],

Cell["\<\
Create three functions to compute Fibonacci numbers: an iterative function, a \
recursive function that stores values, and a recursive function that does not \
store values. Base your functions on Algorithms 7 and 8 in Section 5.4 of the \
text. Create a graph illustrating the time performance of the three functions.\
\>", "Item1Exercise",ExpressionUUID->"227ee954-2f14-4fbd-8606-55a5d9b7a215"],

Cell["\<\
Implement quick sort, described in the prelude to Exercise 50 in Section 5.4 \
of the text. Compare the performance with the merge sort implemented in this \
manual. \
\>", "Item1Exercise",ExpressionUUID->"85785fdb-afb9-461d-86c5-a3c57814d83b"],

Cell["\<\
Implement the algorithm described in Supplementary Exercise 44 for expressing \
a rational number as a sum of Egyptian fractions. \
\>", "Item1Exercise",ExpressionUUID->"cd4b3c66-829e-4c8c-ab6c-3c3797c512a1"],

Cell[TextData[{
 "Use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to study the McCarthy 91 function. (See the prelude to problem 45 in the \
Supplementary Exercises.)"
}], "Item1Exercise",ExpressionUUID->"a9e306a2-9d22-4d2c-a385-8eeb6fd3dbcb"],

Cell["\<\
Write a function in the Wolfram Language that models Knuth\[CloseCurlyQuote]s \
up-arrow notation (see Writing Project 6). Be careful when evaluating this \
function, as the value grows very quickly.\
\>", "Item1Exercise",ExpressionUUID->"f3e3ca3b-b7da-473c-91d7-f984e917d8d1"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Working",
WindowSize->{725, 850},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
DockedCells->Cell[
  BoxData[
   TagBox[
    GridBox[{{"\"Exploring Discrete Mathematics with Mathematica\"", 
       ActionMenuBox[
       "\"Navigation\"", {
        "\"CloseAll\"" :> Module[{$CellContext`DJSection$}, SelectionMove[
             SelectedNotebook[], All, Notebook]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken["OpenCloseGroup"]], {$CellContext`DJSection$, {
              "Section1a", "Section1b", "Section1c", "Section3a", "Section3b",
                "Section3c", "Section3d", "Section3e", "Section3f", 
               "Section4a", "Section4b", "Section4c", "Section5a", 
               "Section5b", "SolutionsCE2", "SolutionsCP2", "Section1", 
               "Section2", "Section3", "Section4", "Section5", "Solutions", 
               "Exercises"}}]; SelectionMove[
             SelectedNotebook[], Before, Notebook]], "\"Section1\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Section1"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section2\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Section2"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section3\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Section3"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section4\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Section4"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Section5\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Section5"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Solutions\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Solutions"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Exercises\"" :> 
         Module[{}, Do[NotebookLocate[$CellContext`DJSection]; FrontEndExecute[
                FrontEndToken[
                "SelectionCloseAllGroups"]], {$CellContext`DJSection, {
               "Section1", "Section2", "Section3", "Section4", "Section5", 
                "Solutions", "Exercises"}}] NotebookLocate["Exercises"]; 
           FrontEndExecute[
             FrontEndToken["SelectionCloseAllGroups"]]; FrontEndExecute[
             FrontEndToken["SelectionOpenAllGroups"]]; SelectionMove[
             SelectedNotebook[], Before, Cell]], "\"Open All\"" :> 
         Module[{$CellContext`DJSection$}, 
           Do[NotebookLocate[$CellContext`DJSection$]; FrontEndExecute[
               FrontEndToken[
               "SelectionOpenAllGroups"]], {$CellContext`DJSection$, {
              "Exercises", "Section1", "Section1a", "Section1b", "Section1c", 
               "Section2", "Section3", "Section3a", "Section3b", "Section3c", 
               "Section3d", "Section3e", "Section3f", "Section4", "Section4a",
                "Section4b", "Section4c", "Section5", "Section5a", 
               "Section5b", "Solutions", "SolutionsCE2", "SolutionsCP2"}}] 
           SelectionMove[
             SelectedNotebook[], Before, Notebook]]}]}}, 
     GridBoxAlignment -> {
      "Columns" -> {Left, Baseline}, "Rows" -> {Right, Baseline}}, AutoDelete -> 
     False, GridBoxItemSize -> {"Columns" -> {
         Scaled[0.8], 
         Scaled[0.2]}}], "Grid"]], "DockedCell", FontFamily -> "Times"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
Magnification->1,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Book"}, "Textbook.nb", CharacterEncoding -> 
       "UTF-8"]]], 
   Cell[
    StyleData[All, "Printout"], PageWidth -> PaperWidth, 
    CellHorizontalScrolling -> True, 
    CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
    ShowAutoStyles -> False, 
    AutoStyleOptions -> {"HighlightMisspelledWords" -> False}, ScriptMinSize -> 
    9, MenuSortingValue -> 1500, 
    PrivateFontOptions -> {"FontType" -> "Outline"}, Magnification -> 1], 
   Cell[
    StyleData["Title"], Editable -> False, ShowCellBracket -> Automatic, 
    CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> False, 
    DefaultNewInlineCellStyle -> {}, LanguageCategory -> "NaturalLanguage", 
    FontFamily -> "Helvetica", FontSize -> 25, FontWeight -> "Bold", 
    FontColor -> GrayLevel[0.137255]], 
   Cell[
    StyleData["BookChapterTitle", StyleDefinitions -> StyleData["Title"]], 
    CellFrame -> {{0, 0}, {1, 1}}, CellDingbat -> Cell[
      BoxData[
       GraphicsBox[{{
          RGBColor[0.09375, 0.570313, 0.816406], 
          RectangleBox[{0, 0}]}, {
          GrayLevel[1], FontSize -> 35, FontWeight -> Bold, FontFamily -> 
          "Helvetica", 
          InsetBox[
           CounterBox["ChapterNumber"], {0.5, 0.45}, {Center, Center}]}}, 
        ImageSize -> {70, 70}]], "Output"], 
    CellMargins -> {{100, 0}, {20, 20}}, CellFrameColor -> GrayLevel[1]], 
   Cell[
    StyleData["DockedCell"], CellMargins -> {{12, 12}, {20, 0}}, 
    CellGroupingRules -> "TitleGrouping", 
    ConversionRules :> {"TeX" -> {"\n\\chapter{", "}"}}, 
    TaggingRules :> {"CounterSettings" -> {"CounterTarget" -> "CellGroup"}}, 
    PageBreakAbove -> False, PageBreakBelow -> False, LineSpacing -> {1, 2}, 
    MenuSortingValue -> 1105, FontFamily -> "Helvetica", FontSize -> 27, 
    FontWeight -> "Bold", Background -> RGBColor[0.09375, 0.570313, 0.816406],
     CounterBoxOptions -> {
     CounterFunction :> Identity}, $CellContext`DefaultReturnCreatedCellStyle -> 
    "Section"], 
   Cell[
    StyleData["FunctionLink"], ConversionRules :> {"TeX" -> {{"", 
         $CellContext`ExportAsHyperRef[], ""}, {"", Automatic, ""}}}, 
    MenuSortingValue -> 1105, ButtonStyleMenuListing -> None, FontFamily -> 
    "Courier", FontVariations -> {"Underline" -> True}, FontColor -> 
    RGBColor[0, 0, 1], 
    ButtonBoxOptions -> {Active -> True, ButtonFunction :> (FrontEndExecute[{
         FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> ButtonData}], 
   Cell[
    StyleData["Problem"], CellMargins -> {{40, 12}, {15, 15}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 15010}, 
    ConversionRules :> {
     "TeX" -> {{"", Automatic, ""}, {"\n\n", Automatic, ""}}}, 
    TaggingRules :> {
     "ExtraConversionRules" -> {"General" -> {"RestartList" -> False}}}], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item1Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {30, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item1Exercise", 
       CounterAssignments -> {{"Item2Exercise", 0}}, MenuSortingValue -> 
       4100], 
      Cell[
       StyleData["Item1Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{35, 12}, {3, 5}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["ExerciseContinuation"], CellMargins -> {{50, 12}, {1, 3}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17000}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, MenuSortingValue -> 4101], 
      Cell[
       StyleData["ExerciseContinuation", "Printout"], 
       CellMargins -> {{35, 12}, {1, 3}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item2Exercise"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {32, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{75, 12}, {1, 2}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 17100}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterIncrements -> "Item2Exercise", MenuSortingValue -> 4200, 
       CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}], 
      Cell[
       StyleData["Item2Exercise", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item2Exercise"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Bold"], 
       CellMargins -> {{50, 12}, {1, 2}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, CounterBoxOptions -> {CounterFunction :> (Part[
           CharacterRange["a", "z"], #]& )}]}, Open]], 
   Cell[
    StyleData["ExerciseEquation"], CellMargins -> {{36, 12}, {7, 7}}, 
    CellGroupingRules -> {"GroupTogetherNestedGrouping", 17200}, 
    CellHorizontalScrolling -> True, 
    CellFrameLabels -> {{None, None}, {None, None}}, DefaultFormatType -> 
    TraditionalForm, InputAutoReplacements -> {}, TextAlignment -> Center, 
    MenuSortingValue -> 4300, 
    ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    StyleData["myCode"], CellMargins -> {{66, 10}, {5, 10}}, 
    StyleKeyMapping -> {"=" -> "WolframAlphaShort"}, Evaluatable -> False, 
    CellGroupingRules -> "InputGrouping", TextClipboardType -> "InputText", 
    PageBreakWithin -> False, GroupPageBreakWithin -> False, 
    DefaultFormatType -> DefaultInputFormatType, ContextMenu -> 
    FEPrivate`FrontEndResource["ContextMenus", "myCode"], ShowAutoStyles -> 
    True, "TwoByteSyntaxCharacterAutoReplacement" -> True, 
    HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"}, 
    AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
    PasteAutoQuoteCharacters -> {}, LanguageCategory -> "Mathematica", 
    FormatType -> InputForm, NumberMarks -> True, 
    LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> "Code", 
    MenuSortingValue -> 1495, MenuCommandKey -> "8", FontWeight -> 
    "Bold", $CellContext`StripStyleOnPaste -> True], 
   Cell[
    StyleData["CodeVar"], DefaultFormatType -> DefaultInputFormatType, 
    LineBreakWithin -> False, MenuSortingValue -> 10000, FontWeight -> "Bold",
     FontSlant -> "Italic", FontColor -> GrayLevel[0.4]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, ShowCellBracket -> 
       Automatic, CellMargins -> {{12, 12}, {3, 24}}, 
       CellGroupingRules -> {"SectionGrouping", 30}, 
       ConversionRules :> {
        "TeX" -> {"\n\\section{", "}"}, 
         "HTML" -> {"<h3 class=\"Section\">", "</h3>"}}, 
       TaggingRules :> {
        "CounterSettings" -> {
          "CounterFormat" -> {"BookChapterNumber", ".", "Section"}, 
           "CounterTarget" -> "Cell", "XRefPrefix" -> "Section"}}, 
       PageBreakBelow -> False, CellFrameMargins -> {{8, 8}, {4, 6}}, 
       CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406], TabSpacings -> 
       2.1, CounterIncrements -> {
        "Section", "SectionHeader", "SubsectionHeader", "SubsubsectionHeader",
          "SubsubsubsectionHeader"}, FontFamily -> "Helvetica", FontSize -> 
       16, FontWeight -> "Bold", Background -> GrayLevel[0.999985]], 
      Cell[
       StyleData["Section", "Printout"], CellFrame -> {{4, 0}, {0, 0.5}}, 
       CellMargins -> {{2, 2}, {3, 21}}, CellFrameMargins -> {{6, 6}, {3, 5}},
        CellFrameColor -> RGBColor[0.09375, 0.570313, 0.816406]], 
      Cell[
       StyleData["Section", "DoubleSpacedPrintout"], 
       CellFrame -> {{4, 0}, {0, 0.5}}, CellMargins -> {{2, 2}, {3, 21}}, 
       CellFrameMargins -> {{6, 6}, {3, 5}}, CellFrameColor -> 
       RGBColor[0.09375, 0.570313, 0.816406], FontSize -> 14]}, Open]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsection"], CellDingbat -> None, 
       CellMargins -> {{12, 12}, {0, 6}}, 
       CellElementSpacings -> {"ClosedGroupTopMargin" -> 12}, 
       CellGroupingRules -> {"SectionGrouping", 50}, 
       ConversionRules :> {
        "TeX" -> {"\n\\subsubsection{", "}"}, 
         "HTML" -> {"<h5 class=\"Subsubsection\">", "</h5>"}}, PageBreakBelow -> 
       False, CellFrameLabelMargins -> 4, 
       CounterIncrements -> {
        "Subsubsection", "SubsubsectionHeader", "SubsubsubsectionHeader"}, 
       FontFamily -> "Helvetica", FontSize -> 11, FontWeight -> "Bold", 
       FontSlant -> "Italic"], 
      Cell[
       StyleData["Subsubsection", "Printout"], FontFamily -> "Helvetica", 
       FontSize -> 11, FontWeight -> "Bold", FontSlant -> "Italic"]}, Open]], 
   
   Cell[
    StyleData["Equation"], CellMargins -> {{26, 10}, {7, 7}}, 
    ConversionRules :> {
     "HTML" -> {{"", ""}, {"<p class=\"Equation\">", "</p>"}}}, 
    CellHorizontalScrolling -> True, DefaultFormatType -> TraditionalForm, 
    InputAutoReplacements -> {}, TextAlignment -> Center, CounterIncrements -> 
    "Equation", ButtonBoxOptions -> {Appearance -> {Automatic, None}}], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Item1Numbered"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Numbered"], "."}], CellSize -> {32, Inherited}, 
         TextAlignment -> Right, 
         TextJustification -> (FontWeight -> "Plain")], 
       CellMargins -> {{36, 12}, {1, 3}}, 
       CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
       ConversionRules :> {{"TeX" -> {"\n\\item ", ""}}, {
         "HTML" -> {"<li>", "</li>"}}}, 
       TaggingRules :> {
        "ExtraConversionRules" -> {
          "General" -> {"NestingLevel" -> 30}, 
           "TeX" -> {"CellGroupEnvironment" -> "enumerate"}, 
           "HTML" -> {"CellGroupEnvironment" -> "ol"}}}, 
       CellFrameLabels -> {{None, None}, {None, None}}, CellFrameLabelMargins -> 
       6, TextJustification -> 1, CounterIncrements -> "Item1Numbered", 
       CounterAssignments -> {{"Item2Numbered", 0}, {"Item3Numbered", 0}}], 
      Cell[
       StyleData["Item1Numbered", "Printout"], CellDingbat -> Cell[
         TextData[{
           CounterBox["Item1Numbered"], "."}], CellSize -> {20, Inherited}, 
         TextAlignment -> Right, FontWeight -> "Plain"], 
       CellMargins -> {{24, 2}, {1, 2}}, CellFrameLabelMargins -> 3, 
       TextJustification -> 1]}, Open]], 
   Cell[
    StyleData["InitializationCell"], Background -> GrayLevel[1]], 
   Cell[
    StyleData["Item1"], TextJustification -> 1], 
   Cell[
    StyleData["Item1Printout"], TextJustification -> 1, MenuSortingValue -> 
    10000], 
   Cell[
    StyleData["Code"], FormatType -> InputForm]}, Visible -> False, 
  FrontEndVersion -> 
  "11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, 2018)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Section1"->{
  Cell[1526, 49, 123, 1, 55, "Section",ExpressionUUID->"daddaeef-b204-47dd-adda-fc8af60412ef",
   CellTags->"Section1"]},
 "Section1a"->{
  Cell[2147, 66, 120, 1, 32, "Subsection",ExpressionUUID->"23439bcd-c311-42a7-bde2-436ac6d76ec8",
   CellTags->"Section1a"]},
 "Section1b"->{
  Cell[46453, 1308, 120, 1, 32, "Subsection",ExpressionUUID->"bd31a980-0692-4a77-a89b-9fff71ffe5be",
   CellTags->"Section1b"]},
 "Section1c"->{
  Cell[62504, 1826, 113, 1, 32, "Subsection",ExpressionUUID->"2351ad9f-4f6d-45e7-8cda-b44fa444c1e1",
   CellTags->"Section1c"]},
 "Section2"->{
  Cell[70455, 2080, 135, 1, 55, "Section",ExpressionUUID->"2abca2a8-1a9c-471b-8a26-5a91e638b1cd",
   CellTags->"Section2"]},
 "Section3"->{
  Cell[97616, 2855, 147, 1, 55, "Section",ExpressionUUID->"f7bb09c9-e3df-4653-a631-0a718b3538f3",
   CellTags->"Section3"]},
 "Section3a"->{
  Cell[98017, 2868, 128, 1, 32, "Subsection",ExpressionUUID->"3c6f5a8b-3705-48ed-a025-2265f2e96a1b",
   CellTags->"Section3a"]},
 "Section3b"->{
  Cell[112182, 3300, 128, 1, 32, "Subsection",ExpressionUUID->"8e0d04b2-6c71-40ef-abbb-9335e015d7c0",
   CellTags->"Section3b"]},
 "Section3c"->{
  Cell[120998, 3569, 121, 1, 32, "Subsection",ExpressionUUID->"a487e06b-c4e0-4a04-b37b-bef3df9bd215",
   CellTags->"Section3c"]},
 "Section3d"->{
  Cell[137323, 4073, 141, 1, 32, "Subsection",ExpressionUUID->"85773493-3e26-4a68-8bfd-98c3f51828fa",
   CellTags->"Section3d"]},
 "Section3e"->{
  Cell[146113, 4335, 126, 1, 32, "Subsection",ExpressionUUID->"0ec5e852-727e-4b2e-96fa-1d963cdc75de",
   CellTags->"Section3e"]},
 "Section3f"->{
  Cell[154038, 4579, 117, 1, 32, "Subsection",ExpressionUUID->"8c06c1de-403c-4d66-8667-6827ffe6c624",
   CellTags->"Section3f"]},
 "Section4"->{
  Cell[165739, 4890, 121, 1, 55, "Section",ExpressionUUID->"2180dab6-1e74-4757-a5a0-cc74cfda0950",
   CellTags->"Section4"]},
 "Section4a"->{
  Cell[166395, 4906, 123, 1, 32, "Subsection",ExpressionUUID->"de33e1a3-92e2-487d-a047-25efa50a43f2",
   CellTags->"Section4a"]},
 "Section4b"->{
  Cell[638449, 18542, 124, 1, 32, "Subsection",ExpressionUUID->"ead0cd15-0651-4117-9f09-0a2a14bcaa25",
   CellTags->"Section4b"]},
 "Section4c"->{
  Cell[690017, 19586, 111, 1, 32, "Subsection",ExpressionUUID->"c91b1a44-b74d-4892-9ba7-ac381e826d22",
   CellTags->"Section4c"]},
 "Section5"->{
  Cell[711119, 20214, 120, 1, 55, "Section",ExpressionUUID->"69df7f65-366b-4a08-83c9-f2a06830f7b9",
   CellTags->"Section5"]},
 "Section5a"->{
  Cell[711654, 20231, 134, 1, 35, "Subsection",ExpressionUUID->"9a92cf9b-fe4b-46de-ade5-03992d4017ab",
   CellTags->"Section5a"]},
 "Section5b"->{
  Cell[757111, 21689, 138, 1, 35, "Subsection",ExpressionUUID->"11ef5f4a-1134-4cc4-832f-0b4f9756b712",
   CellTags->"Section5b"]},
 "Solutions"->{
  Cell[766230, 21965, 170, 3, 55, "Section",ExpressionUUID->"6d1006d9-494f-46e3-93d5-734ef38c08ec",
   CellTags->"Solutions"]},
 "SolutionsCP2"->{
  Cell[766425, 21972, 126, 2, 32, "Subsection",ExpressionUUID->"79a55584-88c3-45d2-8b7f-6b3b1c2b4c1e",
   CellTags->"SolutionsCP2"]},
 "SolutionsCE2"->{
  Cell[789650, 22622, 138, 2, 32, "Subsection",ExpressionUUID->"057e37e3-7b28-45b6-a635-346d212839eb",
   CellTags->"SolutionsCE2"]},
 "Exercises"->{
  Cell[799389, 22895, 107, 1, 55, "Section",ExpressionUUID->"03f9cf8b-2e77-4139-9d94-7ef15e26e7b2",
   CellTags->"Exercises"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Section1", 829525, 23584},
 {"Section1a", 829663, 23587},
 {"Section1b", 829805, 23590},
 {"Section1c", 829950, 23593},
 {"Section2", 830094, 23596},
 {"Section3", 830234, 23599},
 {"Section3a", 830375, 23602},
 {"Section3b", 830520, 23605},
 {"Section3c", 830666, 23608},
 {"Section3d", 830812, 23611},
 {"Section3e", 830958, 23614},
 {"Section3f", 831104, 23617},
 {"Section4", 831249, 23620},
 {"Section4a", 831391, 23623},
 {"Section4b", 831537, 23626},
 {"Section4c", 831684, 23629},
 {"Section5", 831830, 23632},
 {"Section5a", 831973, 23635},
 {"Section5b", 832120, 23638},
 {"Solutions", 832267, 23641},
 {"SolutionsCP2", 832414, 23644},
 {"SolutionsCE2", 832567, 23647},
 {"Exercises", 832717, 23650}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 160, 3, 108, "BookChapterTitle",ExpressionUUID->"47c967f1-5845-4d56-9049-0a22dac73236",
 CounterAssignments->{{"ChapterNumber", 5}}],
Cell[CellGroupData[{
Cell[765, 29, 86, 0, 55, "Section",ExpressionUUID->"47cc0bc9-9590-4b22-ba32-b0ab1a3e37fb"],
Cell[854, 31, 635, 13, 65, "Text",ExpressionUUID->"0b4f3de8-6f51-45bd-a254-ad022bf3fe04"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1526, 49, 123, 1, 55, "Section",ExpressionUUID->"daddaeef-b204-47dd-adda-fc8af60412ef",
 CellTags->"Section1"],
Cell[1652, 52, 470, 10, 50, "Text",ExpressionUUID->"db70ca0a-9e5a-4a85-b0fb-ea42a68b6b01"],
Cell[CellGroupData[{
Cell[2147, 66, 120, 1, 32, "Subsection",ExpressionUUID->"23439bcd-c311-42a7-bde2-436ac6d76ec8",
 CellTags->"Section1a"],
Cell[2270, 69, 155, 2, 20, "Text",ExpressionUUID->"0eef5a25-f624-4a49-a6c3-943c0ea29dc8"],
Cell[2428, 73, 458, 14, 51, "Equation",ExpressionUUID->"c5f23668-0266-4bd3-8164-40852d0cd78e"],
Cell[2889, 89, 215, 3, 20, "Text",ExpressionUUID->"42d38fac-6a8a-432e-88a3-744e3b8c79cf"],
Cell[CellGroupData[{
Cell[3129, 96, 120, 0, 18, "Subsubsection",ExpressionUUID->"87ec4074-c168-4935-bf08-fee7e8d38899"],
Cell[3252, 98, 492, 13, 36, "Text",ExpressionUUID->"db9f157c-3001-41dd-93ec-6f32fd678e80"],
Cell[3747, 113, 695, 14, 66, "Text",ExpressionUUID->"d44b29db-47d6-4a0c-9c9f-03cc5aa675b3"],
Cell[4445, 129, 3313, 86, 100, "Text",ExpressionUUID->"9380b944-ed33-4994-9fb4-b5266949c9fc"],
Cell[7761, 217, 209, 3, 20, "Text",ExpressionUUID->"d8f8056c-df34-4083-ac72-3241426b5810"],
Cell[CellGroupData[{
Cell[7995, 224, 207, 5, 31, "Input",ExpressionUUID->"36f0e232-f861-40d3-8380-d9c88ddfe472"],
Cell[8205, 231, 107, 1, 31, "Output",ExpressionUUID->"ccb0b7b4-b1cf-4fb2-b015-d30e4f3776a5"]
}, Open  ]],
Cell[8327, 235, 992, 24, 51, "Text",ExpressionUUID->"0ac48196-e4a6-430e-8f58-1d4e84b64806"],
Cell[CellGroupData[{
Cell[9344, 263, 318, 9, 31, "Input",ExpressionUUID->"ced40932-4f97-4c44-9b5e-f20b5cfcbea9"],
Cell[9665, 274, 756, 12, 70, "Output",ExpressionUUID->"29528880-8bc5-4d4d-9f51-7a956bcc4772"]
}, Open  ]],
Cell[10436, 289, 867, 21, 51, "Text",ExpressionUUID->"84a2f348-5049-40bb-a42b-deccef75188b"],
Cell[CellGroupData[{
Cell[11328, 314, 375, 11, 31, "Input",ExpressionUUID->"c7a04e72-27e4-463f-a409-7b8448802ceb"],
Cell[11706, 327, 3212, 103, 146, "Output",ExpressionUUID->"d03a98a5-37f4-4f8a-9ff4-bf659ee20c74"]
}, Open  ]],
Cell[14933, 433, 550, 16, 20, "Text",ExpressionUUID->"1d6b9f61-36af-46ec-a370-86e787495344"],
Cell[15486, 451, 2695, 68, 128, "Text",ExpressionUUID->"584abdec-71ae-4a4e-858c-5421a45887f3"],
Cell[CellGroupData[{
Cell[18206, 523, 362, 10, 31, "Input",ExpressionUUID->"3e40bb71-13ce-4d6b-a131-2afcf17517b2"],
Cell[18571, 535, 7302, 135, 228, "Output",ExpressionUUID->"fb3f435f-33ca-477a-8a8f-c642d5d96e3a"]
}, Open  ]],
Cell[25888, 673, 488, 7, 50, "Text",ExpressionUUID->"d7a989c3-eda0-4423-9bc0-70c631912926"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26413, 685, 104, 0, 18, "Subsubsection",ExpressionUUID->"656e596d-897d-4205-9ec6-c9c220c29025"],
Cell[26520, 687, 933, 27, 38, "Text",ExpressionUUID->"938ed338-09b0-4ec1-8a97-56bbbeb0f0d0"],
Cell[27456, 716, 164, 3, 20, "Text",ExpressionUUID->"b4babc3e-7197-4c2e-8440-ec738469cd79"],
Cell[CellGroupData[{
Cell[27645, 723, 381, 11, 31, "Input",ExpressionUUID->"94c74825-3591-4fba-85c1-a10945e33b09",
 InitializationCell->True],
Cell[28029, 736, 245, 5, 31, "Output",ExpressionUUID->"2447c7bc-046a-4be7-9230-26ef647348e9"]
}, Open  ]],
Cell[28289, 744, 495, 14, 20, "Text",ExpressionUUID->"4ee9c175-4037-4939-bea6-3755f307733e"],
Cell[28787, 760, 376, 11, 29, "Equation",ExpressionUUID->"bd63fa19-1d6f-4a4e-abce-c2b99c66bbe2"],
Cell[29166, 773, 236, 7, 20, "Text",ExpressionUUID->"4c4465f4-5dd3-4913-b6b5-380600fcefa7"],
Cell[29405, 782, 172, 4, 26, "Equation",ExpressionUUID->"0ba2ae3d-7d92-41c6-836d-22c535399637"],
Cell[29580, 788, 228, 7, 20, "Text",ExpressionUUID->"77701318-002e-43e5-bfab-509aebf0d381"],
Cell[29811, 797, 212, 6, 26, "Equation",ExpressionUUID->"5ad86855-08b1-4e23-84d2-3965a9651151"],
Cell[30026, 805, 1310, 38, 62, "Text",ExpressionUUID->"aebb1f43-7fb2-4583-8526-b653f0b22da0"],
Cell[CellGroupData[{
Cell[31361, 847, 487, 14, 31, "Input",ExpressionUUID->"24a23fb1-4507-4499-b732-7e6a1353237d",
 InitializationCell->True],
Cell[31851, 863, 1375, 41, 70, "Output",ExpressionUUID->"b055254c-6ac9-48f4-b155-702c88052fca"]
}, Open  ]],
Cell[33241, 907, 941, 21, 85, "Text",ExpressionUUID->"d46d1613-3fd9-4449-9107-c6828aa8511c"],
Cell[CellGroupData[{
Cell[34207, 932, 229, 5, 31, "Input",ExpressionUUID->"99bd79b9-189e-49ec-bd20-ae38a6061cb2"],
Cell[34439, 939, 326, 9, 47, "Output",ExpressionUUID->"b6c0ba7a-dc31-4f0f-ae62-085485019a8a"]
}, Open  ]],
Cell[34780, 951, 1536, 38, 95, "Text",ExpressionUUID->"642230e6-5b2d-4c3a-af6d-08a666ca65f3"],
Cell[36319, 991, 2433, 71, 121, "Text",ExpressionUUID->"6c0f6838-fe1d-4a05-98f4-3085752ab86f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38789, 1067, 99, 0, 18, "Subsubsection",ExpressionUUID->"c3388b61-aeed-4d54-a7d3-291de727528b"],
Cell[38891, 1069, 193, 3, 20, "Text",ExpressionUUID->"b9df7387-6ad9-4032-a6a4-5999105e42d6"],
Cell[39087, 1074, 385, 12, 31, "Input",ExpressionUUID->"c866c538-47a8-463d-8f6f-95d10ea017fb",
 InitializationCell->True],
Cell[39475, 1088, 327, 8, 20, "Text",ExpressionUUID->"e0f916cf-3b68-4bdb-a280-d80b9fab5c77"],
Cell[CellGroupData[{
Cell[39827, 1100, 206, 5, 31, "Input",ExpressionUUID->"2c4681bd-408e-4c53-8ac0-39967df0f97d"],
Cell[40036, 1107, 106, 1, 31, "Output",ExpressionUUID->"5f8958eb-eaa0-429f-b4dc-db04ab836a24"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40179, 1113, 136, 2, 31, "Input",ExpressionUUID->"eb166352-807b-4773-9291-f5aebd9645a5"],
Cell[40318, 1117, 107, 1, 31, "Output",ExpressionUUID->"b1f0f8ca-1732-418d-b3ae-8e6fe184042b"]
}, Open  ]],
Cell[40440, 1121, 118, 0, 20, "Text",ExpressionUUID->"3fa6ddf2-4bf6-4d65-94d6-7bd82a100a2f"],
Cell[40561, 1123, 1539, 41, 75, "Text",ExpressionUUID->"a14504db-5a67-456c-9f0c-2580194e2aaa"],
Cell[42103, 1166, 625, 19, 20, "Text",ExpressionUUID->"6ffb1849-54c6-4b8b-90ce-722a1a49715b"],
Cell[CellGroupData[{
Cell[42753, 1189, 206, 5, 31, "Input",ExpressionUUID->"70f07cfe-b4df-481e-a57f-eb390a31a081"],
Cell[42962, 1196, 230, 6, 50, "Output",ExpressionUUID->"a9173423-61f4-48f6-a83b-1dd727ceb285"]
}, Open  ]],
Cell[43207, 1205, 330, 9, 20, "Text",ExpressionUUID->"5a81b676-6a1d-4215-8665-223da1304bf6"],
Cell[CellGroupData[{
Cell[43562, 1218, 159, 3, 31, "Input",ExpressionUUID->"bcfe3fbd-9d6a-4529-b07d-78ebe8833678"],
Cell[43724, 1223, 295, 9, 48, "Output",ExpressionUUID->"3e7d46a6-6976-45a3-a2e8-dabafe5bafdd"]
}, Open  ]],
Cell[44034, 1235, 1345, 36, 70, "Text",ExpressionUUID->"4a9ba93a-6a1e-4798-ac56-5f446e5f69ba"],
Cell[CellGroupData[{
Cell[45404, 1275, 363, 10, 31, "Input",ExpressionUUID->"e353ec01-e4ca-4a8a-be15-0cea15f4e6de"],
Cell[45770, 1287, 110, 1, 31, "Output",ExpressionUUID->"5f824f84-1c55-4ec7-b659-696dcb591462"]
}, Open  ]],
Cell[45895, 1291, 509, 11, 36, "Text",ExpressionUUID->"625f11e3-ee2a-4237-bfa5-5ff6cd28bec5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46453, 1308, 120, 1, 32, "Subsection",ExpressionUUID->"bd31a980-0692-4a77-a89b-9fff71ffe5be",
 CellTags->"Section1b"],
Cell[46576, 1311, 957, 23, 83, "Text",ExpressionUUID->"ff3ec579-4aa9-4135-abe5-257f26f0b98f"],
Cell[CellGroupData[{
Cell[47558, 1338, 157, 4, 21, "Subsubsection",ExpressionUUID->"ab22606f-840e-43c6-a376-194c80e7d85d"],
Cell[47718, 1344, 1414, 38, 86, "Text",ExpressionUUID->"59f7b595-d31d-4e60-9914-71a89d340f71"],
Cell[CellGroupData[{
Cell[49157, 1386, 330, 10, 31, "Input",ExpressionUUID->"23585170-f2ab-467c-91ea-95e1c5a5071c"],
Cell[49490, 1398, 116, 1, 31, "Output",ExpressionUUID->"7902d23d-1afe-4f6c-bdd3-71b99df5999e"]
}, Open  ]],
Cell[49621, 1402, 329, 7, 36, "Text",ExpressionUUID->"cd5a1473-621d-447d-ac9c-dc5ce99c7b2e"],
Cell[49953, 1411, 856, 24, 57, "Text",ExpressionUUID->"dea75859-c471-4921-96b0-44bf7d04d503"],
Cell[CellGroupData[{
Cell[50834, 1439, 329, 10, 31, "Input",ExpressionUUID->"a4a62592-1fe8-4b34-ba6e-b0ae8f037f1a"],
Cell[51166, 1451, 299, 9, 31, "Output",ExpressionUUID->"ee8a267e-abae-4946-a6ab-0f20321ee342"]
}, Open  ]],
Cell[51480, 1463, 261, 6, 21, "Text",ExpressionUUID->"d015af62-0607-4546-82df-a40e49a35416"],
Cell[CellGroupData[{
Cell[51766, 1473, 140, 2, 31, "Input",ExpressionUUID->"5e0c1fb3-0859-413d-ad3a-778cd5cce6e5"],
Cell[51909, 1477, 292, 9, 31, "Output",ExpressionUUID->"871b1125-0da1-4479-8313-b47361798de8"]
}, Open  ]],
Cell[52216, 1489, 368, 7, 36, "Text",ExpressionUUID->"495a4af2-2e90-43e2-8200-09fd24c28d75"],
Cell[52587, 1498, 322, 7, 36, "Text",ExpressionUUID->"d9516cea-42ee-4a72-9756-ca9295756597"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52946, 1510, 99, 0, 18, "Subsubsection",ExpressionUUID->"0268c6ec-b606-409b-a66e-c1ba854c1093"],
Cell[53048, 1512, 1209, 38, 68, "Text",ExpressionUUID->"f1f96bde-02bf-47ec-9f28-69af7c83f4f3"],
Cell[54260, 1552, 124, 0, 20, "Text",ExpressionUUID->"04dd1f30-c63c-47b9-b74d-4b0ddc5380a5"],
Cell[54387, 1554, 360, 11, 31, "Input",ExpressionUUID->"759e963b-a478-4115-a59d-d96ed2216fa0",
 InitializationCell->True],
Cell[54750, 1567, 471, 13, 20, "Text",ExpressionUUID->"8f140c5d-e6e3-4405-a218-ead653db6a85"],
Cell[CellGroupData[{
Cell[55246, 1584, 198, 5, 31, "Input",ExpressionUUID->"2a079b22-d6b3-4321-81ff-7704e722a7e6"],
Cell[55447, 1591, 107, 1, 31, "Output",ExpressionUUID->"94240cd0-08db-413a-8b34-62e1eac7e8d3"]
}, Open  ]],
Cell[55569, 1595, 268, 7, 20, "Text",ExpressionUUID->"9849048e-d169-4b27-8a29-5ed8d79f9c2c"],
Cell[CellGroupData[{
Cell[55862, 1606, 137, 2, 31, "Input",ExpressionUUID->"87ba7334-3e27-4ef0-8cfa-a29fb09015a0"],
Cell[56002, 1610, 107, 1, 31, "Output",ExpressionUUID->"ea0044f9-466f-459e-9821-e083ee1bba1f"]
}, Open  ]],
Cell[56124, 1614, 98, 0, 20, "Text",ExpressionUUID->"46b7c36e-2284-4a6d-a27f-578b4866717d"],
Cell[56225, 1616, 290, 6, 20, "Text",ExpressionUUID->"95577a10-c63e-41f9-b203-2e7d9d9242ab"],
Cell[56518, 1624, 564, 20, 53, "Equation",ExpressionUUID->"98df4e77-19fc-4aea-adae-d0a0631bbc89"],
Cell[57085, 1646, 272, 7, 20, "Text",ExpressionUUID->"a9babc60-a251-4741-a008-7c9afe8d47da"],
Cell[57360, 1655, 932, 33, 53, "Equation",ExpressionUUID->"f801961a-3798-42a5-b940-63b7f2f47333"],
Cell[58295, 1690, 271, 6, 20, "Text",ExpressionUUID->"aa4a0a58-28d4-4a6c-8d27-2c4ccc0e71e6"],
Cell[CellGroupData[{
Cell[58591, 1700, 385, 13, 31, "Input",ExpressionUUID->"e60ce76f-8950-49b7-99c9-920ddaf46777"],
Cell[58979, 1715, 471, 16, 32, "Output",ExpressionUUID->"d8a22cd3-d795-4843-bd03-94340688ecd5"]
}, Open  ]],
Cell[59465, 1734, 294, 7, 20, "Text",ExpressionUUID->"451cf9da-7aeb-48bd-84c0-2216f79a5696"],
Cell[CellGroupData[{
Cell[59784, 1745, 160, 3, 31, "Input",ExpressionUUID->"b4e2612b-d144-4a8e-b672-06adfd479727"],
Cell[59947, 1750, 222, 6, 31, "Output",ExpressionUUID->"1405ab3d-8c02-49b3-849a-c84c2ed420ee"]
}, Open  ]],
Cell[60184, 1759, 278, 6, 21, "Text",ExpressionUUID->"650d5d6a-9305-4a44-8192-73c4d5293a8b"],
Cell[CellGroupData[{
Cell[60487, 1769, 529, 17, 31, "Input",ExpressionUUID->"d24e75ee-ba0c-4a63-9b14-de3a50d409d3"],
Cell[61019, 1788, 453, 10, 42, "Message",ExpressionUUID->"65b3e0b7-13ac-4d05-b094-368ed18f306a"],
Cell[61475, 1800, 110, 1, 31, "Output",ExpressionUUID->"a2c0b3a0-63d2-4193-a484-247bb3b973c1"]
}, Open  ]],
Cell[61600, 1804, 371, 7, 35, "Text",ExpressionUUID->"950f6f8f-9b45-4635-8a21-64f48c40f25b"],
Cell[61974, 1813, 481, 7, 50, "Text",ExpressionUUID->"86e076de-ac75-45f7-8c8d-a5f9f53d71ae"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62504, 1826, 113, 1, 32, "Subsection",ExpressionUUID->"2351ad9f-4f6d-45e7-8cda-b44fa444c1e1",
 CellTags->"Section1c"],
Cell[62620, 1829, 1316, 36, 72, "Text",ExpressionUUID->"29f14c3c-beb7-49fe-b728-65a9ff8cb3d7"],
Cell[63939, 1867, 311, 8, 23, "Text",ExpressionUUID->"dd7925eb-2752-4db3-994d-3dae7a8a3e93"],
Cell[64253, 1877, 242, 6, 31, "Input",ExpressionUUID->"783e802e-4f33-43cb-a752-bc860301f3c2",
 InitializationCell->True],
Cell[64498, 1885, 403, 12, 20, "Text",ExpressionUUID->"842beb33-559c-448b-a2b6-2ef1ee3951b4"],
Cell[CellGroupData[{
Cell[64926, 1901, 143, 2, 31, "Input",ExpressionUUID->"f5b22f79-12bc-417f-a8f6-025187ae026f"],
Cell[65072, 1905, 107, 1, 31, "Output",ExpressionUUID->"1866b6f6-70a6-446c-8d57-315e6da66a9f"]
}, Open  ]],
Cell[65194, 1909, 119, 0, 20, "Text",ExpressionUUID->"27e14c7c-1454-45e0-b8bb-58dfa8d81456"],
Cell[65316, 1911, 1455, 43, 55, "Text",ExpressionUUID->"d08428f5-488d-4518-9db1-671f55bff3c6"],
Cell[66774, 1956, 640, 21, 23, "Text",ExpressionUUID->"7c5f461b-7ac2-430b-a634-901e2a675810"],
Cell[CellGroupData[{
Cell[67439, 1981, 228, 5, 31, "Input",ExpressionUUID->"e2a198ef-0bdd-4916-a4cd-71b2903c8709"],
Cell[67670, 1988, 254, 7, 32, "Output",ExpressionUUID->"000445a2-cfd2-49b2-8694-78dbe1f9cb28"]
}, Open  ]],
Cell[67939, 1998, 232, 6, 21, "Text",ExpressionUUID->"93496d00-4da1-4403-aebd-c50d16ceb685"],
Cell[CellGroupData[{
Cell[68196, 2008, 138, 2, 31, "Input",ExpressionUUID->"825a8668-abdc-4ff3-883f-984dba62e157"],
Cell[68337, 2012, 436, 13, 32, "Output",ExpressionUUID->"e580aefb-b86d-4a2c-a008-063e8a40bac5"]
}, Open  ]],
Cell[68788, 2028, 648, 15, 52, "Text",ExpressionUUID->"dfd36103-c004-4e4d-bd4e-d1fe82fc63de"],
Cell[CellGroupData[{
Cell[69461, 2047, 362, 9, 31, "Input",ExpressionUUID->"fc77deda-2775-439b-8066-bab597334c0d"],
Cell[69826, 2058, 110, 1, 31, "Output",ExpressionUUID->"745c6b48-f1d5-4498-bdb0-8c6cf2b39047"]
}, Open  ]],
Cell[69951, 2062, 455, 12, 23, "Text",ExpressionUUID->"ec71b2bb-bdea-4f97-9b3b-402dbba42588"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[70455, 2080, 135, 1, 55, "Section",ExpressionUUID->"2abca2a8-1a9c-471b-8a26-5a91e638b1cd",
 CellTags->"Section2"],
Cell[70593, 2083, 634, 11, 65, "Text",ExpressionUUID->"c94da6ed-3ae4-4459-a097-9ad2d08d3419"],
Cell[71230, 2096, 1137, 30, 50, "Text",ExpressionUUID->"a84b67bc-6e95-436d-98dd-bca4c8321a67"],
Cell[72370, 2128, 1125, 28, 65, "Text",ExpressionUUID->"d1db73d0-bd93-4f47-8c51-83a2dacfe6ea"],
Cell[CellGroupData[{
Cell[73520, 2160, 94, 0, 18, "Subsubsection",ExpressionUUID->"c55b2f72-cac6-4f6d-b303-69dee60547c3"],
Cell[73617, 2162, 1362, 39, 50, "Text",ExpressionUUID->"84337b95-2eac-49ac-9268-a409506082a3"],
Cell[74982, 2203, 2702, 81, 72, "Text",ExpressionUUID->"1d98fe50-a999-454c-9e49-af752c8193c4"],
Cell[77687, 2286, 1285, 38, 52, "Text",ExpressionUUID->"9957b041-5021-4f2e-a1d1-1dac040f8b29"],
Cell[CellGroupData[{
Cell[78997, 2328, 1025, 27, 146, "Input",ExpressionUUID->"f73026dc-1518-44c6-9779-96663373ddcb"],
Cell[80025, 2357, 152, 3, 31, "Output",ExpressionUUID->"c289a9cc-6bad-44ff-9ff9-afe72983bb15"]
}, Open  ]],
Cell[80192, 2363, 625, 11, 66, "Text",ExpressionUUID->"d9e2611c-77bf-4b6b-9fe1-624329ffae22"],
Cell[80820, 2376, 1460, 37, 184, "Input",ExpressionUUID->"31d7496f-25d0-4506-b31b-3a7d4c214939",
 InitializationCell->True],
Cell[82283, 2415, 267, 5, 39, "Text",ExpressionUUID->"3ed871b9-8687-4a65-885f-891fee8e2289"],
Cell[CellGroupData[{
Cell[82575, 2424, 177, 3, 31, "Input",ExpressionUUID->"fe6b5250-f844-492d-bbc3-29f3a7d51024"],
Cell[82755, 2429, 152, 3, 31, "Output",ExpressionUUID->"c35d2a0d-a64b-4f13-b02b-b951fe4d63cc"]
}, Open  ]],
Cell[82922, 2435, 214, 3, 20, "Text",ExpressionUUID->"cebb47be-7173-4ca5-9dfb-1ffcf7cc009a"],
Cell[83139, 2440, 177, 3, 31, "Input",ExpressionUUID->"f9c81190-ec27-4e96-b81c-08f0a6966722"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83353, 2448, 105, 0, 18, "Subsubsection",ExpressionUUID->"578f2682-b880-49c1-b1cd-b3ba38b89d4f"],
Cell[83461, 2450, 448, 8, 54, "Text",ExpressionUUID->"9ac532f9-0c4c-4d63-95bf-b037c6813011"],
Cell[CellGroupData[{
Cell[83934, 2462, 417, 10, 70, "Input",ExpressionUUID->"e566f0cb-9341-452f-b92e-147c6a1de650"],
Cell[CellGroupData[{
Cell[84376, 2476, 177, 5, 24, "Print",ExpressionUUID->"c9e3b108-70b2-4765-a542-7842d92507df"],
Cell[84556, 2483, 177, 5, 24, "Print",ExpressionUUID->"7eb16782-5e1e-489f-bd13-901242d6b0e8"],
Cell[84736, 2490, 177, 5, 24, "Print",ExpressionUUID->"a9748a40-c925-4b8b-8912-ad6bc3c52c8d"],
Cell[84916, 2497, 177, 5, 24, "Print",ExpressionUUID->"30488a1f-dff0-4b42-a6a0-d9b9dd89bd6f"]
}, Open  ]]
}, Open  ]],
Cell[85120, 2506, 1202, 30, 65, "Text",ExpressionUUID->"e56db94a-f894-48aa-bc88-2e7ae927e866"],
Cell[86325, 2538, 1434, 41, 35, "Text",ExpressionUUID->"28fb07fa-2053-49d1-9d26-93da4159a296"],
Cell[87762, 2581, 256, 4, 35, "Text",ExpressionUUID->"c647dc0a-e8f3-4645-92fe-c0cf261c8543"],
Cell[88021, 2587, 623, 15, 55, "Text",ExpressionUUID->"b324d677-50e0-4f65-bdc7-54c22577ae87"],
Cell[88647, 2604, 288, 7, 51, "Input",ExpressionUUID->"66f1ccc7-3ba5-47ec-9db1-b86a611edc1d",
 InitializationCell->True],
Cell[88938, 2613, 1174, 30, 71, "Text",ExpressionUUID->"9e38d069-f51f-4221-9291-f89c6cb1b647"],
Cell[90115, 2645, 2133, 51, 336, "Input",ExpressionUUID->"65fa4a01-d4c6-48bb-87f4-0a5689bb1a02",
 InitializationCell->True],
Cell[92251, 2698, 175, 3, 20, "Text",ExpressionUUID->"98eb1556-166f-48c7-96bf-fa1129430a85"],
Cell[CellGroupData[{
Cell[92451, 2705, 178, 3, 31, "Input",ExpressionUUID->"0b653860-75c9-4457-8e64-6c6f52f8d7b6"],
Cell[92632, 2710, 500, 15, 31, "Output",ExpressionUUID->"d696e01c-d6e2-479a-b6d2-d387fadc463d"]
}, Open  ]],
Cell[93147, 2728, 1469, 39, 96, "Text",ExpressionUUID->"1081f727-a142-4797-8c2d-d3301b9ec1fc"],
Cell[94619, 2769, 590, 15, 62, "Text",ExpressionUUID->"ef00774e-c157-4ae5-8e35-0aef1136d830"],
Cell[95212, 2786, 1063, 26, 78, "Text",ExpressionUUID->"ad185b6f-beb3-4d13-8df5-f6ed0def8fe5"],
Cell[96278, 2814, 216, 3, 20, "Text",ExpressionUUID->"772e3028-1f39-4517-8b19-6e1dfb27913b"],
Cell[CellGroupData[{
Cell[96519, 2821, 178, 3, 31, "Input",ExpressionUUID->"8e39bf1b-580e-4433-8d81-9b059946b05d"],
Cell[96700, 2826, 426, 10, 24, "Message",ExpressionUUID->"793a5ecc-8538-4c93-8a39-e68b22828f55"],
Cell[97129, 2838, 426, 10, 24, "Message",ExpressionUUID->"5fd150d3-68c2-49f0-af1c-7d1bdd7fd17d"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97616, 2855, 147, 1, 55, "Section",ExpressionUUID->"f7bb09c9-e3df-4653-a631-0a718b3538f3",
 CellTags->"Section3"],
Cell[97766, 2858, 226, 6, 20, "Text",ExpressionUUID->"96f8dcde-48d9-4f6e-8e8b-212e1f99b190"],
Cell[CellGroupData[{
Cell[98017, 2868, 128, 1, 32, "Subsection",ExpressionUUID->"3c6f5a8b-3705-48ed-a025-2265f2e96a1b",
 CellTags->"Section3a"],
Cell[98148, 2871, 671, 19, 35, "Text",ExpressionUUID->"cd2fad7f-faf9-4f11-af42-2a766b074f0b"],
Cell[98822, 2892, 1816, 49, 65, "Text",ExpressionUUID->"42ad5d34-3586-47e8-8b9d-528615ae15c0"],
Cell[100641, 2943, 1439, 42, 50, "Text",ExpressionUUID->"2b2f06bd-14a3-4807-a507-966bd7f15391"],
Cell[102083, 2987, 322, 7, 35, "Text",ExpressionUUID->"95c39884-b2ce-4175-a958-8804624a1cac"],
Cell[102408, 2996, 288, 8, 31, "Input",ExpressionUUID->"481ee305-53fe-415a-99cc-3d69137ae524",
 InitializationCell->True],
Cell[102699, 3006, 341, 8, 20, "Text",ExpressionUUID->"b10b0098-cbfc-445b-ba2f-ba9c663ad44d"],
Cell[CellGroupData[{
Cell[103065, 3018, 183, 4, 31, "Input",ExpressionUUID->"30c2ea0a-5628-4be0-a2b1-038345096464",
 InitializationCell->True],
Cell[103251, 3024, 107, 1, 31, "Output",ExpressionUUID->"7edf9e74-0f9d-4a75-8b73-c489ea13d6ed"]
}, Open  ]],
Cell[103373, 3028, 636, 20, 43, "Text",ExpressionUUID->"b1dc6fba-1431-416d-8618-42c6fa46fdc3"],
Cell[104012, 3050, 227, 5, 24, "Text",ExpressionUUID->"28b44e23-7267-4baf-bc63-d91dfaf35cdc"],
Cell[CellGroupData[{
Cell[104264, 3059, 134, 2, 31, "Input",ExpressionUUID->"e152eb2c-dcff-4f8c-8f1b-4a4fb1b79e72"],
Cell[104401, 3063, 110, 1, 31, "Output",ExpressionUUID->"56e77e17-2450-4f82-99e8-c24a1808f560"]
}, Open  ]],
Cell[104526, 3067, 282, 8, 24, "Text",ExpressionUUID->"95669d6f-a3b6-453b-bbfd-07c4b778b6e0"],
Cell[CellGroupData[{
Cell[104833, 3079, 238, 6, 31, "Input",ExpressionUUID->"ef870385-7d1e-48d6-942b-cfefbaf05bb7"],
Cell[105074, 3087, 244, 5, 31, "Output",ExpressionUUID->"f8b7a72b-e41c-4a02-8cdc-ae558a77a1f0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105355, 3097, 91, 0, 18, "Subsubsection",ExpressionUUID->"5eda2463-7dbc-415f-8642-b14a91b4bb7a"],
Cell[105449, 3099, 682, 14, 69, "Text",ExpressionUUID->"2f309107-db95-4511-90da-ab47ac001127"],
Cell[CellGroupData[{
Cell[106156, 3117, 142, 2, 31, "Input",ExpressionUUID->"ffb01f96-4b99-4bf6-b663-54fd49c0dfea"],
Cell[106301, 3121, 480, 13, 31, "Output",ExpressionUUID->"293f0086-6984-49a3-b91b-308af77066f1"]
}, Open  ]],
Cell[106796, 3137, 276, 7, 24, "Text",ExpressionUUID->"2f0b4fc7-588a-4100-b6a4-8870ff8c7c2e"],
Cell[107075, 3146, 1172, 32, 89, "Text",ExpressionUUID->"5336645b-efb1-4454-bdc5-0d9938b794f4"],
Cell[108250, 3180, 523, 16, 43, "Text",ExpressionUUID->"22db71ba-5fa3-4834-9180-190e38795ec2"],
Cell[108776, 3198, 2108, 65, 84, "Text",ExpressionUUID->"d8534b34-5de2-4026-be02-c5a2c28de99a"],
Cell[110887, 3265, 858, 20, 69, "Text",ExpressionUUID->"39895587-edac-4f14-aab4-2438ee222742"],
Cell[111748, 3287, 385, 7, 54, "Text",ExpressionUUID->"d9b1d99b-15c7-4f93-98bb-a860110b1eba"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[112182, 3300, 128, 1, 32, "Subsection",ExpressionUUID->"8e0d04b2-6c71-40ef-abbb-9335e015d7c0",
 CellTags->"Section3b"],
Cell[112313, 3303, 991, 29, 35, "Text",ExpressionUUID->"d0df0366-436f-418f-9c2f-328efcf1a9bf"],
Cell[113307, 3334, 167, 3, 20, "Text",ExpressionUUID->"4c11c02a-efd8-49d4-a345-1ec5af5de640"],
Cell[113477, 3339, 301, 8, 51, "Input",ExpressionUUID->"d667a90f-e91e-4c69-9709-823811adc770",
 InitializationCell->True],
Cell[113781, 3349, 119, 0, 20, "Text",ExpressionUUID->"60b0cfdd-eedd-443a-a585-76cef3fcb8d2"],
Cell[CellGroupData[{
Cell[113925, 3353, 142, 2, 31, "Input",ExpressionUUID->"696334fc-b253-4219-a2b4-8af544100615"],
Cell[114070, 3357, 371, 10, 31, "Output",ExpressionUUID->"c34abee3-0453-4ffc-ac64-9047a8c3fe50"]
}, Open  ]],
Cell[114456, 3370, 144, 2, 20, "Text",ExpressionUUID->"47eeb557-4a10-4da4-944f-4c486f04c8c6"],
Cell[114603, 3374, 373, 11, 31, "Input",ExpressionUUID->"ef0aded6-64b4-4ac6-93c1-3efd0fd70bc6",
 InitializationCell->True],
Cell[114979, 3387, 578, 14, 58, "Text",ExpressionUUID->"30137ac9-0392-45b6-9a3f-4e228318e5cd"],
Cell[CellGroupData[{
Cell[115582, 3405, 142, 2, 31, "Input",ExpressionUUID->"e25f77e6-a226-40c8-a639-db1107c158de"],
Cell[115727, 3409, 721, 20, 51, "Output",ExpressionUUID->"c6f8d2a3-5082-4fc2-9cb8-ab561aacf06b"]
}, Open  ]],
Cell[116463, 3432, 1547, 44, 81, "Text",ExpressionUUID->"8ce3da16-0776-413e-91b3-4ab0200cb682"],
Cell[118013, 3478, 183, 4, 24, "Text",ExpressionUUID->"4636cecc-8f7b-49b7-a9c1-de28e2351831"],
Cell[CellGroupData[{
Cell[118221, 3486, 249, 6, 31, "Input",ExpressionUUID->"d933c04b-d664-4fde-b3ea-a09daff60443"],
Cell[118473, 3494, 254, 5, 31, "Output",ExpressionUUID->"a0f0dfa7-330f-45f4-8c8b-b25c89255d44"]
}, Open  ]],
Cell[118742, 3502, 248, 6, 24, "Text",ExpressionUUID->"12f04348-4526-4051-abe4-bc3cc6b11d70"],
Cell[CellGroupData[{
Cell[119015, 3512, 142, 2, 31, "Input",ExpressionUUID->"540f7d4a-49d0-49f0-8cc4-dc3eecee9f20"],
Cell[119160, 3516, 1789, 47, 108, "Output",ExpressionUUID->"2fd07ac5-13e0-44a4-9401-be99445bb698"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120998, 3569, 121, 1, 32, "Subsection",ExpressionUUID->"a487e06b-c4e0-4a04-b37b-bef3df9bd215",
 CellTags->"Section3c"],
Cell[121122, 3572, 1329, 36, 69, "Text",ExpressionUUID->"57f47e80-d585-44fc-a9b5-3c343781fd97"],
Cell[122454, 3610, 309, 6, 21, "Text",ExpressionUUID->"8da5c269-39f6-488e-98a3-4ae3b3d97f76"],
Cell[122766, 3618, 937, 27, 127, "Input",ExpressionUUID->"29a5cd36-fb53-4c83-b441-d4943898f49a",
 InitializationCell->True],
Cell[123706, 3647, 871, 25, 127, "Input",ExpressionUUID->"aeca2099-d9dd-442d-8b64-af48a904e3fb",
 InitializationCell->True],
Cell[124580, 3674, 168, 4, 24, "Text",ExpressionUUID->"f98cbdff-1a59-4bdc-9419-51f46d7df001"],
Cell[CellGroupData[{
Cell[124773, 3682, 134, 2, 31, "Input",ExpressionUUID->"4893e7dd-ab93-4b1f-87e7-0dafeba3ac2f"],
Cell[CellGroupData[{
Cell[124932, 3688, 310, 8, 24, "Print",ExpressionUUID->"865ac51d-998b-48a2-9a0d-52fc46c52e06"],
Cell[125245, 3698, 310, 8, 24, "Print",ExpressionUUID->"12c047ec-6cc0-481b-9bca-a98fde7b8e09"],
Cell[125558, 3708, 310, 8, 24, "Print",ExpressionUUID->"917cbce6-751a-4d76-ac23-418c80e127d1"],
Cell[125871, 3718, 310, 8, 24, "Print",ExpressionUUID->"ff216474-d58e-425f-b110-a5c857fc4b7b"]
}, Open  ]],
Cell[126196, 3729, 109, 1, 31, "Output",ExpressionUUID->"b7d62492-c585-41ce-8572-25abe13f706c"]
}, Open  ]],
Cell[126320, 3733, 2487, 74, 92, "Text",ExpressionUUID->"c226853d-fe48-4b4f-8772-6f065c078eba"],
Cell[128810, 3809, 1671, 51, 119, "Text",ExpressionUUID->"e3b303de-059d-4377-8a03-9d6e4feaea71"],
Cell[130484, 3862, 156, 4, 24, "Text",ExpressionUUID->"c2b9efe5-b214-4c23-9e27-9508ef8f8cbd"],
Cell[CellGroupData[{
Cell[130665, 3870, 134, 2, 31, "Input",ExpressionUUID->"5bce7d72-53ef-4c30-bbfa-3dd3d19c0286"],
Cell[CellGroupData[{
Cell[130824, 3876, 310, 8, 24, "Print",ExpressionUUID->"6d1ffc0f-cee9-4908-9435-be9f61b3295d"],
Cell[131137, 3886, 310, 8, 24, "Print",ExpressionUUID->"d61f2678-440e-4a89-bb5e-f3b9143830bc"],
Cell[131450, 3896, 310, 8, 24, "Print",ExpressionUUID->"3b62cd9c-7a86-4652-b930-4af8b319ceee"],
Cell[131763, 3906, 310, 8, 24, "Print",ExpressionUUID->"e68c4e57-028f-49e4-89b1-2858f1f385dc"],
Cell[132076, 3916, 310, 8, 24, "Print",ExpressionUUID->"3caba6c7-fcba-418f-bb98-42d58d7c11a6"],
Cell[132389, 3926, 310, 8, 24, "Print",ExpressionUUID->"4381fea8-faf0-479e-bd29-478690fa4bfa"],
Cell[132702, 3936, 310, 8, 24, "Print",ExpressionUUID->"e599ac23-0e75-47d3-b472-0db1bc9a15e8"]
}, Open  ]],
Cell[133027, 3947, 109, 1, 31, "Output",ExpressionUUID->"a0db8ae5-c3c2-40fe-b2c3-2213861c9f3c"]
}, Open  ]],
Cell[133151, 3951, 991, 27, 96, "Text",ExpressionUUID->"06c698ff-c667-4a5e-8988-9f2eef6faa30"],
Cell[134145, 3980, 677, 20, 62, "Text",ExpressionUUID->"8942ea12-fc53-4638-a744-8a1983f356f3"],
Cell[134825, 4002, 1237, 34, 100, "Text",ExpressionUUID->"47a9948b-2a24-421d-b642-3e36004cec1b"],
Cell[136065, 4038, 761, 21, 62, "Text",ExpressionUUID->"538d5cf4-b340-4051-8e44-b5c219a587e3"],
Cell[136829, 4061, 457, 7, 50, "Text",ExpressionUUID->"84a18173-070f-4df8-97d4-0797013dcda2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137323, 4073, 141, 1, 32, "Subsection",ExpressionUUID->"85773493-3e26-4a68-8bfd-98c3f51828fa",
 CellTags->"Section3d"],
Cell[137467, 4076, 939, 27, 38, "Text",ExpressionUUID->"8c513f6d-a79e-4c01-ac5d-3b3197494e2d"],
Cell[138409, 4105, 2117, 60, 46, "Equation",ExpressionUUID->"06a28f02-b3f1-4aa0-90ac-9fa6ab970122"],
Cell[140529, 4167, 194, 3, 20, "Text",ExpressionUUID->"0a2c533e-4138-4249-b0ea-b42b3f578f79"],
Cell[140726, 4172, 227, 6, 31, "Input",ExpressionUUID->"d5f87922-b6cd-4515-b321-8a160895b594",
 InitializationCell->True],
Cell[140956, 4180, 512, 11, 36, "Text",ExpressionUUID->"74a9969f-9eb9-43df-bfb5-65c9d4fbcccc"],
Cell[141471, 4193, 709, 22, 31, "Input",ExpressionUUID->"f440e5ef-b948-4af4-b3b9-3e8f93b79da4",
 InitializationCell->True],
Cell[142183, 4217, 282, 8, 23, "Text",ExpressionUUID->"8c13c252-5089-4cce-a7ee-f3a44ae8099f"],
Cell[CellGroupData[{
Cell[142490, 4229, 156, 3, 31, "Input",ExpressionUUID->"a825eb8e-5359-4bf6-8517-1f7e51f7afb1"],
Cell[142649, 4234, 107, 1, 31, "Output",ExpressionUUID->"f1789ea4-5995-4fc4-9553-8063bc30f69f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142793, 4240, 156, 3, 31, "Input",ExpressionUUID->"b5baba4b-ae0f-4ec6-8222-0f8c55a89760"],
Cell[142952, 4245, 108, 1, 31, "Output",ExpressionUUID->"511193d1-0647-4433-afe1-a0b9569a19ff"]
}, Open  ]],
Cell[143075, 4249, 551, 16, 24, "Text",ExpressionUUID->"28740364-0524-407c-803b-651b98622eee"],
Cell[CellGroupData[{
Cell[143651, 4269, 386, 11, 31, "Input",ExpressionUUID->"bf972878-1983-42ca-bf6c-38ec56d0ad9e"],
Cell[144040, 4282, 1359, 28, 210, "Output",ExpressionUUID->"c8663912-51a8-4d9f-a66e-70f2b715e136"]
}, Open  ]],
Cell[145414, 4313, 662, 17, 20, "Text",ExpressionUUID->"b187f112-bf09-48d8-864a-7805167fb220"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146113, 4335, 126, 1, 32, "Subsection",ExpressionUUID->"0ec5e852-727e-4b2e-96fa-1d963cdc75de",
 CellTags->"Section3e"],
Cell[146242, 4338, 208, 3, 20, "Text",ExpressionUUID->"81ed7a51-7f4a-429c-a1bb-0796c7cc76ee"],
Cell[146453, 4343, 245, 6, 20, "Text",ExpressionUUID->"36d23279-a949-4aae-a0ac-3e07f36141bb"],
Cell[146701, 4351, 433, 14, 15, "Text",ExpressionUUID->"d3814a22-b8df-461c-8c27-ebdbe66b8237"],
Cell[147137, 4367, 618, 20, 15, "Text",ExpressionUUID->"00b54168-75a3-4f84-8a2f-35b86e413554"],
Cell[147758, 4389, 169, 3, 20, "Text",ExpressionUUID->"c4950207-eae4-4e15-bbee-d3270187bad0"],
Cell[147930, 4394, 405, 8, 35, "Text",ExpressionUUID->"389cfaa7-5984-4f24-ab41-8fa51b75a3c0"],
Cell[148338, 4404, 333, 8, 24, "Text",ExpressionUUID->"18e635bf-2e0c-4004-b3bc-eec142b743d0"],
Cell[CellGroupData[{
Cell[148696, 4416, 202, 5, 31, "Input",ExpressionUUID->"49e4bf31-bcbe-47a5-86c5-2cb2ca506c5c",
 InitializationCell->True],
Cell[148901, 4423, 152, 3, 31, "Output",ExpressionUUID->"05d258d2-10ae-4a30-b7bd-62bea920fa37"]
}, Open  ]],
Cell[149068, 4429, 1163, 33, 59, "Text",ExpressionUUID->"6d1f16df-108d-4409-9dd6-db16b2d2ce1d"],
Cell[150234, 4464, 784, 22, 40, "Text",ExpressionUUID->"f211502f-eb86-4352-bb18-816e741fd2c8"],
Cell[151021, 4488, 92, 0, 20, "Text",ExpressionUUID->"85e5d70d-7cbc-4876-b547-e2f6c8cc55f6"],
Cell[151116, 4490, 783, 22, 89, "Input",ExpressionUUID->"7a591fbd-efd1-4c27-9939-756bcb666e5b",
 InitializationCell->True],
Cell[151902, 4514, 144, 4, 24, "Text",ExpressionUUID->"90353718-3a8b-4587-a588-d7d8826033a0"],
Cell[CellGroupData[{
Cell[152071, 4522, 190, 4, 31, "Input",ExpressionUUID->"8afd1e7e-4e8a-4c34-ba10-571d303ba712",
 InitializationCell->True],
Cell[152264, 4528, 184, 3, 31, "Output",ExpressionUUID->"228bcfb2-107b-412d-99f8-7290a1fae06f"]
}, Open  ]],
Cell[152463, 4534, 96, 0, 20, "Text",ExpressionUUID->"52a90d46-03d4-47ec-93ef-e47a41e45878"],
Cell[CellGroupData[{
Cell[152584, 4538, 190, 4, 31, "Input",ExpressionUUID->"8f9d06f1-7d90-47a5-a224-1bf2d15421b9",
 InitializationCell->True],
Cell[152777, 4544, 293, 6, 31, "Output",ExpressionUUID->"80e20233-c76d-4422-a661-7f4d59bce130"]
}, Open  ]],
Cell[153085, 4553, 79, 0, 20, "Text",ExpressionUUID->"3091bf33-8caa-4d92-b1b7-ed5af663ef0b"],
Cell[CellGroupData[{
Cell[153189, 4557, 190, 4, 31, "Input",ExpressionUUID->"3cc2645e-2915-40e2-b744-604689bae2bb",
 InitializationCell->True],
Cell[153382, 4563, 607, 10, 51, "Output",ExpressionUUID->"9b67bea2-6226-4310-8220-ed067626a3d9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[154038, 4579, 117, 1, 32, "Subsection",ExpressionUUID->"8c06c1de-403c-4d66-8667-6827ffe6c624",
 CellTags->"Section3f"],
Cell[154158, 4582, 238, 4, 35, "Text",ExpressionUUID->"060b5714-b366-4c95-a5af-1c3e9fc38d5a"],
Cell[154399, 4588, 373, 9, 20, "Text",ExpressionUUID->"b6c24856-1081-47b6-a803-669bb7db50c0"],
Cell[CellGroupData[{
Cell[154797, 4601, 269, 7, 31, "Input",ExpressionUUID->"764d6a97-4e2e-4084-920f-137aaeaaa4e9",
 InitializationCell->True],
Cell[155069, 4610, 207, 4, 31, "Output",ExpressionUUID->"4293a9ad-850d-474b-ba33-9f8be6961694"]
}, Open  ]],
Cell[155291, 4617, 436, 12, 39, "Text",ExpressionUUID->"eb520403-dc37-4c0c-b2ff-307b53cbe869"],
Cell[CellGroupData[{
Cell[155752, 4633, 186, 4, 31, "Input",ExpressionUUID->"5bf6d696-06b8-4437-b650-cc5e0e03a2c8",
 InitializationCell->True],
Cell[155941, 4639, 136, 2, 31, "Output",ExpressionUUID->"d602b7b2-ea4e-4b41-a7bd-fdb4e524210e"]
}, Open  ]],
Cell[156092, 4644, 329, 6, 36, "Text",ExpressionUUID->"1bd8f753-4943-41a3-8ca6-7ef05b4d8625"],
Cell[CellGroupData[{
Cell[156446, 4654, 137, 2, 31, "Input",ExpressionUUID->"fcf0ca88-1d33-479f-a6bc-14af4bc42f89"],
Cell[156586, 4658, 280, 9, 42, "Output",ExpressionUUID->"716ed446-170a-4dc1-a531-e4e8e2ac1ded"]
}, Open  ]],
Cell[156881, 4670, 589, 11, 54, "Text",ExpressionUUID->"e6a6f82f-6ffe-476f-b449-b2a7f22d7193"],
Cell[157473, 4683, 305, 8, 24, "Text",ExpressionUUID->"62fb5421-d900-4537-b51e-a700f070eae5"],
Cell[157781, 4693, 822, 24, 89, "Input",ExpressionUUID->"8c7a6364-1fac-4cf1-96dd-ddb9e8101af7",
 InitializationCell->True],
Cell[158606, 4719, 148, 2, 20, "Text",ExpressionUUID->"a7f04abc-ff61-4ecb-af62-fdebce36272a"],
Cell[CellGroupData[{
Cell[158779, 4725, 227, 5, 31, "Input",ExpressionUUID->"af533175-373f-4fb2-a2e7-639ecc2f88ec",
 InitializationCell->True],
Cell[159009, 4732, 225, 4, 31, "Output",ExpressionUUID->"4de9572d-52d4-4c7d-abb7-cc1cdf7f0bee"]
}, Open  ]],
Cell[159249, 4739, 415, 8, 35, "Text",ExpressionUUID->"af04de4c-cbbb-4b06-93bf-580b5cd7de67"],
Cell[CellGroupData[{
Cell[159689, 4751, 227, 5, 31, "Input",ExpressionUUID->"80a807e9-83e9-48b3-81ed-399b9c026a97",
 InitializationCell->True],
Cell[159919, 4758, 545, 8, 31, "Output",ExpressionUUID->"6cecfcf8-bbb7-4ebe-8b79-f3baf8cfb9d5"]
}, Open  ]],
Cell[160479, 4769, 130, 0, 20, "Text",ExpressionUUID->"7cfbba8d-0a7c-4198-9c84-d34dc1cc27a6"],
Cell[CellGroupData[{
Cell[160634, 4773, 227, 5, 31, "Input",ExpressionUUID->"977c98ef-7988-481e-aaa0-c7a43a00c010",
 InitializationCell->True],
Cell[160864, 4780, 1916, 31, 108, "Output",ExpressionUUID->"87da3f1a-a3f0-433b-9616-0be827e24947"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162817, 4816, 98, 0, 18, "Subsubsection",ExpressionUUID->"ae0f4ac8-f3d1-4c69-abcc-6d698ed708f8"],
Cell[162918, 4818, 357, 5, 35, "Text",ExpressionUUID->"3e611438-d76a-4852-9ca3-98140c176062"],
Cell[163278, 4825, 829, 23, 127, "Input",ExpressionUUID->"2c6813a8-966b-483f-9eae-a4398a9c51b3",
 InitializationCell->True],
Cell[164110, 4850, 398, 7, 35, "Text",ExpressionUUID->"fa235849-12af-4653-ae73-0083e472c580"],
Cell[CellGroupData[{
Cell[164533, 4861, 235, 6, 31, "Input",ExpressionUUID->"550bd813-ffd8-4da5-a180-73c8363c24f6"],
Cell[164771, 4869, 895, 13, 89, "Output",ExpressionUUID->"6044a972-be8c-410e-ab7e-48b9c2b26b5f"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[165739, 4890, 121, 1, 55, "Section",ExpressionUUID->"2180dab6-1e74-4757-a5a0-cc74cfda0950",
 CellTags->"Section4"],
Cell[165863, 4893, 507, 9, 50, "Text",ExpressionUUID->"87207367-32aa-4616-b617-e78e7c039807"],
Cell[CellGroupData[{
Cell[166395, 4906, 123, 1, 32, "Subsection",ExpressionUUID->"de33e1a3-92e2-487d-a047-25efa50a43f2",
 CellTags->"Section4a"],
Cell[166521, 4909, 1054, 31, 41, "Text",ExpressionUUID->"fb3b652e-79a7-4c6d-8a15-0dcb070f66da"],
Cell[167578, 4942, 1285, 38, 62, "Text",ExpressionUUID->"be4e1048-019f-450c-a3ab-c067dacd74ef"],
Cell[CellGroupData[{
Cell[168888, 4984, 90, 0, 18, "Subsubsection",ExpressionUUID->"c1ed22ea-25b2-4112-8bf9-6cd8f74bea23"],
Cell[168981, 4986, 1256, 38, 59, "Text",ExpressionUUID->"e373fffa-646b-4898-915e-54c3dec99dbb"],
Cell[170240, 5026, 334, 5, 35, "Text",ExpressionUUID->"6737ef7f-fba4-45c5-bdc6-e446b00c5fde"],
Cell[170577, 5033, 240, 6, 31, "Input",ExpressionUUID->"34525948-7b11-4e72-a770-8afea90a7966",
 InitializationCell->True],
Cell[170820, 5041, 623, 9, 69, "Text",ExpressionUUID->"e991be3e-f140-4a2e-9a79-b04f24903c28"],
Cell[171446, 5052, 778, 21, 58, "Text",ExpressionUUID->"ddb40c19-ead6-483f-9a25-843eec994a18"],
Cell[172227, 5075, 481, 14, 31, "Input",ExpressionUUID->"1427705a-6638-4b96-af57-f467c35740e9",
 InitializationCell->True],
Cell[172711, 5091, 193, 4, 24, "Text",ExpressionUUID->"3d4cfade-c515-451b-9655-143231991a7a"],
Cell[CellGroupData[{
Cell[172929, 5099, 147, 2, 31, "Input",ExpressionUUID->"c4f32f2c-2eaa-44c3-b2b6-cf33b19508ae"],
Cell[173079, 5103, 746, 21, 70, "Output",ExpressionUUID->"bcbd5d35-9590-4ac0-9533-b1e568c4a93d"]
}, Open  ]],
Cell[173840, 5127, 695, 12, 84, "Text",ExpressionUUID->"11739da3-3a95-412e-84aa-119cd24e103e"],
Cell[174538, 5141, 383, 10, 25, "Text",ExpressionUUID->"d84a6d28-c08a-4d86-b315-3734a01b15d0"],
Cell[CellGroupData[{
Cell[174946, 5155, 171, 3, 31, "Input",ExpressionUUID->"7a33e1f9-0d58-4aa2-8239-44b5ed8f9e71"],
Cell[175120, 5160, 107, 1, 31, "Output",ExpressionUUID->"e4a39ea5-cb7f-4bf4-b5cd-581aa6ec172f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175264, 5166, 182, 4, 31, "Input",ExpressionUUID->"e2af6ead-e7a0-4d85-a8e4-862538b69af1"],
Cell[175449, 5172, 107, 1, 31, "Output",ExpressionUUID->"e9da2365-bade-40f1-afc8-cf12ead0a631"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[175605, 5179, 90, 0, 18, "Subsubsection",ExpressionUUID->"1eed1bef-1541-447d-b975-5bc15530a182"],
Cell[175698, 5181, 1362, 39, 62, "Text",ExpressionUUID->"13f7f130-ad90-4446-993b-3b1cf0842aea"],
Cell[177063, 5222, 174, 3, 20, "Text",ExpressionUUID->"cc02c598-c46c-4d18-b304-2ab530de4b93"],
Cell[177240, 5227, 1341, 41, 108, "Input",ExpressionUUID->"eec132ce-c897-4276-ab6b-7af87a66ced8",
 InitializationCell->True],
Cell[178584, 5270, 312, 10, 25, "Text",ExpressionUUID->"b3d01873-94a6-4527-872f-c5b6aa379cea"],
Cell[CellGroupData[{
Cell[178921, 5284, 171, 3, 31, "Input",ExpressionUUID->"fd788912-17b2-4a39-922f-1dcb4096a4c0"],
Cell[179095, 5289, 107, 1, 31, "Output",ExpressionUUID->"d6041eaa-0a96-45cb-aab7-11840e252952"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[179251, 5296, 118, 0, 18, "Subsubsection",ExpressionUUID->"27c0745d-eecc-45c0-8499-6079db3151c3"],
Cell[179372, 5298, 191, 3, 20, "Text",ExpressionUUID->"265570eb-f0f4-4bf5-9908-4cc1dca67b5b"],
Cell[179566, 5303, 781, 18, 55, "Text",ExpressionUUID->"a29ae294-f4f1-43a9-be77-e4fe30dc3d00"],
Cell[180350, 5323, 1366, 29, 97, "Text",ExpressionUUID->"c3635610-6bac-42fd-bcfd-71c8c96f3b68"],
Cell[181719, 5354, 669, 19, 51, "Input",ExpressionUUID->"b839145e-a5d5-48b7-988d-a4afdf3a0ef2"],
Cell[182391, 5375, 669, 19, 51, "Input",ExpressionUUID->"b5a3c581-48fc-4e03-ba4d-7f71a330907e"],
Cell[183063, 5396, 341, 10, 43, "Text",ExpressionUUID->"cd46b601-2c48-4c92-b20b-0bed35c7a04d"],
Cell[183407, 5408, 595, 13, 52, "Text",ExpressionUUID->"01881a51-e0a2-42e7-aada-4a888f67f543"],
Cell[CellGroupData[{
Cell[184027, 5425, 379, 10, 31, "Input",ExpressionUUID->"69da7323-9d39-4302-9148-a707c66272ca"],
Cell[184409, 5437, 453494, 13087, 232, "Output",ExpressionUUID->"f7e15a84-6fa1-4d45-998f-0db1b99ed1c0"]
}, Open  ]],
Cell[637918, 18527, 482, 9, 51, "Text",ExpressionUUID->"1c393d23-192d-4683-b6ba-e9093b7d390a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[638449, 18542, 124, 1, 32, "Subsection",ExpressionUUID->"ead0cd15-0651-4117-9f09-0a2a14bcaa25",
 CellTags->"Section4b"],
Cell[638576, 18545, 172, 3, 20, "Text",ExpressionUUID->"da42bd57-c6d3-4b15-82a0-0b9d5f3b5db1"],
Cell[CellGroupData[{
Cell[638773, 18552, 99, 0, 18, "Subsubsection",ExpressionUUID->"12f39aef-09c8-490e-ab28-e1afdcb4d23f"],
Cell[638875, 18554, 1076, 29, 50, "Text",ExpressionUUID->"d6b0c54d-6cc2-4f8f-89da-5c3a3c43bbf8"],
Cell[639954, 18585, 590, 16, 70, "Input",ExpressionUUID->"9e316b0f-d24c-4b6c-bd97-b838a89deca6",
 InitializationCell->True],
Cell[640547, 18603, 874, 23, 51, "Text",ExpressionUUID->"bd020ff7-e3f3-4867-b630-e27c86872f12"],
Cell[641424, 18628, 209, 3, 20, "Text",ExpressionUUID->"d4e03d39-418b-49b0-b5b4-76f2007cbf61"],
Cell[CellGroupData[{
Cell[641658, 18635, 143, 2, 31, "Input",ExpressionUUID->"0786c9af-476e-4196-b676-da3e7e233fea"],
Cell[641804, 18639, 113, 1, 31, "Output",ExpressionUUID->"9e66503c-755c-46df-be49-3e59dafd8096"]
}, Open  ]],
Cell[CellGroupData[{
Cell[641954, 18645, 124, 2, 31, "Input",ExpressionUUID->"7a8b9ce1-3362-48be-afd7-19cd0ef3a6f9"],
Cell[642081, 18649, 113, 1, 31, "Output",ExpressionUUID->"39373eec-d364-4157-8bcd-25e479b79645"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[642243, 18656, 99, 0, 18, "Subsubsection",ExpressionUUID->"8615d788-6e0b-40ac-9ecf-635d3bb8bf18"],
Cell[642345, 18658, 580, 14, 58, "Text",ExpressionUUID->"3e3caaee-bf6b-47b1-bb01-8cfb40249f61"],
Cell[642928, 18674, 807, 21, 146, "Input",ExpressionUUID->"456b435b-d9c2-4e3f-a553-63ffa74be5d4",
 InitializationCell->True],
Cell[643738, 18697, 278, 7, 20, "Text",ExpressionUUID->"665b9347-4d84-4dc5-9003-29e4371a3cb9"],
Cell[CellGroupData[{
Cell[644041, 18708, 143, 2, 31, "Input",ExpressionUUID->"0da463b4-772f-4325-875c-d371fc10cf29"],
Cell[644187, 18712, 113, 1, 31, "Output",ExpressionUUID->"f0d01dae-ec86-41ac-ab4b-b2222dcaee8b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[644349, 18719, 113, 0, 18, "Subsubsection",ExpressionUUID->"95752a6b-e388-4ff1-a020-b20d0b855c56"],
Cell[644465, 18721, 219, 3, 35, "Text",ExpressionUUID->"7470239a-3744-401b-8940-369580058260"],
Cell[644687, 18726, 441, 10, 43, "Text",ExpressionUUID->"66389fbb-b48b-476f-89c9-7e3a3d4ed056"],
Cell[645131, 18738, 617, 18, 51, "Input",ExpressionUUID->"8c8aa2d1-4e32-4762-99c4-7ca3a70cde0e"],
Cell[645751, 18758, 463, 13, 31, "Input",ExpressionUUID->"89688a02-4bfb-4f54-a058-32500d243c54"],
Cell[CellGroupData[{
Cell[646239, 18775, 348, 9, 31, "Input",ExpressionUUID->"ebd9048e-5654-4e66-a6ac-1c1d44c5c5a8"],
Cell[646590, 18786, 40618, 728, 237, "Output",ExpressionUUID->"6bd41059-db61-41a7-abbc-0598152f0af3"]
}, Open  ]],
Cell[687223, 19517, 507, 9, 50, "Text",ExpressionUUID->"79938572-d780-4d46-9971-01884795e8b8"],
Cell[687733, 19528, 513, 9, 50, "Text",ExpressionUUID->"2a6d6cfa-a257-4b0a-88fc-d66e7f8e4f59"],
Cell[688249, 19539, 628, 16, 55, "Text",ExpressionUUID->"0aa28949-1f45-4a2e-a0b2-840dcbc8bb06"],
Cell[688880, 19557, 758, 16, 69, "Text",ExpressionUUID->"41109884-b450-47a1-bf5f-40549fb7599e"],
Cell[689641, 19575, 327, 5, 35, "Text",ExpressionUUID->"a622aa28-5eb7-454d-a81e-fd5892f1b27f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[690017, 19586, 111, 1, 32, "Subsection",ExpressionUUID->"c91b1a44-b74d-4892-9ba7-ac381e826d22",
 CellTags->"Section4c"],
Cell[690131, 19589, 123, 0, 20, "Text",ExpressionUUID->"759b6051-0c50-4abf-aa01-31f8d3eb64de"],
Cell[690257, 19591, 574, 12, 62, "Text",ExpressionUUID->"7709d72e-6230-4032-a5b5-cbfe8357a2f2"],
Cell[690834, 19605, 328, 9, 43, "Text",ExpressionUUID->"c630b379-5618-497b-9992-acf38e8b7ce3"],
Cell[691165, 19616, 1393, 39, 203, "Input",ExpressionUUID->"95835695-b418-4d6b-bcba-564047c849d5",
 InitializationCell->True],
Cell[692561, 19657, 1053, 32, 62, "Text",ExpressionUUID->"0dd4f473-bb62-4484-9659-eefbb46c649e"],
Cell[CellGroupData[{
Cell[693639, 19693, 98, 0, 18, "Subsubsection",ExpressionUUID->"e67d4f10-0d6f-45b6-a767-1b11a4498263"],
Cell[693740, 19695, 418, 8, 39, "Text",ExpressionUUID->"34154513-78aa-422d-b103-339dd5e1e1a3"],
Cell[694161, 19705, 426, 8, 58, "Text",ExpressionUUID->"82542118-ccd0-4e43-978a-46e7aae82eda"],
Cell[694590, 19715, 2454, 71, 86, "Text",ExpressionUUID->"a9a3fee4-687f-4f45-ab6d-e99d58ffebf6"],
Cell[697047, 19788, 1347, 35, 72, "Text",ExpressionUUID->"fa11bdff-06d9-402b-aadd-b97454e21d40"],
Cell[698397, 19825, 1406, 40, 53, "Text",ExpressionUUID->"a1beebcc-614d-44db-840b-b2d1706c4a0b"],
Cell[699806, 19867, 150, 4, 24, "Text",ExpressionUUID->"75093958-8905-4dfa-8f79-ba89f0033935"],
Cell[699959, 19873, 2789, 76, 336, "Input",ExpressionUUID->"5bfa3ee1-2f9f-4736-bd7e-ded00ac623d9",
 InitializationCell->True],
Cell[702751, 19951, 154, 4, 24, "Text",ExpressionUUID->"f2245291-97d5-4509-9399-f6714ddb7321"],
Cell[CellGroupData[{
Cell[702930, 19959, 242, 5, 31, "Input",ExpressionUUID->"c6731548-f134-43b3-8932-2b7a4c69406f"],
Cell[703175, 19966, 205, 4, 31, "Output",ExpressionUUID->"00f5a0e5-c358-451e-a023-9a23726ee1e7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[703429, 19976, 98, 0, 18, "Subsubsection",ExpressionUUID->"b67ce10b-fceb-47ec-8ed9-567a31923425"],
Cell[703530, 19978, 1312, 28, 99, "Text",ExpressionUUID->"b586d393-f11f-4501-ab5d-c6819e49575c"],
Cell[704845, 20008, 354, 10, 24, "Text",ExpressionUUID->"c220c0af-2895-4df7-bd51-8d7382766e6b"],
Cell[705202, 20020, 1969, 52, 241, "Input",ExpressionUUID->"be627b95-96bd-4bf0-b691-595961ab713b",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[707196, 20076, 209, 5, 31, "Input",ExpressionUUID->"3427157c-47f0-4edc-99a1-eb1427edac9d"],
Cell[CellGroupData[{
Cell[707430, 20085, 349, 9, 24, "Print",ExpressionUUID->"a5f0736d-2a4d-45fa-b389-984f89cbebef"],
Cell[707782, 20096, 142, 4, 25, "Echo",ExpressionUUID->"3019da94-ec4b-45a3-943d-8fcaa2143868"],
Cell[707927, 20102, 166, 5, 25, "Echo",ExpressionUUID->"65191b76-0c2b-42a9-ab6b-63783e5d1330"],
Cell[708096, 20109, 190, 6, 25, "Echo",ExpressionUUID->"de955a6c-8eb4-4e6d-b18d-e97f2f87d2a9"],
Cell[708289, 20117, 308, 8, 24, "Print",ExpressionUUID->"764c0bb9-4c90-49c5-82ad-1a99c93d2533"],
Cell[708600, 20127, 148, 3, 24, "Print",ExpressionUUID->"74043086-2a67-4988-b166-e356f105705c"],
Cell[708751, 20132, 336, 9, 24, "Print",ExpressionUUID->"58abaaf7-092e-49bb-bdde-8eb5c0a26dba"],
Cell[709090, 20143, 142, 4, 25, "Echo",ExpressionUUID->"9116b2df-8f47-4bd9-8663-18b9005715de"],
Cell[709235, 20149, 166, 5, 25, "Echo",ExpressionUUID->"8c430f49-7b6f-43c6-b2f7-2d5e4bc05177"],
Cell[709404, 20156, 166, 5, 25, "Echo",ExpressionUUID->"ea858364-1428-4353-9d71-ba2dc845efe8"],
Cell[709573, 20163, 308, 8, 24, "Print",ExpressionUUID->"dcd5287f-6161-45ee-934c-699d7c35a5a1"],
Cell[709884, 20173, 148, 3, 24, "Print",ExpressionUUID->"09a9792e-2c0d-43f2-87f0-db5ae62e62fe"],
Cell[710035, 20178, 308, 8, 24, "Print",ExpressionUUID->"83df6c33-0480-4164-89f8-e241fcaee16d"],
Cell[710346, 20188, 148, 3, 24, "Print",ExpressionUUID->"9d78aed7-f574-423f-9964-e9cd68eb56d5"]
}, Open  ]],
Cell[710509, 20194, 166, 4, 31, "Output",ExpressionUUID->"74bd1e28-1b50-4f4e-b774-974b751311eb"]
}, Open  ]],
Cell[710690, 20201, 368, 6, 39, "Text",ExpressionUUID->"328c4484-74c1-46a3-9df4-613c6892b67e"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[711119, 20214, 120, 1, 55, "Section",ExpressionUUID->"69df7f65-366b-4a08-83c9-f2a06830f7b9",
 CellTags->"Section5"],
Cell[711242, 20217, 387, 10, 39, "Text",ExpressionUUID->"3f70ec44-0aac-44c4-9218-31b05fae8034"],
Cell[CellGroupData[{
Cell[711654, 20231, 134, 1, 35, "Subsection",ExpressionUUID->"9a92cf9b-fe4b-46de-ade5-03992d4017ab",
 CellTags->"Section5a"],
Cell[711791, 20234, 678, 20, 39, "Text",ExpressionUUID->"3b9d8d11-ce6d-4358-8d4a-f7bf796e6be3"],
Cell[712472, 20256, 3405, 89, 507, "Input",ExpressionUUID->"a40bc630-cdff-4d29-9a67-db06eeef24cc"],
Cell[715880, 20347, 2193, 64, 69, "Text",ExpressionUUID->"36d46b9e-dde6-44d9-ab67-befee856e145"],
Cell[718076, 20413, 1023, 34, 20, "Text",ExpressionUUID->"274e38e8-de4c-4e80-8871-8006a2fe7cdb"],
Cell[719102, 20449, 116, 0, 20, "Text",ExpressionUUID->"09cf17e4-3fbc-4b8b-8da7-d8b5148489bb"],
Cell[CellGroupData[{
Cell[719243, 20453, 1683, 50, 42, "Item1",ExpressionUUID->"3a5b47ae-9464-4287-b5e2-264b99732297"],
Cell[720929, 20505, 692, 21, 16, "Item1",ExpressionUUID->"8c41a300-f2c0-40a9-b4e6-e4d5b4e0fcbc"],
Cell[721624, 20528, 366, 10, 16, "Item1",ExpressionUUID->"ede84d95-35a4-415d-be45-ead35f6a01b5"],
Cell[721993, 20540, 568, 17, 16, "Item1",ExpressionUUID->"c420c354-1735-45c8-91a6-82b2611a25d1"],
Cell[722564, 20559, 1152, 36, 16, "Item1",ExpressionUUID->"c846f398-ff30-4909-9772-379577cf5b83"],
Cell[723719, 20597, 523, 15, 16, "Item1",ExpressionUUID->"abe961a1-5bf2-4dce-8b3c-7fe7b154232a"]
}, Open  ]],
Cell[724257, 20615, 3916, 128, 65, "Text",ExpressionUUID->"c41a4ec3-f909-49fd-a706-76413aa4d5bb"],
Cell[728176, 20745, 2181, 70, 35, "Text",ExpressionUUID->"2542fcef-9491-49b0-acfa-79e5f9f464ce"],
Cell[730360, 20817, 3741, 118, 65, "Text",ExpressionUUID->"85eebabc-c60f-4720-987b-e352b05c3d34"],
Cell[734104, 20937, 410, 11, 20, "Text",ExpressionUUID->"86a4fc5b-1ea5-437b-8788-6dbb8f30dfe0"],
Cell[CellGroupData[{
Cell[734539, 20952, 1674, 52, 29, "Item1",ExpressionUUID->"9db89ea1-980a-4ffb-90a4-676168f8a3f6"],
Cell[736216, 21006, 693, 21, 16, "Item1",ExpressionUUID->"1b2c1bb1-095d-42bb-a233-f39edaedc551"],
Cell[736912, 21029, 1635, 50, 42, "Item1",ExpressionUUID->"ae1c4ace-81b9-4561-99ca-c30b4023c11a"],
Cell[738550, 21081, 1352, 44, 29, "Item1",ExpressionUUID->"47a6db3e-9551-4054-850e-2c69756bde81"],
Cell[739905, 21127, 4789, 151, 94, "Item1",ExpressionUUID->"f42909cc-9a09-496e-aa3d-262d1cf1e4f1"]
}, Open  ]],
Cell[744709, 21281, 751, 20, 35, "Text",ExpressionUUID->"4b8de131-ff4d-4058-ba70-06afbbce8331"],
Cell[745463, 21303, 1047, 32, 35, "Text",ExpressionUUID->"68a033b5-bcf0-4f99-8cf5-471e834041b7"],
Cell[CellGroupData[{
Cell[746535, 21339, 560, 16, 16, "Item1",ExpressionUUID->"19ee1541-51d5-447d-b501-f00f83295e5e"],
Cell[747098, 21357, 586, 16, 16, "Item1",ExpressionUUID->"0f300f8b-f462-4422-89e0-21139a8d8e3b"],
Cell[747687, 21375, 1581, 49, 29, "Item1",ExpressionUUID->"0896fb99-8337-433f-937f-038a7947ef27"],
Cell[749271, 21426, 1460, 47, 29, "Item1",ExpressionUUID->"787f1691-5977-496c-b57a-84eb0ed5617e"],
Cell[750734, 21475, 839, 26, 16, "Item1",ExpressionUUID->"d2a0fa53-f5f7-4bc8-86f5-7515e1e0428b"]
}, Open  ]],
Cell[751588, 21504, 452, 14, 20, "Text",ExpressionUUID->"32cd8c95-2e51-4354-aa66-a968d072f58f"],
Cell[752043, 21520, 1378, 45, 35, "Text",ExpressionUUID->"6dfcfa55-ca46-4ee5-8c18-fc365cb8655a"],
Cell[753424, 21567, 782, 23, 35, "Text",ExpressionUUID->"6c19541d-142f-4e9e-ac4d-2bb0197825d8"],
Cell[754209, 21592, 2865, 92, 54, "Text",ExpressionUUID->"740b2e8e-47ce-48ac-9fce-1d4f0428424e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[757111, 21689, 138, 1, 35, "Subsection",ExpressionUUID->"11ef5f4a-1134-4cc4-832f-0b4f9756b712",
 CellTags->"Section5b"],
Cell[757252, 21692, 185, 4, 24, "Text",ExpressionUUID->"5f027565-bf61-4ddd-9d1b-b2b6b41fe6b1"],
Cell[757440, 21698, 1370, 39, 203, "Input",ExpressionUUID->"e8ff54e6-2770-4deb-a809-5c41c5d6a5a4"],
Cell[758813, 21739, 1168, 33, 54, "Text",ExpressionUUID->"c038f9b0-4d3e-48f3-bed6-518afd473758"],
Cell[759984, 21774, 1164, 32, 54, "Text",ExpressionUUID->"36744417-bdd6-417e-9cad-3dae7ea279d2"],
Cell[761151, 21808, 964, 26, 39, "Text",ExpressionUUID->"0351849d-73b8-45da-9b31-9c145906570a"],
Cell[762118, 21836, 866, 26, 31, "Text",ExpressionUUID->"3252ac65-1bf9-4777-a3ea-0b6b9e5656cc"],
Cell[762987, 21864, 1046, 30, 35, "Text",ExpressionUUID->"ee76f3a0-8ac9-4ca9-86b9-a290880941fb"],
Cell[764036, 21896, 1611, 46, 81, "Text",ExpressionUUID->"cd658a4c-37a4-4936-a2c5-00c7f80be716"],
Cell[765650, 21944, 531, 15, 24, "Text",ExpressionUUID->"3fbb5714-50ac-4065-ab2a-11c482efbc7c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[766230, 21965, 170, 3, 55, "Section",ExpressionUUID->"6d1006d9-494f-46e3-93d5-734ef38c08ec",
 CellTags->"Solutions"],
Cell[CellGroupData[{
Cell[766425, 21972, 126, 2, 32, "Subsection",ExpressionUUID->"79a55584-88c3-45d2-8b7f-6b3b1c2b4c1e",
 CellTags->"SolutionsCP2"],
Cell[766554, 21976, 951, 30, 55, "Problem",ExpressionUUID->"fb0545bd-04c4-4f33-9733-df0f882c7f20"],
Cell[767508, 22008, 326, 8, 35, "Text",ExpressionUUID->"b03b8b1e-24ab-43cf-9020-23648b204c4c"],
Cell[767837, 22018, 175, 3, 20, "Text",ExpressionUUID->"defe1263-6afb-4c8d-84b2-4d331d380644"],
Cell[768015, 22023, 508, 16, 15, "Text",ExpressionUUID->"8f3277ae-0197-49b4-9436-6d62dcbf86c6"],
Cell[768526, 22041, 1242, 42, 15, "Text",ExpressionUUID->"f1d36bbb-7c35-4fdb-a897-b3b259c356ca"],
Cell[769771, 22085, 269, 4, 35, "Text",ExpressionUUID->"fbbc27af-2fb7-46e7-b8bf-7e63929b5774"],
Cell[770043, 22091, 1098, 32, 50, "Text",ExpressionUUID->"ffdab81f-59be-4aad-8803-f660dcf97b61"],
Cell[771144, 22125, 819, 18, 50, "Text",ExpressionUUID->"9a9fa9d7-78d5-4b27-a1e5-ba81f4baa141"],
Cell[CellGroupData[{
Cell[771988, 22147, 99, 0, 18, "Subsubsection",ExpressionUUID->"3f2dd951-ff12-4a63-9343-f854f2463685"],
Cell[772090, 22149, 313, 7, 43, "Text",ExpressionUUID->"446ac732-fd73-40ce-b7f3-0cbb86d92acb"],
Cell[772406, 22158, 742, 15, 71, "Text",ExpressionUUID->"02fd0597-5f30-425a-bc80-0c98e64bd0eb"],
Cell[773151, 22175, 1447, 42, 127, "Input",ExpressionUUID->"7ba40fa5-b46f-4bb8-942f-f048a97a222b",
 InitializationCell->True],
Cell[774601, 22219, 355, 8, 20, "Text",ExpressionUUID->"141a2b51-e6c1-4183-8091-949b588b266b"],
Cell[CellGroupData[{
Cell[774981, 22231, 229, 6, 31, "Input",ExpressionUUID->"e2b0d2d4-df40-48ee-ae41-cb62c00ed4c1"],
Cell[775213, 22239, 1100, 18, 89, "Output",ExpressionUUID->"8c9f05dd-ebe7-4c4c-b4a0-3a3ccb9a9f88"]
}, Open  ]],
Cell[776328, 22260, 318, 7, 21, "Text",ExpressionUUID->"a0726de4-dc1b-4ef4-b200-0aecfdd24182"],
Cell[776649, 22269, 642, 16, 58, "Text",ExpressionUUID->"49281815-7b62-4a44-9528-193c6045aa9f"],
Cell[777294, 22287, 856, 23, 146, "Input",ExpressionUUID->"4b7ccf4c-19c5-4ef8-b3e1-ce17f862e92a",
 InitializationCell->True],
Cell[778153, 22312, 1103, 25, 92, "Text",ExpressionUUID->"a05d6901-fa3a-477f-93df-851ffe08d973"],
Cell[779259, 22339, 209, 5, 24, "Text",ExpressionUUID->"00aa2b7a-ff80-4812-afa9-3a0e2ffb98e0"],
Cell[779471, 22346, 191, 5, 31, "Input",ExpressionUUID->"91c1a5c4-35aa-4f13-b2d9-3fce59be18ce"],
Cell[779665, 22353, 130, 0, 20, "Text",ExpressionUUID->"68e46185-2dd5-4178-bb1d-1d560c013e44"],
Cell[CellGroupData[{
Cell[779820, 22357, 148, 3, 31, "Input",ExpressionUUID->"83bc8438-783c-433b-b871-00a63e75477f"],
Cell[779971, 22362, 114, 2, 31, "Output",ExpressionUUID->"5c433fb6-1338-4f84-a98d-fb9dd8c405b9"]
}, Open  ]],
Cell[780100, 22367, 112, 0, 20, "Text",ExpressionUUID->"dd8d4772-1773-44bb-b31b-f78e962d0edc"],
Cell[CellGroupData[{
Cell[780237, 22371, 300, 9, 31, "Input",ExpressionUUID->"2894c1f1-5edf-4117-99b2-d984f547bc67"],
Cell[780540, 22382, 878, 15, 89, "Output",ExpressionUUID->"39ab553d-2f2b-4cdc-864d-8ba0e20117fa"]
}, Open  ]],
Cell[781433, 22400, 339, 5, 35, "Text",ExpressionUUID->"a11ecf32-e635-47f3-8f36-41e1af19b93d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[781809, 22410, 95, 0, 18, "Subsubsection",ExpressionUUID->"1ccc45cc-2255-4447-9cef-b678b73940e1"],
Cell[781907, 22412, 508, 11, 37, "Text",ExpressionUUID->"6adf0bb9-04d5-4918-972f-29c1ec788122"],
Cell[CellGroupData[{
Cell[782440, 22427, 160, 3, 31, "Input",ExpressionUUID->"ac37ac49-d2ba-48c7-897e-d548fbcbae37"],
Cell[782603, 22432, 111, 2, 31, "Output",ExpressionUUID->"c6329e18-8271-406f-a636-fc13492a92d8"]
}, Open  ]],
Cell[782729, 22437, 884, 19, 66, "Text",ExpressionUUID->"81dd1126-c27b-46bf-b730-863d0b43d7d0"],
Cell[CellGroupData[{
Cell[783638, 22460, 254, 6, 31, "Input",ExpressionUUID->"c6b9448e-4bad-4f90-b00b-a722c5e52679"],
Cell[783895, 22468, 111, 2, 31, "Output",ExpressionUUID->"90aad99e-8249-416a-830c-dfbc499004bd"]
}, Open  ]],
Cell[784021, 22473, 947, 23, 36, "Text",ExpressionUUID->"5bda99ae-335b-489c-bef5-5e21e965378d"],
Cell[CellGroupData[{
Cell[784993, 22500, 359, 9, 31, "Input",ExpressionUUID->"db086c90-dd75-4d18-95b6-a659db4217ac"],
Cell[785355, 22511, 111, 2, 31, "Output",ExpressionUUID->"30198521-c992-4bd9-8f08-4672a631282e"]
}, Open  ]],
Cell[785481, 22516, 1095, 24, 86, "Text",ExpressionUUID->"688867e8-14ea-4ee0-a5d0-2899f8cf34d1"],
Cell[786579, 22542, 383, 8, 36, "Text",ExpressionUUID->"cf077518-7c6b-4be9-9dfe-f1705a659420"],
Cell[786965, 22552, 468, 13, 31, "Input",ExpressionUUID->"b13f3693-6a95-4e4e-b623-3b24076b25e2",
 InitializationCell->True],
Cell[787436, 22567, 263, 6, 21, "Text",ExpressionUUID->"aff77890-5120-44c3-9689-7e6d63231d5e"],
Cell[CellGroupData[{
Cell[787724, 22577, 178, 4, 31, "Input",ExpressionUUID->"dfe3141a-fb21-4f20-9471-9dfdb427608d"],
Cell[787905, 22583, 1176, 19, 89, "Output",ExpressionUUID->"5ee56659-76b6-4654-8ccb-3712768929e6"]
}, Open  ]],
Cell[789096, 22605, 505, 11, 35, "Text",ExpressionUUID->"2f327cbc-33ed-4c4c-835b-16e32b6789ff"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[789650, 22622, 138, 2, 32, "Subsection",ExpressionUUID->"057e37e3-7b28-45b6-a635-346d212839eb",
 CellTags->"SolutionsCE2"],
Cell[789791, 22626, 236, 3, 55, "Problem",ExpressionUUID->"1d4c9ec9-1906-4014-98a0-3e2f58f2f682"],
Cell[790030, 22631, 644, 19, 36, "Text",ExpressionUUID->"e53f87d5-5666-492b-8176-35ba1a9f52f0"],
Cell[790677, 22652, 671, 15, 50, "Text",ExpressionUUID->"b05d905d-cf83-48fb-ba5b-d028441981a9"],
Cell[CellGroupData[{
Cell[791373, 22671, 547, 15, 70, "Input",ExpressionUUID->"272d77ee-ccb6-4857-bee8-6d74f6a435d6"],
Cell[791923, 22688, 336, 9, 31, "Output",ExpressionUUID->"dfb1b27d-a1a6-4510-9a28-de1d6d1b629c"]
}, Open  ]],
Cell[792274, 22700, 830, 22, 35, "Text",ExpressionUUID->"3ba67443-3e77-48cc-9ef1-a05bc74a967c"],
Cell[793107, 22724, 1377, 37, 50, "Text",ExpressionUUID->"631c7b9d-44cc-4606-be82-25deff731c7e"],
Cell[794487, 22763, 1483, 38, 184, "Input",ExpressionUUID->"5e1d5f33-d106-4009-ac3f-4cb65af54ea6",
 InitializationCell->True],
Cell[795973, 22803, 2174, 51, 132, "Text",ExpressionUUID->"159dbad7-f6c5-4b4f-8b47-ef5761b82330"],
Cell[798150, 22856, 117, 0, 20, "Text",ExpressionUUID->"24e8cf95-f507-4ef4-86bf-44322e374568"],
Cell[CellGroupData[{
Cell[798292, 22860, 486, 13, 51, "Input",ExpressionUUID->"fa4b0c97-4386-42d7-b2b1-8f77073c452d"],
Cell[798781, 22875, 286, 7, 24, "Print",ExpressionUUID->"ee2c19fc-f4cc-4574-a73d-be93b317e314"]
}, Open  ]],
Cell[799082, 22885, 258, 4, 35, "Text",ExpressionUUID->"900d79ec-223d-4072-91f9-eb1002622371"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[799389, 22895, 107, 1, 55, "Section",ExpressionUUID->"03f9cf8b-2e77-4139-9d94-7ef15e26e7b2",
 CellTags->"Exercises"],
Cell[CellGroupData[{
Cell[799521, 22900, 728, 22, 33, "Item1Exercise",ExpressionUUID->"de208d8b-d141-4aad-a4c8-6892dd5d3829"],
Cell[800252, 22924, 670, 20, 23, "Item1Exercise",ExpressionUUID->"8b5169c4-8b7b-4a74-b6b7-81c8aca95a48"],
Cell[800925, 22946, 439, 10, 34, "Item1Exercise",ExpressionUUID->"6113f672-331f-4eec-9a81-b6a9fcecc313"],
Cell[801367, 22958, 1385, 44, 36, "Item1Exercise",ExpressionUUID->"5c84fafc-8b93-415f-8279-6fc69b54aca6"],
Cell[802755, 23004, 422, 10, 34, "Item1Exercise",ExpressionUUID->"69a79f3a-7c4d-4058-ae5f-4d3cf6ec5d05"],
Cell[803180, 23016, 535, 12, 37, "Item1Exercise",ExpressionUUID->"fee1b00f-a640-4681-bacc-9f3a87a8e7c5"],
Cell[803718, 23030, 1133, 28, 47, "Item1Exercise",ExpressionUUID->"b31ce5d3-1628-43e0-83f9-ef3ff00225a5"],
Cell[804854, 23060, 641, 16, 33, "Item1Exercise",ExpressionUUID->"1a492b81-8661-476d-87e7-42a5087073ca"],
Cell[805498, 23078, 596, 17, 41, "Item1Exercise",ExpressionUUID->"5e810a98-89ad-46d1-9fa7-6d10830f82f9"],
Cell[806097, 23097, 335, 7, 20, "Item1Exercise",ExpressionUUID->"e1a03736-b0bd-48ec-9f3c-7ed2a1a994b4"],
Cell[806435, 23106, 1167, 25, 75, "Item1Exercise",ExpressionUUID->"0ed4aa49-8e01-4548-b415-efcfe367c009"],
Cell[807605, 23133, 210, 3, 20, "Item1Exercise",ExpressionUUID->"6faa76ad-fcc3-4f8e-ad7b-717795b3c57a"],
Cell[807818, 23138, 204, 3, 20, "Item1Exercise",ExpressionUUID->"25b801d7-08db-47df-900e-f070ad2e45bb"],
Cell[808025, 23143, 330, 8, 20, "Item1Exercise",ExpressionUUID->"352b7548-28c4-41f3-814f-c8b35b382603"],
Cell[808358, 23153, 182, 3, 20, "Item1Exercise",ExpressionUUID->"3ea49edc-efa6-4085-b8cc-95e854d72945"],
Cell[808543, 23158, 182, 3, 20, "Item1Exercise",ExpressionUUID->"e3ce4af2-61ef-4f48-8306-02a055efc770"],
Cell[808728, 23163, 1432, 38, 63, "Item1Exercise",ExpressionUUID->"3223ab2a-abd6-4f8e-b9ab-cc6fe17d2eb5"],
Cell[810163, 23203, 406, 5, 46, "Item1Exercise",ExpressionUUID->"227ee954-2f14-4fbd-8606-55a5d9b7a215"],
Cell[810572, 23210, 254, 4, 33, "Item1Exercise",ExpressionUUID->"85785fdb-afb9-461d-86c5-a3c57814d83b"],
Cell[810829, 23216, 218, 3, 33, "Item1Exercise",ExpressionUUID->"cd4b3c66-829e-4c8c-ab6c-3c3797c512a1"],
Cell[811050, 23221, 254, 6, 20, "Item1Exercise",ExpressionUUID->"a9e306a2-9d22-4d2c-a385-8eeb6fd3dbcb"],
Cell[811307, 23229, 287, 4, 33, "Item1Exercise",ExpressionUUID->"f3e3ca3b-b7da-473c-91d7-f984e917d8d1"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

